## 1. 接口描述

本接口（AddCdnHost）用于新增加速域名。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**注意事项：**

+ 添加的域名必须尚未被其他用户或自己接入腾讯云 CDN
+ 添加的域名必须通过工信部备案，[备案查询](http://www.miitbeian.gov.cn/publish/query/indexFirst.action) 
+ 一次仅可添加一个域名至腾讯云 CDN
+ 默认调用频次限制为 100次/分钟

<br/>

[查看调用示例](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为AddCdnHost。

| 参数名称        | 是否必选 | 类型     | 描述                                       |
| ----------- | ---- | ------ | ---------------------------------------- |
| host        | 是    | String | 需要接入的 CDN 域名                             |
| projectId   | 是    | String | 项目 ID，指域名要添加入的项目的对应 ID，[查看已有项目及ID](https://console.cloud.tencent.com/project) |
| hostType    | 是    | String | 域名的接入方式，填充 "cname" ，表示用户使用自己的源站          |
| origin      | 否    | String | 源站设置，支持配置一个域名，或多个源站IP<br/>域名模式：www.test.com:8080<br/>IP模式：1.1.1.1:8080,2.2.2.2:8080 |
| serviceType | 否    | String | 加速类型设置<br/>"web"：静态内容加速<br/>"download"：下载文件加速<br/>"media"：流媒体点播加速<br/>不填充默认为静态内容加速 |
| fwdHost     | 否    | String | 回源域名配置，不填充默认为加速域名                        |
| cache       | 否    | String | 缓存过期时间设置，详细说明如下                          |

##### cache 设置示例如下

```
[[0,"all",1000],[1,".jpg;.js",2000],[2,"/a;/www/b",3000],[3,"/a/1.html;/b/2.html",1000]]
```

每一组缓存过期配置有三个参数：第一个参数是缓存类型，第二个参数指定匹配规则，第三个参数代表缓存过期时间，单位为秒。缓存规则优先级从前往后递增。

缓存类型有如下四种：

- 0：全部类型，表示匹配所有文件，默认缓存配置；
- 1：文件类型，表示按文件后缀匹配；
- 2：文件夹类型，表示按目录匹配。
- 3：全路径匹配。

第二个参数指定匹配规则：

- 0：固定填充”all“，表示所有文件；
- 1：后缀，.jps;.js 等，; 分隔；
- 2：目录，如 /www/anc;/a/b 等，;分隔；
- 3：全路径，如 /a/1.html;/b/2.html 等，;分隔。



## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关                           |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |

## 4. 示例

### 4.1 输入示例

> host: www.test.com
> projectId: 0
> hostType: cname
> origin: 8.8.8.8:8080


### 4.2 GET 请求


GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=AddCdnHost
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462440051
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXX
&host=www.test.com
&projectId=0
&hostType=cname
&origin=8.8.8.8:8080
```

### 4.3 POST 请求
POST请求时，参数填充在HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'AddCdnHost',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462868615,
  'Nonce' => 520585444,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'projectId' => '0',
  'hostType' => 'cname',
  'origin' => '8.8.8.8:8080'
)
```

### 4.4 返回结果示例
#### 添加成功

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

#### 添加失败

```json
{
    "code": 4000,
    "message": "(20004)未备案 cdn audit no icp[cdn audit no icp[当前域名未在工信部备案]]",
    "codeDesc": 20004
}

```







