## 1. API Description

This API (UpdateCdnHost) is used to modify the origin server configuration corresponding to the domain.

Domain for API request:<font style="color:red">cdn.api.qcloud.com</font>

1) Modification of origin server configuration is not allowed for domains in Offline and Deploying statuses;
1) Only the origin server configuration of one domain can be modified at a time;

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473). The Action field for this API is UpdateCdnHost.

| Parameter Name   | Required | Type     | Description                                       |
| ------ | ---- | ------ | ---------------------------------------- |
| origin | Yes    | String | You may enter one origin server domain, or multiple origin server IPs (the "ip:port" type is supported, such as 8.8.8.8:8080). The port number should be between 0 and 65535 (exclusive of 0). |
| hostId | Yes    | Int    | The domain ID for which the origin server needs to be configured                              |
| host   | Yes    | String | The domain host for which the origin server needs to be configured                            |

#### Note

+ You can use APIs [Query Domain Information by Domain Name](https://cloud.tencent.com/doc/api/231/3938) and [Query Domain Information](https://cloud.tencent.com/doc/api/231/3937) to obtain the ID of the host;
+ The origin server configuration of domains in Closed or Deploying status cannot be modified via this API.


## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on Error Code page.  |
| message  | String | Module error message description depending on API.                           |
| codeDesc | String | English error message or error code at business side.                           |
| data     | Array  | Output results. Details of the domain for which the origin server is configured.                      |

#### data Field Description

| Parameter Name  | Type    | Description              |
| ----- | ----- | --------------- |
| hosts | Array | Domain information array. See below for details.  |
| total | Int   | Total number of domains            |

#### hosts Field Description

| Parameter Name            | Type     | Description                                       |
| --------------- | ------ | ---------------------------------------- |
| id              | Int    | ID after the domain is connected to CDN                         |
| app_id          | Int    | APPID of domain owner                             |
| owner_uin       | Int    | QQ ID of the user when logging in to Tencent Cloud                        |
| project_id      | Int    | Project ID of the domain                                |
| host            | String | Domain                                       |
| host_type       | String | Connection method. There are three modes: "cos" means the hosted origin when connecting the domain is COS origin; "cname" means self-owned origin is used when connecting the domain; "ftp" means FTP hosted origin provided by CDN is used when connecting the domain. |
| service_type    | String | Domain content type. There are four modes: "file" refers to web page image/small file; "download" refers to large file downloading; "vod" refers to Video on Demand; and "live" refers to Live Video Broadcasting |
| origin          | String | Origin server configuration corresponding to the domain                                 |
| cache           | Array  | Configuration of caching rules, as described below                           |
| disabled        | Int    | Indicate whether the domain is blocked; "0" indicates that the domain is not blocked.                 |
| message         | String | Domain status information, such as "Closed", "Activated" and "Deploying".             |
| enable_overseas | String | Indicate whether the overseas CDN is activated: "no" means the overseas CDN is not activated; "yes" means the overseas CDN is activated. |
| create_time     | String | Domain connection time                                   |
| update_time     | String | Last update time                                  |
| deleted         | String | Delete or not: "no" means the domain is not deleted; "yes" means the domain is deleted. |
| fwd_host_type   | String | Back-to-origin configuration type: "default" means the connected domain is the address for back-to-origin requests; "custom" means the domain uses customized address for back-to-origin requests.  |
| fwd_host        | String | Address for back-to-origin requests                                     |
| middle_resource | Int    | Configuration of intermediate node: "-1" means the domain has closed intermediate node services; "0" means the domain has activated intermediate node services. |
| refer           | Array  | Hotlink protection configuration, as described below                            |
| cname           | String | The accelerated domain with ".cdn.dnsv1.com" as suffix assigned by CDN            |
| cache_mode      | String | Type of caching rules: "simple" means cache completely depends on the the Console; "custom" means cache depends on the cache expiration time set by the Console and the minimum value in max-age set by origin server. |
| furl_cache      | String | Filter parameter: "on" means to enable; "off" means to disable          |
| ssl_type        | Int    | Indicate whether to activate HTTPS: "0" means HTTPS configuration is not activated; others mean HTTPS configuration is activated. |
| bucket_name     | String | bucket name corresponding to the COS origin                     |
| ssl_deploy_time | String | SSL deploying time                                  |
| ssl_expire_time | String | SSL expiration time                                  |
| seo             | String | Indicate whether to enable SEO optimization: "off" means to disable; "on" means to enable                |
| host_id         | Int    | Host ID, same as id                       |

#### cache Field Description

| Parameter Name | Type     | Description                                       |
| ---- | ------ | ---------------------------------------- |
| type | Int    | Type. There are four types: 0 refers to all files, 1 refers to file type, 2 refers to folder type, and 3 refers to full-path file |
| rule | String | Matching rule, corresponding to the types above                        |
| time | Int    | Cache expiration time (in seconds)                               |
| unit | String | The unit used to set cache expiration time. There are four types: "d" refers to day, "h" refers to hour, "m" refers to minute, and "s" refers to second |

#### refer Field Description

| Parameter Name      | Type    | Description                                       |
| --------- | ----- | ---------------------------------------- |
| type      | Int   | Hotlink protection type. There are three types: 0 means that hotlink protection is not configured, 1 means that the configured list is a blacklist, 2 means that the configured list is a whitelist |
| null_flag | Int | Indicate whether the hotlink protection is empty. 1 means the hotlink protection is empty                     |
| list      | Array | The configured hotlink protection list                                 |

**Note**:
+ The fields not described in the above are **invalid fields**, which can be ignored directly.



## 4. Example

### 4.1 Input Example

> host: www.test.com
> hostId: 1234
> origin:  2.2.2.2;3.3.3.3



### 4.2 GET Request

For GET request, all the parameters are required to be appended to the URL:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=UpdateCdnHost
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462520137
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXXXXX
&hostId=1234
&host=www.test.com
&origin=2.2.2.2%3B3.3.3.3
```



### 4.3 POST Request

For POST request, the parameters need to be filled in HTTP Request-body. Request address:

```
https://cdn.api.qcloud.com/v2/index.php
```

Formats such as form-data and x-www-form-urlencoded are supported for the parameters. The array of parameters is as follows:

```
array (
  'Action' => 'UpdateCdnHost',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'hostId' => '1234',
  'origin' => '2.2.2.2;3.3.3.3',
)
```



### 4.4 Example of Returned Result

#### Modification Successful

```json
{
    "retcode": 0,
    "errmsg": "ok",
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": [
        {
            "id": 1234,
            "app_id": 1234567,
            "owner_uin": 7654321,
            "project_id": 0,
            "host": "www.test.com",
            "host_type": "cname",
            "service_type": "web",
            "origin": "2.2.2.2;3.3.3.3",
            "cache": [
                {
                    "type": 0,
                    "rule": "all",
                    "time": 2592000,
                    "unit": "s"
                },
                {
                    "type": 1,
                    "rule": ".php;.jsp;.asp;.aspx",
                    "time": 0,
                    "unit": "s"
                }
            ],
            "status": 4,
            "disabled": 0,
            "message": "Deploying",
            "enable_overseas": "no",
            "create_time": "2016-09-05 18:53:16",
            "update_time": "2016-09-05 19:30:30",
            "deleted": "no",
            "fwd_host_type": "default",
            "fwd_host": "www.test.com",
            "middle_resource": -1,
            "refer": {
                "type": 0,
                "list": [],
                "null_flag": 0
            },
            "readonly": 0,
            "cname": "www.test.com.cdn.dnsv1.com",
            "cache_mode": "simple",
            "furl_cache": "on",
            "extension": "",
            "ssl_type": 0,
            "pid_config": null,
            "bucket_name": "",
            "bucket_project_id": 0,
            "ssl_deploy_time": null,
            "ssl_expire_time": null,
            "seo": "off",
            "cdn_date": "2016-09-05 00:00:00",
            "host_id": 1234,
            "host_config": {
                "rsp_header": {
                    "config_value": [],
                    "config_platform": "default"
                },
                "diagnose": {
                    "config_value": [],
                    "config_platform": "default"
                },
                "ip_cc": {
                    "config_value": [],
                    "config_platform": "default"
                },
                "cluster_switch": {
                    "config_value": [],
                    "config_platform": "default"
                },
                "url_forbid": {
                    "config_value": [],
                    "config_platform": "default"
                }
            }
        }
    ]
}
```

#### Modification Failed

```json
{
    "code": 4000,
    "message": "(9110) Information for this domain does not exist. cdn no such host[success]",
    "codeDesc": 9110
}
```







