## 1. 接口描述
本接口（UpdateCdnConfig）用于修改域名对应的配置信息。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）一次仅支持修改一个域名的配置信息；
2）可对指定域名的多项配置信息进行修改。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为UpdateCdnConfig。

| 参数名称         | 是否必选 | 类型     | 描述                                       |
| ------------ | ---- | ------ | ---------------------------------------- |
| hostId       | 否    | Int    | 要设置的域名对应 ID，与host字段必须填充一个                |
| host         | 否    | String | 要设置的域名，与hostId字段必须填充一个                   |
| projectId    | 否    | Int    | 要设置的域名对应的项目 ID                           |
| cache        | 否    | String | 缓存配置，详细说明见下文                             |
| cacheMode    | 否    | String | 缓存模式，共有两种类型，其中'simple'表示缓存完全依赖控制台设置；若为'custom'，则表示缓存依赖控制台设置的缓存时间和源站吐出的max-age的最小值。 |
| refer        | 否    | String | 防盗链设置，详细说明见下文                            |
| fwdHost      | 否    | String | 回源 Host，CDN 节点回源时所带的 HTTP 头部 host 参数。    |
| fullUrl      | 否    | String | 过滤参数配置，共有两种类型，其中'on'表示关闭过滤参数   'off'表示开启过滤参数。 |
| origin       | 否    | String | 源站设置                                     |
| rspHeader    | 否    | String | 响应头Header设置，仅支持：Content-Disposition、Content-Language、Access-Control-Allow-Origin、Access-Control-Allow-Methods、Access-Control-Max-Age、Access-Control-Expose-Headers 详细说明见下文 |
| reqHeader    | 否    | String | 请求头Header设置，支持自定义Key-Value添加，详细说明见下文     |
| accessIp     | 否    | String | IP黑白名单配置，详细说明见下文                         |
| backupOrigin | 否    | String | 备份源站配置，仅自有源域名可配置备份源站，可设置为多个IP（端口0-65535），或一个域名（端口0-65535） |

#### 详细说明

##### refer 防盗链设置

示例：

```
[1,["qq.baidu.com", "*.baidu.com"],1]
```

第一个字段标识refer类型：

+ 0： 不设置防盗链；
+ 1：设置黑名单；
+ 2：设置白名单；

第二个字段为具体的名单列表，第三个字段为是否包含空refer，1表示包含空refer，0表示不包含空refer。

##### IP黑白名单设置

示例：

```
{"type":1,"list":["1.2.3.4","2.3.4.5"]}
```

+ type为黑白名单类型：1 表示黑名单，2表示白名单；
+ list表示对应的黑名单IP列表，支持 /8、/16、/24格式的网段设置；
+ 最多可设置100条IP黑名单，或者50条IP白名单。

##### 缓存规则设置

cache设置示例如下：

```
[[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000],[3,"/www/1.html",1000]]
```

第一个参数是缓存类型：

缓存类型有如下四种：

- 0：全部类型，表示匹配所有文件，默认缓存配置；
- 1：文件类型，表示按文件后缀匹配；
- 2：文件夹类型，表示按目录匹配。

第二个参数指定匹配规则：

- 0：固定填充”all“；
- 1：后缀，.jps;.js 等，; 分隔；
- 2：目录，如 /www/html; /www/anc 等，; 分隔；
- 3：全路径，如 /www/1.html; /www/2.html 等，; 分隔。

第三个参数指定缓存时间，单位为秒。

##### rspHeader设置

设置示例如下：

```
{"Content-Language":"zh_CN","Access-Control-Allow-Origin":"https://www.test.com"}
```

**注意事项：**

+ 目前Response Header仅支持以下头部设置：
  + Content-Disposition
  + Content-Language
  + Access-Control-Allow-Origin
  + Access-Control-Allow-Methods
  + Access-Control-Max-Age
  + Access-Control-Expose-Headers
+ 按照HTTP协议规范，Access-Control-Allow-Origin 仅能设置为 * ，或者一个域名（需要带http:// 或https:// 头部）；
+ value 值不能超过1000个字节。

##### reqHeader设置

设置示例如下：

```
{"cdn":"tencent"}
```

**注意事项：**

+ value 值不能超过1000个字节。

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |


## 4. 示例

### 4.1 输入示例

> host: www.test.com
> reqHeader:{"cdn":"tencent"}

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=UpdateCdnConfig
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462872270
&Nonce=541116052
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
&host=www.test.com
&reqHeader=%7B%22cdn%22%3A%22tencent%22%7D
```

### 4.3 POST 请求

POST请求时，参数填充在HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'UpdateCdnConfig',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462872294,
  'Nonce' => 479724541,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'reqHeader' => '{"cdn":"tencent"}'
)
```


### 4.4 返回结果示例

#### 设置成功

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

#### 设置失败

```json
{
    "code": 4000,
    "message": "(9175)部署中状态 cdn host in progress[host in progress]",
    "codeDesc": "UserRequestError"
}
```
