## 1. 接口描述

本接口（UpdateCache）用于修改指定域名的缓存规则配置。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）一次仅支持修改一个域名的缓存规则；
2）下线、部署中状态的域名不可修改缓存规则；
3）支持一次设置多条缓存规则。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为UpdateCache。

| 参数名称   | 是否必填 | 类型          | 描述             |
| ------ | ---- | ----------- | -------------- |
| hostId | 是    | Int         | 指定修改配置的域名对应 ID |
| cache  | 是    | JSON String | 缓存规则配置         |

#### 详细说明

cache 设置示例如下：

```
[[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000]]
```

第一个参数是缓存类型：

缓存类型有如下：

- 0：全部类型，表示匹配所有文件，默认缓存配置；
- 1：文件类型，表示按文件后缀匹配；
- 2：文件夹类型，表示按目录匹配。

第二个参数指定匹配规则：

- 0：固定填充”all“；
- 1：后缀，.jps;.js 等，; 分隔；
- 2：目录，如 /www/html; /www/anc/ 等，;分隔。

第三个参数指定缓存时间，单位为秒。



#### 注意事项

+ 可使用接口 [根据域名查询域名信息](https://cloud.tencent.com/doc/api/231/3938) 、[查询域名信息](https://cloud.tencent.com/doc/api/231/3937) 获取 host 对应的ID；
+ 已关闭、部署中的域名无法通过此接口修改缓存设置。


## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |



## 4. 示例

### 4.1 输入示例

> hostId: 1234
> cache: [[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000]]



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=UpdateCache
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462526099
&Nonce=123456789
&Signature=eBAJQT%2BbWkXlGhbXaCbO9sXaf38%3D
&hostId=1234
&cache=%5B%5B0%2C%22all%22%2C1000%5D%2C%5B1%2C%22.jpg%3B.js%22%2C2000%5D%2C%5B2%2C%22%2Fwww%2Fhtml%22%2C3000%5D%5D
```



### 4.3 POST 请求

POST 请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'UpdateCache',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462871237,
  'Nonce' => 523070698,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'hostId' => '1234',
  'cache' => '[[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000]]'
)
```



### 4.4 返回结果示例

#### 修改成功

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

#### 修改失败

```json
{
    "code": 4000,
    "message": "(9175)部署中状态 cdn host in progress[host in progress]",
    "codeDesc": 9175
}
```

