## 1. API Description

This API (UpdateCache) is used to modify the caching rule configuration for specific domains.

Domain name for API request:<font style="color:red">cdn.api.qcloud.com</font>

1) Modify the caching rules of one domain at a time;
2) The caching rules of domains in Offline or Deploying status cannot be modified;
3) Set multiple caching rules at a time.

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. See the [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473) page for details. The Action field for this API is UpdateCache.

| Parameter Name   | Required | Type          | Description             |
| ------ | ---- | ----------- | -------------- |
| hostId    | Yes    | Int         | Specify the domain ID whose configuration is to be modified  |
| cache  | Yes    | JSON String | Caching rule configuration         |

#### Details

Example of cache configuration:

```
[[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000],[3,"/index.html;/test/*.jpg",3000]]
```

The first parameter is cache type:

There are four types:

- 0: All types. This means all files are matched. This is the default cache configuration;
- 1: File type. This means matching based on file extensions;
- 2: Folder type. This means matching based on directories;
- 3: Full-path file. This means matching based on home page or matching a specified file.

The second parameter specifies matching rule:

- 0: "all" is entered in a fixed way;
- 1: Surfix, such as .jps; .js, separated with ";"
- 2: Directory, such as /www/html; /www/anc/, separated with ";"
- 3: Full-path file, such resource full-path as /index.html;/test/\*.jpg, separated with ";". You can only use "\*" for matching.

The third parameter specifies cache expiration time (in seconds).



#### Note

+ You can use APIs [Query Domain Information by Domain Name](https://cloud.tencent.com/doc/api/231/3938) and [Query Domain Information](https://cloud.tencent.com/doc/api/231/3937) to obtain the ID of the host;
+ The caching rules of domains in Closed or Deploying status cannot be modified via this API.


## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on Error Code page.  |
| message  | String | Module error message description depending on API.                           |
| codeDesc | String | English error message or error code at business side.                           |



## 4. Example

### 4.1 Example of Input

> hostId: 1234
> cache: [[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000]]



### 4.2 GET Request

All the parameters are required to be added after URL in GET request:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=UpdateCache
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462526099
&Nonce=123456789
&Signature=eBAJQT%2BbWkXlGhbXaCbO9sXaf38%3D
&hostId=1234
&cache=%5B%5B0%2C%22all%22%2C1000%5D%2C%5B1%2C%22.jpg%3B.js%22%2C2000%5D%2C%5B2%2C%22%2Fwww%2Fhtml%22%2C3000%5D%5D
```



### 4.3 POST Request

In POST request, the parameters will be filled in HTTP Request-body. The request address is:

```
https://cdn.api.qcloud.com/v2/index.php
```

Such formats of parameters as form-data, x-www-form-urlencoded are supported. The array of parameters is as follows:

```
array (
  'Action' => 'UpdateCache',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462871237,
  'Nonce' => 523070698,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'hostId' => '1234',
  'cache' => '[[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000]]'
)
```



### 4.4 Example of Returned Result

#### Modification Successful

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

#### Modification Failed

```json
{
    "code": 4000,
    "message": "(9175) Deploying status cdn host in progress[host in progress]",
    "codeDesc": 9175
}
```


