## 1. 接口描述

本接口（DescribeCdnHostDetailedInfo）用于查询指定时间区、数据类型、项目、域名对应的统计明细。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）一个域名/多个域名指定统计类型的数据明细；
2）一个项目/多个项目指定统计类型的数据明细；
3）类型包括流量、带宽、请求数、IP访问数、命中率；
4）根据查询时间不同，距离当前时间1-3日，明细时间粒度均为5分钟，4-7日时间粒度为1小时，8天及以上时间粒度为1天。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为DescribeCdnHostDetailedInfo。

| 参数名称       | 是否必选 | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | 是    | String | 查询开始时间（日），如设置为 2016-05-03 时，查询的起始时间为：2016-05-03 00:00:00 |
| endDate    | 是    | String | 查询结束时间（日），如设置为2016-05-04时，查询的结束时间为：2016-05-04 23:55:00 |
| statType   | 是    | String | 统计量类型，共有5种类型，其中 'flux' 代表累计流量，单位Byte；'bandwidth'代表峰值带宽，单位bps；'requests'代表请求数，单位次；'ip_visits'代表IP访问数，单位次；'cache'代表缓存命中率，单位为百分比； |
| projects.n | 是    | String | 项目ID，可指定多个：projects.0=123&projects.1=456... |
| hosts.n    | 否    | String | 域名，可指定多个： hosts.0=www.test.com&hosts.1=www.test2.com |


#### 注意事项

- hosts若填充域名，则必须将域名所属项目ID填充入projects参数，否则会报错；
- 返回结果为各域名在各统计点和的数组。




## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |



#### data 字段说明

| 名称             | 类型     | 说明                                       |
| -------------- | ------ | ---------------------------------------- |
| start_datetime | String | 输入时指定的起始日期（日）                            |
| end_datetime   | String | 输入时指定的结束日期（日）                            |
| period         | String | 数据采样时间间隔，单位为分钟。距离查询时间1-3日，为5分钟，4-7日为60分钟，8天及以上，时间粒度为1天。 |
| stat_type      | String | 统计量类型                                    |
| total_data     | Array  | 统计量明细数组                                  |



## 4. 示例

### 4.1 输入示例

> startDate:20160503
> endDate:20160504
> projects.0:0
> statType:flux



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=DescribeCdnHostDetailedInfo
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&statType=flux
&projects.0=0
```



### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'DescribeCdnHostDetailedInfo',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'statType' => 'flux',
  'projects.0' => '0'
)
```





### 4.4 返回结果示例

```json
{
    "retcode": 0,
    "errmsg": "ok",
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "start_datetime": "2016-08-01 00:00:00",
        "end_datetime": "2016-08-01 00:00:00",
        "period": 5,
        "stat_type": "flux",
        "total_data": [
        12345,
        12345,
        ...
        12345
        ]
    }
}
```





