## 1. API Description

This API (DescribeCdnHostDetailedInfo) is used to query the statistical details of specified time range, data type, project and domain.

Domain for API request:<font style="color:red">cdn.api.qcloud.com</font>

1) The detailed data of specified statistical type for one or more domains;
2) The detailed data of specified statistical type for one or more projects;
3) Types include traffic, bandwidth, number of requests, number of IP visits, hit rate;
4) Based on different query time ranges, from the current time, the time granularity is 5 minutes for 1 to 3 days, 1 hour for 4 to 7 days, and 1 day for 8 days or above.

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473). The Action field for this API is DescribeCdnHostDetailedInfo.

| Parameter Name       | Required | Type     | Description                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | Yes    | String | Query start date (day). If this is set as 2016-05-03, the query start time will be 2016-05-03 00:00:00 |
| endDate    | Yes    | String | Query end date (day). If this is set as 2016-05-04, the query end time will be 2016-05-04 23:55:00 |
| statType   | Yes    | String | Type of statistics. There are 5 types: "flux" stands for total traffic (in Byte); "bandwidth" for peak bandwidth (in bps); "requests" for number of requests (times); "ip_visits" for number of IP visits (times); "cache" for cache hit rate (%); |
| projects.n | Yes    | String | Project ID. You may specify multiple IDs: projects.0=123&projects.1=456... |
| hosts.n    | No    | String | Domain. You may specify multiple domains:   hosts.0=www.test.com&hosts.1=www.test2.com |


#### Note

- If you enter a domain for "hosts", you must enter the project ID of this domain into "projects" parameter, otherwise errors will occur;
- The returned result is an array containing the statistical summary for all domains at all statistical points.




## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on the Error Code page.  |
| message  | String | Module error message description related to API.                           |
| codeDesc | String | Error message or error code at business side.                           |
| data     | Array  | Result data, details are described below                             |



#### data Field Description

| Name             | Type     | Description                                       |
| -------------- | ------ | ---------------------------------------- |
| start_datetime | String | Specified start date (day)                            |
| end_datetime | String | Specified end date (day)                            |
| period         | String | Time interval of data sampling (minute). The time granularity is 5 minutes if query time is 1 to 3 days, 60 minutes for 4 to 7 days, and 1 day for 8 days or above.  |
| stat_type      | String | Type of statistics                                    |
| total_data     | Array  | Array of detailed statistics                                  |



## 4. Example

### 4.1 Input Example

> startDate:20160503
> endDate:20160504
> projects.0:0
> statType:flux



### 4.2 GET Request

For GET request, all the parameters are required to be appended to the URL:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=DescribeCdnHostDetailedInfo
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&statType=flux
&projects.0=0
```



### 4.3 POST Request

For POST request, the parameters need to be filled in the HTTP Request-body. Request address:

```
https://cdn.api.qcloud.com/v2/index.php
```

Formats such as form-data, x-www-form-urlencoded are supported for the parameters. The array of parameters is as follows:

```
array (
  'Action' => 'DescribeCdnHostDetailedInfo',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'statType' => 'flux',
  'projects.0' => '0'
)
```





### 4.4 Example of Returned Result

```json
{
    "retcode": 0,
    "errmsg": "ok",
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "start_datetime": "2016-08-01 00:00:00",
        "end_datetime": "2016-08-01 00:00:00",
        "period": 5,
        "stat_type": "flux",
        "total_data": [
        12345,
        12345,
        ...
        12345
        ]
    }
}
```






