## 1. 接口描述

本接口（GetCdnHostsDetailStatistics）用于查询指定区间的带宽、流量、请求数、状态码、命中流量、命中请求数等明细数据。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**注意事项：**

1）、支持一次性查询多个域名（最多10个），每一个域名的指定消耗明细，及所有指定查询域名的明细和；

2）、默认情况下，根据查询时间段不同，时间区间3天以内明细数据，时间粒度均为5分钟；时间区间4-7天时间粒度为1小时，指定区间8天及以上，时间粒度为1天，目前仅保留近三个月内数据；

3）、查询5分钟粒度数据时，仅支持近两个月内数据查询，时间区间跨度为60天内。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnHostsDetailStatistics。

| 参数名称      | 是否必选 | 类型     | 描述                                       |
| --------- | ---- | ------ | ---------------------------------------- |
| startTime | 是    | String | 查询开始时间，可设置为 2016-05-03 00:00:01          |
| endTime   | 是    | String | 查询结束时间，可设置为：2016-05-04 23:55:01          |
| statType  | 是    | String | 统计量类型， 'flux' 代表流量，单位Byte；'bandwidth'代表峰值带宽，单位bps；'requests'代表请求数，单位次；'hit_flux'代表流量命中，单位为Byte，'hit_requests'代表命中请求数，单位为次；'status_code'代表状态码，目前包含200、206、302、304、401、403、404、405、416、500、502 |
| hosts.n   | 是    | String | 域名，可指定多个： hosts.0=www.test.com&hosts.1=www.test2.com |
| detail    | 否    | String | 时间粒度，若填充1，均返回5分钟粒度明细数据                   |


#### 注意事项

- 最小粒度为5分钟数据，00:00:00 时间点的数据，表示 00:00:00 — 00:04:59 时间区间的数据；
- 按小时/天汇总数据时，flux、requests、hit_flux、hit_request、status_code 均为按小时/天累加，bandwidth取峰值数据。




## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |



#### data 字段说明

| 名称             | 类型     | 说明                                       |
| -------------- | ------ | ---------------------------------------- |
| start_datetime | String | 输入时指定的起始时间                               |
| end_datetime   | String | 输入时指定的结束时间                               |
| period         | String | 返回数据的时间粒度                                |
| requests       | Array  | 若指定statType为requests，则返回各域名的请求数明细，其他statType与此类似。 |
| requests_total | Array  | 若指定statType为requests，则返回各域名请求数明细和，其他statType与此类似。 |



## 4. 示例

### 4.1 输入示例

> startTime:2017-06-06 00:00:00
> endTime:2017-06-08 00:00:00
> hosts.0: www. test.com
> statType:requests



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnHostsDetailStatistics
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&startTime=2017-06-06+00%3A00%3A00
&endTime=2017-06-08+00%3A00%3A00
&statType=requests
&hosts.0=www.test.com
```



### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnHostsDetailStatistics',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startTime' => '2017-06-06 00:00:00',
  'endTime' => '2017-06-08 00:00:00',
  'statType' => 'requests',
  'hosts.0' => 'www.test.com'
)
```



### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "errmsg": "ok",
    "data": {
		"period": 5,
        "start_datetime": "2016-06-06 00:00:00",
        "end_datetime": "2016-06-08 00:00:00",
        "requests": {
          "www.test.com":[
        	12345,
        	12345,
        	...
        	12345
        	]
    	},
      	"requests_total":[
			12345,
        	12345,
        	...
        	12345
      	]
	}
}
```





