## 1. 接口描述

本接口（DescribeCdnHostInfo）用于查询指定时间区间、数据类型、项目、域名对应的统计量汇总信息：

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）支持一个域名/多个域名指定类型的总统计信息；
2）支持一个项目/多个项目指定类型的总统计信息；
3）类型包括：流量、带宽、请求数、IP 访问数、命中率，本接口暂时只支持90天内数据查询。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为DescribeCdnHostInfo。

| 参数名称       | 是否必选 | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | 是    | String | 查询开始日期（日），若设置为 2016-05-03 ，实际查询的起始时间为：2016-05-03 00:00:00 |
| endDate    | 是    | String | 查询结束日期（日），若设置为 2016-05-04，实际查询的结束时间为：2016-05-04 23:55:00 |
| statType   | 是    | String | 统计量类型，共有5种类型，其中 'flux' 代表累计流量，单位Byte；'bandwidth'代表峰值带宽，单位bps；'requests'代表请求数，单位次；'ip_visits'代表IP访问数，单位次；'cache'代表缓存命中率，单位为百分比； |
| projects.n | 是    | String | 项目 ID，不可为空，可指定多个：projects.0=123&projects.1=456... |
| hosts.n    | 否    | String | 域名，可指定多个：hosts.0=www.test.com&hosts.1=www.test2.com |



#### 注意事项

+ hosts若填充域名，则必须将域名所属项目ID填充入projects参数，否则会报错；
+ 若为多域名或多项目查询，则结果为和数据。




## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |



#### data 字段说明

| 参数名称           | 类型     | 描述              |
| -------------- | ------ | --------------- |
| start_datetime | String | 查询指定起始时间（日）     |
| end_datetime   | String | 查询指定结束时间（日）     |
| period         | Int    | 数据采样时间间隔，单位为分钟。 |
| detail_data    | Array  | 汇总数据信息，详细说明见下文  |



#### detail_data 字段说明

| 参数名称       | 类型     | 描述                                       |
| ---------- | ------ | ---------------------------------------- |
| host_id    | String | 域名，等于 host_name                          |
| host_name  | String | 域名                                       |
| host_type  | String | 域名类型，若为'cname'，表示的域名接入方式为自有源；若为'cos'，则表示域名的接入方式为COS源；若为'ftp'，则表示域名的接入方式为 FTP 源 |
| host_value | Int    | 查询汇总统计值                                  |



## 4. 示例

### 4.1 输入示例

> startDate:20160503
> endDate:20160504
> projects.0:0
> statType:flux



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=DescribeCdnHostInfo
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462781898
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&statType=flux
&projects.0=0
```



### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'DescribeCdnHostInfo',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'statType' => 'flux',
  'projects.0' => '0'
)
```


### 4.4 返回结果示例

```json
{
    "retcode": 0,
    "errmsg": "ok",
	"code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "start_datetime": "2016-05-03 00:00:00",
        "end_datetime": "2016-05-04 23:55:00",
        "period": 5,
        "stat_type": "flux",
        "detail_data": [
            {
                "host_id": "www.test.com",
                "host_name": "www.test.com",
                "host_type": "cname",
                "host_value": 123456789
            },
            ...
        ]
    }
}
```
