## 1. API Description

This API (DescribeCdnHostInfo) is used to query the statistical summary of specified time range, data type, project and domain:

Domain for API request:<font style="color:red">cdn.api.qcloud.com</font>

1) The statistical summary of specified statistical type for one or more domains is supported;
1) The statistical summary of specified statistical type for one or more projects is supported;
3) Types include traffic, bandwidth, number of requests, number of IP visits, hit rate. Currently you can only query data within 90 days through this API.

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473). The Action field for this API is DescribeCdnHostInfo.

| Parameter Name       | Required | Type     | Description                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | Yes    | String | Query start date (day). If this is set as 2016-05-03, the query start time will be 2016-05-03 00:00:00 |
| endDate    | Yes    | String | Query end date (day). If this is set as 2016-05-04, the query end time will be 2016-05-04 23:55:00 |
| statType   | Yes    | String | Type of statistics. There are 5 types: "flux" stands for total traffic (in Byte); "bandwidth" for peak bandwidth (in bps); "requests" for number of requests (times); "ip_visits" for number of IP visits (times); "cache" for cache hit rate (%); |
| projects.n | Yes    | String | Project ID. This field cannot be left empty. You may specify multiple IDs: projects.0=123&projects.1=456... |
| hosts.n    | No    | String | Domain. You may specify multiple domains: hosts.0=www.test.com&hosts.1=www.test2.com |



#### Note

+ If you enter a domain for "hosts", you must enter the project ID of this domain into "projects" parameter, otherwise errors will occur;
+ The result will be the summary of data if you query multiple domains or projects.




## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on the Error Code page.  |
| message  | String | Module error message description related to API.                           |
| codeDesc | String | Error message or error code at business side.                           |
| data     | Array  | Result data, details are described below                             |



#### data Field Description

| Parameter Name           | Type     | Description              |
| -------------- | ------ | --------------- |
| start_datetime | String | Start date (day) specified for query     |
| end_datetime | String | End date (day) specified for query     |
| period         | Int    | Time interval of data sampling (minute).  |
| detail_data    | Array  | Data summary. Details will be described below  |



#### detail_data Field Description

| Parameter Name       | Type     | Description                                       |
| ---------- | ------ | ---------------------------------------- |
| host_id    | String | Domain. This is equivalent to host_name                          |
| host_name  | String | Domain                                       |
| host_type  | String | Domain type. "cname" refers to self-owned origin, "cos" refers to COS origin, and "ftp" refers to FTP origin |
| host_value | Int    | Statistical summary of query                                  |



## 4. Example

### 4.1 Input Example

> startDate:20160503
> endDate:20160504
> projects.0:0
> statType:flux



### 4.2 GET Request

For GET request, all the parameters are required to be appended to the URL:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=DescribeCdnHostInfo
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462781898
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&statType=flux
&projects.0=0
```



### 4.3 POST Request

For POST request, the parameters need to be filled in the HTTP Request-body. Request address:

```
https://cdn.api.qcloud.com/v2/index.php
```

Formats such as form-data, x-www-form-urlencoded are supported for the parameters. The array of parameters is as follows:

```
array (
  'Action' => 'DescribeCdnHostInfo',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'statType' => 'flux',
  'projects.0' => '0'
)
```


### 4.4 Example of Returned Result

```json
{
    "retcode": 0,
    "errmsg": "ok",
	"code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "start_datetime": "2016-05-03 00:00:00",
        "end_datetime": "2016-05-04 23:55:00",
        "period": 5,
        "stat_type": "flux",
        "detail_data": [
            {
                "host_id": "www.test.com",
                "host_name": "www.test.com",
                "host_type": "cname",
                "host_value": 123456789
            },
            ...
        ]
    }
}
```

