## 1. 接口描述

本接口（GetCdnStatusCode）用于查询指定时间区间、项目、域名对应的状态码统计明细。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）一个域名/多个域名状态码统计明细；
2）一个项目/多个项目状态码统计明细；
3）返回的状态码统计：200、206、304、404、416、500；
4）可指定返回明细的数据采集时间间隔。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnStatusCode。

| 参数名称       | 是否必选 | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | 是    | String | 查询开始时间（日），如设置为 2016-05-03 时，查询的起始时间为：2016-05-03 00:00:00 |
| endDate    | 是    | String | 查询结束时间（日），如设置为2016-05-04时，查询的结束时间为：2016-05-04 23:55:00 |
| projects.n | 是    | String | 项目ID，可指定多个：projects.0=123&projects.1=456 |
| hosts.n    | 否    | String | 域名，可指定多个：hosts.0=www.test.com&hosts.1=www.test2.com |
| period     | 否    | Int    | 数据采样间隔，分钟为单位。                            |



#### 注意事项

- hosts若填充域名，则必须将域名所属项目ID填充入projects参数，否则会报错；
- 返回结果为各域名在各统计时刻和的数组；
- 数据采样间隔，CDN数据采集最小粒度为5分钟，因此period>=5。




## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |



#### data 字段说明

| 参数名称 | 类型    | 描述          |
| ---- | ----- | ----------- |
| 200  | Array | 返回码200的统计明细 |
| 206  | Array | 返回码206的统计明细 |
| 304  | Array | 返回码304的统计明细 |
| 404  | Array | 返回码404的统计明细 |
| 416  | Array | 返回码416的统计明细 |
| 500  | Array | 返回码500的统计明细 |



## 4. 示例

### 4.1 输入示例

> startDate:20160503
> endDate:20160504
> projects.0:0
> hosts.0:www.test.com
> period:5



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnStatusCode
&SecretId=XXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462418819
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&hosts.0=www.test.com
&projects.0=0
&period=5
```



### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnStatusCode',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'period' => 5,
  'projects.0' => '0',
  'hosts.0' => 'www.test.com'
)
```





### 4.4 返回结果示例

```json
{
  "code":0,
  "message":"",
  "codeDesc": "Success",
  "data":[
	{
		"200":[
			123,
			123,
			...
			123
			],
		"206":[
			123,
			123,
			...
			123
			],
		"304":[
			123,
			123,
			...
			123	
			],
		"404":[
			123,
			123,
			...
			123	
			],
		"416":[
			123,
			123,
			...
			123	
			],
		"500":[
			123,
			123,
          	...
			123	
			]
	}
  ]
}
```




