## 1. API Description

This API (GetCdnStatusCode) is used to query the statistical details regarding the status codes of specified time range, project and domain.

Domain for API request:<font style="color:red">cdn.api.qcloud.com</font>

1) Statistical details regarding the status codes for one or more domains;
2) Statistical details regarding the status codes for one or more projects;
3) Returned status code statistics: 200, 206, 304, 404, 416, 500;
4) You can specify the time interval with which the detailed data will be sampled.

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473). The Action field for this API is GetCdnStatusCode.

| Parameter Name       | Required | Type     | Description                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | Yes    | String | Query start date (day). If this is set as 2016-05-03, the query start time will be 2016-05-03 00:00:00 |
| endDate    | Yes    | String | Query end date (day). If this is set as 2016-05-04, the query end time will be 2016-05-04 23:55:00 |
| projects.n | Yes    | String | Project ID. You may specify multiple IDs: projects.0=123&projects.1=456 |
| hosts.n    | No    | String | Domain. You may specify multiple domains: hosts.0=www.test.com&hosts.1=www.test2.com |
| period     | No    | Int    | Time interval of data sampling (minute).                             |



#### Note

- If you enter a domain for "hosts", you must enter the project ID of this domain into "projects" parameter, otherwise errors will occur;
- The returned result is an array containing the statistical summary for all domains at all statistical points;
- For the time interval of data sampling, the minimum time granularity of CDN data sampling is 5 minutes, so period>=5.




## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on the Error Code page.  |
| message  | String | Module error message description related to API.                           |
| codeDesc | String | Error message or error code at business side.                           |
| data     | Array  | Result data, details are described below                             |



#### data Field Description

| Parameter Name | Type    | Description          |
| ---- | ----- | ----------- |
| 200  | Array | Statistical details of the error code 200 |
| 206  | Array | Statistical details of the error code 206 |
| 304  | Array | Statistical details of the error code 304 |
| 404  | Array | Statistical details of the error code 404 |
| 416  | Array | Statistical details of the error code 416 |
| 500  | Array | Statistical details of the error code 500 |



## 4. Example

### 4.1 Input Example

> startDate:20160503
> endDate:20160504
> projects.0:0
> hosts.0:www.test.com
> period:5



### 4.2 GET Request

For GET request, all the parameters are required to be appended to the URL:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnStatusCode
&SecretId=XXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462418819
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&hosts.0=www.test.com
&projects.0=0
&period=5
```



### 4.3 POST Request

For POST request, the parameters need to be filled in the HTTP Request-body. Request address:

```
https://cdn.api.qcloud.com/v2/index.php
```

Formats such as form-data, x-www-form-urlencoded are supported for the parameters. The array of parameters is as follows:

```
array (
  'Action' => 'GetCdnStatusCode',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'period' => 5,
  'projects.0' => '0',
  'hosts.0' => 'www.test.com'
)
```





### 4.4 Example of Returned Result

```json
{
  "code":0,
  "message":"",
  "codeDesc": "Success",
  "data":[
	{
		"200":[
			123,
			123,
			...
			123
			],
		"206":[
			123,
			123,
			...
			123
			],
		"304":[
			123,
			123,
			...
			123	
			],
		"404":[
			123,
			123,
			...
			123	
			],
		"416":[
			123,
			123,
			...
			123	
			],
		"500":[
			123,
			123,
          	...
			123	
			]
	}
  ]
}
```





