## 1. 接口描述

本接口（GetCdnStatTop）用于查询指定时间区间、项目、域名、统计类型，对应的各省份、运营商、URL排名TOP100统计。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）支持一个项目或多个项目联合排名查询；
2）支持一个域名或多个域名联合排名查询。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnStatTop。

| 参数名称       | 是否必选 | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | 是    | String | 查询开始时间（日）                                |
| endDate    | 是    | String | 查询结束时间（日）                                |
| projects.n | 是    | String | 指定项目ID，可指定多个：projects.0=123&projects.1=456 |
| hosts.n    | 否    | String | 域名，可指定多个：hosts.0=www.test.com&hosts.1=www.test2.com |
| statType   | 是    | String | 排名依据，共有三种类型，其中 'flux' 代表累计流量，单位Byte；'bandwidth' 代表峰值带宽，单位bps；'requests' 代表请求数，单位次； |
| period     | 否    | Int    | 数据采样间隔，分钟为单位。                            |


#### 注意事项

- hosts若填充域名，则必须将域名所属项目ID填充入projects参数，否则会报错。
- period：可不传入，默认为5；若传入，则必须大于等于5，否则会报错。



## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |

#### data 字段说明

| 名称             | 类型     | 说明            |
| -------------- | ------ | ------------- |
| province_data  | Array  | 省份排名，结构说明见下文  |
| isp_data       | Array  | 运营商排名，结构说明见下文 |
| url_data       | Array  | URL排名，结构说明见下文 |
| start_datetime | String | 指定查询起始日期      |
| end_datetime   | String | 指定查询结束日期      |
| stat_type      | String | 指定排名依据        |
| period         | Int    | 指定时间粒度        |

#### province_data 字段说明

| 名称    | 类型     | 说明                |
| ----- | ------ | ----------------- |
| id    | Int    | 省份编号              |
| name  | String | 省份名称，如“吉林”        |
| value | Int    | 带宽/流量值，根据指定排序依据而定 |

#### isp_data 字段说明

| 名称    | 类型     | 说明                |
| ----- | ------ | ----------------- |
| id    | Int    | 运营商编号             |
| name  | String | 运营商名称，如“中国移动”     |
| value | Int    | 带宽/流量值，根据指定排序依据而定 |

#### url_data 字段说明

| 名称    | 类型     | 说明                |
| ----- | ------ | ----------------- |
| name  | String | URL               |
| value | Int    | 带宽/流量值，根据指定排序依据而定 |



## 4. 示例

### 4.1 输入示例

> startDate:20160503
> endDate:20160504
> projects.0:0
> hosts.0:www.test.com
> period:5
> statType:flux



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnStatTop
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462421433
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&hosts.0=www.test.com
&projects.0=0
&period=5
&statType=flux
```



### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnStatTop',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'period' => 5,
  'projects.0' => '0',
  'hosts.0' => 'www.test.com',
  'statType' => 'flux'
)
```





### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "start_datetime": "2016-09-01",
        "end_datetime": "2016-09-02",
        "stat_type": "flux",
        "period": 5,
        "province_data": [
            {
                "id": -1,
                "name": "海外",
                "value": 212
            },
            {
                "id": 1051,
                "name": "重庆",
                "value": 207
            }
        ],
        "isp_data": [
            {
                "id": 0,
                "name": "其他",
                "value": 212
            },
            {
                "id": 2,
                "name": "中国电信",
                "value": 207
            }
        ],
        "url_data": [
            {
                "name": "www.test.com/robots.txt",
                "value": 212
            },
            {
                "name": "www.test.com/",
                "value": 207
            }
        ]
    }
}
```

