## 1. API Description

This API (GetCdnStatTop) is used to query the TOP 100 ranking regarding the statistics of provinces, ISPs, URLs of specified time range, project, domain and statistical type.

Domain for API request:<font style="color:red">cdn.api.qcloud.com</font>

1) Query for the combined ranking of one or more projects is supported;
1) Query for the combined ranking of one or more domains is supported;

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473). The Action field for this API is GetCdnStatTop.

| Parameter Name       | Required | Type     | Description                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| startDate  | Yes    | String | Start time (day) of the query                              |
| endDate    | Yes    | String | End time (day) of the query                                |
| projects.n | Yes    | String | Specified Project ID. You may specify multiple IDs: projects.0=123&projects.1=456 |
| hosts.n    | No    | String | Domain. You may specify multiple domains: hosts.0=www.test.com&hosts.1=www.test2.com |
| statType   | Yes    | String | Ranking type. There are 3 types: "flux" stands for total traffic (in Byte); "bandwidth" for peak bandwidth (in bps); "requests" for number of requests (times) |
| period     | No    | Int    | Time interval of data sampling (minute).                             |


#### Note

- If you enter a domain for "hosts", you must enter the project ID of this domain into "projects" parameter, otherwise errors will occur.
- period: Can be left empty, in which case the default value is 5. If you choose to enter a value, it must be equal to or larger than 5, otherwise errors will occur.



## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on the Error Code page.  |
| message  | String | Module error message description related to API.                           |
| codeDesc | String | Error message or error code at business side.                           |
| data     | Array  | Result data, details are described below                             |

#### data Field Description

| Name             | Type     | Description            |
| -------------- | ------ | ------------- |
| province_data  | Array  | Ranking of provinces. Structure is described below  |
| isp_data       | Array  | Ranking of ISPs. Structure is described below |
| url_data       | Array  | Ranking of URLs. Structure is described below |
| start_datetime | String | Specified start date (day) of query |
| end_datetime | String | Specified end date (day) of query |
| stat_type      | String | Specified ranking type        |
| period         | Int    | Specified time granularity        |

##### province_data Field Description

| Name    | Type     | Description                |
| ----- | ------ | ----------------- |
| id    | Int    | Province ID              |
| name  | String | Province name, such as "Jilin"        |
| value | Int    | Bandwidth/traffic value, depending on specified ranking type |

#### isp_data Field Description

| Name    | Type     | Description                |
| ----- | ------ | ----------------- |
| id    | Int    | ISP ID             |
| name  | String | ISP name, such as "China Mobile"     |
| value | Int    | Bandwidth/traffic value, depending on specified ranking type |

#### url_data Field Description

| Name    | Type     | Description                |
| ----- | ------ | ----------------- |
| name  | String | URL               |
| value | Int    | Bandwidth/traffic value, depending on specified ranking type |



## 4. Example

### 4.1 Input Example

> startDate:20160503
> endDate:20160504
> projects.0:0
> hosts.0:www.test.com
> period:5
> statType:flux



### 4.2 GET Request

For GET request, all the parameters are required to be appended to the URL:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnStatTop
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462421433
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXX
&startDate=20160503
&endDate=20160504
&hosts.0=www.test.com
&projects.0=0
&period=5
&statType=flux
```



### 4.3 POST Request

For POST request, the parameters need to be filled in the HTTP Request-body. Request address:

```
https://cdn.api.qcloud.com/v2/index.php
```

Formats such as form-data, x-www-form-urlencoded are supported for the parameters. The array of parameters is as follows:

```
array (
  'Action' => 'GetCdnStatTop',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '20160503',
  'endDate' => '20160504',
  'period' => 5,
  'projects.0' => '0',
  'hosts.0' => 'www.test.com',
  'statType' => 'flux'
)
```





### 4.4 Example of Returned Result

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "start_datetime": "2016-09-01",
        "end_datetime": "2016-09-02",
        "stat_type": "flux",
        "period": 5,
        "province_data": [
            {
                "id": -1,
                "name": "Overseas",
                "value": 212
            },
            {
                "id": 1051,
                "name": "Chongqing",
                "value": 207
            }
        ],
        "isp_data": [
            {
                "id": 0,
                "name": "Others",
                "value": 212
            },
            {
                "id": 2,
                "name": "China Telecom",
                "value": 207
            }
        ],
        "url_data": [
            {
                "name": "www.test.com/robots.txt",
                "value": 212
            },
            {
                "name": "www.test.com/",
                "value": 207
            }
        ]
    }
}
```


