## 1. 接口描述

本接口（GetCdnRefreshLog）用于查询指定时间区间内的刷新日志、刷新次数，可指定URL查询。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnRefreshLog。

| 参数名称      | 是否必选 | 类型     | 描述            |
| --------- | ---- | ------ | ------------- |
| startDate | 否   | String | 查询开始时间  |
| endDate   | 否    | String | 查询结束时间  |
| taskId | 否 | Int | 根据提交刷新URL任务返回的 task_id 查询 | 
| url       | 否    | String | 需要查询的URL（可为空） |

**注意事项：**

+ 支持30天内刷新记录查询；
+ 支持精确到秒的时间区间查询，时间格式为：2017-02-09 00:00:00；
+ startDate&endDate 与 taskId 若都为空，则会导致查询失败，必须填充 startDate&endDate，或是 taskId；
+ 若同时填充startDate&endDate 和 taskId，若该taskId并非在此时间区间内提交，则会提示【日期不合法】；


## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 返回结果数据                                   |

#### data 字段说明

| 参数名称  | 类型    | 描述   |
| ----- | ----- | ---- |
| logs  | Array | 日志详情 |
| total | Int   | 刷新次数 |

#### logs 字段说明

| 参数名称       | 类型     | 描述                             |
| ---------- | ------ | ------------------------------ |
| id         | Int    | 编号                             |
| app_id     | Int    | 用户APP ID                       |
| project_id | Int    | 项目ID                           |
| host       | String | 域名                             |
| type       | Int    | 刷新类型。共两种类型，其中0代表URL刷新；1代表目录刷新； |
| status     | Int    | 刷新结果；若为1，则表示刷新成功，若为0，则表示刷新中，若为负数，则表示刷新失败               |
| url_list   | Array  | 本次刷新时提交的URL列表                  |
| datetime   | String | 提交时间                           |



## 4. 示例

### 4.1 输入示例

> startDate: 2017-02-06 19:00:00
> endDate:  2017-02-06 19:40:00



### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnRefreshLog
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462422547
&Nonce=12345678
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXX
&startDate=2017-02-06+19%3A00%3A00
&endDate=2017-02-06+19%3A40%3A00
```



### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnRefreshLog',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startDate' => '2017-02-06 19:00:00',
  "endDate" => '2017-02-06 19:40:00'
)
```





### 4.4 返回结果示例

```json
{
    "retcode": 0,
    "errmsg": "ok",
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "logs": [
            {
                "id": 6182538,
                "app_id": 123456,
                "project_id": 0,
                "host": "www.test.com",
                "type": 0,
                "status": 1,
                "url_list": [
                    "http://www.test.com/Content/image/test.png"
                ],
                "datetime": "2017-02-06 19:39:59"
            }
        "total": 1
    }
}
```

