## 1. 接口描述

本接口（GetCdnLogList）用于查询指定时间区间内，指定域名日志的下载链接，一次仅可指定一个域名进行查询。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

日志下载链接 API_V1 版本：[GenerateLogList](https://cloud.tencent.com/document/product/228/3950)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为 GetCdnLogList。

| 参数名称      | 是否必选 | 类型     | 描述     |
| --------- | ---- | ------ | ------ |
| host   | 是    | String    | 要查询日志的域名 |
| startDate | 否    | String | 查询起始时间，格式为：2016-12-30 00:00:00  |
| endDate   | 否    | String | 查询结束时间，格式为：2016-12-30 01:00:00 |

#### 注意事项

+ 未填充startDate和endDate时，默认查询区间为当前时间前推30天，每小时提供一个日志下载链接，更多日志相关说明可查看 [日志下载](https://cloud.tencent.com/doc/product/228/6316) ；
+ startDate 为查询开始时间，endDate 为查询结束时间，返回为涵盖指定 startDate 和 endDate 区间的日志数据包，假设 startDate=2016-12-30 00:01:00，endDate=2016-12-30 02:12:00，则会返回 2016123000、2016123001、2016123002 三个小时的数据包；
+ 若某一个小时未产生访问日志，则不会生成下载链接，也不会返回；
+ 日志下载链接的有效期为24小时。

## 3. 输出参数


| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |


#### data字段说明

| 参数名称 | 类型    | 描述            |
| ---- | ----- | ------------- |
| now  | Int   | 当前时间，Unix 时间戳 |
| list | Array | 日志下载链接列表      |


#### list 字段说明

| 参数名称 | 类型     | 描述                                       |
| ---- | ------ | ---------------------------------------- |
| date | Int    | 日志日期                                     |
| type | Int    | 是否有日志；1：有日志；0：无日志                        |
| name | String | 日志名称，格式为：日期小时-域名，如 2016050301-www.test.com |
| link | String | 下载链接                                     |

## 4. 示例

### 4.1 输入示例

> host: www.test.com
> startDate: 2016-12-30 00:00:01
> endDate: 2016-12-30 05:12:00


### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnLogList
&SecretId=XXXXXXXXXXXXXXXXX
&Timestamp=1462430812
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXX
&host=www.test.com
&startDate=2016-12-30+00%3A00%3A01
&endDate=2016-12-30+05%3A12%3A00
```

### 4.3 POST 请求



POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnLogList',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462865760,
  'Nonce' => 1058191224,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'startDate' => '2016-12-30 00:00:01',
  'endDate' => '2016-12-30 05:12:00'
)
```

### 4.4 返回结果示例

```json
{
  "code":0,
  "message":"",
  "codeDesc": "Success",
  "data":{
    "now":1483954368,
    "list":[
  		{
  	  		"date":2016-12-30,
  	  		"type":1,
  	  		"name":"2016123000-www.test.com",
  	  		"link":"http://log-download.cdn.qcloud.com/20161230/00/2016123000-www.selenawang.com.gz?st=XXXXXXXXXXXXXXXXXXXX&e=1483954368"
		},
		{
  	  		"date":2016-12-30,
  	  		"type":1,
  	  		"name":"2016123001-www.test.com",
  	  		"link":"http://log-download.cdn.qcloud.com/20161230/01/2016123001-www.test.com.gz?st=XXXXXXXXXXXXXXXXX&e=1483954368"
		},
      ...
	]
  }
}
```





