## 1. 接口描述
本接口（UpdateCdnConfig）用于修改域名对应的配置信息，此文档仅包含为大客户定制化开发的忽略set-cookie、忽略 cache-control、目录/URL级别referer黑白名单配置功能。

其他通用配置功能 [点击查看](https://cloud.tencent.com/document/product/228/3933)。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）一次仅支持修改一个域名的配置信息；
2）可对指定域名的多项配置信息进行修改。



[签名算法说明（SHA1）](https://cloud.tencent.com/document/product/228/1725)

[示例代码说明（SHA1）](https://cloud.tencent.com/document/product/228/1734)

[签名算法说明（SHA256）](https://cloud.tencent.com/document/product/228/10771)

[示例代码说明（SHA256）](https://cloud.tencent.com/document/product/228/10773)



## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为UpdateCdnConfig。

| 参数名称               | 是否必选 | 类型     | 描述                                       |
| ------------------ | ---- | ------ | ---------------------------------------- |
| host               | 是    | String | 需要修改配置的域名                                |
| ignoreSetCookie    | 否    | String | on或off，设定是否根据源站返回的set-cookie来决定是否缓存；<br/>若设置为on，表示忽略set-cookie，对应的header不缓存，body缓存；若设置为off，表示不忽略set-cookie，对应header不缓存，body 不缓存。<br/>默认情况下为on。 |
| ignoreCacheControl | 否    | String | on或off，设定是否根据源站返回header中cache-control的值，来判定是否遵循配置的节点缓存策略；<br/>若设置为on，表示忽略 cache-control，无论是何值，均遵循CDN配置的缓存过期策略；若设置为off，表示不忽略cache-control，若返回 no-cache、no-store、private值，节点不缓存，若返回 max-age=xxx，不影响CDN配置的缓存过期策略。<br/>默认情况下为off。 |
| pathRefer          | 否    | String | 针对指定目录或文件设置refer黑白名单进行访问控制，具体说明如下。       |

##### pathRefer 防盗链设置详细说明

设置示例：

```
[{"path":"/testB/","refer":[2,["test.com","*.test1.com"],1]},{"path":"/testA/1.jpg","refer":[1,["abc.com"],0]}]
```

"path" 为要配置refer黑白名单的目录或文件；

"refer" 中分为三个字段，第一个字段标识refer类型：

+ 0： 不设置防盗链；
+ 1：设置黑名单；
+ 2：设置白名单；

第二个字段为具体的名单列表，第三个字段为是否包含空refer，1表示包含空refer，0表示不包含空refer。



<font style="color: red">多条规则时，匹配优先级为从前到后，从高到低。</font>



## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |



## 4. 示例

### 4.1 输入示例

> host = `www.test.com`
> pathRefer =[{"path":"/testB/","refer":[2,["test.com","*.test1.com"],1]},{"path":"/testA/1.jpg","refer":[1,["abc.com"],0]}]

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=UpdateCdnConfig
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462872270
&Nonce=541116052
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
&host=www.test.com
&pathRefer=%5B%7B%22path%22%3A%22%2FtestB%2F%22%2C%22refer%22%3A%5B2%2C%5B%22test.com%22%2C%22%2A.test1.com%22%5D%2C1%5D%7D%2C%7B%22path%22%3A%22%2FtestA%2F1.jpg%22%2C%22refer%22%3A%5B1%2C%5B%22abc.com%22%5D%2C0%5D%7D%5D&Signature=l9VqLFlxQNds%2BK5En%2FvhclecGMQ%3D
```

### 4.3 POST 请求

POST请求时，参数填充在HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'UpdateCdnConfig',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462872294,
  'Nonce' => 479724541,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'pathRefer' => '[{"path":"/testB/","refer":[2,["test.com","*.test1.com"],1]},{"path":"/testA/1.jpg","refer":[1,["abc.com"],0]}]'
)
```


### 4.4 返回结果示例

#### 设置成功

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

#### 设置失败

```json
{
    "code": 4000,
    "message": "(9175)部署中状态 cdn host in progress[host in progress]",
    "codeDesc": "UserRequestError"
}
```
