## 1. 接口描述

本接口（GetCdnHostsCacheFlux）用于查询域名级/项目级命中流量明细数据。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**接口说明：**

+ 支持指定日期查询，支持查询当日实时数据，数据延迟约为5分钟左右；
+ 支持按照项目，查询指定项目下每一个域名命中流量明细；
+ 支持指定域名查询命中流量明细，指定域名时，需要填充其对应的项目ID。

**注意事项：**

+ 命中流量是指请求命中CDN边缘节点返回，或命中CDN中间源，即非源站直接返回流量；
+ Range分片回源会导致命中流量统计产生偏差。

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为 GetCdnHostsCacheFlux。

| 参数名称       | 是否必选 | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| date       | 是    | String | 指定查询日期，格式为：2016-10-31                    |
| projects.n | 否    | Int    | 指定查询项目ID，支持多个，如 projects.0=1&projects.1=2，[点击查看项目ID](https://console.cloud.tencent.com/project) |
| hosts.n    | 否    | String | 指定域名查询，支持多个，如 hosts.0=www.abc.com&hosts.1=www.def.com，若填充域名，需要将其对应的项目ID填入projects.n参数 |

**注意事项：**

+ projects.n 与 hosts.n 均不指定查询时，默认返回用户名下所有域名每一个的命中流量明细；
+ 统计数据时间粒度为5分钟，每天288个统计点；
+ 2016-10-31 00:05:00 时刻点的数值，等于 00:00:00 - 00:04:59 间的数据统计值。

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) |
| message  | String | 模块错误信息描述，与接口相关                           |
| codeDesc | String | 英文错误信息，或业务侧错误码                           |
| data     | Object | 返回结果数据，包括日期及各域名对应明细数组，流量的单位为 Byte        |

## 4. 示例
### 4.1 输入示例
> date: 2016-10-31
> projects.0=0

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnHostsCacheFlux
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462422547
&Nonce=12345678
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXX
&date=2016-10-31
&projects.0=0
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnHostsCacheFlux',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'date' => '2016-10-31',
  'projects.0' => '0'
)
```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "2016-10-31": {
        	"www.test.com":[
            	1,
                2,
                3,
                ...
            ],
            "www.test2.com":[
            	1,
                2,
                3,
               ...
            ]
		}
    }
}

```



