## 1. 接口描述

本接口（GetMonthData）查询指定指定月份，项目维度/域名维度/用户维度的月95带宽消耗。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**详细说明：**

+ 月95带宽算法说明：每一个有效天（产生消耗）共有288个带宽统计点（五分钟一个），结算月份所有有效天的统计点从大到小排序，去掉最高5%的点，剩下的最大的统计点，作为计费带宽。假设一个月有30个有效天，则共 288\*30 = 8640 个点，去掉最高 8640 \* 0.05 = 432 个点。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为 GetMonthData。

| 参数名称    | 是否必选 | 类型     | 描述                                       |
| ------- | ---- | ------ | ---------------------------------------- |
| month    | 是    | String | 查询月份，格式必须为：2016-09                    |
| hosts.n | 否    | String | 指定域名查询 |
| projects.n | 否    | String | 指定项目查询  |

**注意事项**

+ 不填充 hosts.n 和 projects.n 时，查询结果为该用户的月95带宽值；
+ hosts.n 支持多个域名，如hosts.0=www.test.com&hosts.1=www.test2.com，指定多个域名时，返回结果为每一个域名的月95带宽；查询指定域名时，需要在projects.n中填充域名对应的项目ID（[点击查看](https://console.cloud.tencent.com/project)）
+ projects.n 支持多个项目，如 projects.0=1&projects.1=2，当指定多个项目时，返回的为所有项目的总月95带宽；


## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Object | 结果数据，详细说明见下文                             |

##### data 字段说明

| 名称        | 类型     | 说明             |
| --------- | ------ | -------------- |
| month      | String | 指定查询的月份  |
| stat_data | Object | 统计数据，详细说明见下文 |

##### stat_data 字段说明

| 名称        | 类型     | 说明             |
| --------- | ------ | -------------- |
| host      | String | 查询的域名，只有指定域名查询时才包含该字段  |
| bandwidth | Int | 月95带宽值，单位为bps |

## 4. 示例

### 4.1 输入示例

> month: 2016-12
> hosts.0: www.test.com
> prjects.0: 0

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetMonthData
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&month=2016-12
&hosts.0=www.test.com
&projects.0=0
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetMonthData',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'month' => '2016-12',
  'hosts.0' => 'www.test.com',
  'projects.0' => '0'
)

```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "month": "2016-12",
        "stat_data": [
            {
                "host": "www.test.com",
                "bandwidth": 29153733
            }
        ]
    }
}
```























