## 1. API Description

This API (GetMonthData) is used to query the bandwidth consumption details for specified month by project, domain and user when the billing method is "95th Percentile Bandwidth".

Domain for API request:<font style="color:red">cdn.api.qcloud.com</font>

**About 95th Percentile Bandwidth**

+ How is 95th Percentile Bandwidth billing calculated: There are 288 bandwidth statistical points (one point every 5 minutes) each effective day (generating consumption). Sort all the statistical points on every effective day within the settlement month in an ascending order and ignore the top 5% statistical points. Then take the largest bandwidth value among the remaining 95% of statistical points as the billing bandwidth. Suppose there are 30 effective days in a month, the total statistical points are: 288\*30 = 8640, and ignore the top 5% statistical points: 8640 \* 0.05 = 432.

[Call Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. Input Parameters

The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/231/4473). The Action field for this API is GetMonthData.

| Parameter Name    | Required | Type     | Description                                       |
| ------- | ---- | ------ | ---------------------------------------- |
| month    | Yes    | String | The month for which the query is made. The format is yyyy-mm. For example, 2016-09                    |
| hosts.n | No    | String | The domain for which the query is made |
| projects.n | No    | String | The project for which the query is made  |

**Note**

+ If both hosts.n and projects.n are left empty, the query result will be bandwidth consumption details of the user based on 95th Percentile Bandwidth billing method;
+ Multiple domains can be entered in hosts.n field, such as hosts.0=www.test.com&hosts.1=www.test2.com. When multiple domains are specified, the returned results will be the bandwidth consumption details of every specified domain based on 95th Percentile Bandwidth billing method; To query the data for specified domain, you need to enter the project ID for this domain. [Click to View](https://console.cloud.tencent.com/project)
+ Multiple projects can be entered in projects.n field, for example, projects.0=1&projects.1=2. When multiple projects are specified, the returned results will be total consumption details for all projects in specified month based on 95th Percentile Bandwidth billing methods;


## 3. Output Parameters

| Parameter Name     | Type     | Description                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | Common error code; 0: Succeeded; other values: Failed. For more information, refer to [Common Error Codes](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) on the Error Code page.  |
| message  | String | Module error message description depending on API.                           |
| codeDesc | String | Error message or error code at business side.                           |
| data     | Object | Data result. For details, refer to the description later.                            |

##### data Field Description

| Name        | Type     | Description             |
| --------- | ------ | -------------- |
| month      | String | Specify the month for which the query is made.  |
| stat_data | Object | Statistical data. For detail, refer to the description later. |

##### stat_data Field Description

| Name        | Type     | Description             |
| --------- | ------ | -------------- |
| host      | String | The domain for which the query is made. This field is included only if "hosts.n" (query by domain) is specified.|
| bandwidth | Int | Bandwidth consumption values based on 95th Percentile Bandwidth bill method (in bps) |

## 4. Example

### 4.1 Input Example

> month: 2016-12
> hosts.0: www.test.com
> prjects.0: 0

### 4.2 GET Request

For GET request, all the parameters are required to be appended to the URL:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetMonthData
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&month=2016-12
&hosts.0=www.test.com
&projects.0=0
```

### 4.3 POST Request

For POST request, the parameters need to be filled in the HTTP Request-body. Request address:

```
https://cdn.api.qcloud.com/v2/index.php
```

Formats such as form-data and x-www-form-urlencoded are supported for the parameters. The array of parameters is as follows:

```
array (
  'Action' => 'GetMonthData',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'month' => '2016-12',
  'hosts.0' => 'www.test.com',
  'projects.0' => '0'
)

```

### 4.4 Example of Returned Result

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "month": "2016-12",
        "stat_data": [
            {
                "host": "www.test.com",
                "bandwidth": 29153733
            }
        ]
    }
}
```
























