## 1. 接口描述

本接口（GetCdnOriginStat）用于查询某段时间内的域名级回源带宽、回源流量、回源请求数、回源失败请求数、回源失败率等统计数据。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**接口说明：**

+ 支持指定起始时间点和结束时间点查询，支持查询当日实时数据，数据延迟约为5分钟左右；
+ 支持按照项目，查询指定项目下每一个域名回源带宽/流量明细；
+ 支持指定域名回源带宽明细查询。


## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnOriginStat。

| 参数名称      | 是否必选 | 描述                                       | 类型     |
| --------- | ---- | ---------------------------------------- | ------ |
| startTime | 是    | 查询起始时间，如2017-10-21 00:06:01              | String |
| endTime   | 是    | 查询结束时间，如2017-10-22 21:03:02              | String |
| hosts.n   | 否    | 查询域名，支持提交多个，查询每一个域名的回源明细数据，如 hosts.0=www.abc.com &hosts.1=www.def.com | String |
| statType  | 是    | 统计类型，bandwidth 表示回源带宽，返回数据单位为bps；flux 表示回源流量，返回数据单位为 Byte；requests 表示回源请求数，单位为次；fail_requests 表示回源失败请求数，单位为次；fail_ratio 表示回源失败率。 | String |
| detail    | 否    | 若填充1，则无论查询时间区间多长，均返回5 分钟粒度数据             |        |

**注意事项：**

+ detail 值为空时，若查询时间跨度小于3天，返回统计数据的默认时间区间为5分钟；若查询时间跨度大于等于3天小于7天，返回统计数据的默认时间区间为60分钟；若查询时间跨度大于等于7天，返回统计数据的默认时间区间为一天；
+ 若起始时间为 2017-10-21 00:06:01 时刻点的数值，统计维度为5分钟时，第一个时间点为 2017-10-21 00:10:00；若结束时间为2017-10-22 21:03:02，最后一个时间点为 21:00:00；
+ 查询 fail_requests 时，会返回各类回源失败明细统计，fail_5xx 表示回源 5XX 错误统计，fail_http_error 表示回源http协议不兼容错误，fail_origin_close 表示源站断开连接错误，fail_timeout 表示回源TCP连接超时错误。


## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见[错误码说明](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) |
| message  | String | 模块错误信息描述，与接口相关                           |
| codeDesc | String | 英文错误信息，或业务侧错误码                           |
| data     | Object | 返回结果数据，包括日期及各域名对应明细数组，详细说明如下             |



## 4. 示例

### 4.1 输入示例

> startTime: 2017-10-28 00:00:00
> endTime: 2017-10-28 00:05:00
> hosts.0: www.test.com
> statType: fail_requests

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnOriginStat
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462422547
&Nonce=12345678
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXX
&startTime=2017-10-28+00%3A00%3A00
&endDate=2017-10-28+00%3A05%3A00
&hosts.0=www.test.com
&statType=fail_requests
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnOriginStat',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startTime' => '2017-10-28 00:00:00',
  'endTime' => '2017-10-28 00:05:00',
  'hosts.0' => 'www.test.com',
  'statType' => 'fail_requests'
)
```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "period": 5,
        "start_datetime": "2017-10-28 00:00:00",
        "end_datetime": "2017-10-28 00:05:00",
        "fail_total": {
            "www.test.com": [
                0,
                0
            ]
        },
        "fail_5xx": {
            "www.test.com": [
                0,
                0
            ]
        },
        "fail_http_error": {
            "www.test.com": [
                0,
                0
            ]
        },
        "fail_origin_close": {
            "www.test.com": [
                0,
                0
            ]
        },
        "fail_timeout": {
            "www.test.com": [
                0,
                0
            ]
        }
    }
}
```

