## 1. 接口描述

本接口（GetPushLogs）用于查询已经提交的预拉热任务执行状态。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**接口说明：**

+ 支持指定日期、指定taskId、指定任务状态、指定关键字查询；
+ 支持分页查询；
+ 暂时仅支持30天内提交的预热任务执行状态。


## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetPushLogs。

| 参数名称     | 是否必选 | 类型     | 描述                                       |
| -------- | ---- | ------ | ---------------------------------------- |
| date     | 是    | String | 查询指定提交日期的预热任务，格式为：2016-07-03             |
| taskId   | 否    | Int    | 预热任务提交时返回的ID，查询指定日期中某一具体任务               |
| status.n | 否    | String | 预热任务状态，若为init，则表示状态为排队中，尚未开始；若为process，则表示预热任务执行中；若为done，表示预热任务已经完成，可指定上述状态中一个或多个进行查询 |
| keyword  | 否    | String | 关键字查询，指定某一个URL中部分字符串进行过滤查询               |
| offset   | 否    | Int    | 查询偏移量，用于分页                               |
| limit    | 否    | Int    | 返回记录数目，用于分页                              |

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81) |
| message  | String | 模块错误信息描述，与接口相关                           |
| codeDesc | String | 英文错误信息，或业务侧错误码                           |
| data     | Object | 返回结果数据，具体说明见下文                           |

#### data 字段说明

| 参数名称  | 类型     | 描述             |
| ----- | ------ | -------------- |
| logs  | Object | 预热任务详情，具体说明见下文 |
| total | Int    | 查询到的预热URL总次数   |

#### logs 字段说明

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| log_id   | Int    | 该条操作记录对应的ID                              |
| task_id  | Int    | 预热任务提交时返回的ID                             |
| host     | String | 域名，预热URL对应的域名                            |
| datetime | String | 预热任务提交的时间                                |
| status   | String | 预热任务当前状态，若为 inprocess表示预热任务执行中；若为 done，表示预热任务已经完成；若为 fail，则表示预热任务失败 |
| url      | String | 预热的URL                                   |


## 4. 示例

### 4.1 输入示例

> date: 2016-09-30

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetPushLogs
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462422547
&Nonce=12345678
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXX
&date=2016-09-30
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetPushLogs',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'date' => '2016-09-30'
)
```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "logs": [
            {
                "log_id": 10736,
                "task_id": 9214,
                "host": "www.test.com",
                "datetime": "2016-09-30 11:31:34",
                "status": "fail",
                "url": "http://www.test.com/2.jpg"
            },
            {
                "log_id": 10735,
                "task_id": 9214,
                "host": "www.test.com",
                "datetime": "2016-09-30 11:31:34",
                "status": "fail",
                "url": "http://www.test.com/1.jpg"
            }
        ],
        "total": 2
    }
}
```

