## 1. 接口描述

本接口（EAddCdnHost）用于添加CDN加速域名。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>


## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://www.qcloud.com/doc/api/231/4473)页面。其中，此接口的 Action 字段为 EAddCdnHost。

| 参数名称    | 是否必选 | 类型     | 描述                                       |
| ------- | ----------- | ------ | -------------------- |
| host    | 是    | String | 加速域名 |
| origin | 是 | String | 源站设置，支持配置一个域名，或配置多个源站IP（支持 'ip:port' 类型，如 8.8.8.8:8080），端口仅支持大于0小于等于65535 |
| projectId | 是 | Int | 项目ID，[点击查看](https://console.qcloud.com/project) |
| hostType | 是 | String | 域名类型， 'cname'表示自有源接入，‘ftp'表示FTP源接入 |
| cache | 否 | json | 缓存过期规则配置，详情见下文 |
| cacheMode | 否 | String | 缓存模式，共有两种类型，其中 'simple'表示缓存完全依赖控制台缓存过期规则设置；若为 'custom'，则表示缓存依赖控制台设置的缓存过期时间和源站吐出的max-age的最小值。 |
|  refer | 否 | json | 防盗链设置，详情见下文 |
| fwdHost | 否 | String | 回源host |
| fullUrl | 否 | String | 是否全路径缓存， 'on'表示开启全路径缓存，'off'表示关闭全路径缓存 |
| middleResource | 否 | String | 是否开启中间源， 'on'表示开启中间源，'off'表示关闭中间源 |


##### 缓存过期规则设置

cache设置示例如下：
```
[[0,"all",1000],[1,".jpg;.js",2000],[2,"/www/html",3000],[3,"/index.html;/test/*.jpg",3000]]
```
第一个参数是缓存类型：

缓存类型有如下四种：

+ 0：全部类型，表示匹配所有文件，默认缓存配置；
+ 1：文件类型，表示按文件后缀匹配；
+ 2：文件夹类型，表示按目录匹配；
+ 3：全路径文件，标识按照首页或指定某一文件匹配。

第二个参数指定匹配规则：

+ 0：固定填充”all“；
+ 1：后缀，.jps;.js 等，; 分隔；
+ 2：目录，如 /www/html; /www/anc/ 等，;分隔；
+ 3：全路径文件，如 /index.html;/test/*.jpg 等资源全路径，; 分隔，仅支持 * 匹配。

第三个参数指定缓存时间，单位为秒。

##### referer防盗链设置

示例：
```
[1,["qq.baidu.com", "*.baidu.com"]]
```

第一个字段标识refer类型：

+ 0： 不设置防盗链；
+ 1：设置黑名单；
+ 2：设置白名单；

第二个字段为具体的名单列表。



## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://www.qcloud.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Object | host_id 表示添加成功的域名对应 ID |


## 4. 示例

### 4.1 输入示例

> host: www.test.com
> origin: 1.1.1.1
> projectId: 0
> hostType: cname
> fwdHost: www.test1.com

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=EAddCdnHost
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&host=www.test.com
&origin=1.1.1.1
&projectId=0
&hostType=cname
&fwdHost=www.test1.com
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'EAddCdnHost',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'origin' => '1.1.1.1',
  'projectId' => '0',
  'hostType' => 'cname',
  'fwdHost' => 'www.test1.com'
)

```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "host_id": 394565
    }
}
```























