## 1. 接口描述

本接口（GetCdnProvIspDetailStat）用于查询指定日期、指定运营商、指定省份、指定域名的带宽消耗明细，时间粒度为5分钟，一天288个统计点。由于运营商/省份需要从日志中分析，数据延迟大概为20-30分钟。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**详细说明：**

+ 由于省份-运营商组合结果非常多，且本接口返回的为细粒度的数据，数据量较大，暂时不支持太多域名同时查询，一次最多可查询5个域名；
+ 若不填充省份仅指定运营商，则返回的全国每一个省份在该运营商的消耗明细，支持指定多个运营商查询；
+ 若不填充运营商，仅指定省份，则返回该省份每一个运营商的消耗明细，支持指定多个省份查询；
+ 若不填充运营商，也不指定省份，则返回每个省份每一个运营商的消耗明细；
+ 若该省份或运营商无数据，则不会返回；
+ 返回的带宽消耗明细单位为bps。

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnProvIspDetailStat。

| 参数名称    | 是否必选 | 类型     | 描述                                       |
| ------- | ---- | ------ | ---------------------------------------- |
| date    | 是    | String | 查询日期，格式必须为：2016-09-28                    |
| hosts.n | 是    | String | 域名，支持多个，如hosts.0=www.test.com&hosts.1=www.test2.com，最多可查询5个 |
| provs.n | 否    | String | 指定省份，省份通过编码区分，点击 [CDN日志省份编码映射表](https://cloud.tencent.com/document/product/228/6316) 查看 |
| isps.n  | 否    | String | 指定运营商，运营商通过编码区分，点击[CDN日志运营商编码映射表](https://cloud.tencent.com/document/product/228/6316) 查看 |

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Object | 结果数据，详细说明见下文                             |

#### data 字段说明

| 名称        | 类型     | 说明             |
| --------- | ------ | -------------- |
| date      | String | 输入时指定的起始日期（日）  |
| prov_data | Object | 省份数据明细，详细说明见下文 |

##### prov_data 字段说明

| 名称        | 类型     | 说明                   |
| --------- | ------ | -------------------- |
| id        | Int    | 省份编码                 |
| name      | String | 省份                   |
| host      | String | 指定查询的域名              |
| isp_value | Object | 运营商信息，每一个运营商对应一个明细数组 |

## 4. 示例

### 4.1 输入示例

> date: 2016-09-28
> hosts.0: www.test.com
> provs.0: 1442
> isps.0: 2

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnProvIspDetailStat
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&date=2016-09-28
&hosts.0=www.test.com
&provs.0=1442
&isps.0=2
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnProvIspDetailStat',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'date' => '2016-09-28',
  'hosts.0' => 'www.test.com',
  'provs.0' => '1442',
  'isps.0' => '2'
)

```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "date": "2016-09-28",
        "prov_data": {
            "www.test.com": [
                {
                    "id": 1442,
                    "name": "浙江",
                    "host": "www.test.com",
                    "isp_value": {
                        "bandwidth": {
                            "2": [
                                1,
                                1,
                                1,
                                0,
                                ...
                            ]
                        }
                    }
                }
            ]
       }
    }
}
```























