## 1. 接口描述

本接口（GetCdnHostsOverseaDetailStat）用于查询指定域名、指定时间区间的消耗统计信息，包括流量，带宽，请求数，状态码，命中流量和命中请求数。

+ 支持一次性查询多个域名（最多5个）的指定消耗明细，域名需要已经开通海外CDN；
+ 默认情况下，根据查询时间段不同，时间区间3天以内明细数据，时间粒度均为5分钟；时间区间4-7天时间粒度为1小时，时间区间8天及以上，时间粒度为1天，目前仅保留近三个月（90天）内数据；
+ 查询指定时间段内的5分钟粒度数据时，输入参数“detail”值需为“1”。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为 GetCdnHostsOverseaDetailStat。

| 参数名称 | 是否必选 | 类型    | 描述                    |
| ------- | ------- | ------  | --------------------- |
|startTime| 是      | String  |  查询开始日期，如：2017-08-03 00:00:00|
|endTime  | 是      | String  |  查询结束日期，如：2017-08-03 23:55:00|
|statType | 是      | String  | 查询统计量类型，'flux'代表流量，单位Byte；'bandwidth'代表峰值带宽，单位bps；'requests'代表请求数，单位次；'hit_flux'代表流量命中，单位为Byte，'hit_requests'代表命中请求数，单位为次；'status_code'代表状态码，目前包含200、206、302、304、401、403、404、405、416、500、502  |
|hosts.n  | 是      | String  | 域名，可指定多个：hosts.0=www.test.com&hosts.1=www.test2.com |
|detail   | 否      | String  | 时间粒度，若填充1，均返回5分钟粒度明细数据 |

**注意事项：**

+ 最小粒度为5分钟数据，00:00:00时间点的数据，表示00:00:00—00:04:59时间区间的数据；
+ 按小时/天汇总数据时，flux、requests、hit_flux、hit_requests、status_code均为按小时/天累加，bandwidth取峰值数据；
+ 该接口返回数据量较大，一次最多查询5个域名。

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Object | 返回结果数据，详细说明如下                            |

#### data字段说明

| 参数名称        | 类型     | 描述                                       |
| -------------- | ------ | ---------------------------------------- |
| period         | Int    | 统计数据时间区间，默认为5分钟                          |
| start_datetime     | String | 查询起始时间 |
| end_datetime       | String | 查询结束时间 |
| requests       | Array  | 若指定statType为requests，则返回各域名的请求数明细，其他statType与此类似。|

**注意事项：**

- bandwidth为Int类型数组，从指定查询日期0点开始，每5分钟一个数据，单位为bps；
- flux为Int类型的数组，从指定查询日期0点开始，每5分钟一个数据，单位为Byte；
- 统计周期为5分钟时，00:00:00的统计量代表了00:00:00-00:04:59期间的统计量。

## 4. 示例

### 4.1 输入示例

> startTime: 2017-09-22 00:00:00
> endTime: 2017-09-22 23:55:00
> statType: flux
> hosts.0: www.test.com

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnHostsOverseaDetailStat
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462422547
&Nonce=12345678
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXX
&startTime=2017-09-22 00:00:00
&endTime=2017-09-22 23:55:00
&statType=flux
&hosts.0=www.test.com
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnHostsOverseaDetailStat',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'startTime' => '2017-09-22 00:00:00',
  'endTime' => '2017-09-22 23:55:00',
  'statType' => 'flux',
  'hosts.0' => 'www.test.com'
)
```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "flux": {
            "www.test.com": [
                2476300,
                2884917
				...
            ]
        },
        "period": 5,
        "start_datetime": "2017-09-22 00:00:00",
        "end_datetime": "2017-09-22 23:55:00"
    }
}

```



