## 1. 接口描述

本接口（GetCdnOverseaProvIspHyDetailStat）用于查询指定日期、指定运营商、指定地区、指定域名的回源带宽/流量明细，时间粒度为5分钟，一天288个统计点。</br>由于地区/省份需要从日志中分析，数据延迟大概为20-30分钟。**注：本接口的调用频率请控制在每分钟一百次内。**

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

**详细说明：**

+ 使用本接口查询的域名需接入腾讯云海外CDN；
+ 由于地区-运营商组合结果非常多，且本接口返回的为细粒度的数据，数据量较大，暂时不支持过多域名同时查询，一次最多可查询5个域名；
+ 目前不细化海外运营商，海外运营商统一编码为-1；
+ 若不填充运营商，仅指定地区，则返回该每一个运营商的消耗明细，支持指定多个地区查询；
+ 若不填充运营商，也不指定地区，则返回每个地区每一个运营商的消耗明细；
+ 若无数据，则不会返回。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为GetCdnOverseaProvIspHyDetailStat。

| 参数名称     | 是否必选 | 类型     | 描述                                       |
| -------- | ---- | ------ | ---------------------------------------- |
| date     | 是    | String | 查询日期，格式必须为：2016-11-20                    |
| hosts.n  | 是    | String | 域名，支持多个，如hosts.0=www.test.com&hosts.1=www.test2.com，最多可查询5个 |
| provs.n  | 否    | String | 指定地区，地区通过编码区分，编码参考下文中海外CDN日志地区编码映射表      |
| isps.n   | 否    | String | 指定运营商，运营商通过编码区分，编码参考下文中海外CDN日志地区编码映射表    |
| statType | 是    | String | 指定查询类型，支持六种数据的查询，requests对应请求数据，单位为个；flux对应流量数据，单位为Byte；statuscode对应状态码个数，单位为个；dlspeed对应回源速度，单位为bit/s；dltime对应回源用时，单位为s；errorcnt对应回源失败次数，单位为个 |

**海外CDN日志地区编码映射表**

73：印度、1195：印度尼西亚、1176：新加坡、57：泰国、144：越南、3701：马来西亚、2588：菲律宾、2026：台湾、1044：日本、3379：韩国、1200：香港、3839：加拿大、669：美国、-2：海外其他地区、-3：未知；

**海外CDN日志运营商编码映射表**

-1：海外运营商；

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Object | 结果数据，详细说明见下文                             |

#### data 字段说明

| 名称        | 类型     | 说明             |
| --------- | ------ | -------------- |
| date      | String | 输入时指定的起始日期（日）  |
| prov_data | Object | 地区数据明细，详细说明见下文 |

##### prov_data 字段说明

| 名称        | 类型     | 说明                              |
| --------- | ------ | ------------------------------- |
| id        | Int    | 地区编码                            |
| name      | String | 地区                              |
| host      | String | 指定查询的域名                         |
| isp_value | Object | 运营商信息，每一个运营商对应一个明细数组，目前海外不细化运营商 |

## 4. 示例

### 4.1 输入示例

> date: 2016-11-20
> hosts.0: www.test.com
> provs.0: 57
> isps.0: -1

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnOverseaProvIspHyDetailStat
&SecretId=XXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462416887
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXX
&date=2016-11-20
&hosts.0=www.test.com
&provs.0=57
&isps.0=-1
&statType=bandwidth
```

### 4.3 POST 请求

POST请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'GetCdnOverseaProvIspHyDetailStat',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'date' => '2016-11-20',
  'hosts.0' => 'www.test.com',
  'provs.0' => '57',
  'isps.0' => '-1',
  'statType' => 'flux'
)
```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "date": "2016-09-28",
        "prov_data": {
            "www.test.com": [
                {
                    "id": 57,
                    "name": "泰国",
                    "host": "www.test.com",
                    "isp_value": {
                        "flux": {
                            "-1": [
                                1,
                                1,
                                1,
                                0,
                                ...
                            ]
                        }
                    }
                }
            ]
       }
    }
}
```
