Common request parameters are the parameters common to all APIs, and will not be discussed in the document for each API unless it is necessary to do so. They are required in each request for the request to be initiated normally. The first letter of each common request parameter is uppercase so that the parameter can be differentiated from API-specific request parameters.

Common request parameters are listed as follows:

| Name       | Type     | Description                                       | Required   |
| --------- | ------ | ---------------------------------------- | ---- |
| Action | String | The name of the API for the desired operation. For example, if you want to call the API of [Query Consumption Details](https://cloud.tencent.com/doc/api/445/6394), the Action parameter is GetCdnOverseaStat.              | Yes |
| Region | String | Identify the region to which the instance you want to operate belongs. The parameter values for regions are as follows:  Beijing: bj, Guangzhou: gz, Shanghai: sh, Hong Kong: hk, North America: ca. **Note: CDN is not region-specific, so this parameter is not required.**  | No |
| Timestamp | UInt | The current UNIX timestamp that records the time at which the API request was initiated.                               | Yes |
| Nonce     | UInt   | A random positive integer that is used in conjunction with Timestamp to prevent replay attacks.         | Yes |
| SecretId  | String | SecretId for identifying identity that is applied for on [Cloud API Key](https://console.cloud.tencent.com/capi). A SecretId corresponds to a unique SecretKey, which is used to generate the request Signature. For more information, refer to [Signature Method](https://cloud.tencent.com/document/api/228/1725).  | Yes |
| Signature | String | Request signature used to verify the legitimacy of the request and automatically generated by system according to input parameters. For more information, refer to [Signature Method](https://cloud.tencent.com/document/api/228/1725).  | Yes |

Assuming that the user wants to query the list of all domains connected to CDN, the request link may be as follows:

```
https://cdn.api.qcloud.com/v2/index.php?
Action=GetCdnOverseaStat
&SecretId=xxxxxxx
&Timestamp=1465055529
&Nonce=59485
&Signature=mysignature
&<API Request Parameters>
```

A complete request needs two types of request parameters: common request parameters and API request parameters. Only five common request parameters are listed above (Region parameter is not required). For information on API parameters, refer to [API Request Parameters](https://cloud.tencent.com/document/api/228/5074) section.
