## 1. 接口描述

本接口（DescribeOverseaCdnHosts）用于查询所有域名的详细信息，包括配置信息，支持分页查询。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为DescribeOverseaCdnHosts。

| 参数名称   | 是否必选 | 类型   | 描述                   |
| ------ | ---- | ---- | -------------------- |
| offset | 否    | Int  | 偏移量，默认为0             |
| limit  | 否    | Int  | 指定查询的返回数量，默认返回前100域名 |
| projects  | 否    | Array  | 项目ID |

#### 注意事项

- 域名较多时，可以利用 offset 和 limit 进行分页查询，也可都不传入，默认返回前100个域名信息；
- projects支持指定多个值，分别用projects.0, projects.1……projects.n表示；
- 该接口调用频次上限为 100次/分钟，超出上限则会返回错误，请勿高频调用。

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |

#### data 字段说明

| 参数名称  | 类型    | 描述       |
| ----- | ----- | -------- |
| hosts | Array | 域名详细信息数组 |
| total | Int   | 域名总数     |

#### hosts 字段说明

| 参数名称         | 类型     | 描述                                       |
| ------------ | ------ | ---------------------------------------- |
| host_id      | Int    | 域名接入 CDN 后的的标识 ID                        |
| app_id       | Int    | 域名归属人对应的 APPID                           |
| project_id   | Int    | 域名所属项目 ID                                |
| host         | String | 域名                                       |
| host_type    | String | 接入方式，共有三种类型，若为 'cos'，则表示域名接入时使用的托管源为COS源；若为'cname'，则表示域名接入时使用的是自有源站；若为'ftp'，则表示该域名接入时使用了 CDN 提供的 FTP 托管源 |
| service_type | String | 域名业务类型，共有三种类型，若为'web'，则表示类型为静态加速；若为'download'，则表示业务类型为下载加速；若为'media'，则表示业务类型为流媒体加速 |
| origin       | String | 域名对应源站配置                                 |
| cache        | Array  | 缓存规则设置，详细说明见下文                           |
| cdn_status   | String | 域名所属状态，online表示域名已启动，offline表示域名已下线，progress表示域名部署中 |
| message      | String | 域名状态信息，如 '已关闭'、'已启动'、'部署中' 等。            |
| create_time  | String | 域名接入时间                                   |
| update_time  | String | 上一次更新时间                                  |
| fwd_host     | String | 回源地址                                     |
| refer        | Array  | 防盗链设置，详细说明见下文                            |
| rsp_header   | Array  | 自定义返回头部                                  |
| cname        | String | CDN 分配的 .cdn.dnsv1.com 后缀加速域名            |
| furl_cache   | String | 过滤参数，若为'on'，则表示开启；若为'off'，则表示关闭          |

#### cache 字段说明

| 参数名称 | 类型     | 描述                                       |
| ---- | ------ | ---------------------------------------- |
| type | Int    | 类型，共有两种类型，其中0表示配置为所有文件，1表示配置为文件类型        |
| rule | String | 匹配规则，与上述 type 相对应                        |
| time | Int    | 缓存时间，单位为 秒                               |
| unit | String | 设置缓存时间时所用单位，共有四种类型，'d'表示天，'h'表示小时，'m'表示分钟，'s'表示秒 |

#### refer 字段说明

| 参数名称 | 类型    | 描述                                       |
| ---- | ----- | ---------------------------------------- |
| type | Int   | 防盗链类型，共有三种类型，0表示未配置防盗链，1表示配置的名单为黑名单，2表示配置的名单为白名单 |
| list | Array | 配置的防盗链名单                                 |

**注意事项**：

- 未在上述文档中说明的字段为 **无效字段**，可直接忽略。

## 4. 示例

### 4.1 输入示例

> offset: 0 limit: 10 projects.0=0

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=DescribeOverseaCdnHosts
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462434006
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXX
&offset=0
&limit=10
&projects.0=0
```

### 4.3 POST 请求

POST 请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'DescribeOverseaCdnHosts',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'offset' => '0',
  "limit" => '10',
  "projects.0" => '0',
)
```

### 4.4 返回结果示例

#### 查询成功

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "hosts": [
            {
                "host_id": 308902,
                "app_id": 1234567,
                "owner_uin": 7654321,
                "project_id": 0,
                "host": "www.test.com",
                "cname": "www.test.com.cdn.dnsv1.com",
                "host_type": "cname",
                "service_type": "web",
                "origin": "8.8.8.8",
                "cache": [
                    {
                        "type": 0,
                        "rule": "all",
                        "time": 2592000,
                        "unit": "d"
                    },
                    {
                        "type": 1,
                        "rule": ".php;.jsp;.asp;.aspx",
                        "time": 0,
                        "unit": "s"
                    }
                ],
                "cdn_status": "online",
                "message": "已开启",
                "create_time": "2016-08-25 21:22:40",
                "update_time": "2016-09-02 15:33:37",
                "fwd_host": "www.test.com",
                "refer": {
                    "type": 2,
                    "list": [
                        "1.1.1.1"
                    ],
                },
                "furl_cache": "on"
            }
        ],
        "total": 1
    }
}
```

#### 查询失败

```json
{
    "code": 4100,
    "message": "鉴权失败，请参考文档中鉴权部分。",
    "codeDesc": "AuthFailure"
}
```