## 1. 接口描述

本接口（OnlineOvHost）用于上线某个海外域名的CDN服务。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为OnlineOvHost。

| 参数名称   | 是否必选 | 类型   | 描述                   |
| ------ | ---- | ---- | -------------------- |
| hostId | 是    | Int  | 海外CDN域名ID             |

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关。                          |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |
| data     | Array  | 结果数据，详细说明见下文                             |

#### data 字段说明

| 参数名称         | 类型    | 描述                |
| --------------- | ------ | ------------------- |
| app_id          | Int    |  腾讯云服务账号[点击查看](http://console.cloud.tencent.com/cloudAccount)，与UIN对应  |
| host_id         | Int    | 海外域名ID      |
| project_id      | Int    | 域名所属的项目ID      |
| host            | String | 域名      |
| cname           | String | CDN 分配的 .cdn.dnsv1.com 后缀加速域名      |
| host_type       | String | 接入方式，共有三种类型，若为 'cos'，则表示域名接入时使用的托管源为COS源；若为'cname'，则表示域名接入时使用的是自有源站；若为'ftp'，则表示该域名接入时使用了 CDN 提供的 FTP 托管源      |
| service_type    | String | 域名业务类型，共有三种类型，若为'web'，则表示类型为静态加速；若为'download'，则表示业务类型为下载加速；若为'media'，则表示业务类型为流媒体加速      |
| status          | Int    | 域名CDN服务状态码      |
| cdn_status      | String | 域名CDN服务状态      |
| origin          | String | 域名对应源站配置    |
| fwd_host        | String | 回源地址    |
| refer           | String | 防盗链设置，详细说明见下文    |
| cache           | String | 缓存规则设置，详细说明见下文    |
| furl_cache      | String | 过滤参数，若为'on'，则表示开启；若为'off'，则表示关闭    |
| rsp_header      | String | 自定义返回头部    |
| https           | Array  | 若type为0，则表示未开通HTTPS配置；若为其他，则表示已开通HTTPS配置  |
| readonly        | Int    | 当前是否被锁定，0表示未被锁定，1表示被锁定    |
| deleted         | String | 'yes'或是'no'，表示域名是否标记为已删除    |
| message         | String | 域名状态的描述信息    |
| create_time     | String | CDN服务创建时间    |
| update_time     | String | CDN服务的最近更新时间    |
| middle_resource | String | 'on'或是'off'，表示是否开启了中间源    |
| dedicated_line  | String | 'on'或是'off'，表示是否使用了专线    |

#### cache 字段说明

| 参数名称 | 类型     | 描述                                       |
| ---- | ------ | ---------------------------------------- |
| type | Int    | 类型，共有两种类型，其中0表示配置为所有文件，1表示配置为文件类型        |
| rule | String | 匹配规则，与上述 type 相对应                        |
| time | Int    | 缓存时间，单位为 秒                               |
| unit | String | 设置缓存时间时所用单位，共有四种类型，'d'表示天，'h'表示小时，'m'表示分钟，'s'表示秒 |

#### refer 字段说明

| 参数名称 | 类型    | 描述                                       |
| ---- | ----- | ---------------------------------------- |
| type | Int   | 防盗链类型，共有三种类型，0表示未配置防盗链，1表示配置的名单为黑名单，2表示配置的名单为白名单 |
| list | Array | 配置的防盗链名单      
**注意事项**：

- 未在上述文档中说明的字段为 **无效字段**，可直接忽略。

## 4. 示例

### 4.1 输入示例

> hostId:11111111

### 4.2 GET 请求

GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=OnlineOvHost
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462434006
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXX
&hostId=11111111
```

### 4.3 POST 请求

POST 请求时，参数填充在 HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'OnlineOvHost',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462782282,
  'Nonce' => 123456789,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXX',
  'hostId' => '11111111',
)
```

### 4.4 返回结果示例

```json
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": [
        {
            "host_id": 11111111,
            "app_id": 12345678,
            "project_id": 0,
            "host": "www.test.com",
            "cname": "www.test.com.cdn.dnsv1.com",
            "host_type": "cname",
            "service_type": "download",
            "status": 4,
            "cdn_status": "offline",
            "origin": "8.8.8.8",
            "fwd_host": "www.test.com",
            "refer": {
                "type": 2,
                "list": [
                    "1.1.1.1"
                ],
            },
            "cache": [
                {
                    "type": 0,
                    "rule": "all",
                    "time": 2592000,
                    "unit": "d"
                },
                {
                    "type": "1",
                    "rule": ".jpg;.png;.css;.js",
                    "time": 86400,
                    "unit": "d"
                }
            ],
            "furl_cache": "off",
            "rsp_header": [],
            "https": {
                "type": 0
            },
            "readonly": 0,
            "deleted": "no",
            "message": "部署中",
            "create_time": "2017-08-08 11:27:59",
            "update_time": "2017-08-08 12:19:11",
            "middle_resource": "off",
            "dedicated_line": "off"
        }
    ]
}
```