## 1. 接口描述

本接口（AddCdnOvHost）用于新增海外加速域名。

接口请求域名：<font style="color:red">cdn.api.qcloud.com</font>

1）接入的域名为海外CDN加速域名；

2）使用此接口，一次仅可添加一个域名至腾讯云海外CDN。

[调用Demo](https://cloud.tencent.com/document/product/228/1734)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](https://cloud.tencent.com/doc/api/231/4473)页面。其中，此接口的Action字段为AddCdnOvHost。

| 参数名称      | 是否必选 | 类型     | 描述                                       |
| --------- | ---- | ------ | ---------------------------------------- |
| host      | 是    | String | 需要接入 CDN 的域名                             |
| projectId | 是    | String | 项目 ID，指域名要添加入的项目的对应 ID                   |
| hostType  | 是    | String | 域名的接入方式，只有两种取值方式，若为 'cname' ，则表示用户使用自己的源站；若为 'cos'，则表示用户使用 COS源 |
| origin | 是    | String | 源站设置，支持配置一个域名或源站IP:Port， 端口只支持80 |
| furlCache    | 否  | String | 过滤参数，若为'on'，则表示不使用过滤参数功能，启用全路径缓存命中规则；若为'off'，则表示使用过滤参数功能，不启用全路径缓存命中规则    |
| fwdHost | 是    | String | 回源域名 |
| serviceType | 是    | String | 业务类型，有三种业务类型：'download'表示下载、'web'表示静态、'media'表示流媒体 |
| cache | 否    | String | 缓存策略 |
| refer | 否    | String | referer防盗链，默认无防盗链规则 |
| rspHeader | 否    | String | 浏览器自定义头部 |


**refer设置如下**

refer字段设置访问的黑名单或白名单，示例如下：

```json
{"type":2,"list":["*.qq.com","www.test.com"]}
```

- type为refer名单类型：0表示不设置，1 表示黑名单，2表示白名单；
- list为具体的名单列表；

**cache设置如下**

cache字段设置资源的缓存策略，示例如下：

```json
[{"type":1, "rule":".jpg;.png", "time" : 1, "unit":'s'}]
```

type为缓存类型，有如下四种：

- 0：表示匹配所有文件，默认缓存配置；
- 1：表示匹配文件类型，按文件后缀匹配；
- 2：表示匹配文件夹类型，按目录匹配；
- 3：表示全路径匹配。

rule为匹配规则，对应不同的缓存类型分别有四种：

- 0：固定填充"all"，表示所有文件；
- 1：后缀，.jps;.js等，用;分隔；
- 2：目录，如/www/anc;/a/b等，用;分隔；
- 3：全路径，如/a/1.html;/b/2.html，用;分隔。

time为缓存时间

unit为缓存时间的单位，有如下四种：

- d：单位为天；
- h：单位为小时；
- m：单位为分钟；
- s：单位为秒。

## 3. 输出参数

| 参数名称     | 类型     | 描述                                       |
| -------- | ------ | ---------------------------------------- |
| code     | Int    | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/231/5078#1.-.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 |
| message  | String | 模块错误信息描述，与接口相关                           |
| codeDesc | String | 英文错误信息，或业务侧错误码。                          |

## 4. 示例

### 4.1 输入示例

> host: www.test.com
> projectId: 0
> hostType: cname
> origin: 8.8.8.8:8080
> fwdHost: www.test.com
> serviceType:web


### 4.2 GET 请求


GET 请求需要将所有参数都加在 URL 后：

```
https://cdn.api.qcloud.com/v2/index.php?
Action=AddOvCdnHost
&SecretId=XXXXXXXXXXXXXXXXXXXXXXXXX
&Timestamp=1462440051
&Nonce=123456789
&Signature=XXXXXXXXXXXXXXXXXXXXXXXXXX
&host=www.test.com
&projectId=0
&hostType=cname
&origin=8.8.8.8:8080
&fwdHost=www.test.com
&serviceType=web
```

### 4.3 POST 请求
POST请求时，参数填充在HTTP Request-body 中，请求地址：

```
https://cdn.api.qcloud.com/v2/index.php
```

参数支持 form-data、x-www-form-urlencoded 等格式，参数数组如下：

```
array (
  'Action' => 'AddCdnOvHost',
  'SecretId' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'Timestamp' => 1462868615,
  'Nonce' => 520585444,
  'Signature' => 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
  'host' => 'www.test.com',
  'projectId' => '0',
  'hostType' => 'cname',
  'origin' => '8.8.8.8:8080'
  'fwdHost' => 'www.test.com'
  'serviceType'=> 'web'
)
```

### 4.4 返回结果示例
#### 添加成功

```json
{
     "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": null
}
```

#### 添加失败

```json
{
    "code": 4000,
    "message": "(9137)域名已经被自己添加",
    "codeDesc": "UserRequestError"

}

```







