## 功能描述
创建目录 API 用于在 COS 的 Bucket 中创建一个新目录。成功创建新目录的前提条件是已经在控制台创建了 Bucket 。如果该 COS 中没有 Bucket 或新建目录名已存在，则创建新目录不成功。
## 请求
语法示例：
```
POST /files/v2/<APPID>/<BucketName>/<DirName>/ HTTP/1.1
Host: <Region>.file.myqcloud.com
Authorization: <MultiEffectSignature>
Content-Type: application/json
Content-Length: <ContentLength>
```

> Authorization: &lt;MultiEffectSignature&gt; 多次有效签名（详细参见 [签名算法](https://cloud.tencent.com/document/product/436/6054) 章节）
> Content-Length: &lt;ContentLength&gt; RFC 2616 中定义的 HTTP 请求内容长度（字节）

### 请求体

该 API 接口请求的请求体具体节点内容为：<style  rel="stylesheet"> table th:nth-of-type(1) { width: 100px; }</style>
```
{
	"op":"create",
	"biz_attr":""
}
```
具体内容描述如下：

|参数名称|	描述	|类型|	必选|
|---|---|---|---|
|op	|操作类型，填”create”	|String	|是|
|biz_attr|	COS 服务调用方自定义属性，可通过 [查询目录属性](https://cloud.tencent.com/document/product/436/6063) 获取该属性值	|String	|否|

## 响应

### 响应体

该响应体返回为 **application/json** 数据，包含完整节点数据的内容展示如下：
```
{
	"code":0,
	"message":"SUCCESS",
	"request_id":"NTk5YWM5MDZfNjIyNWI2NF8xOWQxXzE0NWY4",
	"data":{
	"ctime":1503316230
	}
}
```
具体的参数描述如下：

| 参数名称 | 描述     |类型 | 
| -------- | ------ | ------ | ---------- |
| code     |服务端返回码，如果没有发生任何错误取值为**0**；如果发生错误该参数指称具体的错误码。COS服务相关的错误码可以查看 [COS 错误码汇总](https://cloud.tencent.com/document/product/436/8432) |  Number   | 
| message  |服务端提示内容，如果发生错误该字段将详细描述发生错误的情况。  |  String | 
| data     |服务端返回的应答数据，该内容代表了接口返回的具体的业务数据。 |  Object   | 
|request_id| 该请求的唯一标识 id |String  |


data 数据集参数描述：

|参数名称|描述|类型|
|---|-- |--|
| ctime | 创建时间，10 位 Unix 时间戳（UNIX 时间是从协调世界时 1970 年 1 月 1 日 0 时 0 分 0 秒起的总秒数） | Number |


## 实际案例

### 请求
```
POST /files/v2/1252448703/lewzylu02/testfolder/ HTTP/1.1
Host: gz.file.myqcloud.com
Authorization: 2jDzkKTIf0Dsk1OzTYIIK+ImIcNhPTEyNTI0NDg3MDMmaz1BS0lEMTVJc3NraUJRS1RaYkFvNldoZ2NCcVZsczlTbXVHMDAmZT0xNTAzMzE2MzY0JnQ9MTUwMzMxNjE4NCZyPTE3ODgwJmY9JmI9bGV3enlsdTAy
Content-Type: application/json
Content-Length: 29

{"op":"create","biz_attr":""}
```

### 响应
```
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 110
Connection: keep-alive
Date: Mon, 21 Aug 2017 11:50:30 GMT
Server: tencent-cos
x-cos-request-id: NTk5YWM5MDZfNjIyNWI2NF8xOWQxXzE0NWY4

{"code":0,"message":"SUCCESS","request_id":"NTk5YWM5MDZfNjIyNWI2NF8xOWQxXzE0NWY4","data":{"ctime":1503316230}}
```




