## 功能描述
使用 API 进行文件的复制操作。“请求地址”中的参数为源文件的位置，“请求内容”中的参数 dest_fileid 指明复制至的目标路径（以及新的文件名）。使用该API 接口前请确认该文件已存在，且目标目录也已存在。
>**注意：**
>当复制文件 A 至目标目录时，若目标目录下存在与 A 同名的文件，则请求中的 to_over_write 将决定是否覆盖该同名文件。若选择覆盖，则复制操作成功，若选择不覆盖，则复制操作失败。

## 请求
语法示例：
```
POST http://gz.file.myqcloud.com/files/v2/12xxxxx/iaxxx/cos-test.dat HTTP/1.1
Host: <Region>.file.myqcloud.com
Authorization: <MultiEffectSignature>
Content-Type: multipart/form-data
Content-Length: <ContentLength>
```

> Authorization: &lt;MultiEffectSignature&gt; 多次有效签名（详细参见 [签名算法](https://cloud.tencent.com/document/product/436/6054) 章节）
> Content-Length: &lt;ContentLength&gt; RFC 2616 中定义的 HTTP 请求内容长度（字节）

### 请求参数
该请求的请求参数为空。

### 请求体
该请求的请求体如下：
```
HTTP/1.1 100 Continue
------------------------------e492f6322ce5
Content-Disposition: form-data; name="op"
copy
------------------------------e492f6322ce5
Content-Disposition: form-data; name="dest_fileid"
rabbit.txt.bak
------------------------------e492f6322ce5

```
节点参数具体描述如下：

|参数名称|描述|类型|必选|
|----|-----|-----|----|
|op	|操作类型，填 “copy”	|String	|是|
|dest_fileid	|目标路径（不带路径则为当前路径下，带路径则会复制到携带指定的路径下）	|String	|是|


## 响应

### 响应体

该响应体返回为 **application/json** 数据，包含完整节点数据的内容展示如下：
``` 
    {
		"code":0,
		"message":"SUCCESS",
		"request_id":"NTliODljYzVfMWNiMjk0MGFfNGFF8xNWJjNGE="
		}
 
```
具体的参数描述如下：

|参数名称|描述|类型|
|---|-- |--|
| code     |服务端返回码，如果没有发生任何错误取值为**0**；如果发生错误该参数指称具体的错误码。COS服务相关的错误码可以查看 [COS 错误码汇总](https://cloud.tencent.com/document/product/436/8432) |  Number   | 
| message  |服务端提示内容，如果发生错误该字段将详细描述发生错误的情况。  |  String | 
|request_id| 该请求的唯一标识 id |String  | 


## 实际案例

### 请求
``` 
POST http://gz.file.myqcloud.com/files/v2/12xxxxx/iaxxx/cos-test.dat HTTP/1.1
Authorization: cDauJMRC/rtg2zGUvW+NbdFXyCVhPTE1Nzcmaz1BS0lEem9RbXNrVG9oUHVJVVJUYW5uWDBEQXNLWllIcWxDelomZT0xNTA3ODYyOTczJnQ9MTUwNTI3MDk3MyZyPTgwODg0NjQ0NyZmPSZiPWlhaW55dQ==
Host: gz.file.myqcloud.com
Content-Length: 278
Content-Type: multipart/form-data; boundary=----------------------------e492f6322ce5

HTTP/1.1 100 Continue
------------------------------e492f6322ce5
Content-Disposition: form-data; name="op"
copy
------------------------------e492f6322ce5
Content-Disposition: form-data; name="dest_fileid"
rabbit.txt.bak
------------------------------e492f6322ce5
```

### 响应
```
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 86
Date: Wed, 13 Sep 2017 02:49:41 GMT
Server: tencent-cos
x-cos-request-id: NTliODljYzVfMWNiMjk0MGFfNGFlNF8xNWJjNGE=
X-Cache: MISS from SK-SQUIDDEV-107
X-Cache-Lookup: MISS from SK-SQUIDDEV-107:8080

{
	"code":0,
	"message":"SUCCESS",
	"request_id":"NTliODljYzVfMWNiMjk0MGFfNGFF8xNWJjNGE="
}
```
