## 功能描述
当初始化分片上传返回 -4019 错误的时候，您需调用此接口查询分片的断点和 session，进行续传操作。
使用该接口前请确认对应上传目录已存在，且已获得分片上传所需参数（session 和 slice_size）。
>**注意：**
>使用 API 对大于 20 MB 的文件进行逐片上传之前，需要先使用「初始化分片上传」API，从腾讯云获取到分片上传所需的参数（session 和 slice_size）。

#### 使用分片上传方式上传文件流程：
**第一步：**发送「初始化分片上传」请求。
**第二步：**腾讯云会判断文件的上传状态，若未完成上传，会返回 -4019 错误，用户需调用查询上传分片接口查询已经上传完的分片，并进行断点续传的操作；若文件从未传输过，则返回用户上传的 session。
**第三步：**设置 session 和 offset 参数，构造「逐个分片上传」请求，逐片上传后续文件。
**第四步：**循环执行第三步直到文件的分片数据上传完成。
**第五步：** 调用 finish 接口结束分片上传。

## 请求
语法示例：
```
POST http://gz.file.myqcloud.com/files/v2/12xxxxx/iaxxx/sample_file.txt HTTP/1.1
Host: <Region>.file.myqcloud.com
Authorization: <MultiEffectSignature>
Content-Type: multipart/form-data
Content-Length: <ContentLength>
```
> Authorization: &lt;MultiEffectSignature&gt; 多次有效签名（详细参见 [签名算法](https://cloud.tencent.com/document/product/436/6054) 章节）
> Content-Length: &lt;ContentLength&gt; RFC 2616 中定义的 HTTP 请求内容长度（字节）

### 请求参数
该请求的请求参数为空。

### 请求体
该请求的请求体如下：
```
---------------29035c
Content-Disposition: form-data; name="op"
upload_slice_list
--------------29035c--

```
节点参数具体描述如下：

|参数名称|描述|类型|必选|
|----|-----|-----|----|
|op	|操作类型，填 “upload_slice_list”	|String	|是|


## 响应

### 响应体

该响应体返回为 **application/json** 数据，包含完整节点数据的内容展示如下：
``` 
{
    "code": 0,
    "message": "SUCCESS",
    "request_id": "NTliODllYTZfYzlhMzNfM2E1Nl8xNTY4ZjE=",
    "data": {
        "filesize": 10485760,
        "listparts": [],
        "session": "85bac5e25b873ec432f945a3edd0965dc38ba4a73a4f2b6376e32e47836a732c5ae7dc",
        "slice_size": 1048576
    }
}
```
具体的参数描述如下：

| 参数名称 | 描述     | 类型 |
|------|------|------|
| code     |服务端返回码，如果没有发生任何错误取值为**0**；如果发生错误该参数指称具体的错误码。COS 服务相关的错误码可以查看 [COS 错误码汇总](https://cloud.tencent.com/document/product/436/8432) |  Number   |
|request_id| 该请求的唯一标识 id |String  | 
| message  |服务端提示内容，如果发生错误该字段将详细描述发生错误的情况。  |  String | 
| data     |服务端返回的应答数据，该内容代表了接口返回的具体的业务数据。 |  Object   | 

data 数据集参数描述：

|参数名称|描述|类型|
|---|-- |--|
|filesize|文件大小 | Number	|
|listparts|完全上传的文件分片信息 |	String |
|session	|唯一标识此文件传输过程的 id，命中秒传则不携带 |String	|
|slice_size |分片大小，单位为 Byte。<br>有效值：524288 (512 KB), 1048576 (1 MB), 2097152 (2 MB), 3145728 (3 MB)  | Number	|

## 实际案例

### 请求
``` 
POST http://gz.file.myqcloud.com/files/v2/12xxxxx/iaxxx/sample_file.txt HTTP/1.1
Host: gz.file.myqcloud.com
Authorization: M1PHV1ommktL9npRdcG/Ey8dGzFhPTEyNTg1NzcWlhaW55dQ==
Content-Length: 152
Content-Type: multipart/form-data; boundary=----------------------------2b804029035c

------------------------------2b804029035c
Content-Disposition: form-data; name="op"
upload_slice_list
------------------------------2b804029035c--

```

### 响应
```
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 356
Date: Wed, 13 Sep 2017 02:57:42 GMT
Server: tencent-cos
x-cos-request-id: NTliODllYTZfYzlhMzNfM2E1Nl8xNTY4ZjE=
X-Cache: MISS from SK-SQUIDDEV-107
X-Cache-Lookup: MISS from SK-SQUIDDEV-107:8080

{
    "code": 0,
    "message": "SUCCESS",
    "request_id": "NTliODllYTZfYzlhMzNfM2E1Nl8xNTY4ZjE=",
    "data": {
        "filesize": 10485760,
        "listparts": [],
        "session": "85bac5e25b873ec432f945a3edd0961a4a73a4f2b6376e32e47836a732c5ae7dc",
        "slice_size": 1048576
    }
}

```
