## 功能描述
使用该 API 查询目录的属性信息，包括：目录名、目录属性、创建时间、修改时间。使用该接口前请确认该目录已存在，如果 Bucket 中没有目录则请求不成功。

## 请求
语法示例：
```
GET /files/v2/<APPID>/<BucketName>/<DirName>/?op=stat HTTP/1.1
Host: <Region>.file.myqcloud.com
Authorization: <MultiEffectSignature>
```

> Authorization: &lt;MultiEffectSignature&gt; 多次有效签名（详细参见 [签名算法](https://cloud.tencent.com/document/product/436/6054) 章节）

### 请求参数
该请求的请求参数和描述如下：

|参数名称|描述|类型|必选|
|----|-----|-----|----|
|op	|操作类型，填 “stat”	|String	|是|

## 响应

### 响应体

该响应体返回为 **application/json** 数据，包含完整节点数据的内容展示如下：
``` 
{ 
	"code":0,
	"message":"SUCCESS",
	"request_id":"NTlhM2U5NzJfY2JhMzNiMGFfMTRmNV81MGQ1ZWQ=",
	"data":
	{
	"biz_attr":"",
	"ctime":1503911116,
	"mtime":1503911116
	}
}

```
具体的参数描述如下：

|参数名称|描述|类型|
|---|-- |--|
| code       |服务端返回码，如果没有发生任何错误取值为**0**；如果发生错误该参数指称具体的错误码。COS 服务相关的错误码可以查看 [COS 错误码汇总](https://cloud.tencent.com/document/product/436/8432) |  Number   | 
| message    |服务端提示内容，如果发生错误该字段将详细描述发生错误的情况。  |  String | 
| request_id | 该请求的唯一标识 id |String  | 
| data       |服务端返回的应答数据，该内容代表了接口返回的具体的业务数据。 |  Object   | 

data 数据集参数描述：

|参数名称|描述|类型|
|---|-- |--|
|biz_attr	|COS 服务调用方自定义属性，可通过 [查询目录属性](https://cloud.tencent.com/document/product/436/6063) 获取该属性值|String	|
|ctime	|创建时间，10 位 Unix 时间戳（UNIX时间是从协调世界时 1970 年 1 月 1 日 0 时 0 分 0 秒起的总秒数）|Number	|
|mtime	|修改时间，10 位 Unix 时间戳（UNIX时间是从协调世界时 1970 年 1 月 1 日 0 时 0 分 0 秒起的总秒数）|	Number	|

## 实际案例

### 请求
``` 
GET /files/v2/1251668577/iainyu/sample_folder/?op=stat HTTP/1.1
Host: gz.file.myqcloud.com
Authorization: XbknLMIhah4kb9VhsMqcWMrn80VhPTEyNTE2Njg1Nzcmaz1BS0lEcmJBWWpFQnFxZEVjb25wRmk4TlBFpbnl1L3NhbXBsZV9mb2xkZXIvJmI9aWFpbnl1
```

### 响应
```
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 147
Connection: keep-alive
Date: Mon, 28 Aug 2017 09:59:14 GMT
Server: tencent-cos
x-cos-request-id: NTlhM2U5NzJfY2JhMzNiMGFfMTRmNV81MGQ1ZWQ=

{ 
	"code":0,
	"message":"SUCCESS",
	"request_id":"NTlhM2U5NzJfY2JhMzNiMGFfMTRmNV81MGQ1ZWQ=",
	"data":
	{
	"biz_attr":"",
	"ctime":1503911116,
	"mtime":1503911116
	}
}
```

