## 功能描述
使用该 API 上传 1M 大小的简单文件（超过 20M 的文件，请使用“分片上传文件” API）。成功上传文件的前提条件是 Bucket 中已存在目录。如果该 Bucket 中没有文件目录则请求不成功。

## 请求
语法示例：
```
POST /files/v2/125000000/iainyu/sample_file.txt HTTP/1.1
Host: <Region>.file.myqcloud.com
Content-Type: multipart/form-data
Authorization: <MultiEffectSignature>
Content-Length: <ContentLength>
```

> Authorization: &lt;MultiEffectSignature&gt; 多次有效签名（详细参见 [签名算法](https://cloud.tencent.com/document/product/436/6054) 章节）
> Content-Length: &lt;ContentLength&gt; RFC 2616 中定义的 HTTP 请求内容长度（字节）


### 请求参数
该请求的请求体为空。<style  rel="stylesheet"> table th:nth-of-type(1) { width: 100px; }</style>

### 请求体
该请求的请求体如下：
```
--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="insertOnly"; filename="insertOnly"

--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="sha"; filename="sha"

3b71f43ff30f4b15b5cd85dd9e95ebc7e84eb5a3
--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="biz_attr"; filename="biz_attr"

--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="filecontent"; filename="filecontent"
```
节点参数具体描述如下：

|参数名称|描述|类型|必选|
|----|-----|-----|----|
|op	|操作类型，填 “upload”	|String	|是|
|filecontent|	文件内容	|Binary|是	|
|sha|	文件的 SHA-1 校验码|	String	|否|
|biz_attr|	COS 服务调用方自定义属性，可通过 [查询目录属性](https://cloud.tencent.com/document/product/436/6063) 获取该属性值	|String	|否|
|sha|	文件的 SHA-1 校验码|	String	|否|
| insertOnly |	同名文件覆盖选项，有效值：0 覆盖（删除已有的重名文件，存储新上传的文件）1 不覆盖（若已存在重名文件，则不做覆盖，返回“上传失败”; 若新上传文件sha值与已存在重名文件相同，返回成功）。默认为 1 不覆盖。|	Int	|否|

## 响应

### 响应体

该响应体返回为 **application/json** 数据，包含完整节点数据的内容展示如下：
```
{
	"code":0,
 	"message":"SUCCESS",
	 "request_id":"NTlhNDBhZGVfOTYyMjViNjRfMTc3Ml8yYWQ5NWU=",
	 "data":
 	{
 	"access_url":"http://iainyu-1251668577.file.myqcloud.com/sample_file.txt",
	 "resource_path":"/1251668577/iainyu/sample_file.txt",
	 "source_url":"http://iainyu-1251668577.cosgz.myqcloud.com/sample_file.txt",
 	"url":"http://gz.file.myqcloud.com/files/v2/1251668577/iainyu/sample_file.txt","vid":"dce2a8d7ba11d045c0e19019fab807911503922910"
	 }
}
```
具体的参数描述如下：

|参数名称|描述|类型|
|---|-- |--|--|
| code     |服务端返回码，如果没有发生任何错误取值为**0**；如果发生错误该参数指称具体的错误码。COS服务相关的错误码可以查看 [COS 错误码汇总](https://cloud.tencent.com/document/product/436/8432) |  Number   | 
| message  |服务端提示内容，如果发生错误该字段将详细描述发生错误的情况。  |  String | 
|request_id| 该请求的唯一标识 id |String  |
| data     |服务端返回的应答数据，该内容代表了接口返回的具体的业务数据。 |  Object   | 

data 数据集参数描述：

|参数名称|描述|类型|
|---|-- |--|--|
| access_url | 通过 CDN 访问该文件的资源链接（访问速度更快） | String | 
| resource_path | 该文件在 COS 中的相对路径名，可作为其 ID 标识。 格式` /<APPID>/<BucketName>/<ObjectName>`。推荐业务端存储 resource_path，然后根据业务需求灵活拼接资源 url（通过 CDN 访问 COS 资源的 url 和直接访问 COS 资源的 url 不同）。| String | 
| source_url | （不通过 CDN）直接访问 COS 的资源链接| String |  
| url | 操作文件的 url 。业务端可以将该 url 作为请求地址来进一步操作文件，对应 API ：文件属性、更新文件、删除文件、移动文件中的请求地址。|String|  

>说明：腾讯云 COS 会默认为每个资源生成经 CDN 的访问链接 access_url，当业务端尚未开通 CDN 时，仍然可以获得该链接，但是无法访问。

## 实际案例

### 请求
```
POST /files/v2/1251668577/iainyu/sample_file.txt HTTP/1.1
Host: gz.file.myqcloud.com
Connection: keep-alive
Accept-Encoding: gzip, deflate
Accept: */*
User-Agent: cos-python-sdk-v4
Authorization: KJoSAJ9YFXGIGzLfuUSdsPKhJ2JhPTEyNTE2Njg1Nzcmaz1BS0lEcmJBWWpFQnFxZEVjb25wRmk4TlBGc09qcm5YNExZVUUmZT0xNTAzOTIzMjEwJnQ9MTUwMzkyMjkxMCZyPTY4Mjk2MTA2OCZmPS8xMjUxNjY4NTc3L2lhaW55dS9zYW1wbGVfZmlsZS50eHQmYj1pYWlueXU=
Content-Length: 1049199
Content-Type: multipart/form-data; boundary=6815dbc897af4706bd5a39f49b157928

--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="insertOnly"; filename="insertOnly"

--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="sha"; filename="sha"

3b71f43ff30f4b15b5cd85dd9e95ebc7e84eb5a3
--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="biz_attr"; filename="biz_attr"

--6815dbc897af4706bd5a39f49b157928
Content-Disposition: form-data; name="filecontent"; filename="filecontent"
```

### 响应
```
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 427
Connection: keep-alive
Date: Mon, 28 Aug 2017 12:21:50 GMT
Server: tencent-cos
x-cos-request-id: NTlhNDBhNmZfY2JhMzNiMGFfMTUwMV80ZjI1YTA=

{"code":0,
 "message":"SUCCESS",
 "request_id":"NTlhNDBhZGVfOTYyMjViNjRfMTc3Ml8yYWQ5NWU=",
 "data":
 {
 "access_url":"http://iainyu-1251668577.file.myqcloud.com/sample_file.txt",
 "resource_path":"/1251668577/iainyu/sample_file.txt",
 "source_url":"http://iainyu-1251668577.cosgz.myqcloud.com/sample_file.txt",
 "url":"http://gz.file.myqcloud.com/files/v2/1251668577/iainyu/sample_file.txt","vid":"dce2a8d7ba11d045c0e19019fab807911503922910"
 }
}

```




