## 描述

使用 API 对大于 20 MB 的文件进行分片上传之前，需要先使用本 API 创建「分片上传会话」，即得到此次上传的 session。

前置条件：指定目录已存在。

**分片上传使用流程说明**

1. 发送「初始化分片上传」请求。
2. 腾讯云会判断文件的上传状态，若未完成上传，会返回-4019错误，用户需调用查询上传分片接口查询已经上传完的分片，并进行断点续传的操作；若文件从未传输过，则返回用户上传的session。
3. 设置 session 和 offset 参数，构造「逐个分片上传」请求，逐片上传后续文件。
4. 循环执行第 3 步直到文件的分片数据上传完成。
5. 调用finish接口结束分片上传。

## 请求

### 请求语法

``` http
POST /files/v2/<appid>/<bucket_name>[/dir_name]/<file_name>  HTTP/1.1
Host: <Region>.file.myqcloud.com
Content-Type: multipart/form-data
Authorization: <multi_effect_signature>
```

说明：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

### 请求内容

| **参数名称**   | **必选** | **类型** | **描述**                                   |
| ---------- | ------ | ------ | ---------------------------------------- |
| op         | 是      | String | 操作类型，填"upload_slice_init"                     |
| filesize   | 是      | Int 64 | 文件总大小，单位为 Byte                           |
| slice_size | 是      | Int 64 | 分片大小，单位为 Byte。<br />有效值：524288 (512 KB), 1048576 (1 MB), 2097152 (2 MB), 3145728 (3 MB) |
| biz_attr    | 否      | String | 文件属性，业务端维护                               |
| insertOnly | 否      | Int    | 同名文件是否覆盖。<br />有效值：<br />0 覆盖（删除已有的重名文件，存储新上传的文件）<br />1 不覆盖（若已存在重名文件，则不做覆盖，返回上传失败）。<br />**不填此参数，默认不覆盖。** |

## 返回

### 返回内容

| **参数名称** | **必选** | **类型** | **描述**     |
| -------- | ------ | ------ | ---------- |
| code     | 是      | Int    | 服务端返回码     |
| message  | 是      | String | 服务端提示内容    |
| data     | 是      | 数据集合   | 服务器返回的应答数据 |

data 数据集合：

| 参数名称          | 必选   | 类型     | 描述                                       |
| ------------- | ---- | ------ | ---------------------------------------- |
| session       | 否    | String | 唯一标识此文件传输过程的 id，命中秒传则不携带                 |
| slice_size    | 否    | Int    | 分片大小，单位为 Byte。<br />有效值：524288 (512 KB), 1048576 (1 MB), 2097152 (2 MB), 3145728 (3 MB) |

## 示例

### 初始化请求

此示例呈现了一个正常的初始化分片上传的请求和返回，对象存储系统中没有相同的文件，即没有命中秒传。

#### 请求

``` http
POST /files/v2/10055004/accesslog/testfolder/111.txt HTTP/1.1
Host: sh.file.myqcloud.com
Authorization: JAVEi4cbYHm5cqGpUp96HKP+JXNhPTEwMDU1MDA0Jms9QUtJRHpuOHd3S3VYanhpeFFBa1JCQzJEUlhCdFBkN0NybEpRJmU9MTQ3MjY0Nzc4MCZ0PTE0NzI2NDc2MDAmcj00NjQ3OTQxODkmZj0mYj1hY2Nlc3Nsb2c=
Method:POST
Content-Length: 361
Content-Type: multipart/form-data; boundary=----------------------------f43b7cf5bf1b

------------------------------f43b7cf5bf1b
Content-Disposition: form-data; name="op"

upload_slice_init
------------------------------f43b7cf5bf1b
Content-Disposition: form-data; name="filesize"

36864
------------------------------f43b7cf5bf1b
Content-Disposition: form-data; name="slice_size"

524288
------------------------------f43b7cf5bf1b--
```

#### 返回

``` http
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 168
Date: Wed Aug 31 20:46:40 2016
Server: tencent-cos

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "session": "58ccd1b3120e85c4ebb7b786154408df4fe22230cb8f328d41599b237661855d6242793ba2481c1ac0b1277051003cab", 
        "slice_size": 524288
    }
}
```

至此，请求者获取到 session可继续进行「逐个分片上传」。
