## 描述

使用 API 查询文件的属性信息，包括文件大小、文件 SHA-1 校验码、文件创建时间、修改时间、访问权限、自定义头部信息等。

前置条件：该文件已存在。

## 请求

### 请求语法

``` http
GET /files/v2/<appid>/<bucket_name>[/dir_name]/<file_name>?op=stat HTTP/1.1
Host: <Region>.file.myqcloud.com
Authorization: <multi_effect_signature>
```

说明：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

## 返回

### 返回内容

| **参数名称** | **必选** | **类型** | **描述**     |
| -------- | ------ | ------ | ---------- |
| code     | 是      | Int    | 服务端返回码     |
| message  | 是      | String | 服务端提示内容    |
| data     | 否      | 数据集合   | 服务器返回的应答数据 |

data 数据集合：

| 参数名称           | 必选   | 类型     | 描述                                       |
| -------------- | ---- | ------ | ---------------------------------------- |
| biz_attr       | 是    | Int    | 文件属性，业务端维护                               |
| filesize       | 是    | Int    | 文件大小                                     |
| sha            | 是    | String | 文件 SHA-1 校验码                             |
| ctime          | 是    | String | 创建时间，10 位 Unix 时间戳                       |
| mtime          | 是    | String | 修改时间，10 位 Unix 时间戳                       |
| access_url     | 是    | String | 通过 CDN 访问该文件的资源链接                        |
| source_url     | 是    | String | （不通过 CDN ）直接访问 COS 的资源链接                 |
| authority      | 否    | String | Object 的权限，默认与 Bucket 权限一致，此时不会返回该字段。<br />如果设置了独立权限，则会返回该字段。<br />有效值：<br />eInvalid 空权限，此时系统会默认调取 Bucket 权限<br >eWRPrivate 私有读写<br />eWPrivateRPublic 公有读私有写 |
| custom_headers | 否    | 数据集合   | 用户自定义头部                                  |

custom_headers 数据集合：

| **参数名称**            | 必选   | 类型     | 描述          |
| ------------------- | ---- | ------ | ----------- |
| Cache-Control       | 否    | String | 文件的缓存机制     |
| Content-Type        | 否    | String | 文件的 MIME 信息 |
| Content-Disposition | 否    | String | MIME 协议的扩展  |
| Content-Language    | 否    | String | 文件的语言       |
| Content-Encoding    | 否    | String | 文件的加密格式     |
| x-cos-meta-自定义内容    | 否    | String | 自定义内容       |

## 示例

#### 请求

``` http
GET /files/v2/10055004/accesslog/testfolder/111.txt?op=stat HTTP/1.1
Host: sh.file.myqcloud.com
Authorization: QVZWK/lxpiMoz+ArZH9Hny7IvDZhPTEwMDU1MDA0Jms9QUtJRHpuOHd3S3VYanhpeFFBa1JCQzJEUlhCdFBkN0NybEpRJmU9MTQ3MjY0NjAzOCZ0PTE0NzI2NDU4NTgmcj0yODU2NDU2NDcmZj0mYj1hY2Nlc3Nsb2c=
```

#### 返回

``` http
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 576
Date: Wed Aug 31 20:17:38 2016
Server: tencent-cos

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "access_url": "http://accesslog-10055004.file.myqcloud.com/testfolder/111.txt", 
        "authority": "eWPrivateRPublic", 
        "biz_attr": "", 
        "ctime": 1472645858, 
        "custom_headers": {
            "Cache-Control": "no", 
            "Content-Language": "ch", 
            "Content-Type": "application/pdf"
        }, 
        "filelen": 21, 
        "filesize": 21, 
        "forbid": 0, 
        "mtime": 1472645858, 
        "preview_url": "http://accesslog-10055004.preview.myqcloud.com/testfolder/111.txt?cmd=txt_preview", 
        "sha": "1fe86826617c3a32da4f06bccc71a2a718b274c6", 
        "slicesize": 21, 
        "source_url": "http://accesslog-10055004.cossh.myqcloud.com/testfolder/111.txt"
    }
}
```