## 描述

使用 API 列出指定目录下的所有文件目录，可带前缀查询，只支持向后翻页。

前置条件：目录已存在。

说明：在返回内容中不包含 biz_attr 字段，如需查询，请调用查询目录属性接口。

## 请求

### 请求语法

``` http
GET <Request_URL>?op=list&num=<Int64>  HTTP/1.1
Host: <Region>.file.myqcloud.com 
Authorization: <multi_effect_signature>
```

请求地址 **Request_URL** 示例

直接查询 bucket 目录下所有文件和目录：

`sh.file.myqcloud.com/files/v2/<appid>/<bucket_name>/`

查询指定 bucket 中文件夹 dir_name 下的文件和目录：

`sh.file.myqcloud.com/files/v2/<appid>/<bucket_name>/<dir_name>/`

带前缀的查询：

`sh.file.myqcloud.com/files/v2/<appid>/<bucket_name>/<dir_name>/[prefix]`

**说明**：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

对于Request_URL，带前缀查询时，[prefix] 末尾无 ‘ / ’ 。

### 请求参数

| 参数名称    | **必选** | **类型** | **描述**                                   |
| ------- | ------ | ------ | ---------------------------------------- |
| op      | 是      | String | 操作类型，填 ”list”                            |
| num     | 是      | Int    | 本次查询所要列出的目录总数,最大支持1000                   |
| context | 否      | String | 透传字段，从响应的返回内容中得到。若查看第一页，则将空字符串作为 context 传入。若需要翻页，需要将前一页返回内容中的 context 透传到参数中。 |

## 返回

### 返回内容

| 参数名称    | **必选** | **类型** | **描述**     |
| ------- | ------ | ------ | ---------- |
| code    | 是      | Int    | 服务端返回码     |
| message | 是      | String | 服务端提示内容    |
| data    | 是      | 数据集合   | 服务器返回的应答数据 |

其中的 data 数据集合：

| 参数名称     | 必选   | 类型     | 描述                                 |
| -------- | ---- | ------ | ---------------------------------- |
| context  | 是    | String | 透传字段，用于翻页，业务端不需理解，需要往后翻页则透传给腾讯云    |
| listover | 是    | Bool   | 是否有内容可以继续往后翻页                      |
| infos    | 是    | 数据集合   | 文件和文件夹列表，若当前目录下不存在文件或文件夹，则该返回值可能为空 |

其中的 infos 数据集合：

| 参数名称       | 必选   | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| name       | 是    | String | 文件名                                      |
| filesize   | 否    | Int    | 文件大小，当类型为文件时返回                           |
| filelen    | 否    | Int    | 文件已传输大小，当类型为文件时返回                        |
| sha        | 否    | String | 文件 sha，当类型为文件时返回                         |
| ctime      | 是    | Number | 创建时间，10位 Unix 时间戳                        |
| mtime      | 是    | Number | 修改时间，10位 Unix 时间戳                        |
| access_url | 否    | String | 生成的资源可访问的cdn url，当类型为文件时返回               |
| authority  | 否    | String | 如果没有对文件单独设置该属性，则可能不会返回该字段。返回值：eInvalid（表示继承 bucket 的读写权限）；eWRPrivate（私有读写）；eWPrivateRPublic（公有读私有写）。说明：文件可以和 bucket 拥有不同的权限类型，已经设置过权限的文件如果想要撤销，将会直接被赋值为 eInvalid，即继承 bucket 的权限 |
| source_url | 否    | String | 生成的资源可访问的源站 url，当类型为文件时返回                |

## 示例

#### 请求

``` http
GET /files/v2/10055004/accesslog/aaa/bbb/?op=list&order=0&num=5 HTTP/1.1
Host: sh.file.myqcloud.com
Authorization: F/mImHxxGlI5A7lLYnGa8aBtK6thPTEwMDU1MDA0Jms9QUtJRHpuOHd3S3VYanhpeFFBa1JCQzJEUlhCdFBkN0NybEpRJmU9MTQ3MjY0MDIwNiZ0PTE0NzI2NDAwMjYmcj03OTUxNzkyMCZmPSZiPWFjY2Vzc2xvZw==
```

#### 返回

``` http
HTTP/1.1 200 OK
Content-Type: application/json; charset=utf-8
Content-Length: 2502
Date: Wed Aug 31 18:40:26 2016
Server: tencent-cos

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "context": "/accesslog/aaa/bbb/14709104920.89088300.txt", 
        "infos": [
            {
                "access_url": "http://accesslog-10055004.file.myqcloud.com/aaa/bbb/14709104920.63503400.txt", 
                "authority": "eInvalid", 
                "ctime": 1470910492, 
                "filelen": 10264, 
                "filesize": 10264, 
                "mtime": 1470910492, 
                "name": "14709104920.63503400.txt", 
                "preview_url": "http://accesslog-10055004.preview.myqcloud.com/aaa/bbb/14709104920.63503400.txt?cmd=txt_preview", 
                "sha": "cad7d66231fa548b2e5b5f431fcf8f1bf028d0b0", 
                "source_url": "http://accesslog-10055004.cossh.myqcloud.com/aaa/bbb/14709104920.63503400.txt"
            }, 
            {
                "access_url": "http://accesslog-10055004.file.myqcloud.com/aaa/bbb/14709104920.71280700.txt", 
                "authority": "eInvalid", 
                "ctime": 1470910492, 
                "filelen": 10264, 
                "filesize": 10264, 
                "mtime": 1470910492, 
                "name": "14709104920.71280700.txt", 
                "preview_url": "http://accesslog-10055004.preview.myqcloud.com/aaa/bbb/14709104920.71280700.txt?cmd=txt_preview", 
                "sha": "4ba80f5c809954e93b97de3a3bb0950f6374bdf7", 
                "source_url": "http://accesslog-10055004.cossh.myqcloud.com/aaa/bbb/14709104920.71280700.txt"
            }, 
            {
                "access_url": "http://accesslog-10055004.file.myqcloud.com/aaa/bbb/14709104920.77835100.txt", 
                "authority": "eInvalid", 
                "ctime": 1470910492, 
                "filelen": 10264, 
                "filesize": 10264, 
                "mtime": 1470910492, 
                "name": "14709104920.77835100.txt", 
                "preview_url": "http://accesslog-10055004.preview.myqcloud.com/aaa/bbb/14709104920.77835100.txt?cmd=txt_preview", 
                "sha": "2130bd5f70e0da1a50e9ad70907f5d694ad88bb4", 
                "source_url": "http://accesslog-10055004.cossh.myqcloud.com/aaa/bbb/14709104920.77835100.txt"
            }, 
            {
                "access_url": "http://accesslog-10055004.file.myqcloud.com/aaa/bbb/14709104920.83866400.txt", 
                "authority": "eInvalid", 
                "ctime": 1470910492, 
                "filelen": 10264, 
                "filesize": 10264, 
                "mtime": 1470910492, 
                "name": "14709104920.83866400.txt", 
                "preview_url": "http://accesslog-10055004.preview.myqcloud.com/aaa/bbb/14709104920.83866400.txt?cmd=txt_preview", 
                "sha": "1f47ec790b23c950869449309797737e39f1cb92", 
                "source_url": "http://accesslog-10055004.cossh.myqcloud.com/aaa/bbb/14709104920.83866400.txt"
            }, 
            {
                "access_url": "http://accesslog-10055004.file.myqcloud.com/aaa/bbb/14709104920.89088300.txt", 
                "authority": "eInvalid", 
                "ctime": 1470910492, 
                "filelen": 10264, 
                "filesize": 10264, 
                "mtime": 1470910493, 
                "name": "14709104920.89088300.txt", 
                "preview_url": "http://accesslog-10055004.preview.myqcloud.com/aaa/bbb/14709104920.89088300.txt?cmd=txt_preview", 
                "sha": "afe17bb32c0835e8b9ce69450f95e3e6f2af4606", 
                "source_url": "http://accesslog-10055004.cossh.myqcloud.com/aaa/bbb/14709104920.89088300.txt"
            }
        ], 
        "listover": false
    }
}
```