## 描述

腾讯云对象存储的 RESTful API 请求结构如下表：

| 参数名称         | 必选   | 类型     | 描述                        |
| ------------ | ---- | ------ | ------------------------- |
| Version      | 是    | String | HTTP 版本                   |
| URL          | 是    | String | HTTP 请求地址，总长度不得超过 1024 字节 |
| Header       | 是    | 数据集合   | HTTP 请求头部                 |
| Http Method  | 是    | String | HTTP 请求方法，常用 GET 或 POST   |
| Request Body | 否    | json   | HTTP 请求正文                 |

URL 请求地址格式举例：

``` 
<Region>.file.myqcloud.com/files/v2/<appid>/<bucket_name>[/dir_name/<file_name>]
```

说明：

Region：所在地域，枚举值为 [可用地域](https://cloud.tencent.com/document/product/436/6224) 中适用于 JSON API 的地域简称，如 sh, gz, sgp 等。

appid：数字，在腾讯云对象存储 Web 控制台中，创建项目后得到 appid，用于唯一标识某个项目。

bucket_name：字母和数字的组合串。对应某个项目下的 bucket 名称。

<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数，具体要求以各 API 文档为准。

Header 结构：

| **参数名称**       | **必选** | **类型** | **描述**                                   |
| -------------- | ------ | ------ | ---------------------------------------- |
| Host           | 是      | String | 文件云服务器域名，形式为 <Region>.file.myqcloud.com ，其中 Region 为 [可用地域](https://cloud.tencent.com/document/product/436/6224) 中适用于 JSON API 的地域简称，如：sh.file.myqcloud.com , sgp.file.myqcloud.com 等。      |
| Authorization  | 是      | String | 用户的有效签名，用于鉴权。对应***签名鉴权*** 中得到的 sign 字符串  |
| Content-Type   | 是      | String | 按要求填 application/json 或 multipart/form-data |
| Content-Length | 是      | Int    | 请求长度，单位：字节                               |

## 示例

#### 请求

```http
POST /files/v2/10000202/buckettest/foldertest/  HTTP/1.1
Host: sh.file.myqcloud.com
Content-Type: application/json
Content-Length: 15
Authorization: 1k2i3/EXIiTDirFg9DoKgWNHc4JhPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MTQ2NTg3NTU0OSZ0PTE0NjU4NzUzNjkmcj03MTI5NDYyMzQmZj0mYj1qb25ueHU1

{
    "op": "create"
}
```

