## 描述

使用 API 对大于 20 MB 的文件进行分片上传之前，需要先使用本 API 创建「分片上传会话」，即得到此次上传的 session。

前置条件：指定目录已存在。

**分片上传使用流程说明**

1. 发送「初始化分片上传」请求。
2. 腾讯云会根据文件 SHA-1 校验值判断「秒传」状态。若成功匹配则返回该文件的 URL，秒传完成；若失败，则需要进行分片上传流程，腾讯云会将分片上传所需的参数（session 和 offset）返回给请求者。
3. 设置 session 和 offset 参数，构造「逐个分片上传」请求，逐片上传后续文件。
4. 循环执行第 3 步直到文件上传完成，在最后一个分片完成时，接口将会返回完整的文件信息。

## 请求

### 请求语法

``` http
POST /files/v1/<appid>/<bucket_name>[/dir_name]/<file_name>  HTTP/1.1
Host: web.file.myqcloud.com
Content-Type: multipart/form-data
Authorization: <multi_effect_signature>
```

说明：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

### 请求内容

| **参数名称**   | **必选** | **类型** | **描述**                                   |
| ---------- | ------ | ------ | ---------------------------------------- |
| op         | 是      | String | 操作类型，填"upload_slice"                     |
| filesize   | 是      | Int 64 | 文件总大小，单位为 Byte                           |
| sha        | 是      | String | 文件的 SHA-1 校验码                           |
| slice_size | 是      | Int 64 | 分片大小，单位为 Byte。<br />有效值：524288 (512 KB), 1048576 (1 MB), 2097152 (2 MB), 3145728 (3 MB) |
| insertOnly | 否      | Int    | 同名文件是否覆盖。<br />有效值：<br />0 覆盖（删除已有的重名文件，存储新上传的文件）<br />1 不覆盖（若已存在重名文件，则不做覆盖，返回上传失败）。<br />**不填此参数，默认不覆盖。** |

## 返回

### 返回内容

| **参数名称** | **必选** | **类型** | **描述**     |
| -------- | ------ | ------ | ---------- |
| code     | 是      | Int    | 服务端返回码     |
| message  | 是      | String | 服务端提示内容    |
| data     | 是      | 数据集合   | 服务器返回的应答数据 |

data 数据集合：

| 参数名称          | 必选   | 类型     | 描述                                       |
| ------------- | ---- | ------ | ---------------------------------------- |
| session       | 否    | String | 唯一标识此文件传输过程的 id，命中秒传则不携带                 |
| offset        | 否    | Int64  | 开始传输的位移，命中秒传则不携带                         |
| slice_size    | 否    | Int    | 分片大小，单位为 Byte。<br />有效值：524288 (512 KB), 1048576 (1 MB), 2097152 (2 MB), 3145728 (3 MB) |
| access_url    | 否    | String | 生成的文件下载 url，命中秒传时携带                      |
| url           | 否    | String | 操作文件的 url，命中秒传时携带                        |
| resource_path | 否    | String | 资源路径格式，格式为 /appid/bucket/xxx，命中秒传时携带     |

## 示例

### 初始化请求

此示例呈现了一个正常的初始化分片上传的请求和返回，对象存储系统中没有相同的文件，即没有命中秒传。

#### 请求

``` http
POST http://web.file.myqcloud.com/files/v1/10000202/buckettest/foldertest/test_slice_upload.pptx  HTTP/1.1
Authorization: HwioEOF7cLldzfnmWesQTFC+itlhPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MTQ2NTg3NTU1NCZ0PTE0NjU4NzUzNzQmcj0xMjIwMTAwOTYzJmY9JmI9am9ubnh1NQ==
Content-Type: multipart/form-data; boundary=---------------8d39448177b638c
Host: web.file.myqcloud.com
Content-Length: 621

-----------------8d39448177b638c

Content-Disposition: form-data; name="op"

upload_slice

-----------------8d39448177b638c

Content-Disposition: form-data; name="sha"

C463C820624B5DB23E7A801DE09063BBC0414FAA

-----------------8d39448177b638c

Content-Disposition: form-data; name="filesize"

70658912

-----------------8d39448177b638c

Content-Disposition: form-data; name="slice_size"

3145728

-----------------8d39448177b638c

Content-Disposition: form-data; name="biz_attr"



-----------------8d39448177b638c

Content-Disposition: form-data; name="insertOnly"

0

-----------------8d39448177b638c--
```

#### 返回

``` http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:36:14 GMT
Content-Type: /
Content-Length: 134

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "offset": 0, 
        "session": "0e009a57-3eb7-4f9d-a651-5f3a294e5616+CtQT49EHAA==", 
        "slice_size": 3145728
    }
}
```

至此，请求者获取到 session 和 offset，可继续进行「逐个分片上传」。

### 命中秒传的请求

此示例呈现了一个命中秒传的分片上传的请求和返回，对象存储系统中已有相同的文件（通过 SHA-1 校验）并直接返回成功，即无需再进行逐个分片上传。

#### 请求

```http
POST http://web.file.myqcloud.com/files/v1/10000202/buckettest/foldertest/test_slice_upload.pptx  HTTP/1.1
Authorization: HwioEOF7cLldzfnmWesQTFC+itlhPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MTQ2NTg3NTU1NCZ0PTE0NjU4NzUzNzQmcj0xMjIwMTAwOTYzJmY9JmI9am9ubnh1NQ==
Content-Type: multipart/form-data; boundary=---------------8d39448177b638c
Host: web.file.myqcloud.com
Content-Length: 621

-----------------8d39448177b638c

Content-Disposition: form-data; name="op"

upload_slice

-----------------8d39448177b638c

Content-Disposition: form-data; name="sha"

C463C820624B5DB23E7A801DE09063BBC0414FAA

-----------------8d39448177b638c

Content-Disposition: form-data; name="filesize"

70658912

-----------------8d39448177b638c

Content-Disposition: form-data; name="slice_size"

3145728

-----------------8d39448177b638c

Content-Disposition: form-data; name="biz_attr"



-----------------8d39448177b638c

Content-Disposition: form-data; name="insertOnly"

0

-----------------8d39448177b638c--
```

#### 返回

```http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:37:11 GMT
Content-Type: /
Content-Length: 354

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "access_url": "http://buckettest-10000202.file.myqcloud.com/foldertest/test_slice_upload.pptx", 
        "resource_path": "/foldertest/test_slice_upload.pptx", 
        "source_url": "http://buckettest-10000202.cos.myqcloud.com/foldertest/test_slice_upload.pptx", 
        "url": "http://web.file.myqcloud.com/files/v1/buckettest/foldertest/test_slice_upload.pptx"
    }
}
```
