## 描述

使用 API 对腾讯云对象存储中某个文件的属性进行设置或修改。

前置条件：该文件已存在。

说明：目前只提供了对 authority 和 custom_headers 的更新操作，在更新时需要用 flag 来决定此次操作是更新 authority 还是 custom_headers或者二者都更新。

对于自定义头部 custom_headers 中的各属性值，均由用户来定义和维护，腾讯云对象存储不负责维护其属性值是否正确有效。

## 请求

### 请求语法

``` http
POST /files/v1/<appid>/<bucket_name>[/dir_name]/<file_name>  HTTP/1.1
Host: web.file.myqcloud.com
Content-Type: application/json
Authorization: <once_signature>
```

说明：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

### 请求内容

| **参数名称**       | **必选** | **类型** | **描述**                                   |
| -------------- | ------ | ------ | ---------------------------------------- |
| op             | 是      | String | 操作类型，填”update”                           |
| flag           | 是      | Int    | 需要执行的修改操作，有效值：<br />0x40 修改 customheader 属性<br />0x80 修改 authority 属性<br />0x40 0x80 同时修改两个属性 |
| authority      | 否      | String | Object 的权限，默认与 Bucket 权限一致，此时不会返回该字段。<br />如果设置了独立权限，则会返回该字段。<br />有效值：<br />eInvalid 空权限，此时系统会默认调取 Bucket 权限<br >eWRPrivate 私有读写<br />eWPrivateRPublic 公有读私有写 |
| custom_headers | 否      | 数据集合   | 用户自定义 header，在执行更新操作时，只需填写需要增加或修改的项      |

其中，custom_headers 数据集合可以包含以下参数：

| 参数名称                | 必选   | 类型     | 描述          |
| ------------------- | ---- | ------ | ----------- |
| Cache-Control       | 否    | String | 文件的缓存机制     |
| Content-Type        | 否    | String | 文件的 MIME 信息 |
| Content-Disposition | 否    | String | MIME 协议的扩展  |
| Content-Language    | 否    | String | 文件的语言       |
| Content-Encoding    | 否    | String | 文件的编码格式     |
| x-cos-meta-自定义内容    | 否    | String | 自定义内容       |

## 返回

### 返回内容

| **参数名称** | **必选** | **类型** | **描述**  |
| -------- | ------ | ------ | ------- |
| code     | 是      | Int    | 服务端返回码  |
| message  | 是      | String | 服务端提示内容 |

## 示例

#### 请求

``` http
POST http://web.file.myqcloud.com/files/v1/10000202/buckettest/foldertest/test_upload.pptx  HTTP/1.1
Host: web.file.myqcloud.com
Content-Type: application/json
Content-Length: 235
Authorization: JRPR4MhTuiBpcb9xNS/sEyeck9BhPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MCZ0PTE0NjU4NzU0MzEmcj0xNjg4MzA5NDMwJmY9LzEwMDAwMjAyL2pvbm54dTUvZm9sZGVydGVzdC90ZXN0X3VwbG9hZC5wcHR4JmI9am9ubnh1NQ==

{
    "op": "update", 
    "authority": "eWPrivateRPublic", 
    "custom_headers": {
        "Cache-Control": "no", 
        "Content-Type": "application/pdf", 
        "Content-Disposition": "inline filename=\"QC-7677.pdf\"", 
        "Content-Language": "en", 
        "Content-Encoding": "deflate", 
        "x-cos-meta-test": "test"
    }, 
    "flag": 0x40 | 0x80,
}
```

注：0x40 | 0x80 ，flag 取值表示同时对 authority 和 custom_headers 进行更新操作

#### 返回

``` http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:37:11 GMT
Content-Type: /
Content-Length: 30

{
    "code": 0, 
    "message": "SUCCESS"
}
```
