## 描述

使用 API 查询文件的属性信息，包括文件大小、文件 SHA-1 校验码、文件创建时间、修改时间、访问权限、自定义头部信息等。

前置条件：该文件已存在。

## 请求

### 请求语法

``` http
GET /files/v1/<appid>/<bucket_name>[/dir_name]/<file_name>?op=stat HTTP/1.1
Host: web.file.myqcloud.com
Authorization: <multi_effect_signature>
```

说明：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

## 返回

### 返回内容

| **参数名称** | **必选** | **类型** | **描述**     |
| -------- | ------ | ------ | ---------- |
| code     | 是      | Int    | 服务端返回码     |
| message  | 是      | String | 服务端提示内容    |
| data     | 否      | 数据集合   | 服务器返回的应答数据 |

data 数据集合：

| 参数名称           | 必选   | 类型     | 描述                                       |
| -------------- | ---- | ------ | ---------------------------------------- |
| name           | 是    | String | 文件名                                      |
| biz_attr       | 是    | Int    | 文件属性，业务端维护                               |
| filesize       | 是    | Int    | 文件大小                                     |
| sha            | 是    | String | 文件 SHA-1 校验码                             |
| ctime          | 是    | String | 创建时间，10 位 Unix 时间戳                       |
| mtime          | 是    | String | 修改时间，10 位 Unix 时间戳                       |
| access_url     | 是    | String | 通过 CDN 访问该文件的资源链接                        |
| source_url     | 是    | String | （不通过 CDN ）直接访问 COS 的资源链接                 |
| authority      | 否    | String | Object 的权限，默认与 Bucket 权限一致，此时不会返回该字段。<br />如果设置了独立权限，则会返回该字段。<br />有效值：<br />eInvalid 空权限，此时系统会默认调取 Bucket 权限<br >eWRPrivate 私有读写<br />eWPrivateRPublic 公有读私有写 |
| custom_headers | 否    | 数据集合   | 用户自定义头部                                  |

custom_headers 数据集合：

| **参数名称**            | 必选   | 类型     | 描述          |
| ------------------- | ---- | ------ | ----------- |
| Cache-Control       | 否    | String | 文件的缓存机制     |
| Content-Type        | 否    | String | 文件的 MIME 信息 |
| Content-Disposition | 否    | String | MIME 协议的扩展  |
| Content-Language    | 否    | String | 文件的语言       |
| Content-Encoding    | 否    | String | 文件的加密格式     |
| x-cos-meta-自定义内容    | 否    | String | 自定义内容       |

## 示例

#### 请求

``` http
GET http://web.file.myqcloud.com/files/v1/10000202/buckettest/foldertest/test_upload.pptx?op=stat  HTTP/1.1
Host: web.file.myqcloud.com
Authorization: uJLmKdb5SphC2tlILDlVhj5umO5hPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MTQ2NTg3NTYxMSZ0PTE0NjU4NzU0MzEmcj03OTgyOTM4OTQmZj0mYj1qb25ueHU1
```

#### 返回

``` http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:37:11 GMT
Content-Type: /
Content-Length: 586

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "access_url": "http://buckettest-10000202.file.myqcloud.com/foldertest/test_upload.pptx", 
        "authority": "eWPrivateRPublic", 
        "biz_attr": "", 
        "ctime": "1465875373", 
        "custom_headers": {
            "Cache-Control": "no", 
            "Content-Disposition": "inline filename=\"QC-7677.pdf\"", 
            "Content-Language": "en", 
            "Content-Type": "application/pdf", 
            "x-cos-meta-test": "test"
        }, 
        "filelen": "78380", 
        "filesize": "78380", 
        "mtime": "1465875431", 
        "name": "test_upload.pptx", 
        "sha": "D80DFA67880831C3691AA1458589C6BED4423736", 
        "source_url": "http://buckettest-10000202.cos.myqcloud.com/foldertest/test_upload.pptx"
    }
}
```