## 描述

使用 API 对大于 20 MB 的文件进行逐片上传之前，需要先使用「初始化分片上传」API，从腾讯云获取到分片上传所需的参数（session 和 offset）。

前置条件：指定目录已存在，且已获得分片上传所需参数（session 和 offset）。

**分片上传使用流程说明**

1. 发送「初始化分片上传」请求。
2. 腾讯云会根据文件 SHA-1 校验值判断「秒传」状态。若成功匹配则返回该文件的 URL，秒传完成；若失败，则需要进行分片上传流程，腾讯云会将分片上传所需的参数（session 和 offset）返回给请求者。
3. 设置 session 和 offset 参数，构造「逐个分片上传」请求，逐片上传后续文件。
4. 循环执行第 3 步直到文件上传完成，在最后一个分片完成时，接口将会返回完整的文件信息。

## 请求

### 请求语法

``` http
POST /files/v1/<appid>/<bucket_name>[/dir_name]/<file_name>  HTTP/1.1
Host: web.file.myqcloud.com
Content-Type: multipart/form-data
Authorization: <multi_effect_signature>
```

说明：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

### 请求内容

| **参数名称**    | **必选** | **类型** | **描述**                        |
| ----------- | ------ | ------ | ----------------------------- |
| op          | 是      | String | 操作类型，填 “upload_slice”         |
| filecontent | 是      | Binary | 文件内容                          |
| sha         | 否      | String | 本次文件分片的 SHA-1 校验值。            |
| session     | 是      | String | 唯一标识此文件传输过程的 id，由后台下发，  调用方透传 |
| offset      | 是      | Int 64 | 本次分片位移                        |

## 返回

### 返回内容

| **参数名称** | **必选** | **类型** | **描述**     |
| -------- | ------ | ------ | ---------- |
| code     | 是      | Int    | 服务端返回码     |
| message  | 是      | String | 服务端提示内容    |
| data     | 是      | 数据集合   | 服务器返回的应答数据 |

data 数据集合：

| 参数名称          | 必选   | 类型     | 描述                                       |
| ------------- | ---- | ------ | ---------------------------------------- |
| session       | 否    | String | 唯一标识此文件传输过程的 id                          |
| offset        | 否    | Int 64 | 请求包体里的传输的位移,调用方如果用多线程等方式传输,可以用来唯一确定本次分片结果 |
| access_url    | 否    | String | 通过 CDN 访问该文件的资源链接（访问速度更快）                |
| resource_path | 否    | String | 该文件在COS中的相对路径名，可作为其 ID 标识。 格式 /appid/bucket/filename。推荐业务端存储 resource_path ，然后根据业务需求灵活拼接资源 url（通过 CDN 访问 COS 资源的 url 和直接访问 COS 资源的 url 不同）。 |
| source_url    | 否    | String | （不通过 CDN ）直接访问 COS 的资源链接                 |
| url           | 否    | String | 操作文件的 url。业务端可以将该 url 作为请求地址来进一步操作文件，对应 API：查询文件属性、更新文件、删除文件、移动文件中的请求地址。 |

说明：腾讯云对象存储会默认为每个资源生成经 CDN 的访问链接 access_url，当业务端尚未开通 CDN 时，仍然可以获得该链接，但是无法访问。

## 示例

### 逐个分片上传

#### 请求

``` http
POST http://web.file.myqcloud.com/files/v1/10000202/buckettest/foldertest/test_slice_upload.pptx HTTP/1.1
Authorization: rwgLlrlmBriWmcgWJOgyPJxxjOFhPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MTQ2NTg3NTU1NCZ0PTE0NjU4NzUzNzQmcj0xNjgzODY5NTI5JmY9JmI9am9ubnh1NQ==
Content-Type: multipart/form-data; boundary=---------------8d394481796664d
Host: web.file.myqcloud.com
Content-Length: 3146245

-----------------8d394481796664d

Content-Disposition: form-data; name="op"

upload_slice

-----------------8d394481796664d

Content-Disposition: form-data; name="session"

0e009a57-3eb7-4f9d-a651-5f3a294e5616+CtQT49EHAA==

-----------------8d394481796664d

Content-Disposition: form-data; name="offset"

0

-----------------8d394481796664d

Content-Disposition: form-data; name="fileContent"; filename="test_slice_upload.pptx"

Content-Type: application/octet-stream
```

#### 返回

``` http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:36:17 GMT
Content-Type: /
Content-Length: 113

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "offset": 3145728, 
        "session": "0e009a57-3eb7-4f9d-a651-5f3a294e5616+CtQT49EHAA=="
    }
}
```

### 最后一个分片

若发出的请求为最后一个分片，即 最后请求的 offset + 最后分片大小 = 初始化中传入的 filesize，则被认为分片上传完成。

#### 返回

``` http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:37:11 GMT
Content-Type: /
Content-Length: 354

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "access_url": "http://jonnxu5-10000202.file.myqcloud.com/foldertest/test_slice_upload.pptx", 
        "resource_path": "/foldertest/test_slice_upload.pptx", 
        "source_url": "http://jonnxu5-10000202.cos.myqcloud.com/foldertest/test_slice_upload.pptx", 
        "url": "http://web.file.myqcloud.com/files/v1/foldertest/test_slice_upload.pptx"
    }
}
```

至此，完成分片上传。



#### 

