## 描述

使用 API 列出指定目录下的所有文件目录，可带前缀查询。

前置条件：目录已存在。

说明：在返回内容中可能会包含 biz_attr 字段，用于兼容以往版本，目前无实际作用。

## 请求

### 请求语法

``` http
GET <Request_URL>?op=list&num=<Int64>  HTTP/1.1
Host: web.file.myqcloud.com 
Authorization: <multi_effect_signature>
```

请求地址 **Request_URL** 示例

直接查询 bucket 目录下所有文件和目录：

`web.file.myqcloud.com/files/v1/<appid>/<bucket_name>/`

查询指定 bucket 中文件夹 dir_name 下的文件和目录：

`web.file.myqcloud.com/files/v1/<appid>/<bucket_name>/<dir_name>/`

带前缀的查询：

`web.file.myqcloud.com/files/v1/<appid>/<bucket_name>/<dir_name>/[prefix]`

**说明**：<箭头括号>表示 ***必须***  替换为有效值的变量，[英文方括号]表示可选的命令或参数。

对于Request_URL，带前缀查询时，[prefix] 末尾无 ‘ / ’ 。

### 请求参数

| 参数名称    | **必选** | **类型** | **描述**                                   |
| ------- | ------ | ------ | ---------------------------------------- |
| op      | 是      | String | 操作类型，填 ”list”                            |
| num     | 是      | Int    | 本次查询所要列出的目录总数                            |
| pattern | 否      | String | 返回的数据逻辑，有效值：<br />eListBoth 查询文件和目录<br />eListDirOnly 仅查询目录<br />eListFileOnly 仅查询文件<br />默认值为 eListBoth 。 |
| order   | 否      | Int    | 列出顺序，有效值：<br />0 正序（默认）；1 反序             |
| context | 否      | String | 透传字段，从响应的返回内容中得到。若查看第一页，则将空字符串作为 context 传入。若需要翻页，需要将前一页返回内容中的 context 透传到参数中。order 用于指定翻页顺序。若 order 填 0，则从当前页正序/往下翻页；若 order 填 1，则从当前页倒序/往上翻页。 |

## 返回

### 返回内容

| 参数名称    | **必选** | **类型** | **描述**     |
| ------- | ------ | ------ | ---------- |
| code    | 是      | Int    | 服务端返回码     |
| message | 是      | String | 服务端提示内容    |
| data    | 是      | 数据集合   | 服务器返回的应答数据 |

其中的 data 数据集合：

| 参数名称      | 必选   | 类型     | 描述                                 |
| --------- | ---- | ------ | ---------------------------------- |
| context   | 是    | String | 透传字段，用于翻页，业务端不需理解，需要往前/往后翻页则透传给腾讯云 |
| has_more  | 是    | Bool   | 是否有内容可以继续往前/往后翻页                   |
| dircount  | 是    | Int    | 子目录（总）数量                           |
| filecount | 是    | Int    | 子文件（总）数量                           |
| infos     | 是    | 数据集合   | 文件和文件夹列表，若当前目录下不存在文件或文件夹，则该返回值可能为空 |

其中的 infos 数据集合：

| 参数名称       | 必选   | 类型     | 描述                                       |
| ---------- | ---- | ------ | ---------------------------------------- |
| name       | 是    | String | 文件名                                      |
| biz_attr   | 否    | String | 目录/文件 描述                                 |
| filesize   | 否    | Int    | 文件大小，当类型为文件时返回                           |
| filelen    | 否    | Int    | 文件已传输大小，当类型为文件时返回                        |
| sha        | 否    | String | 文件 sha，当类型为文件时返回                         |
| ctime      | 是    | String | 创建时间，10位 Unix 时间戳                        |
| mtime      | 是    | String | 修改时间，10位 Unix 时间戳                        |
| access_url | 否    | String | 生成的资源可访问的 url，当类型为文件时返回                  |
| authority  | 否    | String | 如果没有对文件单独设置该属性，则可能不会返回该字段。返回值：eInvalid（表示继承 bucket 的读写权限）；eWRPrivate（私有读写）；eWPrivateRPublic（公有读私有写）。说明：文件可以和 bucket 拥有不同的权限类型，已经设置过权限的文件如果想要撤销，将会直接被赋值为 eInvalid，即继承 bucket 的权限 |

## 示例

#### 请求

``` http
GET /files/v1/10000202/buckettest/foldertest/?op=list&num=100&pattern=eListBoth  HTTP/1.1
Host: web.file.myqcloud.com
Authorization: iJ4BBGcPalBqB7z5bQVYEB0DcNBhPTEwMDAwMjAyJms9QUtJRFBOUHVyNUIyN3FjdVJhakNFbXpLVjkzVTdrOFZjZXFXJmU9MTQ2NTg3NTYxMSZ0PTE0NjU4NzU0MzEmcj0xNDU2NDI1MTQ3JmY9JmI9am9ubnh1NQ==
```

#### 返回

``` http
HTTP/1.1 200 OK
Server: nginx
Date: Tue, 14 Jun 2016 03:37:11 GMT
Content-Type: /
Content-Length: 1000

{
    "code": 0, 
    "message": "SUCCESS", 
    "data": {
        "context": "testSubfolder1/|test_upload.pptx|0|", 
        "dircount": 2, 
        "filecount": 2, 
        "has_more": false, 
        "infos": [
            {
                "biz_attr": "", 
                "ctime": "1465875372", 
                "mtime": "1465875372", 
                "name": "testSubfolder1"
            }, 
            {
                "biz_attr": "", 
                "ctime": "1465875373", 
                "mtime": "1465875373", 
                "name": "testSubfolder2"
            }, 
            {
                "access_url": "http://buckettest-10000202.file.myqcloud.com/foldertest/test_slice_upload.pptx", 
                "biz_attr": "", 
                "ctime": "1465875374", 
                "filelen": 70658912, 
                "filesize": 70658912, 
                "mtime": "1465875431", 
                "name": "test_slice_upload.pptx", 
                "sha": "C463C820624B5DB23E7A801DE09063BBC0414FAA", 
                "source_url": "http://buckettest-10000202.cos.myqcloud.com/foldertest/test_slice_upload.pptx"
            }, 
            {
                "access_url": "http://buckettest-10000202.file.myqcloud.com/foldertest/test_upload.pptx", 
                "biz_attr": "", 
                "ctime": "1465875373", 
                "filelen": 78380, 
                "filesize": 78380, 
                "mtime": "1465875373", 
                "name": "test_upload.pptx", 
                "sha": "D80DFA67880831C3691AA1458589C6BED4423736", 
                "source_url": "http://buckettest-10000202.cos.myqcloud.com/foldertest/test_upload.pptx"
            }
        ]
    }
}
```