## 概述

COS的权限体系依赖CAM，CAM是腾讯云权限系统，其中记录所有云产品的所有权限记录，每条权限记录由4个部分组成：`用户`，`操作`，`条件`，`资源`；即说明在什么条件下，谁是否可以对哪条资源做什么类型的操作。权限记录意在描述每一个具体的行为是否合乎权限要求。

其中`资源`的信息用CAM标准的QCS表示方法统一表达

`qcs: project:serviceType:region:account:resource`

`qcs:项目:产品:区域:用户标识:资源标识`

图为权限系统中的一条权限，下文将详细讲解每一个部分的组成

```JSON
{    
    "version":"2.0",
    "principal":   {"qcs":["qcs::cam::uin/<RootAccout>:uin/<SubAccount>","qcs::cam::uin/<RootAccout>:uin/<SubAccount>"]},
    "statement":
    [
       {
            "effect":"allow",        
            "action":["name/cos:<ActionName>"],
            "resource":["qcs::cos:<Region>:uid/<Accout>:prefix//<uid>/<BucketName>/<ObjectName>",
                      "qcs::cos:<Region>:uid/<Accout>:prefix//<uid>/<BucketName>/[dir1]/*"],
        }
    ]
}
```

## 用户

### 定义

principal字段用来表达这条权限信息的被授权对象是谁。这里的用户可以为一个子账户，也可以为一个主账号，也可以是一个用户的集合。一旦被授权，该用户（包括子账户）可以用**自己的AccessKey和SercetKey**组成签名进行访问自己或者他人的资源。

### 语法

账户信息可以理解为CAM的一种资源，在具体使用中，project字段为空，region字段为空，可以得到以下简单的表达

主账户语法：`qcs::cam::uin/<RootAccout>:uin/<RootAccount>`

子账户语法：`qcs::cam::uin/<RootAccout>:uin/<SubAccount>`

### 示例

账号为398626565的主账号

qcs::cam::uin/398626565:uin/398626565

主账号398626565的子账号1241534935

qcs::cam::uin/398626565:uin/1241534935

## 资源

### 定义

resource字段用来表达这条权限信息的被授权资源范围是哪些。这里的资源可以为一个具体的文件，也可以为一个Bucket，支持前缀匹配。

### 语法

腾讯云资源标示

`qcs: project:serviceType:region:account:resource`

`qcs:项目:产品:区域:用户标识:资源标识`

其中，项目默认填 id/0，产品填 cos，区域根据实际填写例如 华东区 ce（china-east），用户标识用于标识资源的父维度 appid/ID，资源标识用于标识资源的子维度 Bucket/Object 等。

### 示例

上海 COS Bucket: bucketname-125102314.cn-earth.myqcloud.com

qcs:id/0:cos:ce:uid/125102314:prefix//125102314/bucketname/

广州 COS Object: testbucket-125102315.cn-south.myqcloud.com/foldertest/file.txt

qcs:id/0:cos:ce:uid/125102315:prefix//125102315/testbucket/foldertest/file.txt

## 操作

### 定义

action字段用来表达这条权限信息的被授权的操作有哪些。这里可以为一个独立的操作，也可以为一组操作的集合。

### 语法

`cos:接口名字`

接口用大驼峰式命名方式

### 示例

Get Bucket接口

`cos:GetBucket`

## 条件(即将上线)

### 定义

condtion字段用来表达这条权限信息的在什么条件下可以被执行。condition由条件操作符、条件名和条件值构成。

### 语法

`"条件操作符":{"条件名":["条件值","条件值"]}`

| 条件操作符                   | 含义     | 条件名                    | 举例                                       |
| ----------------------- | ------ | ---------------------- | ---------------------------------------- |
| ip_equal                | ip等于   | ip,ip要符合CIDR规范         | {" ip_equal  ":{"ip":"10.121.2.10/24"}}  |
| ip_not_equal            | ip不等于  | ip，ip要符合CIDR规范         | {" ip_not_equal  ":{"ip":["10.121.2.10/24",  "10.121.2.20/24"]}} |
| date_not_equal          | 时间不等于  | qcs:current_time(当前时间) | {"date_not_equal":{"qcs:current_time":"2016-06-01  00:01:00"}} |
| date_greater_than       | 时间大于   | qcs:current_time(当前时间) | {" date_greater_than  ":{"qcs:current_time":"2016-06-01 00:01:00"}} |
| date_greater_than_equal | 时间大于等于 | qcs:current_time(当前时间) | {"  date_greater_than_equal ":{"qcs:current_time":"2016-06-01  00:01:00"}} |
| date_less_than          | 时间小于   | qcs:current_time(当前时间) | {" date_less_than  ":{"qcs:current_time":"2016-06-01 00:01:00"}} |
| date_less_than_equal    | 时间小于等于 | qcs:current_time(当前时间) | {"  date_less_than_equal ":{"qcs:current_time":"2016-06-01  00:01:00"}} |

### 示例

请求IP必须为10.121.2.10/24

{" ip_equal  ":{"ip":"10.121.2.10/24"}}

## ACL

### 定义

ACL为一组预定义的权限，即`用户`，`操作`，`条件`，`资源`这四个条件中有一个或者几个已经被确定。

### 语法

『x-cos-acl』：定义Bucket的ACL属性，有效值：private, public-read，默认值：private

『x-cos-grant-read』：赋予被授权者读的权限，格式x-cos-grant-read: uin=" ",uin=" "
当需要给子账户授权时，uin="RootAcountID/SubAccountID"，当需要给根账户授权时，uin="RootAcountID"

『x-cos-grant-write』：赋予被授权者写的权限，格式x-cos-grant-write: uin=" ",uin=" "
当需要给子账户授权时，uin="RootAcountID/SubAccountID"，当需要给根账户授权时，uin="RootAcountID"

『x-cos-grant-full-control』：赋予被授权者读写权限，格式x-cos-grant-full-control: uin=" ",uin=" "
当需要给子账户授权时，uin="RootAcountID/SubAccountID"，当需要给根账户授权时，uin="RootAcountID"

### 示例

x-cos-acl：public-read

| 用户   | 资源               | 操作                   | 条件   |
| ---- | ---------------- | -------------------- | ---- |
| 所有人  | 该Bucket或者该Object | 读权限组（包含所有Get/Head接口） | 无条件  |

x-cos-grant-write：uin="1241534935/1241534935"

| 用户                | 资源               | 操作                     | 条件   |
| ----------------- | ---------------- | ---------------------- | ---- |
| 账号为1241534935的主账号 | 该Bucket或者该Object | 写权限组（包含所有Put/Delete接口） | 无条件  |

## 整体示例

```JSON
{
  "version":"2.0"
  "principal":{"qcs":["qcs::cam::uin/909619481:uin/909619481"]},
  "statement":[
   {"action":["name/cos:GetBucket"],
    "effect":"allow",
    "resource":["qcs:id/0:cos:sg:uid/1251668577:prefix//1251668577/arlenhuangtestsgnoversion/*"]
   }
  ]
}
```

无条件限制，账号`909619481`的主账户对前缀为`1251668577/arlenhuangtestsgnoversion/`的所有资源拥有`GetBucket`权限
