## 1. 接口描述
识别用户产生的内容中是否含有敏感、色情、欺诈广告等关键词。
协议：HTTP/HTTPS
域名：csec.api.qcloud.com
接口名：KeywordFilter
<font color="red">注意：本接口只具备根据文本内容来识别恶意的能力，如果想获得更加综合的识别能力（文本+行为+信用），请使用消息过滤接口(UgcAntiSpam)</font>

## 2. 输入参数
<table class="t">
<tbody><tr>
<th> <b>参数名称</b>
</th><th> <b>是否必须</b>
</th><th> <b>类型</b>
</th><th> <b>描述</b>
</th></tr>
<tr>
<td> content
</td><td> 必须
</td><td> string
</td><td> 需要检测的文本
</td></tr></tbody></table>

## 3. 输出参数
<table class="t">
<tbody><tr>
<th> <b>参数名称</b>
</th><th> <b>类型</b>
</th><th> <b>描述</b>
</th></tr>
<tr>
<td> level
</td><td> Int
</td><td> 恶意等级<br>0：无恶意，为匹配关键词<br>1~4：恶意等级由低到高
</td></tr>
<tr>
<td> type
</td><td> Int
</td><td> 系统命中关键词类别<br>0    其他<br>1    广告<br>2    色情<br>3    敏感<br>4    灌水<br>5    跨站追杀<br>6    个性
</td></tr>
<tr>
<td> selfType
</td><td> Int
</td><td> 用户自定义关键词分类
<tr>
<td> beatTips
</td><td> String
</td><td> 打击原因，如命中的关键词
</td></tr></tbody></table>
## 4. 消息结构体介绍
消息结构体用于存储用户输入的文本、图片、视频和系统表情等内容，使用 TLV 格式存储，其中 Type 是 4 个字节，Length 是 4 个字节，Value 的值通过 Length 指定，Type 和 Length 都是网络字节序，其中所有的中文字符均为 UTF8 编码。目前支持的 Type 类型如下：
<table class="t">
<tbody><tr>
<th> <b>值</b>
</th><th> <b>类型</b>
</th><th> <b>说明</b>
</th></tr>
<tr>
<td> 1
</td><td> 文本
</td><td> 字符串内容，使用UTF8编码。
</td></tr>
<tr>
<td> 2
</td><td> 图片超链接
</td><td> 如果无法提供超链接，通过 Length=0表示存在图片。
</td></tr>
<tr>
<td> 3
</td><td> 视频超链接
</td><td> 如果无法提供超链接，通过 Length=0表示存在视频。
</td></tr>
<tr>
<td> 4
</td><td> 音频超链接
</td><td> 如果无法提供超链接，通过 Length=0表示存在音频。
</td></tr>
<tr>
<td> 5
</td><td> 网站超链接
</td><td> 如果无法提供超链接，通过 Length=0表示存在网站。
</td></tr>
<tr>
<td> 6
</td><td> 系统表情
</td><td> 无需传入系统表情编码，通过 Length=0表示存在系统表情
</td></tr>
<tr>
<td> 7
</td><td> 文章标题
</td><td> 字符串内容，使用UTF8编码。
</td></tr>
<tr>
<td> 8
</td><td> 位置
</td><td> 无需传入位置，通过 Length=0表示存在位置。
</td></tr>
<tr>
<td> 9
</td><td> 第三方自定义
</td><td> 无需传入第三方内容，通过 Length=0表示存在第三方内容。
</td></tr>
<tr>
<td> 10
</td><td> 文件
</td><td> 无需传入文件，通过 Length=0表示存在文件。
</td></tr>
<tr>
<td> 1000
</td><td> 其他
</td><td> 无需传入其他内容，通过 Length=0表示存在其他内容。
</td></tr></tbody></table>
## 5. 示例
输入
<pre>
http://csec.api.qcloud.com/v2/index.php?Action=KeywordFilter
&context=AAAAAQAAAELmtYvor5Xlj5HluJbvvIzmnInkurrmiZPlh7vkuYjvvJ/og7bm
sLTvvIzkvaDmmK/ms5Xova7lip/niLHlpb3ogIUAAAADAAAAQWh0dHA6Ly9pbWcue
mNvb2wuY24vY29tbXVuaXR5LzAzMzIwZGQ1NTRjNzVjNzAwMDAwMTU4ZmNlMT
cyMDkuanBn
&<a href="https://cloud.tencent.com/doc/api/229/6976">公共请求参数</a>
</pre>
输出
```
{
    "code": 0,
	"codeDesc":"success" ,
    "message": "No Error",
    "level": 0
}
```

## 5. 样例代码
[样例代码](https://console.cloud.tencent.com/tianyu/guide/service/KeywordFilter)