## 1. 接口描述
 
本接口（GetMongoDBSlowLog）用于查看实例慢日志。
接口请求域名：<font style='color:red'>mongodb.api.cloud.tencent.com </font>

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href='https://cloud.tencent.com/document/api/240/8320' title='公共请求参数'>公共请求参数</a>页面。其中，此接口的 Action 字段为 GetMongoDBSlowLog。

| 参数名称 | 是否必选  | 类型 | 描述 |
|:---------|---------|---------|---------|
| Limit | 是 | Int | 分页大小，最大不超过100。 |
| Offset | 是 | Int | 当前页码。最多支持查询1W条结果，即Limit乘以Offset不超过10000。 查询接口中单次查询一般都有一个默认最大返回记录数，要遍历所有资源，需要使用 limit，offset进行分页查询；例如查询第110~149 这40条记录，则可以设置 offset=110 limit=40。 |
| QueryMaxTime | 是 | Int | 慢查询阈值，单位为毫秒，最小为100毫秒。|
| MongodbId | 是 | String | 待操作的实例ID，可通过 [DescribeMongoDBInstances](https://cloud.tencent.com/document/api/240/8312) 接口返回值中的 instanceId 获取。 |
| BeginTime | 是 | String | 开始时间，格式如：2017-02-08 16:46:34。查询实例在 [beginTime, endTime] 时间段内开始的慢日志。 |
| EndTime | 是 | String | 结束时间，格式如：2017-02-08 19:09:26。查询实例在 [beginTime, endTime] 时间段内开始的慢日志。 |


## 3. 输出参数

| 参数名称 | 类型 | 描述 |
|:---------|---------|---------|
| code | Int | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href='https://www.cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81' title='公共错误码'>公共错误码</a>。|
| message | String | 错误信息描述，成功时，该值为空。 |
| codeDesc | String | 业务侧错误码英文描述。成功时返回Success，错误时返回具体业务错误原因。 |
| totalCount | Int | 实例总数。 |
| slowLogs | Array | 慢日志。 |

## 4. 错误码
以下错误码表列出了该接口的业务逻辑错误码。

| 错误代码 | 英文提示 | 错误描述 |
|---------|---------|---------|
|11050|InvalidParameter|业务参数错误。|
|11056|InstanceNotExists|没有找到对应实例。|
|11077|TimeFormatError|beginTime或者endTime时间格式错误，正确格式：2006-01-02 15:04:05。|
|11078|QueryTimeRangeError|开始时间beginTime 大于结束时间endTime。|
|11081|StartTimeTooOld|只允许查询7天内的数据。|
|11082|QueryNumExcessive|只允许查询1万条慢日志。|
|11083|QueryTimeRangeMoreThan1day|查询时间不允许超过1天。|
|11084|LimitExcessive|单次查询最多只允许100条记录。|
|11085|QueryMaxTimeTooSmall|慢查询阈值必须大于等于100毫秒。|

## 5. 示例
<pre>
https://mongodb.api.cloud.tencent.com/v2/index.php?Action=GetMongoDBSlowLog
&<<a href="https://cloud.tencent.com/document/api/240/8320">公共请求参数</a>>
&Offset=0
&Limit=5
&QueryMaxTime=100
&BeginTime=2017-10-20 19:16:59
&EndTime=2017-10-20 20:16:00
&MongodbId=cmgo-a1234567
</pre>
返回示例如下：
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "totalCount": 221,
    "slowLogs": [
        "Fri Oct 20 19:28:21.748 I COMMAND  [conn64407066] command admin.$cmd command: serverStatus { serverStatus: 1 } keyUpdates:0 writeConflicts:0 numYields:0 reslen:21178 locks:{} protocol:op_query 490ms",
        "Fri Oct 20 19:30:23.076 I COMMAND  [conn64407817] command admin.$cmd command: serverStatus { serverStatus: 1 } keyUpdates:0 writeConflicts:0 numYields:0 reslen:21178 locks:{} protocol:op_query 479ms",
        "Fri Oct 20 19:36:27.095 I COMMAND  [conn64410069] command admin.$cmd command: serverStatus { serverStatus: 1 } keyUpdates:0 writeConflicts:0 numYields:0 reslen:21178 locks:{} protocol:op_query 473ms",
        "Fri Oct 20 20:13:51.758 I COMMAND  [conn64423918] command admin.$cmd command: serverStatus { serverStatus: 1 } keyUpdates:0 writeConflicts:0 numYields:0 reslen:21182 locks:{} protocol:op_query 466ms",
        "Fri Oct 20 19:25:19.744 I COMMAND  [conn64405942] command admin.$cmd command: serverStatus { serverStatus: 1 } keyUpdates:0 writeConflicts:0 numYields:0 reslen:21178 locks:{} protocol:op_query 460ms"
    ]
}
```
