## 1. 接口描述
 
本接口(GetMongoDBPerformance)用于查询实例在[beginTime,endTime]时间段内的性能，包括连接数、超过100毫秒的慢查询数。
1. 为了提升查询效率，建议查询的时间跨度不超过2个小时，即 [beginTime,endTime] 时间跨度不超过2个小时，默认查询最近1个小时内实例性能；
2. 为保证服务稳定性，请勿频繁调用该接口，限制每秒不超过10次调用，每分钟不超过200次调用。

接口请求域名：<font style='color:red'>mongodb.api.qcloud.com </font>

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href='/doc/api/372/4153' title='公共请求参数'>公共请求参数</a>页面。其中，此接口的Action字段为GetMongoDBPerformance。

| 参数名称 | 是否必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| instanceIds | 否 | String | 实例Id数组，数组下标从0开始，如果实例id数组为空，默认查询所有实例的性能。 可通过 [DescribeMongoDBInstances](/document/product/240/8312) 接口返回值中的 instanceId 获取。|
| beginTime | 否 | String | 开始时间，格式如：2017-02-08 16:46:34。查询实例在 [beginTime, endTime] 时间段内的性能，如果beginTime，endTime 都不传，默认查询最近1个小时内实例性能。为提升查询效率，建议[beginTime, endTime] 的时间跨度不超过2个小时 |
| endTime | 否 | String | 结束时间，格式如：2017-02-08 17:46:34。查询实例在 [beginTime, endTime] 时间段内的性能，如果beginTime，endTime 都不传，默认查询最近1个小时内实例性能。为提升查询效率，建议[beginTime, endTime] 的时间跨度不超过2个小时 |

## 3. 输出参数
| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href='https://www.qcloud.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81' title='公共错误码'>公共错误码</a>。|
| message | String | 模块错误信息描述，与接口相关。|
| codeDesc | String | 业务侧错误码英文描述。成功时返回Success，错误时返回具体业务错误原因。 |
| data | Array | 查询结果 |
| data.mongodbPerformance | Array | 性能  | 
| data.mongodbPerformance.instanceId | String | 实例Id，如：cmgo-hwhghv1h | 
| data.mongodbPerformance.performance | Array | 实例性能，包括连接数、超过100毫秒的慢查询数 |
| data.mongodbPerformance.performance.time | String | 查询时间点，如：2017-04-21 14:38:00，每分钟统计一次 |
| data.mongodbPerformance.performance.conn | Int | 在查询时间点的连接数 |
| data.mongodbPerformance.performance.query100ms | String | 超过100毫秒的慢查询数 |

## 4. 错误码
以下错误码表列出了该接口的业务逻辑错误码。

| 错误代码 | 英文提示 | 错误描述 |
|---------|---------|---------|
|11050|InvalidParameter|业务参数错误|
|10716|NoInstanceIds|请求的实例ID不存在|
|11077|TimeFormatError|beginTime或者endTime时间格式错误，正确格式：2006-01-02 15:04:05|
|11078|QueryTimeRangeError|开始时间beginTime 大于结束时间endTime|
|11079|NoInstanceInUser|请求的实例Id不属于该用户|

## 5. 示例
<pre>
https://mongodb.api.qcloud.com/v2/index.php?Action=GetMongoDBPerformance
&<<a href="https://www.qcloud.com/doc/api/229/6976">公共请求参数</a>>
&instanceIds.0=cmgo-hwhghv1h
&beginTime=2017-04-21 14:37:00
&endTime=2017-04-21 14:40:00
</pre>
返回示例如下：
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "mongodbPerformance": [
            {
                "instanceId": "cmgo-hwhghv1h",
                "performance": [
                    {
                        "time": "2017-04-21 14:40:00",
                        "conn": 0,
                        "query100ms": 0
                    },
                    {
                        "time": "2017-04-21 14:37:00",
                        "conn": 0,
                        "query100ms": 0
                    },
                    {
                        "time": "2017-04-21 14:38:00",
                        "conn": 1806,
                        "query100ms": 3
                    },
                    {
                        "time": "2017-04-21 14:39:00",
                        "conn": 1807,
                        "query100ms": 9
                    }
                ]
            },
            {
                "instanceId": "cmgo-hwhghv1h",
                "performance": [
                    {
                        "time": "2017-04-21 14:37:00",
                        "conn": 0,
                        "query100ms": 0
                    }
                ]
            },
            {
                "instanceId": "cmgo-hwhghv1h",
                "performance": [
                    {
                        "time": "2017-04-21 14:38:00",
                        "conn": 1806,
                        "query100ms": 3
                    }
                ]
            },
            {
                "instanceId": "cmgo-hwhghv1h",
                "performance": [
                    {
                        "time": "2017-04-21 14:39:00",
                        "conn": 1807,
                        "query100ms": 9
                    }
                ]
            }
        ]
    }
}
```