## 1. 接口描述
本接口(DescribeMongodbDealDetail)用于查询订单详情。
接口请求域名：<font style='color:red'>mongodb.api.qcloud.com </font>

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href='/doc/api/372/4153' title='公共请求参数'>公共请求参数</a>页面。其中，此接口的Action字段为DescribeMongodbDealDetail。

| 参数名称 | 是否必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| dealIds.n | 是 | String | 订单号组成的数组，数组下标从0开始 |


## 3. 输出参数
| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码，0表示成功，其他值表示失败。详见错误码页面的<a href='https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81' title='公共错误码'>公共错误码</a>。|
| message | String | 错误信息描述, 成功时，该值为空 |
| codeDesc | String | 业务侧错误码英文描述。成功时返回Success，错误时返回具体业务错误原因。 |
| details | Array | 返回的订单详情数组 |

其中，details 表示订单详情数组，其参数构成如下：

| 参数名称 | 类型 | 描述 |
|:---------|---------|---------|
| details.dealId | String | 短订单号ID，调用云API时使用此ID |
| details.dealName | String | 长订单号ID，反馈订单问题给官方客服使用此ID |
| details.zoneId | Int | 可用区ID|
| details.goodsNum | Int | 订单关联的实例数 |
| details.creater | String | 创建订单的用户uin |
| details.creatTime | String | 订单创建时间 |
| details.overdueTime | String | 订单过期时间 |
| details.endTime | String | 订单完成时间 |
| details.status | Int | 订单状态<br>1：未支付<br>2：已支付，未发货<br>3：发货中<br>4：发货成功<br>5：发货失败<br>6：已退款<br>7：已关闭订单<br>8：订单过期<br>9：订单已失效<br>10：产品已失效<br>11：代付拒绝<br>12：支付中 |
| details.price | Int | 订单实际总价，单位：分 |
| details.goodsDetail | Object | 订单关联的商品详情 |

**创建实例时返回的goodsDetail：**

| 参数名称 | 类型 | 描述 |
|:---------|---------|---------|
| memSize| int | 实例的内存容量，单位：MB|
| disksize | int | 实例的磁盘大小，单位：GB|
| typeId | String | 实例类型英文名称。 GIO：高IO版；TGIO：高IO万兆|
| clusterType | Array | 实例集群类型，0：副本集|
| secondaryNum | Array | 副本集实例从节点个数，暂时只支持从节点个数为1、2|
| zoneId | Array | 可用区ID |
| mongoVersion | Array | 数据库版本号，比如：MONGO_3_MMAP、MONGO_3_WT|
| timeSpan | Array | 实例的时长，单位以timeUnit返回为准 |
| timeUnit | Array | 实例时长单位，m：月；d：天|
| SerialIds | Array | 实例ID的数组|

**续费实例时返回的goodsDetail：**

| 参数名称 | 类型 | 描述 |
|:---------|---------|---------|
| curDeadline| String | 续费前，实例的到期时间|
| timeSpan | int | 续费时长，单位以timeUnit返回为准|
| timeUnit | String | 续费时长的单位，m：月；d：天|
| SerialIds | Array | 实例ID的数组|

**升级实例时返回的goodsDetail：**

| 参数名称 | 类型 | 描述 |
|:---------|---------|---------|
| curDeadline | String | 实例的到期时间|
| newMemsize | int | 升级后实例的内存容量，单位：MB|
| newDisksize | int | 升级后实例的磁盘容量，单位：GB|
| oldMemsize | int | 升级前实例的内存容量，单位：MB|
| oldDisksize | int | 升级前实例的磁盘容量，单位：GB|
| SerialIds | Array | 实例ID的数组|

## 4. 错误码
以下错误码表列出了该接口的业务逻辑错误码。

| 错误代码 | 英文提示 | 错误描述 |
|---------|---------|---------|
|11201|InvalidParameter|业务参数错误|

## 5. 示例
输入
<pre>
https://mongodb.api.qcloud.com/v2/index.php?Action=DescribeMongodbDealDetail
&<<a href="https://cloud.tencent.com/doc/api/229/6976">公共请求参数</a>>
&dealIds.0=3373037
&dealIds.1=3374462
&dealIds.2=3374558
</pre>
输出
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "details": [
        {
            "dealId": "3373037",
            "dealName": "20170206121420",
            "zoneId": 100002,
            "goodsNum": 1,
            "creater": "3374998458",
            "creatTime": "2017-02-06 14:07:46",
            "overdueTime": "2017-02-21 14:07:46",
            "endTime": "2017-02-06 14:11:54",
            "status": 4,
            "price": 72200,
            "goodsDetail": {
                "memSize": 4096,
                "disksize": 30,
                "typeId": "GIO",
                "clusterType": "ReplSet",
                "secondaryNum": 2,
                "zoneId": 100002,
                "mongoVersion": "MONGO_3_MMAP",
                "timeSpan": 1,
                "timeUnit": "m",
                "SerialIds": [
                    "cmgo-6ozqe0uh"
                ]
            }
        },
        {
            "dealId": "3374462",
            "dealName": "20170206124372",
            "zoneId": 100002,
            "goodsNum": 1,
            "creater": "3374998458",
            "creatTime": "2017-02-06 16:32:45",
            "overdueTime": "2017-02-21 16:32:45",
            "endTime": "2017-02-06 16:32:46",
            "status": 4,
            "price": 72200,
            "goodsDetail": {
                "curDeadline": "2017-03-06 14:07:46",
                "timeSpan": 1,
                "timeUnit": "m",
                "SerialIds": [
                    "cmgo-6ozqe0uh"
                ]
            }
        },
        {
            "dealId": "3374558",
            "dealName": "20170206124575",
            "zoneId": 100002,
            "goodsNum": 1,
            "creater": "3374998458",
            "creatTime": "2017-02-06 16:43:17",
            "overdueTime": "2017-02-21 16:43:17",
            "endTime": "2017-02-06 16:45:49",
            "status": 4,
            "price": 142421,
            "goodsDetail": {
                "curDeadline": "2017-04-06 14:07:46",
                "newMemsize": 8192,
                "newDisksize": 60,
                "oldMemsize": 4096,
                "oldDisksize": 30,
                "SerialIds": [
                    "cmgo-6ozqe0uh"
                ]
            }
        }
    ]
}

```
