## 1. 接口描述
本接口(GetCdbDeviceMonitorInfo)用于查询云数据库物理机当天的监控信息，<font style="color:red">**暂只支持内存488G、硬盘6T的实例查询**</font>。
接口请求域名：<font style="color:red">cdb.api.qcloud.com</font>

可以在云监控中[MySQL监控数据接口](https://cloud.tencent.com/document/api/248/11006)通过云API来获取CDB实例的监控指标。


## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见 [公共参数](https://cloud.tencent.com/document/api/236/6921) 页面。其中，此接口的Action字段为GetCdbDeviceMonitorInfo。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| cdbInstanceId | 是 | String | 实例ID，格式如：cdb-c1nl9rpv。与云数据库控制台页面中显示的实例ID相同，可使用[查询实例列表](/doc/api/253/1266) 接口获取，其值为输出参数中字段 uInstanceId 的值。 |
| count5Min | 否 | Int | 返回当天最近count5Min个5分钟监控数据，默认返回当天所有5分钟监控数据，最小值1，最大值288|


## 3. 输出参数
| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href='https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81' title='公共错误码'>公共错误码</a>。|
| message | String | 模块错误信息描述，与接口相关。|
| codeDesc | String | 英文错误描述 |
| data | Object | 实例监控数据 |
其中， data 参数的构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| cpu | Object | 60秒内 cpu平均负载 * 100 | 
| net | Object | 实例网络监控数据 | 
| mem | Object | 实例内存监控数据 | 
| disk | Object | 实例磁盘监控数据 |
其中， cpu 构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| load | Array | 实例CPU监控数据 | 
| rate | Object | 实例CPU平均使用率 | 
| rate.total | Array | 60秒内 实例CPU的总平均使用率 |
| rate.0 | Array | 60秒内 cpu 0 的平均使用率 （CPU处于非空闲状态的百分比） | 
| rate.1 | Array | 60秒内 cpu 1 的平均使用率 （CPU处于非空闲状态的百分比） |
其中， net 构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| pkg_in | Array | 60秒内 网卡入包量 | 
| pkg_out | Array | 60秒内 网卡出包量 | 
| flow_in | Array | 60秒内 入流量，单位：KB | 
| flow_out | Array | 60秒内 出流量，单位：KB | 
| conn | Array | 4分钟采集一次  tcp连接数 | 
其中， mem 构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| total | Array | 4分钟采集一次 free命令中Mem:一行total的值,单位：KB | 
| used | Array | 4分钟采集一次 free命令中Mem:一行used的值,单位：KB | 
其中， disk 构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| util_max | Array | 60秒内 平均每秒有百分之几的时间用于IO操作（取所有分区最大值） | 
| await_time_max | Array | 60秒内 平均每次设备I/O操作的等待时间*100（取所有分区最大值） | 
| read | Array | 60秒内 所有磁盘平均每秒完成的读操作次数总和100 | 
| write | Array | 60秒内 所有磁盘平均每秒完成的写操作次数总和*100 | 


## 4. 错误码表
以下错误码表列出了该接口的业务逻辑错误码。

| 错误代码 | 英文提示 | 错误描述 |
|---------|---------|---------|
| 9638 | NoSupportQuery | 该实例不在运行中或者不是云数据库物理机 |
| 9572 | InstanceNotExists | 实例不存在 |
| 9013 | InternalError | 系统内部错误 |


## 5. 示例
输入
<pre>
https://cdb.api.qcloud.com/v2/index.php?Action=GetCdbDeviceMonitorInfo
&<<a href="/document/product/236/6921">公共请求参数</a>>
&cdbInstanceId=cdb-c1nl9rpv
&count5Min=1
</pre>

输出
```
{
    "code":"0",
    "message":"",
    "codeDesc":"Success",
    "data":{
        "cpu":{
            "load":[
                "8"
            ],
            "rate":{
                "total":[
                    "3"
                ],
                "0":[
                    "5"
                ],
                "1":[
                    "4"
                ],
                "2":[
                    "4"
                ],
                "3":[
                    "2"
                ]
            }
        },
        "mem":{
            "total":[
                "32740732"
            ],
            "used":[
                "32493912"
            ]
        },
        "net":{
            "pkg_in":[
                "0"
            ],
            "pkg_out":[
                "0"
            ],
            "flow_in":[
                "0"
            ],
            "flow_out":[
                "0"
            ],
            "conn":[
                "39"
            ]
        },
        "disk":{
            "util_max":[
                "0"
            ],
            "await_time_max":[
                "240"
            ],
            "read":[
                "0"
            ],
            "write":[
                "251"
            ]
        }
    }
}
```

