## 1. 接口描述
本接口(CdbTdsqlGetResourceUsageInfo)用于查看数据库实例资源的使用情况。
接口请求域名：<font style="color:red">tdsql.api.qcloud.com</font>

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共参数](https://cloud.tencent.com/document/api/213/6976
)。其中，此接口的Action字段为CdbTdsqlGetResourceUsageInfo。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| cdbInstanceId | 是 | Int | 实例ID|
| shardId | 否 | Int | 分片id, 0的时候表示获取整个集群的监控或者单机实例的监控|
| startTime | 是 | date | 开始日期，格式yyyy-mm-dd|
| endTime | 是 | date | 结束日期，格式yyyy-mm-dd|

## 3. 输出参数
公共返回值结构在[返回值](https://cloud.tencent.com/document/api/213/6976)可以查看，此处只列出data字段的返回值格式。

返回值为对应性能的点阵。
按时间顺序先后返回各个时间段的数据值，连续时间段如果值相同将被合并为{段数，值}的形式。比如[2，3]就表示连续2个时间段的值为3，一个时间段的长度由请求的开始时间和结束时间的差值决定，小于1天是5分钟一段，大于1天小于7天是30分钟一段，大于7天是2个小时一段。


指标列表

|指标名|含义|
|------|-----|
|binlog_disk_available|binlog日志磁盘可用空间,单位GB|
|cpu_usage_rate|CPU利用率|
|mem_available|内存可用空间,单位GB|
|data_disk_available|磁盘可用空间,单位GB|
## 4. 错误码表

以下是本接口常见的错误码，如果有不在此列的错误请查阅[TDSQL错误码表](/doc/api/309/7150)

| 错误码 | 描述 |
|---------|---------|
| BaradError | Barad错误 |
| NoInstanceFound | 实例不存在 |
| InnerSystemError | 内部系统错误，和业务无关 |
| InstanceStatusError | 实例状态错误 |
| ShardNotExist | 分片不存在 |
| MetricNotExist | 指定的维度不存在 |
| OssOpertaionFailed | OSS内部失败 |
| MakeRequestFailed | 拼接请求时发生错误 |
| BadRequest | 发起请求错误 |
| ReadDataFailed | 读取返回数据错误 |
| NoDataFetched | 未拉取到数据 |
| JsonUnmarshaFailed | json 解析错误 |
| NoDataFetched | 未拉取到数据 |
| BaradError | Barad数据合并错误 |
## 5. 示例
输入
<pre>
https://tdsql.api.qcloud.com/v2/index.php?
&<<a href="https://cloud.tencent.com/doc/api/229/6976">公共请求参数</a>>
&Action=CdbTdsqlGetResourceUsageInfo
&cdbInstanceId=40732
&startTime=2016-07-17
&endTime=2016-07-18
</pre>

输出
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "binlog_disk_available": {
            "StartTime": "2016-07-17 00:00:00",
            "EndTime": "2016-07-18 23:59:59",
            "Data": [
                [
                    161,
                    20.89
                ],
                [
                    91,
                    20.88
                ],
                [
                    36,
                    null
                ]
            ]
        },
        "cpu_usage_rate": {
            "StartTime": "2016-07-17 00:00:00",
            "EndTime": "2016-07-18 23:59:59",
            "Data": [
                37,
                28,
                [
                    4,
                    39
                ],
                42,
                41,
                42,
                41,
                42,
                [
                    2,
                    40
                ],
                39,
                [
                    2,
                    40
                ],
                43,
                39,
                45,
                [
                    3,
                    39
                ],
                44,
                43,
                [
                    3,
                    39
                ],
                [
                    2,
                    40
                ],
                42,
                41,
                [
                    2,
                    40
                ],
                [
                    4,
                    39
                ],
                40,
                39,
                42,
                39,
                42,
                [
                    4,
                    22
                ],
                31,
                28,
                26,
                27,
                29,
                42,
                7,
                22,
                19,
                [
                    3,
                    5
                ],
                18,
                15,
                21,
                5,
                15,
                [
                    3,
                    5
                ],
                6,
                [
                    3,
                    5
                ],
                6,
                [
                    10,
                    5
                ],
                6,
                5,
                6,
                [
                    5,
                    5
                ],
                6,
                [
                    8,
                    5
                ],
                6,
                [
                    5,
                    5
                ],
                6,
                [
                    51,
                    5
                ],
                12,
                [
                    2,
                    5
                ],
                20,
                23,
                21,
                25,
                5,
                27,
                20,
                [
                    2,
                    23
                ],
                21,
                20,
                21,
                19,
                39,
                33,
                29,
                [
                    5,
                    39
                ],
                42,
                40,
                44,
                40,
                41,
                39,
                42,
                39,
                43,
                [
                    2,
                    39
                ],
                [
                    2,
                    41
                ],
                39,
                41,
                42,
                46,
                [
                    2,
                    39
                ],
                41,
                40,
                39,
                41,
                45,
                40,
                43,
                44,
                40,
                46,
                [
                    2,
                    39
                ],
                [
                    2,
                    40
                ],
                41,
                44,
                39,
                40,
                41,
                [
                    2,
                    40
                ],
                [
                    2,
                    39
                ],
                34,
                [
                    3,
                    40
                ],
                39,
                [
                    2,
                    40
                ],
                37,
                39,
                40,
                37,
                39,
                31,
                38,
                33,
                34,
                30,
                6,
                22,
                23,
                24,
                [
                    2,
                    22
                ],
                19,
                18,
                6,
                14,
                6,
                [
                    2,
                    5
                ],
                [
                    36,
                    null
                ]
            ]
        },
        "data_disk_available": {
            "StartTime": "2016-07-17 00:00:00",
            "EndTime": "2016-07-18 23:59:59",
            "Data": [
                [
                    252,
                    100
                ],
                [
                    36,
                    null
                ]
            ]
        },
        "mem_available": {
            "StartTime": "2016-07-17 00:00:00",
            "EndTime": "2016-07-18 23:59:59",
            "Data": [
                [
                    231,
                    3.91
                ],
                [
                    21,
                    3.9
                ],
                [
                    36,
                    null
                ]
            ]
        }
    }
}
```

