## 1. API Description
This API (CdbTdsqlGetResourceUsageInfoDetail) is used to view details of instance resource usage.

Domain for API request: tdsql.api.qcloud.com



## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters are also needed when the API is called. For more information, please see [Common Request Parameters](https://cloud.tencent.com/document/api/213/6976
). The Action field for this API is CdbTdsqlGetResourceUsageInfoDetail.

| Parameter Name | Required | Type | Description |
|---------|---------|---------|---------|
| cdbInstanceId | Yes | Int | Instance ID |
| shardId | No | Int | Shard ID. 0 indicates acquiring the monitoring data of the entire cluster or standalone instance |
| startTime | Yes | date | Start date. Format: yyyy-mm-dd |
| endTime | Yes | date | End date. Format: yyyy-mm-dd |


## 3. Output Parameters
Returned values are in the form of array of performance data.
Data values for different time periods are returned in chronological order. If a value is same over consecutive time periods, the value is returned in the form of [number of periods, value]. For example, [2,3] indicates the value is 3 over two continuous time periods. The length of each time period depends on the difference between the start time and end time of the request. The length of time period is 5 minutes for requests shorter than a day, 30 minutes for requests longer than a day but shorter than 7 days, and 2 hours for those longer than 7 days.
Slightly different from API [View Instance Performance Data](/doc/api/309/5409), this API returns the detailed data of master/slave. The API [View Instance Performance Data](/doc/api/309/5408)
returns the overall data of the entire instance (master/slave1/slave2 refers to the information of the master, slave 1, slave 2, respectively).

Metrics

| Metric | Description |
|------|-----|
| binlog_disk_available | Available space of binlog disk (in GB) |
| cpu_usage_rate | CPU utilization |
| mem_available | Available memory (in GB) |
| data_disk_available | Available disk space (in GB) |
## 4. Error Codes

The following are the common error codes for this API. Other error codes not listed here can be found in [TDSQL Error Codes](/doc/api/309/7150).

| Error Code | Description |
|---------|---------|
| BaradError | Barad error |
| NoInstanceFound | Instance does not exist |
| InnerSystemError | Internal system error (unrelated to service) |
| InstanceStatusError | Instance status error |
| ShardNotExist | Shard does not exist |
| MetricNotExist | Specified metric does not exist |
| OssOpertaionFailed | OSS internal failure |
| MakeRequestFailed | Failed to join parameters into request |
| BadRequest | Failed to initiate request |
| ReadDataFailed | Failed to read returned data |
| NoDataFetched | No data is fetched |
| JsonUnmarshaFailed | Json resolution failed |
| NoDataFetched | No data is fetched |
| BaradError | Barad data consolidation error |
## 5. Example
Input
<pre>
https://tdsql.api.qcloud.com/v2/index.php?Action=CdbTdsqlGetResourceUsageInfoDetail
&<<a href="https://cloud.tencent.com/doc/api/229/6976">Common request parameters</a>>
&cdbInstanceId=40746
&startTime=2016-08-21
&endTime=2016-08-22
</pre>
Output
```
{
    "code":"0",
    "message":"",
    "codeDesc":"Success",
    "data":{
        "master":{
            "binlog_disk_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "149",
                        "20.89"
                    ],
                    [
                        "109",
                        "20.88"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "cpu_usage_rate":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    "3.6",
                    "11",
                    "10.4",
                    "10.6",
                    [
                        "2",
                        "3.6"
                    ],
                    "4",
                    "6.6",
                    "10.6",
                    "11.4",
                    "10.4",
                    "4",
                    "3.6",
                    "4.2",
                    "10.4",
                    "10.6",
                    "10",
                    "3.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "10.6",
                    "11",
                    "10.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "10.8",
                    "11",
                    "10.4",
                    [
                        "2",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "2",
                        "10.4"
                    ],
                    "10.6",
                    "3.8",
                    "4",
                    "3.6",
                    "12.2",
                    "10.6",
                    "10.8",
                    "4.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "9.4",
                    "10.8",
                    "11",
                    "5.2",
                    [
                        "2",
                        "3.6"
                    ],
                    "10",
                    "11",
                    "10.6",
                    "5.6",
                    [
                        "2",
                        "3.6"
                    ],
                    "4",
                    "10.6",
                    [
                        "2",
                        "10.4"
                    ],
                    "3.6",
                    "4",
                    "3.8",
                    "6.8",
                    "10.4",
                    "10.6",
                    "7.4",
                    "4",
                    "3.6",
                    "7.6",
                    "10.6",
                    "10.8",
                    "6.4",
                    [
                        "2",
                        "3.6"
                    ],
                    "9.2",
                    "10.6",
                    "11",
                    "5.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "8.6",
                    "11",
                    [
                        "2",
                        "10.6"
                    ],
                    [
                        "2",
                        "3.6"
                    ],
                    "4",
                    [
                        "2",
                        "10.6"
                    ],
                    "10.4",
                    "3.6",
                    "10.4",
                    "10.8",
                    "10.6",
                    "11.2",
                    "11.4",
                    "5.2",
                    "3.6",
                    "4.4",
                    "6.4",
                    "10.8",
                    [
                        "3",
                        "10.6"
                    ],
                    "10.4",
                    "11",
                    [
                        "3",
                        "10.6"
                    ],
                    "4.8",
                    "4",
                    "3.8",
                    "3.6",
                    "10.4",
                    "10.8",
                    "11",
                    "9.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "10.8",
                    "11",
                    "9.6",
                    [
                        "3",
                        "3.6"
                    ],
                    "10.8",
                    [
                        "2",
                        "10.6"
                    ],
                    [
                        "2",
                        "3.6"
                    ],
                    "4",
                    "10.6",
                    "10.4",
                    "10.6",
                    "3.6",
                    "4",
                    "3.8",
                    "7.2",
                    [
                        "2",
                        "10.6"
                    ],
                    "7.4",
                    [
                        "3",
                        "3.6"
                    ],
                    "10.6",
                    "11",
                    "10.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "11",
                    "10.6",
                    "10.4",
                    "3.6",
                    [
                        "2",
                        "4"
                    ],
                    "10",
                    "9.4",
                    "10.8",
                    [
                        "2",
                        "11"
                    ],
                    "7",
                    [
                        "2",
                        "3.6"
                    ],
                    "6.4",
                    "11",
                    "10.6",
                    "9.2",
                    "3.6",
                    [
                        "2",
                        "4"
                    ],
                    "10.2",
                    [
                        "2",
                        "10.4"
                    ],
                    "5.8",
                    "4",
                    "3.6",
                    "4.4",
                    "10.4",
                    [
                        "2",
                        "11"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "11"
                    ],
                    [
                        "2",
                        "10.6"
                    ],
                    "5",
                    [
                        "2",
                        "4"
                    ],
                    "3.6",
                    [
                        "2",
                        "10.6"
                    ],
                    "9.2",
                    "4",
                    [
                        "2",
                        "3.6"
                    ],
                    "10.4",
                    "11",
                    "10.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "9",
                    "10.4",
                    "10.6",
                    "6.8",
                    "3.6",
                    [
                        "2",
                        "4"
                    ],
                    [
                        "2",
                        "10.6"
                    ],
                    "7",
                    [
                        "2",
                        "4"
                    ],
                    "3.6",
                    "10.6",
                    "10.8",
                    "11",
                    "6.6",
                    [
                        "2",
                        "3.6"
                    ],
                    "8.4",
                    [
                        "2",
                        "11"
                    ],
                    "5.2",
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "10.8"
                    ],
                    "9.2",
                    [
                        "2",
                        "3.6"
                    ],
                    "3.8",
                    "10.8",
                    [
                        "2",
                        "10.4"
                    ],
                    [
                        "2",
                        "3.6"
                    ],
                    "4",
                    "6.6",
                    [
                        "2",
                        "10.6"
                    ],
                    "10.4",
                    [
                        "2",
                        "4"
                    ],
                    "3.6",
                    [
                        "3",
                        "10.4"
                    ],
                    "4",
                    "3.6",
                    "3.4",
                    [
                        "30",
                        null
                    ]
                ]
            },
            "data_disk_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "258",
                        "100"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "mem_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "15",
                        "3.84"
                    ],
                    [
                        "4",
                        "3.83"
                    ],
                    [
                        "26",
                        "3.84"
                    ],
                    [
                        "2",
                        "3.83"
                    ],
                    [
                        "28",
                        "3.84"
                    ],
                    [
                        "3",
                        "3.83"
                    ],
                    [
                        "19",
                        "3.84"
                    ],
                    [
                        "8",
                        "3.85"
                    ],
                    [
                        "2",
                        "3.83"
                    ],
                    [
                        "28",
                        "3.84"
                    ],
                    [
                        "2",
                        "3.83"
                    ],
                    [
                        "28",
                        "3.84"
                    ],
                    [
                        "3",
                        "3.83"
                    ],
                    [
                        "27",
                        "3.84"
                    ],
                    [
                        "2",
                        "3.83"
                    ],
                    [
                        "29",
                        "3.84"
                    ],
                    [
                        "2",
                        "3.83"
                    ],
                    [
                        "13",
                        "3.84"
                    ],
                    [
                        "3",
                        "3.83"
                    ],
                    [
                        "14",
                        "3.84"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            }
        },
        "slave1":{
            "binlog_disk_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "121",
                        "20.88"
                    ],
                    [
                        "113",
                        "20.87"
                    ],
                    [
                        "24",
                        "20.86"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "cpu_usage_rate":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    "11.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4.2",
                    "4",
                    "11.6",
                    "3.8",
                    [
                        "3",
                        "4"
                    ],
                    "4.2",
                    "5",
                    "3.8",
                    [
                        "2",
                        "4"
                    ],
                    "4.2",
                    "3.8",
                    "4",
                    "3.8",
                    "4.4",
                    "4",
                    [
                        "2",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "2",
                        "3.8"
                    ],
                    "3.6",
                    [
                        "2",
                        "4.2"
                    ],
                    "4",
                    "4.2",
                    [
                        "3",
                        "4"
                    ],
                    "7.4",
                    "3.8",
                    "4",
                    "8",
                    "3.8",
                    "4",
                    "7.6",
                    "4.2",
                    "4",
                    "7.4",
                    "3.8",
                    "4",
                    "7.4",
                    "3.8",
                    "4",
                    "3.8",
                    "4",
                    [
                        "2",
                        "4.2"
                    ],
                    "3.8",
                    "4",
                    "4.4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4.4",
                    "4",
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    [
                        "3",
                        "4"
                    ],
                    "4.2",
                    "4",
                    "3.8",
                    "7.6",
                    "4",
                    "4.2",
                    "7.8",
                    [
                        "2",
                        "3.8"
                    ],
                    "7.8",
                    "4.2",
                    "3.6",
                    "7.4",
                    [
                        "2",
                        "4"
                    ],
                    "8.4",
                    "3.8",
                    "4",
                    "7.2",
                    "4.2",
                    "3.8",
                    "15.2",
                    "4.2",
                    "4",
                    "7.6",
                    "4.4",
                    "3.8",
                    "3.6",
                    "4",
                    "3.8",
                    "4",
                    "3.6",
                    "3.8",
                    "3.6",
                    "3.8",
                    "4",
                    [
                        "2",
                        "3.6"
                    ],
                    "3.8",
                    [
                        "2",
                        "4"
                    ],
                    "3.8",
                    "3.6",
                    "7.4",
                    [
                        "2",
                        "4"
                    ],
                    "7.6",
                    "4",
                    "3.8",
                    "8",
                    "4",
                    "3.8",
                    "7.8",
                    "3.8",
                    "4",
                    "7.6",
                    "3.6",
                    "3.8",
                    "7.8",
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    "3.6",
                    "3.8",
                    "3.6",
                    "4",
                    [
                        "3",
                        "3.8"
                    ],
                    "3.6",
                    "4",
                    "3.8",
                    "3.6",
                    [
                        "3",
                        "4"
                    ],
                    "3.6",
                    [
                        "2",
                        "3.8"
                    ],
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    "5",
                    "3.8",
                    "3.6",
                    "7.8",
                    "3.6",
                    "3.8",
                    "8",
                    [
                        "2",
                        "4"
                    ],
                    "8",
                    "3.6",
                    "4",
                    "7.6",
                    [
                        "2",
                        "3.6"
                    ],
                    "6.6",
                    "3.8",
                    "4",
                    "7.6",
                    [
                        "2",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    "3.8",
                    "3.6",
                    "3.8",
                    "4",
                    "3.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    "3.8",
                    [
                        "2",
                        "3.6"
                    ],
                    [
                        "3",
                        "4"
                    ],
                    "3.8",
                    "3.6",
                    [
                        "2",
                        "4"
                    ],
                    "6.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "8",
                    "4",
                    "3.6",
                    "7.4",
                    "3.8",
                    "4",
                    "7.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "8",
                    "4",
                    "3.6",
                    "7.8",
                    "3.6",
                    "4",
                    "7.6",
                    [
                        "2",
                        "3.6"
                    ],
                    "7",
                    "4",
                    "3.8",
                    "8",
                    [
                        "2",
                        "3.6"
                    ],
                    [
                        "3",
                        "4"
                    ],
                    "3.6",
                    [
                        "2",
                        "3.8"
                    ],
                    "4",
                    "3.6",
                    "3.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    "3.6",
                    "3.8",
                    "3.6",
                    "3.8",
                    "7.8",
                    "3.6",
                    "3.8",
                    "7.2",
                    "3.6",
                    "4",
                    "7.4",
                    "3.8",
                    [
                        "30",
                        null
                    ]
                ]
            },
            "data_disk_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "258",
                        "100"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "mem_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "258",
                        "3.92"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            }
        },
        "slave2":{
            "binlog_disk_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "121",
                        "20.88"
                    ],
                    [
                        "113",
                        "20.87"
                    ],
                    [
                        "24",
                        "20.86"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "cpu_usage_rate":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    "3.8",
                    "4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    [
                        "3",
                        "3.8"
                    ],
                    "4.2",
                    "4",
                    [
                        "3",
                        "3.8"
                    ],
                    "4.2",
                    "4",
                    [
                        "3",
                        "3.8"
                    ],
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    "4",
                    [
                        "3",
                        "3.8"
                    ],
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "4",
                        "3.8"
                    ],
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    [
                        "3",
                        "3.8"
                    ],
                    [
                        "2",
                        "4.2"
                    ],
                    [
                        "3",
                        "3.8"
                    ],
                    "4",
                    "4.2",
                    "3.8",
                    "3.6",
                    [
                        "2",
                        "4"
                    ],
                    "4.2",
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    [
                        "4",
                        "3.6"
                    ],
                    "4",
                    [
                        "4",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    [
                        "4",
                        "3.6"
                    ],
                    "4",
                    [
                        "4",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "2",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    [
                        "2",
                        "4"
                    ],
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    "3.8",
                    [
                        "3",
                        "3.6"
                    ],
                    "4",
                    [
                        "4",
                        "3.6"
                    ],
                    "4",
                    [
                        "2",
                        "3.6"
                    ],
                    "3.4",
                    "3.6",
                    "4",
                    "3.4",
                    [
                        "3",
                        "3.6"
                    ],
                    "3.8",
                    "4",
                    [
                        "2",
                        "3.4"
                    ],
                    [
                        "2",
                        "3.6"
                    ],
                    [
                        "2",
                        "3.8"
                    ],
                    "3.2",
                    [
                        "2",
                        "3.4"
                    ],
                    [
                        "2",
                        "3.8"
                    ],
                    [
                        "2",
                        "3.6"
                    ],
                    "3.4",
                    "3.6",
                    "4",
                    [
                        "3",
                        "3.6"
                    ],
                    "3.4",
                    "4",
                    [
                        "2",
                        "3.6"
                    ],
                    [
                        "3",
                        "3.4"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "data_disk_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "258",
                        "100"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            },
            "mem_available":{
                "StartTime":"2016-08-21 00:00:00",
                "EndTime":"2016-08-22 23:59:59",
                "Data":[
                    [
                        "2",
                        "3.91"
                    ],
                    "3.92",
                    [
                        "3",
                        "3.91"
                    ],
                    "3.92",
                    "3.91",
                    "3.92",
                    [
                        "4",
                        "3.91"
                    ],
                    [
                        "3",
                        "3.92"
                    ],
                    [
                        "4",
                        "3.91"
                    ],
                    "3.92",
                    [
                        "26",
                        "3.91"
                    ],
                    "3.92",
                    [
                        "210",
                        "3.91"
                    ],
                    [
                        "30",
                        null
                    ]
                ]
            }
        }
    }
}
```


