Common request parameters are needed for all APIs. These parameters will not be discussed in the document for each API unless necessary. However, **these parameters are required in each request for the request to be initiated successfully**. The first letter of each common request parameter is uppercase so that the parameter can be differentiated from API request parameters.

Common request parameters are listed as follows:

<table class="t">
<tbody><tr>
<th> <b>Name</b>
</th><th> <b>Type</b>
</th><th> <b>Description</b>
</th><th width="50"> <b>Required</b>
</th></tr>
<tr>
<td> Action
</td><td> String
</td><td> The name of the API for the desired operation. For example, if you want to call the <a href="/doc/api/261/1388" title="Query List of Instances">Query List of Instances</a> API, the Action parameter is DescribeCmem.
</td><td> Yes
</td></tr>
<tr>
<td> Region
</td><td> String
</td><td> Region parameter, used to identify the region to which the instance you want to operate belongs. The parameter values for regions are as follows: <br>Beijing: bj, Guangzhou: gz, Shanghai: sh, Hong Kong: hk, North America: ca. <br><B>Note: Generally, this parameter is required, unless otherwise indicated in the relevant API.</B>
</td><td> No
</td></tr>
<tr>
<td> Timestamp
</td><td> UInt
</td><td> The current UNIX timestamp that records the time at which the API request was initiated.
</td><td> Yes
</td></tr>
<tr>
<td> Nonce
</td><td> UInt
</td><td> A random positive integer that is used in conjunction with Timestamp to prevent replay attacks.
</td><td> Yes
</td></tr>
<tr>
<td> SecretId
</td><td> String
</td><td> The SecretId which is used for identifying identity and applied for on <a href="https://console.cloud.tencent.com/capi">Cloud API Key</a>. A SecretId corresponds to a unique SecretKey, which is used to generate the request Signature. For more information, refer to <a href="/doc/api/261/4574" title="Signature Method">Signature Method</a>.
</td><td> Yes
</td></tr>
<tr>
<td> Signature
</td><td> String
</td><td> Request signature, used to verify the legitimacy of the request and automatically generated by system according to input parameters. For more information, refer to <a href="/doc/api/261/4574" title="Signature Method">Signature Method</a>.
</td><td> Yes
</td></tr></tbody></table>

If a user wants to query the CVM instance list for Guangzhou, the request link may be as follows:

```
https://cvm.api.qcloud.com/v2/index.php?
Action=DescribeCmem
&SecretId=xxxxxxx
&Region=gz
&Timestamp=1465055529
&Nonce=59485
&Signature=mysignature
&<API Request Parameter>
```

A complete request needs two types of request parameters: common request parameters and API request parameters. Only six common request parameters are listed above. For more information on API request parameters, please see <a href="/doc/api/261/4568" title="API Request Parameters">API Request Parameters</a> section.
