## 1. 接口描述

域名：monitor.api.qcloud.com
接口：GetMonitorData

腾讯云容器服务为用户解决容器集群的搭建以及运维管理工作，无缝衔接了腾讯云的计算、网络、存储、监控、安全能力，帮助用户升级开发模式、变更应用交付、重构数据管理方式。助力企业快速上云、提速应用部署、简化集群管理，将精力花在刀刃上。具体介绍请参考<a href="https://cloud.tencent.com/document/product/457/6759">容器服务产品概述</a>页面。

查询容器服务 - 实例维度监控数据，入参取值如下：
namespace：qce/docker
dimensions.0.name=clusterId
dimensions.0.value为集群ID
dimensions.1.name=serviceName
dimensions.1.value为服务名称
dimensions.2.name=namespace
dimensions.2.value为命名空间名称
dimensions.3.name=podName
dimensions.3.value为实例名称

| 英文          | 中文含义                                     |
| ----------- | ---------------------------------------- |
| clusterId   | 请填写[查询集群列表](https://cloud.tencent.com/document/api/457/9448)接口中返回的clusterId(集群的Id)字段 |
| serviceName | 请填写[查询服务列表](https://cloud.tencent.com/document/api/457/9440)接口中返回的serviceName(服务名)字段 |
| namespace   | 请填写[查询服务列表](https://cloud.tencent.com/document/api/457/9440)接口中返回的namespace(命名空间)字段 |
| podName     | 请填写[查询服务实例列表](https://cloud.tencent.com/document/api/457/9433)接口中返回的name(实例名称)字段 |

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/405/公共请求参数" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为GetMonitorData。

### 2.1输入参数

| 参数名称               | 必选   | 类型       | 输入内容    | 描述                                       |
| ------------------ | ---- | -------- | ------- | ---------------------------------------- |
| namespace          | 是    | String   | qce/cvm | 命名空间，每个云产品会有一个命名空间，具体名称见输入内容一栏。          |
| metricName         | 是    | String   | 具体的指标名称 | 指标名称，具体名称见2.2                            |
| dimensions.n.name  | 是    | String   | 维度的名称   | 维度的名称，具体维度名称见第1节，与dimensions.n.value配合使用。 |
| dimensions.n.value | 是    | String   | 对应的维度的值 | 对应的维度的值，具体维度名称见第1节，与dimensions.n.name配合使用。 |
| period             | 否    | Int      | 60/300  | 监控统计周期，绝大部分指标支持60s统计粒度，部分指标仅支持300s统计粒度，统计粒度根据指标的不同而变。输入参数时可参考2.2的指标详情列表。 |
| startTime          | 否    | Datetime | 起始时间    | 起始时间，如"2016-01-01 10:25:00"。 默认时间为当天的”00:00:00” |
| endTime            | 否    | Datetime | 结束时间    | 结束时间，默认为当前时间。 endTime不能小于startTime       |

### 2.2 指标名称
| 监控项     | 指标名称              | 单位   | 说明                        |
| ------- | ----------------- | ---- | ------------------------- |
| 实例网络入带宽 | pod_in_bandwidth  | Mbps | 同一实例内容器共享网络，实例(pod)的网络入带宽 |
| 实例网络出带宽 | pod_out_bandwidth | Mbps | 同一实例内容器共享网络，实例(pod)的网络出带宽 |
| 实例网络入流量 | pod_in_flux       | MB   | 同一实例内容器共享网络，实例(pod)的网络入流量 |
| 实例网络出流量 | pod_out_flux      | MB   | 同一实例内容器共享网络，实例(pod)的网络出流量 |
| 实例网络入包量 | pod_in_packets    | 个/s  | 同一实例内容器共享网络，实例(pod)的网络入包量 |
| 实例网络出包量 | pod_out_packets   | 个/s  | 同一实例内容器共享网络，实例(pod)的网络出包量 |
## 3. 输出参数

| 参数名称       | 类型       | 描述                  |
| ---------- | -------- | ------------------- |
| code       | Int      | 错误码, 0: 成功, 其他值表示失败 |
| message    | String   | 返回信息                |
| startTime  | Datetime | 起始时间                |
| endTime    | Datetime | 结束时间                |
| metricName | String   | 指标名称                |
| period     | Int      | 监控统计周期              |
| dataPoints | Array    | 监控数据列表              |


## 4. 错误码表

| 错误代码 | 错误描述    | 英文描述                                 |
| ---- | ------- | ------------------------------------ |
| -502 | 资源不存在   | OperationDenied.SourceNotExists      |
| -503 | 请求参数有误  | InvalidParameter                     |
| -505 | 参数缺失    | InvalidParameter.MissingParameter    |
| -507 | 超出限制    | OperationDenied.ExceedLimit          |
| -509 | 错误的维度组合 | InvalidParameter.DimensionGroupError |
| -513 | DB操作失败  | InternalError.DBoperationFail        |

## 5. 示例

输入

<pre>
https://monitor.api.qcloud.com/v2/index.php?
&<a href="/doc/api/405/公共请求参数" title="公共请求参数">公共请求参数</a>
&namespace=qce/docker
&metricName=pod_in_bandwidth
&dimensions.0.name=clusterId
&dimensions.0.value=cls-xxxxx
&dimensions.1.name=serviceName
&dimensions.1.value=test
&dimensions.2.name=namespace
&dimensions.2.value=default
&dimensions.3.name=podName
&dimensions.3.value=test-3488000495-nj6s9
&startTime=2017-03-28 14:10:00
&endTime=2016-03-28 15:10:00
&period=60
</pre>

输出

```
{
	"code": 0,
	"message": "",
	"metricName": "pod_in_bandwidth",
	"startTime": "2017-03-28 14:10:00",
	"endTime": "2016-03-28 15:10:00",
	"period": 60,
    "dataPoints": [
        30,
        35，
        40
    ]
}
```