## 1. 接口描述

域名：monitor.api.qcloud.com
接口：GetMonitorData

腾讯云消息服务（Cloud Message Queue）是分布式消息队列服务，能够为分布式部署的不同应用之间或者一个应用的不同组件之间，提供基于消息的可靠的异步通信机制，消息被存储在高可靠、高可用的CMQ队列中，多进程可以同时读写，互不干扰。
CMQ 分为两种模型：queue和topic

查询消息服务CMQ产品监控数据，入参取值如下：
namespace：qce/cmq
维度名称取值：queueId,queueName
dimensions.0.name=queueId
dimensions.0.value为CMQ 队列实例id
dimensions.1.name=queueName
dimensions.1.value为CMQ 队列实例名称

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/405/公共请求参数" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为GetMonitorData。

### 2.1输入参数

| 参数名称               | 必选   | 类型       | 输入内容          | 描述                                       |
| ------------------ | ---- | -------- | ------------- | ---------------------------------------- |
| namespace          | 是    | String   | qce/cvm       | 命名空间，每个云产品会有一个命名空间，具体名称见输入内容一栏。          |
| metricName         | 是    | String   | 具体的指标名称       | 指标名称，具体名称见2.2                            |
| dimensions.0.name  | 是    | String   | queueId       | 入参为CMQ 队列实例id                            |
| dimensions.0.value | 是    | String   | 具体的CMQ 队列实例id | 输入具体queueId，如queue-3abkyggi              |
| dimensions.1.name  | 是    | String   | queueName     | 入参为CMQ 队列实例名称                            |
| dimensions.1.value | 是    | String   | 具体的CMQ 队列实例名称 | 输入具体queueName，如 test1                    |
| period             | 否    | Int      | 60/300        | 监控统计周期，绝大部分指标支持60s统计粒度，部分指标仅支持300s统计粒度，统计粒度根据指标的不同而变。输入参数时可参考2.2的指标详情列表。 |
| startTime          | 否    | Datetime | 起始时间          | 起始时间，如"2016-01-01 10:25:00"。 默认时间为当天的”00:00:00” |
| endTime            | 否    | Datetime | 结束时间          | 结束时间，默认为当前时间。 endTime不能小于startTime       |

### 2.2 指标名称

| 指标名称                 | 含义         | 单位   | 维度                |
| -------------------- | ---------- | ---- | ----------------- |
| invisibleMsgNum      | 队列不可见消息数量  | 条    | queueId,queueName |
| visibleMsgNum        | 队列可见消息数量   | 条    | queueId,queueName |
| sendMsgReqCount      | 发送消息请求量    | 次    | queueId,queueName |
| sendMsgNum           | 发送的消息数量    | 条    | queueId,queueName |
| recvMsgReqCount      | 接收消息请求量    | 次    | queueId,queueName |
| recvMsgNum           | 接收的消息数量    | 条    | queueId,queueName |
| recvNullMsgNum       | 接收空消息的数量   | 条    | queueId,queueName |
| batchRecvNullMsgNum  | 批量接收空消息的数量 | 条    | queueId,queueName |
| delMsgReqCount       | 删除消息的请求量   | 次    | queueId,queueName |
| delMsgNum            | 删除消息的数量    | 条    | queueId,queueName |
| sendMsgSize          | 发送的消息大小    | MB   | queueId,queueName |
| batchSendMsgSize     | 批量发送的消息大小  | MB   | queueId,queueName |
| batchSendMsgReqCount | 批量发送消息的请求量 | 次    | queueId,queueName |
| batchRecvMsgReqCount | 批量接收消息的请求量 | 次    | queueId,queueName |
| batchDelMsgReqCount  | 批量删除消息的请求量 | 次    | queueId,queueName |


## 3. 输出参数

| 参数名称       | 类型       | 描述                  |
| ---------- | -------- | ------------------- |
| code       | Int      | 错误码, 0: 成功, 其他值表示失败 |
| message    | String   | 返回信息                |
| startTime  | Datetime | 起始时间                |
| endTime    | Datetime | 结束时间                |
| metricName | String   | 指标名称                |
| period     | Int      | 监控统计周期              |
| dataPoints | Array    | 监控数据列表              |


## 4. 错误码表

| 错误代码 | 错误描述    | 英文描述                                 |
| ---- | ------- | ------------------------------------ |
| -502 | 资源不存在   | OperationDenied.SourceNotExists      |
| -503 | 请求参数有误  | InvalidParameter                     |
| -505 | 参数缺失    | InvalidParameter.MissingParameter    |
| -507 | 超出限制    | OperationDenied.ExceedLimit          |
| -509 | 错误的维度组合 | InvalidParameter.DimensionGroupError |
| -513 | DB操作失败  | InternalError.DBoperationFail        |

## 5. 示例

输入

<pre>
https://monitor.api.qcloud.com/v2/index.php?
&<a href="/doc/api/405/公共请求参数" title="公共请求参数">公共请求参数</a>
&namespace=qce/cmq
&metricName=invisibleMsgNum
&dimensions.0.name=queueId
&dimensions.0.value=queue-06c1jrku
&dimensions.1.name=queueName
&dimensions.1.value=qta-cbeba170-a6d9-11e6-8372-9000e086cbc0
&startTime=2016-06-28 14:10:00
&endTime=2016-06-28 14:20:00
</pre>

输出

```
{
    "code": 0,
    "message": "",
    "metricName": "invisibleMsgNum",
    "startTime": "2016-06-28 14:10:00",
    "endTime": "2016-06-28 14:20:00",
    "period": 300,
    "dataPoints": [
        50,
        35，
        20
    ]
}
```