## 1. 接口描述

域名：monitor.api.qcloud.com
接口：GetMonitorData

查询黑石物理服务器监控数据，入参取值如下：
namespace：qce/cpm
dimensions.0.name=instanceId
dimensions.0.value为黑石物理机的实例ID

| 英文         | 中文含义                                     |
| ---------- | ---------------------------------------- |
| instanceId | 黑石物理服务器实例ID，通过查询黑石物理服务器接口[DescribeDevice](/document/product/386/6728)获得 |

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/405/公共请求参数" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为GetMonitorData。

### 2.1输入参数

| 参数名称               | 必选   | 类型       | 输入内容          | 描述                                       |
| ------------------ | ---- | -------- | ------------- | ---------------------------------------- |
| namespace          | 是    | String   | qce/cvm       | 命名空间，每个云产品会有一个命名空间，具体名称见输入内容一栏。          |
| metricName         | 是    | String   | 具体的指标名称       | 指标名称，具体名称见2.2                            |
| dimensions.0.name  | 是    | String   | instanceId    | 入参为黑石物理机的实例ID                            |
| dimensions.0.value | 是    | String   | 具体的黑石物理机的实例ID | 输入具体instanceId                           |
| period             | 否    | Int      | 60/300        | 监控统计周期，绝大部分指标支持60s统计粒度，部分指标仅支持300s统计粒度，统计粒度根据指标的不同而变。输入参数时可参考2.2的指标详情列表。 |
| startTime          | 否    | Datetime | 起始时间          | 起始时间，如"2016-01-01 10:25:00"。 默认时间为当天的”00:00:00” |
| endTime            | 否    | Datetime | 结束时间          | 结束时间，默认为当前时间。 endTime不能小于startTime       |

### 2.2 指标名称
> 当前黑石物理服务器监控维度的取值周期为300秒(period参数)，暂不支持更细粒度的数据获取

| 指标名称             | 含义                 | 单位      | 纬度         |
| ---------------- | ------------------ | ------- | ---------- |
| cpu_usage        | CPU使用率             | %       | instanceId |
| cpu_load_avg     | CPU平均负载            | 标量，无单位  | instanceId |
| mem_use          | MEM内存使用量           | MByte   | instanceId |
| mem_proc_use     | 应用内存使用量            | MByte   | instanceId |
| mem_virtual_use  | 虚拟内存使用量            | MByte   | instanceId |
| mem_usage        | 内存使用率              | %       | instanceId |
| io_read_traffic  | 磁盘IO读流量            | KByte/s | instanceId |
| io_write_traffic | 磁盘IO写流量            | KByte/s | instanceId |
| io_await         | 磁盘IO等待时间           | ms      | instanceId |
| io_util          | 磁盘IO的CPU使用率        | %       | instanceId |
| io_service_time  | 磁盘IO的服务时间          | ms      | instanceId |
| lan_outtraffic   | 内网网卡出带宽(多个网卡，取最大值) | Mbps    | instanceId |
| lan_intraffic    | 内网网卡入带宽(多个网卡，取最大值) | Mbps    | instanceId |
| lan_outpkg       | 内网网卡出包量(多个网卡，取最大值) | 个/秒     | instanceId |
| lan_inpkg        | 内网网卡入包量(多个网卡，取最大值) | 个/秒     | instanceId |
| wan_outtraffic   | 外网出带宽              | Mbps    | instanceId |
| wan_intraffic    | 外网入带宽              | Mbps    | instanceId |
| wan_outpkg       | 外网出包量              | 个/秒     | instanceId |
| wan_inpkg        | 外网入包量              | 个/秒     | instanceId |
| wan_outflux      | 外网出流量              | GByte   | instanceId |


## 3. 输出参数

| 参数名称       | 类型       | 描述                  |
| ---------- | -------- | ------------------- |
| code       | Int      | 错误码, 0: 成功, 其他值表示失败 |
| message    | String   | 返回信息                |
| startTime  | Datetime | 起始时间                |
| endTime    | Datetime | 结束时间                |
| metricName | String   | 指标名称                |
| period     | Int      | 监控统计周期              |
| dataPoints | Array    | 监控数据列表              |


## 4. 错误码表

| 错误代码 | 错误描述    | 英文描述                                 |
| ---- | ------- | ------------------------------------ |
| -502 | 资源不存在   | OperationDenied.SourceNotExists      |
| -503 | 请求参数有误  | InvalidParameter                     |
| -505 | 参数缺失    | InvalidParameter.MissingParameter    |
| -507 | 超出限制    | OperationDenied.ExceedLimit          |
| -509 | 错误的维度组合 | InvalidParameter.DimensionGroupError |
| -513 | DB操作失败  | InternalError.DBoperationFail        |

## 5. 示例

输入

<pre>
https://monitor.api.qcloud.com/v2/index.php?
&<a href="/doc/api/405/公共请求参数" title="公共请求参数">公共请求参数</a>
&namespace=qce/cpm
&metricName=cpu_usage
&dimensions.0.name=instanceId
&dimensions.0.value=cpm-xxxx
&startTime=2016-06-28 14:10:00
&endTime=2016-06-28 14:20:00
&period=300
</pre>

输出

```
{
    "code": 0,
    "message": "",
    "metricName": "inpkg",
    "startTime": "2016-06-28 14:10:00",
    "endTime": "2016-06-28 14:20:00",
    "period": 300,
    "dataPoints": [
        30,
        35，
        40
    ]
}
```