## 1. 接口描述

本接口 (CreateKey) 用于创建用户管理数据秘钥的主秘钥CMK（Custom Master Key），通过CMK后续可以调用其他接口诸如创建数据秘钥、加解密等操作。

每个用户，在每个地区，最多可以创建1000个用户主密钥。

如果用户有提高数量限制的需求，可以通过工单系统向我们提交申请。

kms请求域名接口和说明可参考[地域和域名说明](https://cloud.tencent.com/document/product/573/8922)。

> 任何时候，包括内测期间，如果使用外网域名产生公网下行流量，都会收取流量费用。 所以强烈建议服务在腾讯云上的用户使用**内网**域名，内网不会产生流量费用。

- 输入参数有些是可选的，不填取默认值。
- 输出参数在成功情况下所有出参都会返回给用户；失败情况下，至少会有code, message, requestId返回。


## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，其它参数见[公共请求参数](https://cloud.tencent.com/document/product/573/8913)页面。

| 参数名称 | 是否必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| description| 否| String| key的描述。|
| alias| 否| String| 作为密钥更容易辨识，更容易被人看懂的别名。 可为空，0-32个字符。|
| keyUsage| 否| String| 指定key的用途。目前，默认为 ‘ENCRYPT/DECRYPT’，即key用于加密和解密。|


## 3. 输出参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 0：表示成功，others：错误，详细错误见下表。|
| message | String | 错误提示信息。|
| requestId| String| 服务器生成的请求Id。出现服务器内部错误时，用户可提交此 Id 给后台定位问题。|
| keyMetadata| Struct| 密钥信息。|

keyMetadata定义如下:

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| keyId| String| key的全局唯一标识符。|
| alias| String| 作为密钥更容易辨识，更容易被人看懂的别名。|
| createTime|  Uint32| 密钥创建时间，unix时间戳。|
| description|  String| key的描述。|
| keyState|  String| key的状态。|
| keyUsage|  String| key的用途。|



<table class="t">
<tbody><tr>
<th> <b>错误代码</b>
</th><th> <b>模块错误代码</b>
</th><th> <b>英文提示</b>
</th><th> <b>描述</b>
</th></tr>
<tr>
<td> 4490
</td><td> 10470
</td><td> string of KeyUsage must be ENCRYPT/DECRYPT
</td><td> KeyUsage参数错误，目前只能是ENCRYPT或者是DECRYPT。
</td></tr>
<tr>
<td> 4500
</td><td> 10480
</td><td> alias is already existed in your account, please input another unique one
</td><td> 别名已经存在，请换一个别名。
</td></tr>

<tr>
<td> 4510
</td><td> 10610
</td><td> number of CMK in your account has reached the limit
</td><td> CMK数量达到最大值。一个账户的CMK数量是有限(200)的，达到最大值后，就不能创建新的CMK了。
</td></tr>
<tr>
<td> 4520
</td><td> 10620
</td><td> keySpec value error
</td><td> keySpec错误。
</td></tr>
</tbody></table>

注意：上表所列错误码是接口特有错误码，如果您要查找的错误码不在其中，可能在[公共错误码](https://cloud.tencent.com/document/product/573/8919)中。


## 4. 示例

输入：

<pre>
 https://kms-sh.api.tencentyun.com/v2/index.php?Action=CreateKey
 &alias=kms-test-1
 &description=this key is for kms test, and don't delete it
 &keyUsage=ENCRYPT/DECRYPT
 &<<a href="https://cloud.tencent.com/doc/api/229/6976">公共请求参数</a>>
</pre>

输出：

```
{
"code" : 0,
"message" : "",
"requestId":"14534664555",
"keyMetadata": {
"keyId": "kms-94kalsdf",
"alias":"kms-test-1",
"createTime":1483945424,
"description": "this key is for kms test, and don't delete it",
"keyState": "Enabled",
"keyUsage": "ENCRYPT/DECRYPT"
}
```






