
### 1. 如何实现直播秒开能力？
**秒开**即从触发视频播放开始到真正看到第一帧画面所消耗的时间要尽可能的短，不能让观众有明显的等待时间：
![](//mc.qcloudimg.com/static/img/9a1541e3d8f6796e8025b571d5267c7c/image.png)

这种能力主要依靠云端服务的优化以及播放器的配合，如果您组合使用腾讯RTMP SDK 配合视频云服务实现直播能力，最快可以实现**200ms左右**的首屏打开速度，如果网络下行足够够好的话甚至可以瞬开。

不过需要注意的是，SDK中只有**极速模式**和**自动模式**才支持秒开，流畅模式因为有强制缓冲逻辑，并不支持秒开。

### 2. 如何实现画质和流量的平衡？
影响画质的主要因素是三个：**分辨率**、**帧率**和**码率**。
- **分辨率**：目前腾讯云RTMP SDK支持的三种分辨率均为9:16的常规分辨率：360\*480，540\*960，720\*1280。

- **帧率**：FPS <=10 会明显感觉到卡顿，但也并不是越高越好，一般推荐是20FPS即可达到很流畅的效果。

- **码率**：编码器每秒编出的数据大小，单位是kbps，比如800kbps代表编码器每秒产生800kb（或100KB）的数据。

**好的画质是分辨率、帧率和码率三者之间的平衡**：
- **码率不是越大越好**
如果不做码率大小上的限制，那么分辨率越高，画质越细腻；帧率越高，视频也越流畅，但相应的码率也会很大，因为每秒钟需要用更多的数据来承载较高的清晰度和流畅度。这对腾讯云而言这是好事（收入跟流量呈正比），但对您可能意味着更多的费用开支。
   
- **帧率不要超过24**
如果限定一个码率，比如800kbps，那么帧率越高，编码器就必须加大对单帧画面的压缩比，也就是通过降低画质来承载足够多的帧数。如果视频源来自摄像头，24FPS已经是肉眼极限，所以一般20帧的FPS就已经可以达到很好的用户体验了。

 有些玩过3D游戏的朋友可能会说，游戏的帧率越高越流畅。这里要注意一定不要混淆场景：游戏追求高帧率的目的是为了尽可能让3D模型渲染出来的运动效果更加接近真实运动轨迹，所以帧率越高越好。 但对摄像头而言，它要采集的目标是真实世界的物体，真实世界本来就没有刷新率的说法，所以这个理论不适用。
 
- **分辨率不盲目攀高**
 如果限定一个码率，比如800kbps，那么分辨率越高就会让编码器越 “为难" ，可以想象，它必须拆东墙补西墙，通过减少色彩信息或者引入马赛克这种“鱼目混珠”的手段来承载足够多的像素点。所以，同样的是2G的一个电影文件，1080p画质的版本可能不如720p画质的版本看起来更清晰。

 如果您之前没有太多音视频编码的实战经验，我们比较建议您使用demo里的设置参数，我们在DEMO中提供了720p、540p 以及 360p 三种画质选择以及相应的配置。


### 3. 如何降低延迟并减少画面卡顿？
这里说的**延迟**是主播 -> 观众的时间延迟，而**卡顿**指的是出现500ms以上的播放停滞。
如果是在完美的网络环境下，可以做到超低延迟下没有卡顿，但现实是国内的网络环境并不完美，数据在经过互联网传输时必然会有抖动和丢包，从而对播放端的流畅播放产生影响。
  ![tx_live_service_lag](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/tx_live_service_lag.jpg)

因此，为了缓解这些不稳定因素，云服务和终端APP都需要引入一些缓冲，但缓冲的加入就不可避免地引入了延迟。
所以，**延迟和流畅是一架天平的两端**，如果过分强调降低延迟，就会导致轻微的网络波动即产生明显的播放端卡顿。反推之，如果过分强调流畅，就意味着引入大量的延迟，一个典型的案例就是HLS协议，通过引入10-30秒的延迟来实现流畅的播放体验。

为了能够让您无需了解过多流控处理知识就能优化出较好的播放体验，腾讯视频云RTMP SDK经过多个版本的改进，优化出一套自动调节技术，并在其基础上推出了三种比较优秀的延迟控制方案：
- **自动模式**：如果您不太确定您的主要场景是什么，可以选择这个模式。
  >当把播放器中的 setAutoAdjustCache 开关打开，即为自动模式，在该模式下，播放器会根据当前网络情况，对延迟进行自动调节，默认情况下，播放器会在1s - 5s 这个区间内自动调节延迟大小（您也可以通过setMinCacheTime 和 setMaxCacheTime对默认值进行修改），以保证在足够流畅的情况下尽量降低观众跟主播端的延迟，确保良好的互动体验。

- **极速模式**：主要适用于**秀场直播**和**全民直播**等对延迟要求比较苛刻的场景。
  > 我们所谓的极速模式，即（setMinCacheTime = setMaxCacheTime = 1s） ， 而您也发现了，自动模式跟极速模式的差异只是MaxCacheTime 有所不同 （极速模式的 MaxCacheTime 一般比较低，而自动模式的MaxCacheTime 则相对较高 ），这种灵活性主要得益于SDK内部的自动调控技术，可以在不引入卡顿的情况下自动修正延时大小，而MaxCacheTime 反应的就是调节速度：MaxCacheTime的值越大，调控速度会越发保守，当然卡顿概率就会越低。

- **流畅模式**：主要适用于**游戏直播**和**点播场景**等对延迟要求不是特别高的场景。
  > 当把播放器中的 setAutoAdjustCache 开关关闭，即为流畅模式，在该模式下，播放器采取的处理策略跟Adobe Flash内核的缓存出策略如出一辙：当视频出现卡顿后，会进入 loading 状态直到缓冲区蓄满，之后进入playing状态，直到下一次遭遇无法抵御的网络波动。默认情况下，缓冲大小为5s，您可以通过setCacheTime进行更改。


### 4. Android推流如何达到30FPS?
如果您在Android平台上通过setVideoFPS设置帧率为30，可能会发现实际帧率只有20FPS，什么原因？

- **硬件限制**
  部分安卓机器的Camera接口无法实现30FPS及以上的数据采集频率，这个问题在很多机型的前置摄像头上尤为明显。

- **编码不足**  我们一般说编码不足是说编码器的计算量太大，机器性能无法胜任，对于Android而言尤为明显。其实Android的CPU核心数一直领先iPhone，然而CPU晶体管数量却没有什么优势，这就意味着Android手机的单个核心计算能力是远不及iPhone的，再加上Android系统的降频策略往往比较激进，所以每个核心的计算能力被软件又限制了一层。

- **优化方案**
  如果您得目标画质是360 * 640 级别，主要场景是是做美女主播等秀场模式，那么软件编码在绝大多数中高端Android手机上是可以实现30FPS的，如果更高的分辨率，就推荐启用硬件编码了。Android RTMP SDK的[硬件编码](https://cloud.tencent.com/doc/api/258/4734#step-7.3A-.E7.A1.AC.E4.BB.B6.E7.BC.96.E7.A0.81)中有详细介绍，当然，鱼与熊掌不可兼得，这会牺牲部分机型的兼容。

- **20FPS足以**
  是的，如果视频源来自摄像头捕捉的画面，20FPS大部分场景下就已经安全足够了，要知道24FPS以上，我们的眼睛就无法看到有任何不流畅的地方。更高的帧率则只适合于手机游戏直播这类用3D模型和实时计算模拟出的动画场景。

