﻿
## 调用方式
下图是直播码后台接口的调用方式，简单分为两种，主动请求和被动通知：
![](//mc.qcloudimg.com/static/img/ae90fa870c89c023a409988377de0bdc/image.png)

### 主动请求
即客户服务器主动调用腾讯云后台API查询所需的信息或者对直播流进行控制，包括如下API:

| API                                | 功能介绍                                                   |
|---------------------------------|--------------------------------------------------------------|
| [Get_LiveStat](https://cloud.tencent.com/doc/api/258/6110)  | 统计信息查询 - 查询推流和播放相关信息|
| [Get_LivePushStat](https://cloud.tencent.com/doc/api/258/6110) | 统计信息查询 - 查询推流相关信息|
| [Get_LivePlayStat](https://cloud.tencent.com/doc/api/258/6110)  |  统计信息查询 - 查询播放相关信息 |
| [Live_Channel_GetStatus](https://cloud.tencent.com/doc/api/258/5958) |  仅查询某条流的状态信息（旧版本接口） | 
| [Live_Channel_SetStatus](https://cloud.tencent.com/doc/api/258/5959) | 对某条流实行**禁播**操作，主要用于鉴黄场景 | 
| [Live_Tape_GetFilelist](https://cloud.tencent.com/doc/api/258/5960)| 查询某条流在直播过程中的**录制**文件列表 | 
| [Live_Queue_Get](https://cloud.tencent.com/doc/api/258/5961)| 查询某条流在直播过程中的**截图**文件列表 | 


### 被动通知
[通知服务](https://cloud.tencent.com/doc/api/258/5957)，即腾讯云后台服务集群在一些关键事情发生时，以事件的形式主动通知客户服务器，需要客户提前到腾讯云注册接收事件通知的URL，目前支持的通知类型有：
 
| 事件类型（event_type）   | 功能介绍                                                          |
|:-------------------------------:|--------------------------------------------------------------|
| 0                                   | 通知一条直播流发生断流                                     | 
| 1                                   | 通知一条直播流开始或者恢复推流                        | 
| 100                               | 通知有一个新的录制文件已经生成                         | 
| 200                               | 通知有一个新的截图文件已经生成                         | 

## 安全检查

### 方案介绍
出于性能考虑，直播码相关后台API没有使用HTTPS接入方式，故安全检查非常重要。直播码相关的服务端API都使用了同一种统一的安全检查方法，即**t + sign 校验**：
- **t（过期时间）**：如果一个API请求或者通知中的 t 值所规定的时间已经过期，则可以判定这个请求或者通知为无效的，这样做可以防止网络重放攻击。t 的格式为UNIX时间戳，即从1970年1月1日（UTC/GMT的午夜）开始所经过的秒数。

- **sign（安全签名）**:  <font color='blue'>sign = MD5(key + t) </font>，即把加密key 和 t 进行字符串拼接后，计算一下md5值。这里的key即CGI调用key，您在腾讯云直播管理控制台开通直播码服务时可以指定，如下图所示：
![](//mc.qcloudimg.com/static/img/28a16dbab36fc3867301d2311204b8e4/image.png)

由于MD5是不可逆的hash算法，所以只要确保KEY不泄露，即使攻击者拿到很多对t和sign也无法反算出KEY值，进而无法进行伪装攻击。

### 校验对象

- **主动请求**
对于主动请求这种场景，调用方是您的后台服务器，被调用方式腾讯云后台集群，所以t+sign是由您的后台服务器生成并附在请求头中，之后腾讯云后台对其进行安全确认，以确保请求来自真实的腾讯云客户。

- **被动通知**
对于被动通知这种场景，通知的来源是腾讯云后台集群，被通知方是您的后台服务器，所以t+sign是由腾讯云负责生成并附在通知消息中，之后您的后台服务器对其进行安全确认，以确保请求确实是来自腾讯云。


### 计算示例
- **计算 t**
   比如我们现在的时间是 2016-08-22 15:16:27， 我们希望有效期是1分钟，也就是 2016-08-22 15:16:27 以后再收到携带这个 t 的请求或者通知即判定为非法的：
```
	t = "2016-08-22 15:17:27" = 1471850187
```
  
- **计算 sign**
    假设我们的key是 **5d41402abc4b2a76b9719d911017c592**，那么我们计算的签名结果就是：
```
	sign = MD5(5d41402abc4b2a76b9719d911017c5921471850187) = b17971b51ba0fe5916ddcd96692e9fb3
```
 
 



