﻿﻿﻿
## 功能介绍
所谓安全防盗链，是一种加了防盗链签名的URL，经过签名的URL能够跟腾讯云服务器的安全机制进行配合，可以将URL的使用权限定在您的APP上，恶意第三方拿到URL也不能使用和传播。

（1）**推流** - 推流URL加防盗链的必要性极高，尤其是在直播码跟用户ID绑定的情况下，因为知名主播的直播码ID很容易被攻击者窃取，进而伪装主播进行抢占式推流，所以为推流URL增加防盗链签名，确保只有真正的主播才能在登录后拿到防盗链签名非常有必要。

（2）**播放** - 播放URL加防盗链并不是100%必要的，只有在您的视频源是热门资源时（比如某个独家的赛事直播）才比较有价值，因为您要防止您的竞争对手拿到播放地址后在自家的APP里上架这个节目。播放地址防盗链引入后的副作用就是播放时可能需要申请防盗链签名，导致直播打开速度不稳定。

## 原理介绍
下图都是典型的安全防盗URL，您会发现这些地址都有一个共同的特点，就是在原来的推流或者播放地址后拼接**txSecret**和**txTime**参数。

![](//mccdn.qcloud.com/static/img/b75148662176ff29eef17210b5d3d4f1/image.png)

**txTime**声明了该播放器的有效时间，比如5分钟，当这个地址在5分钟后被再次使用时，腾讯云将会判定其为过期地址而拒绝服务。

但我们知道，简单声明txTime是没有意义的，因为任何攻击者都可以在一个窃取的URL后面拼接上一个声明100天过期的txTime，所以腾讯云需要有一种安全措施确保攻击者无法伪造txTime，这个安全措施就是**txSecret**。

**txSecret**是您的服务器计算出来的一个安全签名，计算公式是：**txSecret = MD5( KEY + stream_id + txTime )**

>- **KEY**
>  需要您跟腾讯云在控制台上提交或者兑换的**安全密钥**，您应当确保除了您和腾讯云之外，外部无法获知，而且最好定期更换。
>	
>- **stream_id**
>	即直播码，当同时在线的主播比较多的时候，txTime 很容易碰撞，所以加入 stream_id 来防碰撞。
>	
>- **MD5**
>	最著名的单向不可逆HASH算法了，因为不可逆性，所以攻击者无法根据txSecret逆向计算出KEY，也就无法根据自己伪造的txTime计算出一个可以通过腾讯云验证的txSecret来。


## 合成方法
安全防盗链机制需要您的服务器和腾讯云后台协同才能完成，如下图：
![](//mccdn.qcloud.com/static/img/4ea1512fd335f68f30cca0a01e902966/image.png)

- **step1 - 交换秘钥**
首先，您需要在官网的控制台，协商一个**加密密钥**，这个加密密钥用于在您的服务器上生成防盗链签名，由于腾讯云跟您持有同样的密钥，所以您生成的防盗链签名，腾讯云是可以进行解密确认的。

 加密秘钥分为**推流防盗链KEY**和**播放防盗链KEY**，前者用于生成推流防盗链URL，后者用于生成播放防盗链URL。目前在[直播管理控制台](https://console.cloud.tencent.com/live)上可以自助配置推流防盗链KEY，如下图：
 ![](//mc.qcloudimg.com/static/img/6dcddb480ffab18886d8b245a2707af9/image.png)

 > 播放防盗链KEY由于同步周期长，不适合调试期频繁修改，如您需要配置请联系我们。

- **step2 - 生成txTime**
签名中明文部分为txTime，含义是该链接的有效期，比如现在我当前的时间是2016-07-29 11:13:45，而且期望新生成的URL是在5分钟后即作废，那么txTime就可以设置为 2016-07-29 11:18:45。

 不过这么长一串时间字符串放在URL里显然不太“经济”，实际适用中，我们是把  2016-07-29 11:18:45 转换成Unix时间戳，也就是1469762325 （转换方式各种后台编程语言都由直接可用的时间函数来处理），然后转换成16进制，也就是 txTime=579ACB15。

- **step3 - 生成txSecret**
txSecret的生成方法是 = **MD5(KEY+ stream_id + txTime)**，这里的 KEY 就是您在Step1中跟腾讯云交换的加密密钥，stream_id在本例中为 8888_test001，txTime为刚才计算的579ACB15，MD5即标准的MD5单向不可逆哈希算法。

- **step4 - 合成防盗链地址**
  现在我们有了推流（或者播放）URL，有了用来告知腾讯云该URL过期时间的txTime，有了只有腾讯云才能解密并且验证的txSecret，就可以拼合成一个防盗链的安全URL了。
