## 方案概述
直播码方案是不同于频道托管的另一套**直播频道管理方案**，不同之处在于：

[频道托管](https://cloud.tencent.com/doc/api/258/5659)模式适合于做直播活动，因为从频道的创建，到地址管理、禁播、后台打水印，各种功能您都能在[管理控制台](https://console.cloud.tencent.com/live)上找到网页操作入口，点点鼠标就可以完成所有工作。

然而，对于需要频繁创建和管理直播频道的场景，比如类似映客花椒这样的直播APP而言，这套模式就显得比较掣肘了：您需要频道的跟腾讯云后台同步主播频道的名字、描述、状态、地址等信息，同时要理解其内部的各种安全保护规则：比如后台API有每分钟x次的访问次数限制，再比如没有关闭的频道不允许删除等等。

**直播码方案**则更适合于非手工场景，在这种模式下，直播流的控制和管理允许完全由客户自主掌控，除了对接难度低之外，这套方案的定制空间也非常大：
（1）**自主定义推流和播放地址**：不需要到腾讯云申请推流或者播放URL，您可以自主指定，比如大部分客户直接拿用户的账号ID拼出推流URL即可推流。
（2）**更符合直播类APP的开发**：直播码方案里，腾讯云将主要精力用于推流、转码、CDN分发、录制以及安全保护等音视频相关功能，状态、列表、地址等部分则完全放开，不做过多限制和干预。您可以自主实现自己需要的业务场景，也可以选择使用腾讯云后台API来获取频道信息，不需要遵循腾讯云后台的各种限制规则，自由度非常高，适合直播APP这种比较复杂的直播应用场景。

![](//mccdn.qcloud.com/static/img/aa6cf00971df050b3b781b126064131f/image.png)

## 对接攻略

直播码方案上手非常简单，只需要按如下三步实现对接，您就可以拥有一个超简单版的直播后台了：

### 1. 开启直播码模式
腾讯云视频直播服务器的初始的接入模式是频道托管模式，您需要手动切换一下才能进入直播码模式，切换操作请参考[服务开通](https://cloud.tencent.com/doc/api/258/6100)。


### 2. 分配推流地址
主播在开始推流之前会先到您的后台服务器上申请推流地址，直播码的推流地址有其拼装规则，如下：
![](//mc.qcloudimg.com/static/img/6ea8ebb159c57fc4ef934a5e57a55dcd/image.png)

- **BIZID**: 
上图中的8888只是个示例数字，代表您在腾讯云分配到的BIZID，BIZID您可以在[直播管理控制台](https://console.cloud.tencent.com/live)的顶部区域找到它，如下图：
![](//mc.qcloudimg.com/static/img/1400072859844bc1fa5dcf45bfa205c1/image.png)

- **直播码**：
上图中8888_test_12345_test就是直播码了，这里唯一的要求就是以**BIZID+下划线**作为前缀，剩下的部分您可以自由指定，只要确保不跟已经分配过的直播码冲突就行了。

- **防盗链签名**：
上图中的txTime标志URL的过期时间，txSecret则叫做防盗链签名，两个部分合在一起用于安全保护，详情可以参考[安全保护](https://cloud.tencent.com/doc/api/258/5693)。

- **地址生成器**：
我们在管理控制台中准备了一个地址生成器，用来方便您平时测试URL，毕竟手算防盗链签名不太方便：
![](//mc.qcloudimg.com/static/img/7e0b45fcf24595bfb31da3e3dbc8812e/image.png)

> **其他客户怎么做？**
> 很多客户选择用用户的账号ID作为直播码，比如您在腾讯云直播平台的BIZID为2121，您的用户大部分是手机号注册的，所以账号即为手机号，比如15919131751，那么您可以给TA分配一个推流地址为:
> 
>  `rtmp://2121.livepush.myqcloud.com/live/2121_15919131751?txSecret=aaa&txTime=bbb`


### 3. 管理直播列表
您可以自己根据需求维护直播频道列表，下图是一种推荐的实现方案：
![server](//mccdn.qcloud.com/static/img/56bb81fdbc4c5ab4cdea9448cbe3554c/image.png)

- **Step1: 发起直播**: 
>APP在发起直播时会向服务器请求一个推流URL，推流URL的生成方式我们在刚才已经介绍过了。
>
>您的服务器在返回APP一个推流URL的同时，也要向直播列表中添加一条记录。该记录中最重要的信息就是**直播码**和**用户ID**了（不少客户会直接拿用户ID作为房间号，这样后面管理很方便），除此之外，您还可以根据需要增加**封面图片地址**、**点赞人数**以及**正在观看人数**等点缀列表用的信息。

- **Step2: 结束直播**: 
> APP在结束直播时，同样需要通知一下服务器，这样服务器就可以第一时间把相应的记录删掉，否则直播列表里就满满都是已经离线的主播了。

- **Step3: 漏网之鱼**: 
> 但Step2总有意外，比如主播的APP崩溃了，或者流量突然用完了，这类情况会让APP根本没有机会通知服务器该主播已经下线，这些情况如果不考虑，会在直播列表中残留一些 “僵尸频道”，有两种解决办法：
> 
> （方案一）您可以使用腾讯云的**[消息通知服务](https://cloud.tencent.com/doc/api/258/5957)**：您的服务器可以注册一个自己的**回调URL**给腾讯云，腾讯云会在您关心的频道在线状态有变化时通知给您，这种方案反应比较实时。
> 
> （方案二）您可以通过腾讯云的状态查询接口（**[Live_Channel_GetStatus](https://cloud.tencent.com/doc/api/258/5958)**）定时地检查所有<font color='red'>“正在直播中”</font>的频道是不是真的都是“正在推流”状态，不过这种方案在要查询的频道数特别多的时候，响应速度不理想。推荐的调用方式是一分钟轮询一次，如果某个频道在连续三次的轮询结果中均为离线，您就可以考虑将它的状态设置为离线了。
>
> （方案三）也可以让在APP和服务器之间增加**心跳机制**：主播在推流时，每分钟向服务器发送一个心跳包，如果服务器连续三次没有收到心跳包，即判定主播已经离线。

### 4. 对接直播播放
有了直播码，推流地址就可以拼装出来，播放地址也同样，下图是用直播码 **8888_test_12345_test** 拼装出来的rtmp flv 和 hls 三种播放地址，APP拿到播放地址后就可以直接丢给腾讯云的RTMP SDK进行播放了：
![play](//mccdn.qcloud.com/static/img/8438aadc91d16a1f02921bb178881893/image.png)

> **特别提醒**
> <font color='red'>极不推荐您在APP端拼装播放地址</font>，这样会导致逻辑被锁死在APP的代码上，建议由服务器拼装完成后返送给APP，这是为后续扩展考虑，比如随着产品的发展，您可能要在地址里增加更多的参数和后缀来实现更多的功能特性。

### 5. 对接录制回看
所谓录制回看，是指您可以把直播过程录制下来，然后作为线上点播视频，以回看的形式提供给您的APP用户，具体对接方案可以参考[录制回看](https://cloud.tencent.com/doc/api/258/5691)。



