# 频道托管方案
## 方案概述
腾讯云视频直播服务的主要功能主要包括：提供音视频通道、提供CDN加速、提供直播流管理服务，**频道托管方案**就是一种直播流管理的包装形式，与之相对应的还是[**直播码管理方案**](https://cloud.tencent.com/doc/api/258/5649)。

**频道**，也就是直播流，频道托管，即把直播流的维护和管理完全放在腾讯云上托管起来，作为客户，您只需要像访问数据库一样访问腾讯云提供的频道查询、频道创建、频道修改和频道删除入口，即可完成您的业务逻辑。

- **优势**
全程可视化交互，操作人性化程度高，频道托管方案中所有针对频道（直播流）的增、删、改、查操作均可以对应于[直播管理控制台](https://console.cloud.tencent.com/live/livemanage)里的UI按钮操作，您不需要有专门的技术知识背景亦可使用。如果您是做直播类主题活动，那么这套方案有着很强的优势。

- **不足**
如果您要实现一个复杂的APP，需要时时刻刻高负荷的对频道（直播流）进行增删改查，并且要保证直播流状态的高度精确和一致性，频道托管的自由度、对接成本以及维护成本均会高于直播码。

接下来我将通过几个步骤介绍如何通过频道托管方案构建一个完整的闭环直播体验，于此同时，出门左转直播码[对接攻略](https://cloud.tencent.com/doc/api/258/5649)中也有类似的一套解决方案：
![](//mccdn.qcloud.com/static/img/5f9f08330b500d2c81b7c28be5307fee/image.png)

## 直播中列表
使用频道托管方案，您的服务器上需要有一个基础设施，就是**直播中的频道列表**，该列表是对当前正在直播中的频道的一个缓存，其存在的意义主要是为了让您的APP（观众端）能够随时获取直播列表：
![](//mc.qcloudimg.com/static/img/f64b39ec200d1bc3c74d45ae32d04982/image.png)

>  **为什么要自己缓存：**
>  您可能会问，腾讯云已经在管理一个频道列表，我甚至能在控制台里看到它，为什么还需要我自己缓存呢？
>  主要基于三个方便的考虑：
>  （1）腾讯云的频道列表只有频道名称和频道ID等基础信息，不包换像用户头像、封面、位置、点赞人数等个性化定制信息。
>  （2）腾讯云的服务端API访问有频次限制，一般默认是100次每分钟，超过后即被拒绝，所以您的服务器端拥有一个缓存不仅可以避开频率限制也可以降低APP用户拉取列表的等待时间。

## 对接攻略
### Step1:创建频道
主播在开启直播之前，首先要**创建频道**，您可以调用 [CreateLVBChannel](https://cloud.tencent.com/doc/api/258/4715) 获得一个频道ID和RTMP推流URL，于此同时，新创建的频道要加入到刚才提到的**直播中频道列表**里。

### Step2:SDK推流
Step2如果一切顺利，您的服务器会拿到推流URL，接下来可以直接返回给您的APP，剩下的工作交给APP来完成：把推流URL交给RTMP SDK进行推流，具体使用方法详见[推流SDK介绍](http://cloud.tencent.com/doc/api/258/4734)。

### Step3:删除频道
APP端如果推流结束，记得一定要将通知后台进行**频道删除**，注意<font color='red'>没有关闭的频道删除可能失败</font>，所以删除一个频道之前，要先通过[StopLVBChannel](https://cloud.tencent.com/doc/api/258/4720)接口先将频道状态置为停止，之后在调用[DeleteLVBChannel](https://cloud.tencent.com/doc/api/258/4722)接口对频道进行删除。

删除后的频道要记得同样要从您缓存的**直播中频道列表**中同步地删除。
![1-3](//mc.qcloudimg.com/static/img/3cc24ef70bf5d0adfa6612d0eab77bb5/image.png)

前面三步实现的是主播端的逻辑，现在我们把视角切到观众这一侧的逻辑：

### Step4:查询频道列表
用户在打开您的APP之后，首先要做的是查看直播列表，你可以直接从缓存的直播中频道列表里返回给TA（外带封面、位置、点赞人数等装饰性信息）。

播放URL在 Step1 中创建频道时就可以拿到，不过您也可以在您的服务端自行拼装，拼装规则如下：
![simple url](//mc.qcloudimg.com/static/img/cb33257ac2623be2296b3f34a1927ae7/image.png)

>  **不要在APP拼接URL：**
>  千万不要再APP客户端拼装播放URL，这等于把后续的灵活性锁死了，服务器更新一下URL拼装规则是分分钟可以发布的事情，客户端却不是这样。

### Step5:SDK播放
观众在直播列表中选择一个中意的主播，并点击进入视频观看界面，这时APP即可在Step4中已经拉取到的直播列表里选到对应的播放URL，之后，使用腾讯云提供的播放SDK即可进行播放。具体使用方法详见具体使用方法详见[播放SDK介绍](http://cloud.tencent.com/doc/api/258/4736)

### Step6:僵尸频道
所谓僵尸频道是指那些创建了之后没有使用且没有被回收的频道，它会挤占您可以创建的频道的数量，导致您可以创建的频道数量会越来越少，最终直至超限（报20101错误码）。

如果只按照Step1-Step3来对接，那么频道的创建和删除始终都只由APP来发起，这样就会有一个隐患：APP可能在开始直播后没有正常退出（崩溃或者被后台强杀）导致该频道一直处于“未直播”状态，进而变成一个僵尸频道。

要避免这个问题，最好的办法是在您的服务器加一个**“定制回收机制”**：
- **轮询模块**： 每隔3分钟调用一次[DescribeLVBChannelList](https://cloud.tencent.com/doc/api/258/4716)获取频道列表（指定channelStatus == 0 可以只返回没有在推流的频道ID）。

- **回收模块**：如果连续三次轮询中，某一个频道ID的状态都是<font color='red'>无输入流</font>，也就是已经持续9分钟没有推流了，那我们就可以判定这个频道为僵尸频道，可以大胆的将其停止并关闭并回收（[StopLVBChannel](https://cloud.tencent.com/doc/api/258/4720) + [DeleteLVBChannel](https://cloud.tencent.com/doc/api/258/4722)）。

![](//mc.qcloudimg.com/static/img/e663d5652dc086a6239f1224274f2c16/image.png)


## FAQ

### 1. 频道数总超限制？
部分客户对接后发现在 [CreateLVBChannel](http://cloud.tencent.com/doc/api/258/4703) 时总是会被报告 20101（ 频道数超过上限）错误，这是因为腾讯云直播服务对单个客户最多可创建的频道数量进行了限制。

这个阈值很大，只要没有逻辑错误一般是不会被限制到的，但如果您频繁遭遇20101错误，那很可能是僵尸频道堆积所致，推荐您按**Step6**中的方案进行微调。

### 2. 用户数 = 频道数？
不少客户认为APP有多少潜在的主播就应该有多少个频道，这种模式在技术上是可以实现的，但是并不经济。一方面，按照正常的发展规律会出现99%以上的频道都是闲置不用的。另一方面，用户跟频道号直接绑定后，TOP主播的频道号很容易被探测到，带来的安全风险也需要有更复杂的保护机制进行完善。

本文前面部分所推荐的方案是一种动态创建和回收频道的方案，它能保证绝大多数时间频道都是在使用的，而且由于每个频道都是动态创建的，跟用户ID没有绑定关系，所以很难进行安全攻击。

### 3. 推流地址的保护？
不少客户担心推流地址如果外泄了怎么办？其实这个担心在频道托管方案里是多虑的：

一方面，如果一个推流地址正在推流中，另一个客户端是无法去挤占的，这是一个最基本的保护。

另一方面，如果您按照本文档中建议的方式对接频道托管方案，那么每个主播每次直播所创建的频道都是动态生成的， <font color='red'>动态生成的频道最大的一个优势就是其推流地址是随机计算出来的</font>，非常难于猜测和攻击，而且直播结束之后APP会通知后台回收，所以猜测碰撞以及攻击成本都很高，没有必要做特殊的保护。

### 4. 频道收费情况？
腾讯云的频道收费是根据**直播中频道**的最高并发数进行收费的，也就是每天有多少个主播在同时在线直播。

活跃的频道有大量的后台服务器计算成本开销，包括转码、回源、统计和必要的监控。出于成本考虑，腾讯云会对正在直播的频道的并发数收取后台服务器计算费用。如果并发数小于等于**5**个，这部分是免费的，如果并发频道数大于**5个**，超出的数量按 **60元/个/月** 进行收费。



