
没有绝对完美的安全保护，只有最适合当前业务场景的安全机制。

所以，安全保护一定是一个跟业务场景密切耦合的话题，也正是因为如此，我们在小直播中并没有默认实现多少安全保护措施，换言之它默认是<font color='red'>**不安全**</font>的。

本节我们将从几个具体的保护点入手，来强化小直播的安全特性，这些保护点需要您结合自己的业务场景进行实际对接：

## 登录鉴权

登录检查就是App在跟后台Server交互时，需要检查当前用户是否已经登录过，小直播App跟后台的交互协议有如下几条：

| 协议   | 作  用 | 是否有必要做登录检查 |
|---------|---------|:---------------------------:|
| RequestLVBAddr| 请求推流地址| <font color='red'>是</font>|
| ChangeStatus| 修改直播间推流状态| <font color='red'>是</font> |
| ChangeCount | 修改点赞、观看人数等计数项| 否 |
| FetchList       | 拉取直播or回看列表| 否 |
| GetCOSSign  | 获取COS文件上传的签名|<font color='red'>是</font>|
| GetUserInfo  | 获取指定主播的详细信息|否|

- **观众端**
一般而言，对普通观众的登录态检查并不是特别必要，否则容易影响直播活跃度。

- **推流端**
对主播的登录检查一般都是必须的，尤其是随着相关部门对主播的身份认证抓的越来越严格了，越来越多的直播平台要求不仅仅是注册用户才能直播，还必须是认证的用户才能直播。

所以，我们需要保护的交互协议主要是 RequestLVBAddr、ChangeStatus 和 GetCOSSign 三条协议，前两个是创建直播间时必须的，适用于主播。 GetCOSSign 是用来上传直播封面等信息用的，隶属个人资料，也必然以登录为基础。

相信您目前后台的登录和权限校验系统已经很完善了，如何给后台协议添加登录Session检查并没有什么困难，但这里我们还是简单以 RequestLVBAddr 为例做一个说明：

![](//mc.qcloudimg.com/static/img/1a9e97f735c89d3557c3e76db15bc7e5/image.png)

1. App 将用户名和密码进行MD5单向不可逆加密，然后连同用户名和时间戳一起发给服务器。更安全的登录协议需要更复杂的流程，比如密码空间置换避免彩虹表破解等等。

2. 服务器确认用户是合法的注册用户之后，给客户分配一个短期有效的 sessionkey，App会将这个 sessionkey 存在手机上。

3. 主播按下“开始直播”按钮时，App会向后台发起 RequestLVBAddr 请求，请求头部需要携带 sessionkey（http请求一般放在cookie字段里）

4. 后台检查 sessionkey 是否有效以及是否过期，检查通过后才会向 App 下发 房间号 和 推流URL。


## 消息鉴权
小直播中实现了三种腾讯云通讯对接方案（这块研发同学们估计是想得多多益善吧），一种是**[访客模式](https://cloud.tencent.com/doc/api/258/6448#5.3.1-.E8.AE.BF.E5.AE.A2.EF.BC.88.E6.89.98.E7.AE.A1.EF.BC.89.E6.A8.A1.E5.BC.8F)**，一种是**账号密码登录模式**吗，还有一种是**短信验证登录模式**。

访客模式是我们的推荐方案，因为该模式即简单有好用，一个GuestLogin函数就能解决问题，但它并没有很好地机制来进行身份鉴权，任何一个App用户都可以拿到一个访客账号，拿到访客账号既可以收发消息。

对于直播聊天室场景而言，消息的鉴权并不是特别重要，因为直播室里的聊天消息本身就不严肃。但如果您的场景需要实现**只有注册用户才能收发消息**，就要完成腾讯云IM通讯系统和您的账号系统的绑定。

相比于访客模式，要完成腾讯云IM通讯系统和您的账号系统的绑定，在对接步骤要繁琐很多，毕竟它要面对的问题是安全信任问题，如下是对接步骤：

> 1. 在腾讯云通讯[管理控制台](https://console.cloud.tencent.com/avc)，将集成模式改成**独立模式**，并下载签名用的公私钥。
> ![](//mc.qcloudimg.com/static/img/4e79ff175d8053f8998e02732468e398/image.png)
> 
> 2. 手机App的登录逻辑依旧按您原来的流程，即ID + PASSWORD到您的登录服务器进行验证。如果登录成功了，您的登录服务器需要额外签发一个UserSig签名给App，该签名使用步骤1中下载到的私钥对相应的ID进行[非对称加密](https://cloud.tencent.com/doc/product/269/1510)。
>
> 3. 手机App在拿到ID和UserSig以后，就可以调用IM SDK的imLogin(ID, UserSig)接口进行登录了，腾讯云后台会使用步骤一中相应的公钥进行解密，从而验证ID是否得到了您的登录服务器的认可。

以上步骤的示意图如下：
![](//mc.qcloudimg.com/static/img/1e541b2931d0cb8fb1815f26aa8fb493/image.png)

这里貌似有点复杂，实际上它背后的原理是关于**两家公司的后台服务器怎么相互信任的故事**，我们打个更形象的比方：
> 1. 某个女性用户在您的App上登录了，她使用了之前在您这里注册的ID和登录口令，ID叫做 “花仙子”。
>
> 2. 您这边在拿到ID和口令后立刻进行了验证，并且确认她可以登录App。于此同时，您还开给她一张**放行条(UserSig)**，上面写着“<font color='blue'> '花仙子' 是良民的干活，到你腾讯的地盘，你可得伺候好了，不要亏待她...</font>”，为了确保这个放行条不被伪造，您还在上面用正楷签了名。
>
> 3. 腾讯云在看了您的放行条以后，确认签字为您本人亲笔所签，自然会提供相应的服务。

上述就是消息鉴权背后的对接方案，它的核心目标就是限制哪些没有得到您的后台服务器认可的用户收发消息，但让您的服务器检查每一条消息又是不合适的，所以才演化出了这样一套方案。


