
## 背景介绍
绝大多数客户拿到小直播代码之后，第一件事情就是替换账号系统，毕竟自己APP的账号系统是不能随便动的。

在小直播的设计之初我们就考虑到了这一点，所以跟直播录播相关的功能设计均没有强依赖账号体系和用户资料，目的就是能让您快速完成账号体系的替换。

要把小直播的默认账号体系替换成您自己的账号系统，大概有如下几个模块要调整：

| 目标模块 | 调整目标 |
|------------|-------------|
| 直播聊天室 | 让您的App可以轻松收发消息 |
| 主播个人资料 | 让主播直接使用他（她）在您的App上已有注册的身份发起直播 |
| 定制群发消息 | 当您觉得小直播已有的消息格式不够用的时候，可以定制自己的消息格式 |


## 直播间聊天室
小直播使用IM消息模块实现了直播间聊天室的如下几个功能：
- 普通文本消息：包括发送者的昵称以及消息本身。
- 弹幕消息：本质也是文本消息，只是消息的展示方式会更显花哨。
- 点赞消息：当一位观众为主播点赞时，要保证其他观众也能看到
- 系统通知，比如“XXX已加入房间”或者“主播已离开”等等。

小直播中实现了三种腾讯云通讯对接方案（这块研发同学们估计是想得多多益善吧），一种是**访客模式**，一种是**账号密码登录模式**吗，还有一种是**短信验证登录模式**。

如果要替换自己的账号系统，果断使用**访客模式**启动 IM SDK 就可以了，其他两种均不适用。

> **[访客模式](https://cloud.tencent.com/doc/api/258/6448#5.3.1-.E8.AE.BF.E5.AE.A2.EF.BC.88.E6.89.98.E7.AE.A1.EF.BC.89.E6.A8.A1.E5.BC.8F)**  ：是腾讯云通讯服务的运行模式之一，该模式下，腾讯云会为每个App用户生成一个“**访客账号**“，该账号只会用来收发消息，可以理解为一个“傀儡账号”。消息发送者的真实用户信息（昵称、头像等等）不跟该账号绑定，而是跟着消息体一起发出去。

- **step1: 确认集成模式**
> 确保腾讯[云通讯控制台](https://console.cloud.tencent.com/avc)中的集成模式为**托管模式**，这样能让腾讯云为访客模式的访客账号提供后台支持。
> ![](//mc.qcloudimg.com/static/img/d52ac3662d5310673a5d6c6a78f50da4/image.png)

- **step2: 屏蔽TLS常规登录逻辑**
> iOS平台：TCLoginViewController##viewDidLoad 实现了小直播自带的用户名密码“自动登录”逻辑。
> Android平台：TCLoginActivity##onCreate 里对 userNameLoginViewInit 函数的调用相当于是一种“自动登录”。

- **step3: 只对接访客模式**
> iOS平台：访客模式启动IM SDK 的代码位于TCIMPlatform.h 中的 guestLogin。
> Android平台：访客模式启动IM SDK 的代码位于TCLoginMgr.java 中的 guestLogin 函数。

## 主播个人资料
这里说的用户资料都是主播的资料（比如昵称、头像），也就是APP当前用户的资料，观众这一方看到的各个主播的信息是在拉取直播间列表的时候就已经取到了。

小直播默认使用了腾讯云的托管账号服务，故其默认的用户资料是存储于腾讯云托管账号资料系统中的，所以替换账号后，用户资料部分自然也要相应的调整。

- **iOS平台**
  + **屏蔽旧逻辑**：
  屏蔽自动从腾讯服务器拉取用户资料的逻辑，小直播在登录成功后，会自动从服务器拉取用户资料，如果资料存在您自己的服务器，这个逻辑需要屏蔽，做法是删除TCIMPlatform.m中的setIdentifier的调用：
   ![](//mc.qcloudimg.com/static/img/6942eb366e524855e8a2a898e6689cf5/image.jpg)
  + **对接新资料**：
  推荐的做法是调用TCUserInfoMgr中的setUserProfile接口设置新的用户资料（如昵称、头像、封面等），小直播在用到用户资料时，将会从用户资料管理类TCUserInfoMgr中获取，从而最小化您的适配工作：
  ![](//mc.qcloudimg.com/static/img/e78f80670d85478432e4fe5d932d2430/image.jpg)

- **Android平台**
  小直播默认的逻辑是在登录完成后，调用TCUserInfoMgr中的queryUserInfo()，改函数的作用是从腾讯云账号系统中拉取用户资料并将其设置到mUserInfo成员变量中，故修改该函数即为最简单和快速的适配方案：
  ![](//mc.qcloudimg.com/static/img/3cc88fb62c6b7fac4215c034806f8d06/image.jpg)


## 定制群发消息
小直播发送各类消息（如文本消息、弹幕消息、点赞消息、成员进退消息）等，都统一采用了IM SDK的文本消息类型，消息体采用json格式。一条群发消息内含三类关键信息：
- **消息类型**
我们在小直播中定义的消息类型一共有 5 种，它们分别是：

| 消息类型 | 数字 | 含义 |
|:---------|---------|---------|
| AVIMCMD_Custom_Text | 1 | 文本消息 |
| AVIMCMD_Custom_EnterLive | 2 | 用户加入直播 |
| AVIMCMD_Custom_ExitLive | 3 | 用户退出直播 |
| AVIMCMD_Custom_Like | 4 | 点赞消息 |
| AVIMCMD_Custom_Danmaku | 5 | 弹幕消息 |

- **发送者信息**
用户账号ID、昵称、头像等，该信息来源于 **TCUserInfoMgr** 模块，小直播会从TCUserInfoMgr获取当前用户的资料信息并拼接到json格式的消息体中。

- **消息内容**
政府对直播的规范性问题抓的比较紧，所以消息本身的敏感字过滤功能很关键，腾讯云通讯服务本身有脏字过滤功能，这里不用有后顾之忧。

如果您希望修改或者增加新的消息格式，相关代码位于TCMsgHandler（iOS）和TCChatRoomMgr（Android）中：
![](//mc.qcloudimg.com/static/img/ae64a2ccf99503803fd7eb88f909d6a5/image.jpg)




