## 1. API Description
 
This API (DescribeSecurityGroupEx) is used to query the basic information of one or more security groups based on multiple indexes.
Domain name for API request: <font style="color:red">dfw.api.qcloud.com</font>
1) When sgId is entered for this API, an exact match query will be performed based on the security group ID generated by the system.
2) When projectId is entered for this API, a query will be performed on all the security group lists under this project ID.
3) When sgName is entered for this API, a match query, where partial name match is allowed, will be performed based on the security group name string.
4) When offsetLine indicates line offset from line 0 which is the first line of total lines. The default value is 0.
6) When limit indicates the quantity of lines in one page in response. The default value is 20.
7) This API returns the list for security group lists, the members of which include the unique system ID, name, remark text, creation time, and the project ID of the security group, associated cloud instance count, it's version of this security group itself, do not include details like security group rules.
 

## 2. Input Parameters
 
The following request parameter list only provides API request parameters. Public request parameters need to be added when the API is called. See the Public Request Parameters page for details. The Action field for this API is DescribeSecurityGroupEx.
<table class="t"><tbody><tr>
<th><b>Parameter Name</b></th>
<th><b>Required</b></th>
<th><b>Type</b></th>
<th><b>Description</b></th>
<tr>
<td> projectId <td> No <td> Int <td> Project ID; if it's left empty, all security groups under this project are returned
<tr>
<td> sgId <td> No <td> String <td> Filters results by sgId, and only supports exact filtering
<tr>
<td> sgName <td> No <td> String <td> Filters results by sgName, and supports fuzzy filtering
<tr>
<td> offsetLine <td> No <td> Int <td> line offset from 0 which is the first line of total lines. The default value is 0.
<tr>
<td> limit <td> No <td> Int <td> the quantity of lines in one page in response. The default value is 20.
<tr>
</tbody></table>

 

## 3. Output Parameters
 

| Parameter Name | Type | Description |
|---------|---------|---------|
| code | Int | Error code, 0: succeeded, other values: failed |
| message | String | Error message |
| data.totalNum | Int | total number of user's security group before paged|
| data.detail | Object | Returned detailed data structure|

detail structure
<table class="t"><tbody><tr>
<th><b>Parameter Name</b></th>
<th><b>Type</b></th>
<th><b>Description</b></th>
<tr>
<td> data.sgId <td> String <td> Security group ID
<tr>
<td> data.sgName <td> String <td> Security group name
<tr>
<td> data.sgRemark <td> String <td> Security group remark
<tr>
<td> data.createTime <td> String <td> Creation time of security group
<tr>
<td> data.projectId <td> Int <td> Project ID
<tr>
<td> data.beAssociateCount <td> Int <td> associated cloud instance count
<tr>
<td> data.version <td> Int <td> it's version of this security group itself, varied when every time rules edited.
</tbody></table>

## 4. Error Codes
 <table class="t"><tbody><tr>
<th><b>Error Code</b></th>
<th><b>Description</b></th>
<tr>

<td> 7000 <td> Security group backend exception
</tbody></table>


## 5. Example
 
Input
<pre>

  https://dfw.api.qcloud.com/v2/index.php?Action=DescribeSecurityGroupEx
  &<<a href="https://cloud.tencent.com/doc/api/229/6976">Common request parameters</a>>

</pre>

Output
```

{
    "code": 0,
    "message": "",
    "data":{
     "totalNum":50,
     "detail": [
         {
             "sgId": "sg-k3tjgics",
             "sgName": "test",
             "sgRemark": "",
             "createTime": "2015-05-20 16:07:58",
             "projectId": 1002207,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-56p1yd1o",
             "sgName": "示例安全组",
             "sgRemark": "",
             "createTime": "2015-10-15 17:12:17",
             "projectId": 1003744,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-ooa41c4o",
             "sgName": "示例安全组",
             "sgRemark": "",
             "createTime": "2015-09-11 16:12:28",
             "projectId": 1002110,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-7tk6qery",
             "sgName": "示例安全组",
             "sgRemark": "",
             "createTime": "2015-10-15 17:12:13",
             "projectId": 1003774,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-cqovl1fw",
             "sgName": "示例安全组",
             "sgRemark": "",
             "createTime": "2015-05-22 19:15:38",
             "projectId": 1002443,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-exnsygsm",
             "sgName": "test1",
             "sgRemark": "",
             "createTime": "2015-08-25 17:07:25",
             "projectId": 0,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-9g8qfrwi",
             "sgName": "一二三四五六七八九十_-...12345",
             "sgRemark": "",
             "createTime": "2015-08-25 17:07:47",
             "projectId": 0,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-gte8a2ys",
             "sgName": "694949",
             "sgRemark": "",
             "createTime": "2015-05-25 15:48:24",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-fdn9vtdy",
             "sgName": "314294",
             "sgRemark": "",
             "createTime": "2015-05-25 15:42:13",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-00qjxbwq",
             "sgName": "773675",
             "sgRemark": "",
             "createTime": "2015-05-25 15:41:24",
             "projectId": 1002026
         },
         {
             "sgId": "sg-p837l8ko",
             "sgName": "532215",
             "sgRemark": "",
             "createTime": "2015-05-25 13:27:12",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-de37xrpo",
             "sgName": "740402",
             "sgRemark": "",
             "createTime": "2015-05-25 13:27:13",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-bvdaobny",
             "sgName": "427637",
             "sgRemark": "",
             "createTime": "2015-05-25 13:25:53",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-kqj119xe",
             "sgName": "795911",
             "sgRemark": "",
             "createTime": "2015-05-25 13:26:22",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-4no9kdc8",
             "sgName": "729144",
             "sgRemark": "",
             "createTime": "2015-05-25 15:48:24",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-o1wkaolg",
             "sgName": "218045",
             "sgRemark": "",
             "createTime": "2015-05-25 15:48:24",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-nty6p48a",
             "sgName": "670689",
             "sgRemark": "",
             "createTime": "2015-05-25 15:41:10",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-7ky1tlz4",
             "sgName": "442978",
             "sgRemark": "",
             "createTime": "2015-05-25 13:27:44",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-glud1qis",
             "sgName": "775093",
             "sgRemark": "",
             "createTime": "2015-05-25 13:27:36",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-eydbxnra",
             "sgName": "24167",
             "sgRemark": "",
             "createTime": "2015-05-25 15:41:35",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         },
         {
             "sgId": "sg-opd592g8",
             "sgName": "419195",
             "sgRemark": "",
             "createTime": "2015-05-25 15:48:24",
             "projectId": 1002026,
             "beAssociateCount": 0,
             "version": 0
         }
     ]
    }
}

```

