## 1. 接口描述
本接口(DescribeScalingConfiguration)用于查询启动配置的信息，查询时可以指定伸缩组ID来查询该伸缩组下的所有伸缩配置。
接口请求域名：<font style="color:red">scaling.api.qcloud.com</font>
注意：该接口调用时，Region参数不是必须的，可以不传入！


## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/372/4153" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为DescribeScalingConfiguration。

| 参数名称 | 是否必选  | 类型 | 描述 | 
|---------|---------|---------|---------|
| scalingConfigurationIds.n | 否 | String | 待查询的各启动配置ID构成的数组，数组下标从0开始，最多可指定20个。|
| scalingConfigurationName | 否 | String |待查询的启动配置名称，暂不支持传入启动配置名称数组。 |
| offset | 否 | Int | 偏移量，默认为0。 | 
| limit | 否 | Int | 一次最多可查询的启动配置数量，默认为20。 | 
| projectId | 否 | String | 项目ID，不传则查询全部项目启动配置。0表示默认项目，如需指定其他项目，可调用<a href="/doc/api/403/4400" title="查询项目列表">查询项目列表</a>(DescribeProject)接口查询。|



## 3. 输出参数
| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href="https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81" title="公共错误码">公共错误码</a>。|
| codeDesc | String |业务侧错误码。成功时返回Success，错误时返回具体业务错误原因。|
| message | String | 模块错误信息描述，与接口相关。|
| data | Array | 输出结果，查询到的伸缩组列表信息。 |

其中，data参数的构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| totalCount | Int | 查询到的启动配置数量。 |
| scalingConfigurationSet | Array | 查询到的启动配置信息的集合。 |

其中，scalingConfigurationSet包含了若干个启动配置信息，每个启动配置信息的构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| scalingConfigurationId | String | 查询到的启动配置ID。|
| scalingConfigurationName | String | 查询到的启动配置名称。|
| scalingGroupIdSet | Array | 使用该启动配置的各伸缩组信息。 |
| cpu | Int | 服务器核数。 | 
| mem | Int | 服务器内存大小，单位为GB。 | 
| imageType | Int | 镜像类型。若为1，表示私有镜像；若为2，表示公共镜像。| 
| imageId | String | 镜像ID。 | 
| storageType | Int | 数据盘类型。若为1，表示本地盘；若为2，表示云硬盘。| 
| storageSize | Int | 数据盘大小，单位为GB。| 
| rootSize | Int | 系统盘大小，单位为GB。|
| bandwidthType | String |带宽的类型。若为PayByHour，表示按带宽使用时长计费；若为PayByTraffic，表示按流量计费。 
| bandwidth | Int | 公网带宽大小，单位为Mbps。| 
| wanIp | Int |外网IP，若为1，表示开通；若为0，表示不开通。| 
| keyId | String | 密钥ID。 | 
| password | String | 密码。| 
| sgSet | Array | 安全组信息。| 
| needMonitorAgent | Int |是否开启云监控服务。若为1，表示开通，若为0，表示不开通。| 
| needSecurityAgent | Int |是否开启云安全服务。若为1，表示开通，若为0，表示不开通。| 
| createTime | String | 创建该启动配置的时间。| 
| projectId | Int |所属项目ID。| 

其中scalingGroupIdSet包含了使用该启动配置的所有伸缩组信息，它是由一系列伸缩组信息组成的，每个伸缩组信息结构如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| scalingGroupIdSet.n.scalingGroupId| String | 伸缩组ID。|
| scalingGroupIdSet.n.scalingGroupName| String | 伸缩组名称。|

## 4. 错误码
对于接口的通用性错误，请参考[AS错误码](https://cloud.tencent.com/doc/api/372/4173)。

## 5. 示例

```
https://scaling.api.qcloud.com/v2/index.php?
&<公共请求参数>
```
返回示例如下，从中可以看出，totalCount为1，说明该用户只有一个启动配置。并且该启动配置中的scalingGroupIdSet参数只包含一组信息，说明只有一个伸缩组使用该启动配置。
```
{
    "code":"0",
    "message":"",
    "codeDesc":"Success",    
    "data":{
        "totalCount":1,
        "scalingConfigurationSet": [
            {
                "scalingConfigurationId": "xxx",
                "scalingConfigurationName": "xxxx",
                "scalingGroupIdSet": [
                    {
                        "scalingGroupId": "xxxxxx",
                        "scalingGroupName": "xxx"
                    }
                ],
                "sgSet": [],
                "needMonitorAgent": 1,
                "bandwidthType": 1,
								"projectId":0,
                "cpu": 1,
                "needSecurityAgent": 1,
                "rootSize": 20,
                "wanIp": 1,
                "imageType": 1,
                "keyId": "skey-xxx",
                "bandwidth": 1,
                "storageType": 1,
                "createTime": "2016-03-16 16:52:06",
                "imageId": "img-xxx",
                "mem": 1,
                "storageSize": 10,
                "password": ""
            },
        ]
    }
}
```

