## 提交作业
## 1. 接口描述
本接口（SubmitJob）用于提交一个作业
接口请求域名：batch.api.qcloud.com

## 2. 输入参数
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
Version | String | 是 | API版本
Job | Job object | 是 | 作业信息，通过JSON形式传递
Placement |  Placement object | 是 | 作业所提交的位置信息。通过该参数可以指定作业所属可用区等信息。
ClientToken | String | 否 | 用于保证请求幂等性的字符串。该字符串由用户生成，需保证不同请求之间唯一，最大值不超过64个ASCII字符。若不指定该参数，则无法保证请求的幂等性。

#### 数据类型

--------

#### Job
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
JobName | String | 是 | 作业名称
JobDescription | String | 否 | 作业描述
Priority | Integer | 是 | 作业优先级，任务（Task）和任务实例（TaskInstance）会继承作业优先级
Tasks.N | array of Task objects | 是 | 任务信息
Dependences.N | array of Dependence objects | 否 |  依赖信息

#### Placement
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
Zone | String | 是 | 作业所属的可用区ID。

#### task
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
TaskName | String | 是 | 任务名称，在一个作业内部唯一
TaskInstanceNum | Integer | 是 | 任务实例运行个数
Application | Application object | 是 | 应用程序信息
ComputeEnv  | ComputeEnv object | 否 | 运行环境信息，ComputeEnv 和 EnvId 必须指定一个（且只有一个）参数。
EnvId  | String | 否 | 计算环境ID，ComputeEnv 和 EnvId 必须指定一个（且只有一个）参数。
RedirectInfo | RedirectInfo object | 是 | 重定向路径
RedirectLocalInfo | RedirectLocalInfo object | 是 | 重定向路径
InputMappings | array of InputMapping object | 否 | 输入映射
OutputMappings | array of OutputMapping object | 否 | 输出映射
OutputMappingConfigs | array of OutputMappingConfig object | 否 | 输出映射配置
Authentications | array of Authentication object | 否 | 授权信息
FailedAction | string | 否 | TaskInstance失败后处理方式，取值包括TERMINATE（默认）、INTERRUPT、FAST_INTERRUPT。
MaxRetryCount | Integer | 否 | 任务失败后的最大重试次数，默认为0
Timeout | Integer | 否 | 任务启动后的超时时间，单位秒，默认为3600秒

备注：关于FailedAction 。TaskInstance失败后处理方式，取值包括TERMINATE（默认）、INTERRUPT、FAST_INTERRUPT。TERMINATE表示正常销毁、释放资源；INTERRUPT表示n次重试后失败保留现场，前n-1次正常销毁；FAST_INTERRUPT表示首次失败即保留现场，不再重试。中断后，TaskInstance处于FAILED_INTERRUPTED状态，配额等不会释放。FailedAction 对于提交的指定计算环境的作业无效。

#### Application
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
Command | String | 是 | 任务执行命令
DeliveryForm | String | 是 | 应用程序的交付方式，包括PACKAGE、LOCAL 两种取值，分别指远程存储的软件包、计算环境本地。
PackagePath | String | 否 | 应用程序软件包的远程存储路径
Docker | String | 否 | 应用使用Docker的相关配置。在使用Docker配置的情况下，DeliveryForm 为 LOCAL 表示直接使用Docker镜像内部的应用软件，通过Docker方式运行；DeliveryForm 为 PACKAGE，表示将远程应用包注入到Docker镜像后，通过Docker方式运行。

#### Docker
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
User | String | 是 | Docker Hub 用户名或 Tencent Registry 用户名
Password | String | 是 | Docker Hub 密码或 Tencent Registry 密码
Server | String | 否 | Docker Hub 可以不填，但确保有公网。或者是 Tencent Registry 服务地址“ccr.ccs.tencentyun.com”
Image | String | 是 | Docker Hub“[user/repo]:[tag]”或 Tencent Registry“[namespace/repo]:[tag]”

#### ComputeEnv
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
EnvType | String | 是 | 计算环境管理类型，包括托管和非托管两种
EnvData | EnvData object | 是 | 计算环境具体参数
MountDataDisks | array of MountDataDisk | 否 | 数据盘挂载选项

#### EnvData
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
InstanceType | String | 是 | CVM实例类型，托管类型必填
ImageId | String | 是 | CVM镜像ID，托管类型必填
SystemDisk | SystemDisk object | 否 | 实例系统盘配置信息。若不指定该参数，则按照系统默认值进行分配。
DataDisks | array of DataDisk objects | 否 | 实例数据盘配置信息。若不指定该参数，则默认不购买数据盘，当前仅支持购买的时候指定一个数据盘。
VirtualPrivateCloud	| VirtualPrivateCloud object | 否 | 私有网络相关信息配置。通过该参数可以指定私有网络的ID，子网ID等信息。若不指定该参数，则默认使用基础网络。若在此参数中指定了私有网络ip，那么InstanceCount参数只能为1。
InternetAccessible | InternetAccessible object | 否 | 公网带宽相关信息设置。若不指定该参数，则默认公网带宽为0Mbps。
InstanceName	| String | 否 | 实例显示名称。如果不指定则batch指定默认命名。最大长度不能超60个字节。
LoginSettings | LoginSettings object | 否 | 实例登录设置。通过该参数可以设置实例的登录方式密码、密钥或保持镜像的原始登录设置。如果不指定则batch生成默认密码。
SecurityGroupIds | array of Strings | 否 | 实例所属安全组。该参数可以通过调用 DescribeSecurityGroups 的返回值中的sgId字段来获取。若不指定该参数，则默认不绑定安全组。不绑定安全组将暴露所有端口到公网和内网，实例的所有业务（如80、443等端口）将均可被访问，但会有一定的安全风险，建议选择按需新建的安全组。当前仅支持购买的时候指定一个安全组。

EnvData 参数参考CVM API文档提供的参数 https://cloud.tencent.com/document/api/213/9384

#### RedirectInfo
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
StdoutRedirectPath | String | 否 | 标准输出重定向路径
StderrRedirectPath | String | 否 | 标准错误重定向路径
StdoutRedirectFileName | String | 否 | 标准输出重定向文件名，支持三个占位符${BATCH_JOB_ID}、${BATCH_TASK_NAME}、${BATCH_TASK_INSTANCE_INDEX}
StderrRedirectFileName | String | 否 | 标准错误重定向文件名，支持三个占位符${BATCH_JOB_ID}、${BATCH_TASK_NAME}、${BATCH_TASK_INSTANCE_INDEX}

#### RedirectLocalInfo
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
StdoutLocalPath | String | 否 | 标准输出重定向本地路径
StderrLocalPath | String | 否 | 标准错误重定向本地路径
StdoutLocalFileName | String | 否 | 标准输出重定向本地文件名，支持三个占位符${BATCH_JOB_ID}、${BATCH_TASK_NAME}、${BATCH_TASK_INSTANCE_INDEX}
StderrLocalFileName | String | 否 | 标准错误重定向本地文件名，支持三个占位符${BATCH_JOB_ID}、${BATCH_TASK_NAME}、${BATCH_TASK_INSTANCE_INDEX}

#### InputMapping
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
SourcePath | String | 是 | 源端路径
DestinationPath | String | 是 | 目的端路径

#### OutputMapping
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
SourcePath | String | 是 | 源端路径
DestinationPath | String | 是 | 目的端路径

#### OutputMappingConfig
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
Scene | String | 是 | 存储类型，仅支持COS
WorkerNum | String | 是 | 并行worker数量
WorkerPartSize | String | 是 | worker分块大小

#### Authentication
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
Scene | String | 是 | 授权场景，例如COS
SecretId | String | 是 | SecretId
SecretKey | String | 是 | SecretKey

#### dependence
名称 | 类型  | 是否必选 | 描述
-----|------|-----|------
StartTask | String | 是 | 依赖关系的起点任务名称
EndTask | String | 是 | 依赖关系的起点任务名称

```
{
    "Job": {
        "JobName": "dag job",
        "JobDescription": "test dag job",
        "Priority": 1,

        "Tasks": [
            {
                "TaskName": "A",
                "TaskInstanceNum": 1,
                # other params
                "Application": {
                    "Command": "python a.py",
                    "DeliveryForm": "PACKAGE",
                    "PackagePath": "http://batchbucket-appid.cosgz.myqcloud.com/app/app.tgz",
                },
                "ComputeEnv": {
                    "EnvType": "MANAGED",
                    "EnvData": {
                        "InstanceType": "S1.SMALL1",
                        "ImageId"： "img-bq1gnde3"，
                    },
                }，
                "InputMappings": [
                    {
                        "SourcePath": "cos://batchbucket-appid.cosgz.myqcloud.com/input/",
                        "DestinationPath": "/data/input/"
                    }
                ],
                "OutputMappings": [
                    {
                        "SourcePath": "/data/output/",
                        "DestinationPath": "cos://batchbucket-appid.cosgz.myqcloud.com/output/"
                    }
                ],
                "RedirectInfo": {
                    "StdoutRedirectPath": "cos://batchbucket-appid.cosgz.myqcloud.com/log/",
                    "StdoutRedirectFileName": "prefix.${BATCH_TASK_NAME}.${BATCH_TASK_INSTANCE_INDEX}.log",
                    "StderrRedirectPath": "cos://batchbucket-appid.cosgz.myqcloud.com/log/"
                    "StderrRedirectFileName": "prefix.project1.log"
                },
				"RedirectLocalInfo": {
                    "StdoutLocalPath": "/data/stdout/",
                    "StdoutLocalFileName": "stdout.${BATCH_TASK_NAME}.${BATCH_TASK_INSTANCE_INDEX}",
                    "StderrLocalPath": "/data/stderr/"
                    "StderrLocalFileName": "stderr.${BATCH_TASK_NAME}.${BATCH_TASK_INSTANCE_INDEX}"
                },
                "Authentications": [
                    {
                        "Scene"： "COS",
                        "SecretId": "xxx",
                        "SecretKey": "yyy"
                    }
                ],
                "MaxRetryCount": 3,
                "Timeout": 86400,
            },
            {
                "TaskName": "B",
                "TaskInstanceNum": 3,
                # other params
                "Application": {
                    "Command": "python b.py",
                    "DeliveryForm": "PACKAGE",
                    "PackagePath": "http://batchbucket-appid.cosgz.myqcloud.com/app/app.tgz",
                },
                "ComputeEnv": {
                    "EnvType": "MANAGED",
                    "EnvData": {
                        "InstanceType": "S1.SMALL1",
                        "ImageId"： "img-bq1gnde3"，
                    },
                }，
                "InputMappings": [
                    {
                        "SourcePath": "cos://batchbucket-appid.cosgz.myqcloud.com/input/",
                        "DestinationPath": "/data/input/"
                    }
                ],
                "OutputMappings": [
                    {
                        "SourcePath": "/data/output/",
                        "DestinationPath": "cos://batchbucket-appid.cosgz.myqcloud.com/output/"
                    }
                ],
                "RedirectInfo": {
                    "StdoutRedirectPath": "cos://batchbucket-appid.cosgz.myqcloud.com/log/",
                    "StderrRedirectPath": "cos://batchbucket-appid.cosgz.myqcloud.com/log/"
                },
                "Authentications": [
                    {
                        "Scene"： "COS",
                        "SecretId": "xxx",
                        "SecretKey": "yyy"
                    }
                ],
                "MaxRetryCount": 3,
                "Timeout": 86400,
            },
            {
                "TaskName": "C",
                "TaskInstanceNum": 1,
                # other params
                "Application": {
                    "Command": "python c.py",
                    "DeliveryForm": "PACKAGE",
                    "PackagePath": "http://batchbucket-appid.cosgz.myqcloud.com/app/app.tgz",
                    "Docker": {
                        "User": "batch",
                        "Password": "xxx",
                        "Server": "ccr.ccs.tencentyun.com",
                        "Image": "[namespace][repo]:[tag]"
                    }
                },
                "ComputeEnv": {
                    "EnvType": "MANAGED",
                    "EnvData": {
                        "InstanceType": "S1.SMALL1",
                        "ImageId"： "img-bq1gnde3"，
                    },
                }，
                "InputMappings": [
                    {
                        "SourcePath": "cos://batchbucket-appid.cosgz.myqcloud.com/input/",
                        "DestinationPath": "/data/input/"
                    }
                ],
                "OutputMappings": [
                    {
                        "SourcePath": "/data/output/",
                        "DestinationPath": "cos://batchbucket-appid.cosgz.myqcloud.com/output/"
                    }
                ],
                "RedirectInfo": {
                    "StdoutRedirectPath": "cos://batchbucket-appid.cosgz.myqcloud.com/log/",
                    "StderrRedirectPath": "cos://batchbucket-appid.cosgz.myqcloud.com/log/"
                },
                "Authentications": [
                    {
                        "Scene"： "COS",
                        "SecretId": "xxx",
                        "SecretKey": "yyy"
                    }
                ],
                "MaxRetryCount": 3,
                "Timeout": 86400,
            }
        ],
        "Dependences": [
            {
                "StartTask": "A",
                "EndTask": "B",
            },
            {
                "StartTask": "B",
                "EndTask": "C",
            }
        ]
    }
    "Placement": {
        "Zone": "ap-guangzhou-2",
    },
    "ClientToken": "xxxx"
}
```


### 3. 输出参数
参数名称 | 类型  | 描述
-----|------|-----
JobId | String | 当通过本接口来提交作业时会返回该参数，表示一个作业ID。返回作业ID列表并不代表作业解析/运行成功，可根据 DescribeJob 接口查询其状态。
RequestId | String | 唯一请求ID。每次请求都会返回一个唯一的RequestId，当客户调用接口失败找后台研发人员处理时需提供该RequestId具体值。

```
# 接口正常返回示例
{
    "Response": {
        "JobId": "job-08gkkznp",
        "RequestId": "eac6b301-a322-493a-8e36-83b295459397"
    }
}
