## 接口描述
### 功能描述
CreateFunction 用于创建函数，调用该接口时必须指定函数名称、代码和处理方法，其他的参数如：函数描述、运行时内存大小、运行超时时间等都为可选参数。
### 接口域名
接口请求域名为： `scf.api.qcloud.com`

## 请求

语法示例：
```
GET https://scf.api.qcloud.com/v2/index.php/?Action=CreateFunction
    &<公共请求参数>
    &functionName=<FunctionName>
    &code=<代码 zip 文件 base64 编码后的字符串>
    &handler=<function.handler>
    &description=<Description String>
    &memorySize=<128>
    &timeout=<2>
	&runtime=<Python2.7>
	&codeObject.cosBucketName=<cosBucketName>
	&codeObject.cosObjectName=<cosObjectName>
```

### 请求参数

以下请求参数为本接口接口请求参数，正式调用时需要加上公共请求参数，详见 [公共请求参数](/doc/api/244/4183) 页面。其中，此接口的 Action 字段为 CreateFunction。

|参数名称|描述|类型|必选|
|-----------|--------|----------|----------|
|functionName|创建的函数名称，函数名称支持26个英文字母大小写、数字、连接符和下划线，第一个字符只能以字母开头，最后一个字符不能为连接符或者下划线，名称长度2-60|String|是|
|code|包含函数及其依赖项的 zip 格式文件，使用该接口时要求将 zip 文件的内容转成 base64 编码，并在 base64 编码后的字符前加上 `@` 字符后使用URL编码处理。zip 文件最大支持 `10M`，<br>**注意：**该字段不参与鉴权。|String|是|
|handler|函数处理方法名称，名称格式支持 "文件名称.方法名称" 形式，文件名称和函数名称之间以"."隔开，文件名称和函数名称要求以字母开始和结尾，中间允许插入字母、数字、下划线和连接符，文件名称和函数名字的长度要求是 2-60 个字符|String|是|
|description|函数描述,最大支持 1000 个英文字母、数字、空格、逗号、换行符和英文句号，不支持中文|String|否|
|memorySize|函数运行时内存大小，默认为 128M，可选范围 128MB-1536MB，并且以 128MB 为阶梯|Int|否|
|timeout|函数最长执行时间，单位为秒，可选值范围 1-300 秒，默认为 3 秒|Int|否|
|runtime|函数运行环境，目前仅支持 Python2.7，Python3.6，Nodejs6.10 和 Java8|Int|否|
|codeObject|scf 支持从 cos 导入代码，该参数指定 cos 路径，包括 cosBucketName 和 cosObjectName，<br>**注意：**该字段不能与code同时指定。|Object|否|

**注意**：一个帐号在一个地域有函数配额限制，同时每个函数支持的触发器同样有配额限制。

## 响应
响应示例：
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

### 响应参数
|参数名称|描述|类型|
|-------|---|---------------|
|code|公共错误码, 0 表示成功，其他值表示失败。详见错误码页面的 [公共错误码](/doc/api/244/1530)|Int|
|message|模块错误信息描述，与接口相关|String|
|codeDesc|英文错误码，成功返回 Success，失败有相应的英文说明|String|


## 实际案例

### 请求

```
GET https://scf.api.qcloud.com/v2/index.php?
    Action=CreateFunction
    &Nonce=610072102
    &Region=gz
    &Timestamp=1505790265
    &SecretId=AKIDutrojKl3CKQZNAr763UXks05898Lmciu
    &functionName=test7
    &description=helloWorldfunction
    &memorySize=128
    &timeout=3
    &handler=index.main_handler
    &code=%40UEsDBBQAAAAIAEWpMkuPqFdcYgAAAHAAAAAIAAAAaW5kZXgucHkliksOQDAQQPcSd5iw8Al7cQI3sBTRqTZppzKm4viKt3zvldC3PWxBWdpHiKKHV%2BSZQg1%2BtbSYlZRDrvFCki6dJHhLM%2BYZJA62JHU1oXMB5sBOVc1fGCUyQWG%2BpDl4ODddPFBLAQI%2FABQAAAAIAEWpMkuPqFdcYgAAAHAAAAAIACQAAAAAAAAAIAAAAAAAAABpbmRleC5weQoAIAAAAAAAAQAYAHFx%2BHN%2FMNMBIZcEb38w0wEhlwRvfzDTAVBLBQYAAAAAAQABAFoAAACIAAAAAAA%253d
    &Signature=XuQknRcWlZvpBItk7G6hmoOuPfE%3D
```

### 响应

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}

```
