## 接口描述
### 功能描述
UpdateFunction 更新函数的相关字段包括代码、处理方法、描述、运行时内存大小和运行超时时间等。   

### 接口域名
无服务器云函数接口请求域名为： `scf.api.qcloud.com`

## 请求
语法示例：
```
GET https://scf.api.qcloud.com/v2/index.php?
    Action=UpdateFunction
    &<公共请求参数>
    &functionName=<FunctionName>
	&code=<代码 zip 文件 base64 编码后的字符串>
	&handler=<function.handler>
	&description=<Description String>
    &memorySize=<256>
    &timeout=<30>
	&runtime=<Python2.7>
	&codeType=<Zipfile>
	&codeObject.cosBucketName=<cosBucketName>
	&codeObject.cosObjectName=<cosObjectName>
```

### 请求参数
以下请求参数为本接口的接口请求参数，正式调用时需要加上公共请求参数，见 [公共请求参数](/doc/api/244/4183) 页面。其中，此接口的 Action 字段为 UpdateFunction。

|参数名称|描述|类型|必选|
|-----------|--------|----------|----------|
|functionName|要修改的函数名称|String|是|
|code|包含函数代码文件及其依赖项的 zip 格式文件，使用该接口时要求将 zip 文件的内容转成 base64 编码并在 base64 编码后的字符前加上 `@` 字符后使用URL编码处理。zip 文件最大支持 `10M`，<br>**注意：**该字段不参与鉴权。|String|否|
|handler|函数处理方法名称。名称格式支持“文件名称.函数名称”形式，文件名称和函数名称之间以"."隔开，文件名称和函数名称要求以字母开始和结尾，中间允许插入字母、数字、下划线和连接符，文件名称和函数名字的长度要求 2-60 个字符|String|否|
|description|函数描述。最大支持 1000 个英文字母、数字、空格、逗号和英文句号，不支持中文|String|否|
|memorySize|函数运行时内存大小，默认为 128 M，可选范 128 M-1536 M|Int|否|
|timeout|函数最长执行时间，单位为秒，可选值范 1-300 秒，默认为 3 秒|Int|否|
|runtime|函数运行环境，目前仅支持 Python2.7，Python3.6，Nodejs6.10 和 Java8|Int|否|
|codeType|代码更新类型，当前支持三种：Inline表示在线更新，Zipfile表示通过代码包更新，Cos表示通过从 cos 导入代码更新|String|是|
|codeObject|scf 支持从 cos 导入代码，该参数指定 cos 路径，包括 cosBucketName 和 cosObjectName，<br>**注意：**该字段不能与 code 同时指定。|Object|否|

## 响应
响应示例：
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```

### 响应参数
|参数名称|描述|类型|
|-------|---|---------------|
|code|公共错误码， 0 表示成功，其他值表示失败|Int|
|message|模块错误信息描述，与接口相关|String|
|codeDesc|英文错误码，成功返回 Success，失败有相应的英文说明|String|

## 实际案例

### 请求

```
GET https://scf.api.qcloud.com/v2/index.php?
    Action=UpdateFunction
    &SecretId=AKIDutrojKl3CKQZNAr763UXks05898Lmciu
    &Nonce=44144
    &Timestamp=1505803748
    &Region=gz
    &Signature=iAPNvkpfW95lc96bhMtxTIN8pXY%3D
    &functionName=test5
    &memorySize=1024
    &timeout=300
```
### 响应
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success"
}
```
