## 接口描述
### 功能描述

GetMonitorData 接口提供了获取无服务器云函数的监控数据。可以根据用户传入的函数名获得相应的监控数据。

### 接口域名
接口请求域名为： `monitor.api.qcloud.com`

## 请求
语法示例：
```
GET https://monitor.api.qcloud.com/v2/index.php?Action=GetMonitorData
    &<公共请求参数>
    &namespace=qce/scf
    &metricName=duration
    &dimensions.0.name=functionName
    &dimensions.0.value=test
    &startTime=2017-07-24 14:00:00
    &endTime=2017-07-24 14:05:00
    &period=300
```

### 请求参数
以下请求参数为本接口接口请求参数，正式调用时需要加上公共请求参数，详见 [公共请求参数](/doc/api/244/4183) 页面。其中，此接口的 Action 字段为 CreateFunction。

| 参数名称 | 描述 | 类型 |必选 | 
|-----------|--------|----------|----------|
|namespace| 命名空间，每个云产品会有一个命名空间。无服务器云函数的命名空间名为：`qce/scf`|String|是|
|metricName|指标名称，想要获取的具体监控指标，如运行时间是 duration，调用次数是 invocation 等|String|是|
|dimensions.n.name|  纬度的名称。当前无服务器云函数只有一个维度：functionName，与 dimensions.n.value 配合使用|String|是| 
| dimensions.n.value|  纬度名称对应的值|String| 是|
| startTime|  起始时间，如 ”2017-01-01 00:00:00”。默认时间为当天的 ”00:00:00”。|Datetime|否| 
| endTime|  结束时间，如 ”2017-01-01 10:00:00”。默认为当前时间。<br>**注意：**endTime 不能小于startTime，且 endTime 与 startTime 最好为同一天| Datetime|否|
| period|监控统计周期。当前支持 60s 和 300s 两种粒度，如不传，默认使用 300s 粒度。|  Int| 否|

当前无服务器云函数可展示的指标（metricName）列表如下：

| 指标名称 | 含义 | 单位 |
|---------|---------|---------|
| duration | 运行时间 | 毫秒(ms) |
| invocation | 调用次数 | 次 |
| error | 调用错误次数 | 次 |

当前无服务器云函数只支持云函数名称维度，说明如下：
此维度体现的是一个云函数的监控指标，需要传入的维度（dimensions.n.name）如下：

| 维度 | 维度解释 | 格式 |
|---------|---------|---------|
|  functionName | 无服务器云函数名称 | string |

如果您想查询名称为 test 的云函数的运行时间（duration）的监控数据，则 API 请求示例如下：
```
GET https://monitor.api.qcloud.com/v2/index.php?Action=GetMonitorData
    &<公共请求参数>
    &namespace=qce/scf
    &metricName=duration
    &dimensions.0.name=functionName
    &dimensions.0.value=test
```

## 响应
响应示例：
```
{
    "code": 0,
    "message": "",
    "metricName": "duration",
    "startTime": "2017-07-24 14:00:00",
    "endTime": "2017-07-24 14:05:00",
    "period": 300,
    "dataPoints":  [
        0.65213,
        0.5586
    ]
}
```

### 响应参数

|参数名称|描述|类型|
| --- | --- | --- |
| code|公共错误码，0 表示成功，其他值表示失败。详见错误码页面的 [公共错误码](https://cloud.tencent.com/doc/api/244/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)| Int| 
| codeDesc|  英文错误码|String|
| message|  错误信息详细描述|String|
| startTime| 起始时间|Datetime| 
| endTime|结束时间| Datetime| 
| metricName|  指标名称|String|
| period| 监控统计周期|Int| 
| dataPoints|  监控数据列表。数组每个元素是监控点数据|Object|

## 实际案例

### 请求
```
GET https://monitor.api.qcloud.com/v2/index.php?
    Action=GetMonitorData
    &SecretId=AKIDutrojKl3CKQZNAr763UXks05898Lmciu
    &Nonce=62089
    &Timestamp=1505804102
    &Region=gz
    &Signature=LWI%2BdudHPe56OYcsvKWiXImdO5s%3D
    &namespace=qce%2Fscf
    &metricName=duration
    &dimensions.0.name=functionName
    &dimensions.0.value=test5
    &startTime=2017-09-19+12%3A00%3A00
    &endTime=2017-09-19+14%3A05%3A00
    &period=300

```
### 响应
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "metricName": "duration",
    "startTime": "2017-09-19 12:00:00",
    "endTime": "2017-09-19 14:05:00",
    "period": "300",
    "dataPoints": [
        2.983,
        1.131,
        0.732,
        0.773,
        0.921,
        0.901,
        0.775,
        0.931,
        0.812,
        0.757,
        1.06,
        0.805,
        0.834,
        0.812,
        0.881,
        0.807,
        0.831,
        0.992,
        0.793,
        1.968,
        0.868,
        0.93,
        6.365,
        0.732,
        0.836,
        1.433
    ]
}
```