## 1. API Description

This API (SendMessage) is used to send a message to the specified queue.

Domain for public network API request:<font style="color:red">cmq-queue-region.api.qcloud.com</font>

Domain for private network API request:<font style="color:red">cmq-queue-region.api.tencentyun.com</font>

> At any time (including alpha test), any downstream traffic generated when using public network domain will incur traffic fee. It is strongly recommended that users on Tencent Cloud use **private network** domain, as it will not incur any traffic fee.

- The "region" should be replaced by a specific region: gz (Guangzhou), sh (Shanghai), bj (Beijing). The "region" value in the common parameter should be kept consistent with that in the domain. In case of inconsistency, the one in the domain should prevail. The request should be sent to the region specified by the domain.
- Requests for accessing via public network domain support both HTTP and HTTPS. Requests for accessing via private network only support HTTP.
- Some of the input parameters are optional, so the default values are not required.
- All output parameters will be returned to the user when the request is successful; otherwise, at least code, message, and requestId will be returned.


## 2. Input Parameters

The following request parameter list only provides API request parameters. For other parameters, refer to [Common Request Parameters](https://cloud.tencent.com/document/api/213/6976).

| Parameter Name | Required | Type | Description |
|---------|---------|---------|---------|
| queueName | Yes | String | Queue name. This is unique under the same account in one region. The name of queue is a string with no more than 64 characters. It must start with letter, and the rest may contain letters, numbers and dashes (-). |
| msgBody | Yes | String | Message body. At least 1 Byte. Maximum length depends on the maximum length attribute of queue messages you have configured. |
| delaySeconds | No | Int | Time needed before the message becomes visible to user after it has been sent to the queue (in seconds). |
## 3. Output Parameters

| Parameter Name | Type | Description |
|---------|---------|---------|
| code | Int | 0: Succeeded, others: Error. For detailed errors, please refer to the table below. |
| message | String | Error message. |
| requestId | String | ID of the request generated by the server. When there is an internal error on the server, users can submit this ID to backend to locate the problem. |
| msgId | String | Unique ID of the message generated by the server. |


<table class="t">
<tbody><tr>
<th> <b>Error Code</b>
</th><th> <b>Module Error Code</b>
</th><th> <b>Error Message</b>
</th><th> <b>Description</b>
</th></tr>
<tr>
<td> 4400
</td><td> 10230
</td><td> exceed maximum message size
</td><td> There's at least one message that reached the maximum message length limit. You can use the <a  href="https://cloud.tencent.com/doc/api/431/5834">GetQueueAttributes</a> API to view the maximum message length for the queue.
</td></tr>
<tr>
<td> 4000
</td><td> 10120
</td><td> message body can't be empty
</td><td> The message body of msgBody cannot be empty. It should be at least 1 Byte.
</td></tr>
<tr>
<td> 4410
</td><td> 10240
</td><td> reach maximum retention number of message
</td><td> The maximum number of messages in a queue has been reached. You can use the <a  href="https://cloud.tencent.com/doc/api/431/5834">GetQueueAttributes</a> API to view the maximum number of messages for the queue.
</td></tr>
</tbody></table>

Note: The error codes listed in the above table are specific to the API. If the error code you are looking for is not here, you may find it in the [Common Error Codes](https://cloud.tencent.com/document/product/406/5903).

## 4. Example

Input:

<pre>
 https://domain/v2/index.php?Action=SendMessage
 &queueName=test-queue-123
 &msgBody=helloworld
 &<<a href="https://cloud.tencent.com/doc/api/229/6976">Common Request Parameters</a>>
</pre>

Output:

```
{
"code" : 0,
"message" : "",
"requestId":"14534664555",
"msgId":"123345346"
}
```







