## 1. 接口描述

本接口 (CreateQueue) 用于在用户账户下创建一个新队列。

外网接口请求域名：<font style="color:red">cmq-queue-region.api.qcloud.com</font>

内网接口请求域名：<font style="color:red">cmq-queue-region.api.tencentyun.com</font>

> 任何时候，包括内测期间，如果使用外网域名产生公网下行流量，都会收取流量费用。 所以强烈建议服务在腾讯云上的用户使用**内网**域名，内网不会产生流量费用。

- region 需用具体地域替换：gz（广州），sh（上海），bj（北京）。公共参数中的 region 值要与域名的 region 值保持一致，如果出现不一致的情况，以域名的 region 值为准，将请求发往域名 region 所指定的地域。
- 外网域名请求既支持http，也支持https。内网请求仅支持http。
- 输入参数有些是可选的，不填取默认值。
- 输出参数在成功情况下所有出参都会返回给用户；失败情况下，至少会有code, message, requestId返回。

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，其它参数见[公共请求参数](https://cloud.tencent.com/doc/api/431/5883)页面。

| 参数名称 | 是否必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| queueName| 是| String| 队列名字，在单个地域同一帐号下唯一。队列名称是一个不超过 64 个字符的字符串，必须以字母为首字符，剩余部分可以包含字母、数字和横划线(-)。|
| maxMsgHeapNum| 否| Int| 最大堆积消息数。取值范围在公测期间为 `1,000,000 - 10,000,000`，正式上线后范围可达到 `1000,000-1000,000,000`。默认取值在公测期间为 `10,000,000`，正式上线后为 `100,000,000`。|
| pollingWaitSeconds| 否| Int| 消息接收长轮询等待时间。取值范围 0-30 秒，默认值 0。|
| visibilityTimeout| 否| Int| 消息可见性超时。取值范围 1-43200 秒（即12小时内），默认值 30。|
| maxMsgSize| 否| Int| 消息最大长度。取值范围 1024-65536 Byte（即1-64K），默认值 65536。|
| msgRetentionSeconds| 否| Int| 消息保留周期。取值范围 60-1296000 秒（1min-15天），默认值 345600 (4 天)。|
|rewindSeconds|否|Int|队列是否开启回溯消息能力，该参数取值范围0-msgRetentionSeconds,即最大的回溯时间为消息在队列中的保留周期，0表示不开启。|
|deadLetterPolicy|否|string|可选参数，死信队列策略配置参数，不填默认不开启死信队列功能。必须是Json格式的字符串（json.dump后的值），包含参数有：deadLetterQueue、policy、maxReceiveCount、maxTimeToLive，具体定义如下字段描述。|
|deadLetterPolicy:: deadLetterQueue|是|string|死信队列的名称，条件：必须是同地域、同帐号下的队列；该队列本身没有设置死信队列（不允许嵌套）；该队列被指定为其他队列的死信队列的次数未达到上限，目前上限为6个队列。|
|deadLetterPolicy::policy|是|int|死信策略，0：消息被多次消费未删除；1：Time-To-Live 过期。|
|deadLetterPolicy:: maxReceiveCount|否|int|Policy=0时是必填参数。最大接收次数，支持设定值为1-1000次。|
|deadLetterPolicy:: maxTimeToLive|否|int|Policy=1时是必填参数。最大未消费过期时间，允许设置5min-12小时，单位为秒，且必须小于消息保留周期msgRetentionSeconds的值。|
## 3. 输出参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 0：表示成功，others：错误，详细错误见下表。|
| message | String | 错误提示信息。|
| requestId| String| 服务器生成的请求Id。出现服务器内部错误时，用户可提交此 Id 给后台定位问题。|
| queueId| String| 队列的唯一标识Id。|


<table class="t">
<tbody><tr>
<th> <b>错误代码</b>
</th><th> <b>模块错误代码</b>
</th><th> <b>英文提示</b>
</th><th> <b>描述</b>
</th></tr>
<tr>
<td> 4000
</td><td> 10020
</td><td> queue name format error
</td><td> 队列名字格式错误。<a href="https://cloud.tencent.com/doc/api/431/5832">规则</a>详见创建队列接口的queueName字段说明。
</td></tr>
<tr>
<td> 4450
</td><td> 10220
</td><td> number of queues has reached the limit
</td><td> 队列数量达到最大值。一个账户的队列数量是有限(1000)的，达到最大值后，就不能创建新的队列了。
</td></tr>
<tr>
<td> 6040
</td><td> 10660
</td><td> it will take some time to release resources of previous queue before you create a new one with the same name, please try later
</td><td> 创建同名队列失败。因为刚才删除同名队列需要释放资源，目前CMQ为了保证数据一致性，在删除队列之后，十秒内不能创建同名队列。
</td></tr>
<tr>
<td> 4000
</td><td> 10710
</td><td> deadLetterPolicy must be a json string
</td><td> 死信队列策略必须为json string。
</td></tr>
<tr>
<td> 4000
</td><td> 10720
</td><td> deadLetterPolicy params error,please check it
</td><td> 死信队列策略参数错误，请检查参数是否合法。
</td></tr>
<tr>
<td> 4000
</td><td> 10730
</td><td> deadLetter queue not exist
</td><td> 死信队列不存在，请确认设为死信队列的队列已经创建。
</td></tr>
<tr>
<td> 4000
</td><td> 10740
</td><td> deadLetter queue is not allowed to nest
</td><td> 死信队列不允许嵌套。
</td></tr>
<tr>
<td> 4000
</td><td> 10750
</td><td> it is not allowed to be deleted when the queue is dead letter queue
</td><td> 当队列为死信队列时，不允许被删除。
</td></tr>
<tr>
<td> 4000
</td><td> 10760
</td><td> the deadLetterPolicy must has deadLetterQueue member, only be a string
</td><td> 死信队列策略参数中必须包含deadLetterQueue字段，请检查该字段是否存在。
</td></tr>
<tr>
<td> 4000
</td><td> 10770
</td><td> the deadLetterPolicy must has policy member , only set 0 or 1
</td><td> 死信队列策略参数中必须包含policy字段，且该字段值只能为0或者1。
</td></tr>
<tr>
<td> 4000
</td><td> 10780
</td><td> the deadLetter Queue bind too many times
</td><td> 死信队列绑定次数超过上限。
</td></tr>
</tbody></table>

注意：上表所列错误码是接口特有错误码，如果您要查找的错误码不在其中，可能在[公共错误码](https://cloud.tencent.com/document/product/406/5903)中。


## 4. 示例

输入：

<pre>
 https://domain/v2/index.php?Action=CreateQueue
 &queueName=test-queue-123
 &<<a href="https://cloud.tencent.com/doc/api/229/6976">公共请求参数</a>>
</pre>

输出：

```
{
"code" : 0,
"message" : "",
"requestId":"14534664555",
"queueId":"queue-ajksdfasdowe"
}
```






