## 1. API Description

This API (RewindQueue) is used for message rewind. For more information, please see [Message Rewind](https://cloud.tencent.com/document/product/406/8129).
Domain for public network API request: cmq-queue-region.api.qcloud.com

Domain for private network API request: cmq-queue-region.api.tencentyun.com

> Whenever (including during alpha test) any public network downstream traffic is generated from the use of a public network domain, a fee will be charged. It is strongly recommended that users whose services are on the Tencent Cloud use **private network** domains, because no fee will be charged for the traffic consumed in the private network.

- region should be replaced with a specific region: gz (Guangzhou), sh (Shanghai), or bj (Beijing). The region value in the common parameters should be consistent with the region value of the domain. If there is an inconsistency, the request will be sent to the region specified by the domain.
- Public network domain requests both support http and https. Private network requests only support http.
- Some of the input parameters are optional. If not specified, the default value will be taken.
- All the output parameters will be returned to the user when the request is successful; otherwise, at least code, message, and requestId will be returned.

## 2. Input Parameters

The following request parameter list only provides API request parameters. For other parameters, refer to [Common Request Parameters](https://cloud.tencent.com/doc/api/431/5883).

| Parameter Name | Required | Type | Description |
|---------|---------|---------|---------|
| queueName | Yes | String | Queue name. This is unique under the same account in one region. The queue name is a string of no more than 64 characters, which can contain letters, numbers, and hyphens (-) and must begin with a letter. |
| startConsumeTime | Yes | Unix timestamp | If this time is set, API (Batch) receiveMessage will consume messages after this timestamp based on the order of production messages. |

## 3. Output Parameters

| Parameter Name | Type | Description |
|---------|---------|---------|
| code | Int | 0: Succeeded, others: Error. See the table below for specific errors. |
| message | String | Error message. |
| requestId | String | Request ID generated by server. When there is an internal error on the server, users can submit this ID to the backend to locate the problem. |



<table class="t">
<tbody><tr>
<th> <b>Error Code</b>
</th><th> <b>Module Error Code</b>
</th><th> <b>Error Message</b>
</th><th> <b>Description</b>
</th></tr>
<tr>
<td> 6050
</td><td> 10670
</td><td> your queue cannot be rewinded
</td><td> Queue cannot be rewound.
</td></tr>
<tr>
<td> 4000
</td><td> 10680
</td><td> invalid rewind time, you can get the vaild range of that via GetQueueAttributes
</td><td> Invalid rewind time. You can view the queue attributes to get the correct rewind time.
</td></tr>
<tr>
<td> 4000
</td><td> 10700
</td><td> rewindSeconds cannot be greater than msgRetentionSeconds
</td><td> The rewind time cannot be greater than the message retention period.
</td></tr>

</tbody></table>

Note: The error codes listed in the above table are specific to this API. If the error code you are looking for is not in the table, you may find it in the [Common Error Codes](https://cloud.tencent.com/document/product/406/5903).


## 4. Example

Input:

<pre>
 https://domain/v2/index.php?Action=RewindQueue
 &queueName=test-queue-123&startConsumeTime=unix timestamp
 &<<a href="https://cloud.tencent.com/doc/api/229/6976">Common request parameters</a>>
</pre>

Output:

```
{
"code" : 0,
"message" : "",
"requestId":"14534664555"
}
```







