## 1. API Description

This API (AssignPrivateIpAddresses) is used to apply for the private IP of ENI.
Domain for API request: <font style="color:red">vpc.api.qcloud.com</font>

1) An ENI can only be bound to limited IP addresses. For more information on VPC resource restrictions, refer to <a href="https://cloud.tencent.com/doc/product/215/537" title="VPC Usage Restrictions">VPC Usage Restrictions</a>.
2) You can specify the private IP address to be applied. Private IP address type cannot be the primary IP. The primary IP already exists and cannot be modified. The private IP must be in the subnet of the ENI, and cannot be occupied.
3) You can apply for one or multiple auxiliary private IPs on the ENI. The API will return a specified number of auxiliary private IPs in the subnet segment of the ENI.


## 2. Input Parameters
The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to <a href="/doc/api/245/4772" title="Common request parameters">Common Request Parameters</a>. The Action field for this API is AssignPrivateIpAddresses.

| Parameter Name | Required | Type | Description |
|---------|---------|---------|---------|
| vpcId | Yes | String | Virtual private cloud ID of ENI, for example: vpc-7t9nf3pu |
| networkInterfaceId | Yes | String | ENI ID, for example: eni-m6dyj72l |
| privateIpAddressSet.n | No | Array | Specify the IP address to be applied when applying for private IP. You can specify primary IP. Optional.  |
| privateIpAddressSet.n.primary | Yes | Bool | Primary IP or not, can only set one primary IP.  |
| privateIpAddressSet.n.privateIpAddress | Yes | String | Specified private IP address.  |
| secondaryPrivateIpAddressCount | No | Int |(Optional) Specify the quantity of  private IPs. The IP will be automatically generated by the system.|

## 3. Output Parameters

| Parameter Name | Type | Description |
|---------|---------|---------|
| code | Int | Error code. 0: Succeeded; other values: Failed.|
| message | String | Error message |
| taskId | Int | Task ID. The operation result can be queried with taskId. For more information, refer to <a href="https://cloud.tencent.com/doc/api/245/%e6%9f%a5%e8%af%a2%e4%bb%bb%e5%8a%a1%e6%89%a7%e8%a1%8c%e7%bb%93%e6%9e%9c%e6%8e%a5%e5%8f%a3">API for Querying Task Execution Result</a>.  |

## 4. Error Code Table
The following error code list only provides the business logic error codes for this API. For additional common error codes, refer to <a href="https://cloud.tencent.com/doc/api/245/4924" title="VPC Error Codes">VPC Error Codes</a>.

| Error code | Description |
|---------|---------|
| InvalidVpc.NotFound | VPC does not exist. Please check the information you entered. You can query the VPC via the <a href="http://cloud.tencent.com/doc/api/245/%E6%9F%A5%E8%AF%A2%E7%A7%81%E6%9C%89%E7%BD%91%E7%BB%9C%E5%88%97%E8%A1%A8" title="DescribeVpcEx">DescribeVpcEx</a> API |
| InvalidNetworkInterface.NotFound | ENI does not exist. Please check the information you entered. You can query the ENI via the <a href="https://cloud.tencent.com/doc/api/245/%e6%9f%a5%e8%af%a2%e5%bc%b9%e6%80%a7%e7%bd%91%e5%8d%a1%e4%bf%a1%e6%81%af?viewType=preview" title="DescribeNetworkInterfaces">DescribeNetworkInterfaces</a> API |
| InvalidPrivateIpAddress.InUse | This private IP already in use |

## 5. Example
Input
<pre>
https://vpc.api.qcloud.com/v2/index.php?Action=AssignPrivateIpAddresses
&<<a href="https://cloud.tencent.com/doc/api/229/6976">Common request parameters</a>>
&vpcId=vpc-7t9nf3pu
&networkInterfaceId=eni-m6dyj72l
&secondaryPrivateIpAddressCount=1
</pre>
Output
```
{
    "code":"0",
    "message":"",
    "taskId":16284
}
```


