Common request parameters are the parameters common to all APIs, and will not be discussed in the document for each API unless it is necessary to do so. **They are required in each request for the request to be initiated normally**. The first letter of each common request parameter is uppercase so that the parameter can be differentiated from API request parameters.

Common request parameters are listed as follows:

<table class="t">
<tbody><tr>
<th> <b>Name</b>
</th><th> <b>Type</b>
</th><th> <b>Description</b>
</th><th width="50"> <b>Required</b>
</th></tr>
<tr>
<td> Action
</td><td> String
</td><td> The name of the API for the desired operation. For example, if you want to call the API <a href="/doc/api/229/831" title="查看实例列表">Query Scaling Group List</a>, the Action parameter is DescribeInstances.
</td><td> Yes
</td></tr>
<tr>
<td> Region
</td><td> String
</td><td> Region parameter that is used to identify the region to which the instance you want to operate belongs. The parameter values for regions are as follows:  <br>Beijing: bj, Guangzhou: gz, Shanghai: sh, Hong Kong: hk, North America: ca. <br><B>Note: Generally, this parameter is required, unless otherwise indicated in the relevant API.</B>
</td><td> No
</td></tr>
<tr>
<td> Timestamp
</td><td> UInt
</td><td> The current UNIX timestamp that records the time at which the API request was initiated.
</td><td> Yes
</td></tr>
<tr>
<td> Nonce
</td><td> UInt
</td><td> A random positive integer that is used in conjunction with Timestamp to prevent replay attacks.
</td><td> Yes
</td></tr>
<tr>
<td> SecretId
</td><td> String
</td><td> The SecretId which is used for identifying identity and applied for on <a href="https://console.cloud.tencent.com/capi">Cloud API Key</a>. A SecretId corresponds to a unique SecretKey, which is used to generate the request Signature. For more information, refer to <a href="/doc/api/372/4214" title="签名方法">Signature Method</a>.
</td><td> Yes
</td></tr>
<tr>
<td> Signature
</td><td> String
</td><td> Request signature, which is used to verify the legitimacy of the request and automatically generated by system according to input parameters. For more information, refer to <a href="/doc/api/372/4214" title="签名方法">Signature Method</a>.
</td><td> Yes
</td></tr></tbody></table>

Assuming that the user wants to query the list of CVM instances for Guangzhou, the request link may be as follows:

```
https://cvm.api.qcloud.com/v2/index.php?
Action=DescribeInstances
&SecretId=xxxxxxx
&Region=gz
&Timestamp=1465055529
&Nonce=59485
&Signature=mysignature
&<API Request Parameter>
```

A complete request needs two types of request parameters: common request parameters and API request parameters. Only six common request parameters are listed above. For information on API parameters, refer to <a href="/doc/api/372/接口请求参数" title="接口请求参数">API Request Parameters</a> section.
