## 1. API Description
 CreateLoadBalancer is used to create cloud load balancer instances. You must purchase one or multiple cloud load balancer instances before using Cloud Load Balance. When successfully calling the API, the unique ID of the cloud load balancer instance will be returned. Users can purchase the following types of cloud load balancer instances: public network (without daily rate), public network (with daily rate), and private network. Please refer to [Product Type](/doc/product/214/产品类型).
 
Domain for API access: lb.api.qcloud.com

## 2. Request Parameters
  The following request parameter list only provides API request parameters. Common request parameters need to be added when the API is called. For more information, refer to [Common Request Parameters](/doc/api/244/4183). The Action field for this API is CreateLoadBalancer.

| Parameter Name | Required | Type | Description |
|-|-|-|--|
| loadBalancerType | Yes | Int | Type of the cloud load balancer.  <br> 2: public network with static IP (including application-based cloud load balancer); 3: private network. |
| forward | No | Int | Indicate whether the purchased cloud load balancer instance is application-based. 1: Application-based cloud load balancer; 0: non-application-based cloud load balancer. The default is non-application-based cloud load balancer instance. |
| loadBalancerName | No | String | Name of the cloud load balancer instance. You can only create one instance. The name can contain 1-20 characters, including English letters, Chinese characters, numbers, "-" or "_". <br>Note: If a duplicate name exists in the system, the system will automatically generate a name for created cloud load balancer instance. |
| domainPrefix | No | String | Domain prefix. The domain name of cloud load balancer instance consists of the domain prefix entered by user and the domain suffix automatically generated by Tencent Cloud to ensure the uniqueness. This field is not applicable to application-based cloud load balancers. <br>The name can contain 1-20 characters, including English letters (in lowercase), numbers or "-". This field is not applicable to the cloud load balancer of private network. <br> Note: If a duplicate domain prefix exists in the system, the system will automatically generate a prefix for created cloud load balancer instance. For example xxxxx.region.appId.clb.myqcloud.com. You only need to enter the prefix "xxxxx". |
| vpcId | No | String | VPC ID of the cloud load balancer instance. You can query it via <a href="http://cloud.tencent.com/doc/api/245/%E6%9F%A5%E8%AF%A2%E7%A7%81%E6%9C%89%E7%BD%91%E7%BB%9C%E8%AF%A6%E6%83%85" title="DescribeVpcs">DescribeVpcs</a>. If left empty or 0, the network is <a href="https://cloud.tencent.com/doc/product/215" title="basic network">basic network</a>; if the numerical digits of vpcId is greater than 0, the network is <a href="https://cloud.tencent.com/doc/product/215" title="VPC">VPC</a>. |
| subnetId | No | String | When you purchase the cloud load balancer instance of private network within the VPC, you need to specify the subnet ID. The VIP of the cloud load balancer instance of private network will be generated from this subnet. In other cases, this field can be left empty. |
| projectId | No | Int | The project ID of the cloud load balancer instance.　You can query it via <a href="/doc/api/403/4400" title="DescribeProject">DescribeProject</a>. If left empty, it is the default project. |
| number | No | Int | Number of purchased cloud load balancer instances; default: 1. |



 

## 3. Response Parameters

| Parameter Name | Type | Description |
|-------|---|---------------|
| code | Int | Common error code; 0: Succeeded; other values: Failed. For more information, please refer to [Common Error Code](/doc/api/244/1530) in the Error Code page. |
| message | String | Module error message description depending on API. |
| codeDesc | String | Error code. For a successful operation, "Success" will be returned. For a failed operation, a message describing the failure will be returned. |
| unLoadBalancerIds | Array | The array of the unified ID of the cloud load balancer instance. |
| dealIds | Array | The order number corresponding to each cloud load balancer instance that is used to query the information on subsequent execution. (You can query order details via <a href="http://cloud.tencent.com/doc/api/229/%E8%8E%B7%E5%8F%96%E8%AE%A2%E5%8D%95%E4%BF%A1%E6%81%AF" title="DescribeDeals">DescribeDeals</a>.)  |


## 4. Example
 
Purchase a cloud load balancer instance of the public network type (with daily rate) and with the name of "test":
```
https://lb.api.qcloud.com/v2/index.php?Action=CreateLoadBalancer
&<Common request parameters>
&loadBalancerType=2
&loadBalancerName=test
```
Output:
```
{
    "code" : 0,
    "message" : "",
	"codeDesc": "Success",
    "unLoadBalanceIds":[
        "lb-abcdefgh"
		],
    "dealIds":[
        121
    ]
}
```
lb-abcdefgh is the unified ID of the cloud load balancer instance you just purchased. Next, use API [Query the List of Cloud Load Balancer Instances](/doc/api/244/1261) to query whether the Cloud Load Balancer instance has been successfully created.


