## 功能描述

DescribeDevice接口用来查询服务器列表。

接口访问域名：bm.api.qcloud.com

## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDevice
	&<公共请求参数>
	&offset=<偏移量>
	&limit=<查询返回物理机的数量>
	&unVpcId=<私有网络的ID>
	&deviceClass=<设备类型>
	&instanceIds.0=<设备ID1>
	&instanceIds.1=<设备ID2>
	&lanIps.0=<业务内网IP1>
	&lanIps.1=<业务内网IP2>
	&alias=<实例名>
```

### 请求参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为DescribeDevice。

| 参数名称              | 必选   | 类型            | 描述                                       |
| ----------------- | ---- | ------------- | ---------------------------------------- |
| offset            | 否    | Int           | 偏移量，默认为0。                                |
| limit             | 否    | Int           | 查询返回物理机的数量，默认为20。                        |
| unVpcId           | 否    | String        | 私有网络ID。通过接口[查询私有网络列表(DescribeBmVpcEx)](/doc/api/456/6646)获取私有网络信息, 取unVpcId字段，如vpc-8e0ypm3z                                  |
| unSubnetId        | 否    | String        | 子网ID。 通过接口[查询子网列表(DescribeBmSubnetEx)](/doc/api/456/6648)获取私有子网信息, 取unSubnetId字段，如subnet-34xt45as                                 |
| deviceClass       | 否    | String        | 设备类型，通过接口[DescribeDeviceClass](/doc/api/456/6636)获得设备类型信息。 |
| lanIps            | 否    | Array(String) | 业务内网IP列表。                                |
| wanIps            | 否    | Array(String) | 外网IP列表。                                  |
| instanceIds       | 否    | Array(String) | 设备ID列表。                                  |
| alias             | 否    | String        | 设备别名，模糊查询。                               |
| deadlineStartTime | 否    | String        | 按照设备到期时间(起始时间)进行过滤，时间类型为“2016-05-25 12:00:00”。 |
| deadlineEndTime   | 否    | String        | 按照设备到期时间(结束时间)进行过滤，时间类型为“2016-05-25 13:00:00”。 |
| autoRenewFlag     | 否    | Int           | 自动续费标志。0：不自动续费，1：自动续费。                   |


## 响应

### 响应示例
```
{
  "code": 0,
  "message": "OK",
  "data": {
    "totalNum": 2,
    "deviceList": [
      {
        "instanceId": "cpm-d1y5rcex3",
        "subnetId": "3",
        "vpcId": "1025",
        "unVpcId": "vpc-8e0ypm3z",
        "unSubnetId" : "subnet-34xt45as",
        "lanIp": "10.6.10.67",
        "deviceStatus": "4",
        "operateStatus": "1",
        "osTypeId": "1",
        "raidId": "1",
        "alias": "网关设备",
        "appId": "1251000000",
        "zoneId": "1000800001",
        "projectId": "0",
        "wanIp": "",
        "deliverTime": "2016-05-10 17:54:48",
        "deadline": "2018-05-10 00:00:00",
        "isVpcGateway": "1",
        "autoRenewFlag": "1",
        "deviceClass" : "M10"
      },
      {
        "instanceId": "cpm-lad4pu06",
        "subnetId": "4",
        "vpcId": "1025",
		"unVpcId": "vpc-8e0ypm3z",
        "unSubnetId" : "subnet-34xt45as",
        "lanIp": "10.6.10.73",
        "deviceStatus": "4",
        "operateStatus": "1",
        "osTypeId": "1",
        "raidId": "1",
        "alias": "服务器",
        "appId": "1251001002",
        "zoneId": "1000800001",
        "projectId": "0",
        "wanIp": "115.159.240.23",
        "deliverTime": "2016-05-17 18:23:24",
        "deadline": "2017-03-18 22:40:09",
        "isVpcGateway": "0",
        "autoRenewFlag": "0",
        "deviceClass" : "TS60"
      }
    ],
    "serverTimestamp": 1464164820301
  }
}
```

### 响应参数
响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括服务器等信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 设备列表，具体结构描述如data结构所示。                    |


data结构

| 参数名称       | 类型            | 描述                                    |
| ---------- | ------------- | ------------------------------------- |
| totalNum   | Int           | 设备总数                                  |
| deviceList | Array(Object) | 对象数组。数组元素为设备信息，具体结构描述如deviceList结构所示。 |

deviceList结构

| 参数名称          | 类型     | 描述                                       |
| ------------- | ------ | ---------------------------------------- |
| instanceId    | String | 设备ID。                                  |
| vpcId         | Int    | 私有网络ID, 整型格式                                |
| subnetId      | Int    | 私有子网ID， 整型格式                                  |
| unVpcId       | String | 私有网络ID, 字符串格式                                |
| unSubnetId      | String | 私有子网ID， 字符串格式                                  |
| deviceStatus  | Int    | 设备的运营状态， [查看](#deviceStatus)。            |
| operateStatus | Int    | 设备的操作状态， [查看](#operateStatus)。           |
| osTypeId      | Int    | 操作系统ID。操作系统含义参见接口 [查询操作系统列表(DescribeOs)](/doc/api/456/6727)。 |
| raidId        | Int    | RAID方式ID。RAID含义参见接口 [查询机型RAID方式以及系统盘大小(DescribeDeviceClassPartition)](/document/product/386/7370)。 |
| alias         | String | 设备别名。                                    |
| wanIp         | String | 弹性IP。                                    |
| lanIp         | String | 业务内网IP。                                  |
| deliverTime   | String | 设备交付时间。                                  |
| deadline      | String | 设备到期时间。                                  |
| autoRenewFlag | Int    | 自动续费标志。0：不自动续费，1：自动续费。                   |
| deviceClass   | String | 设备类型。                                    |


#### 设备的运营状态

| 状态ID | 含义      |
| ---- | ------- |
| 1    | 申领设备中   |
| 2    | 正在初始化设备 |
| 3    | 初始化失败   |
| 4    | 运营中     |
| 5    | 硬件故障    |
| 6    | 网络配置故障  |
| 7    | 正在隔离    |
| 8    | 已隔离     |
| 9    | 隔离失败    |
| 10   | 正在解隔离   |
| 11   | 解隔离失败   |
| 12   | 正在下线    |
| 13   | 已下线     |
| 14   | 到期      |

#### 设备的操作状态

| 状态ID | 含义     |
| ---- | ------ |
| 1    | 运行中    |
| 2    | 正在关机   |
| 3    | 已关机    |
| 4    | 关机失败   |
| 5    | 正在开机   |
| 6    | 开机失败   |
| 7    | 正在重启   |
| 8    | 重启失败   |
| 9    | 正在重装系统 |
| 10   | 重装失败   |
| 11   | 正在重置密码 |
| 12   | 绑定弹性IP |
| 13   | 解绑弹性IP |
| 14   | 绑定负载均衡 |
| 15   | 解绑负载均衡 |

## 错误码

| 错误码   | 英文提示                  | 错误描述    |
| ----- | --------------------- | ------- |
| 9001  | InternalError.DbError | 操作数据库错误 |
| 10001 | InvalidParameter      | 参数错误    |


## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDevice
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Region=bj
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
	&offset=1
	&limit=30
	&unVpcId=vpc-8e0ypm3z
    &deviceClass=M10
    &instanceIds.0=cpm-34xw423x
    &instanceIds.1=cpm-34xw234y
    &lanIps.0=10.1.1.1
    &lanIps.1=10.1.2.2
	&alias=实例名
```

### 输出

```
{
  "code": 0,
  "message": "OK",
  "data": {
    "totalNum": 2,
    "deviceList": [
      {
        "instanceId": "cpm-d1y5rcex3",
        "subnetId": "3",
        "vpcId": "1025",
		"unVpcId": "vpc-8e0ypm3z",
        "unSubnetId" : "subnet-34xt45as",
        "lanIp": "10.6.10.67",
        "deviceStatus": "4",
        "operateStatus": "1",
        "osTypeId": "1",
        "raidId": "1",
        "alias": "网关设备",
        "appId": "1251000000",
        "zoneId": "1000800001",
        "projectId": "0",
        "wanIp": "",
        "deliverTime": "2016-05-10 17:54:48",
        "deadline": "2018-05-10 00:00:00",
        "isVpcGateway": "1",
        "autoRenewFlag": "1",
        "deviceClass" : "M10"
      },
      {
        "instanceId": "cpm-lad4pu06",
        "subnetId": "4",
        "vpcId": "1025",
		"unVpcId": "vpc-8e0ypm3z",
        "unSubnetId" : "subnet-34xt45as",
        "lanIp": "10.6.10.73",
        "deviceStatus": "4",
        "operateStatus": "1",
        "osTypeId": "1",
        "raidId": "1",
        "alias": "服务器",
        "appId": "1251001002",
        "zoneId": "1000800001",
        "projectId": "0",
        "wanIp": "115.159.240.23",
        "deliverTime": "2016-05-17 18:23:24",
        "deadline": "2017-03-18 22:40:09",
        "isVpcGateway": "0",
        "autoRenewFlag": "0",
        "deviceClass" : "TS60"
      }
    ],
    "serverTimestamp": 1464164820301
  }
}
```