## 功能描述

DescribeDevicePosition接口用来查询服务器所在的位置，如机架，上联交换机等信息。

接口访问域名：bm.api.qcloud.com


## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDevicePosition
	&<公共请求参数>
	&offset=<偏移量>
	&limit=<查询返回物理机的数量>
	&unVpcId=<私有网络的ID>
	&unSubnetId=<私有子网的ID>
	&instanceIds.0=<设备ID1>
	&instanceIds.1=<设备ID2>
	&alias=<实例名>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为DescribeDevicePosition。

| 参数名称        | 必选   | 类型            | 描述                |
| ----------- | ---- | ------------- | ----------------- |
| offset      | 否    | Int           | 偏移量，默认为0。         |
| limit       | 否    | Int           | 查询返回物理机的数量，默认为20。 |
| unVpcId       | 否    | String           | 私有网络的ID, 字符串格式,如vpc-xew3x33d          |
| unSubnetId    | 否    | String           | 私有子网的ID, 字符串格式,如subnet-a234d3x4          |
| instanceIds | 否    | Array(String) | 设备ID列表。           |
| alias       | 否    | String        | 设备别名，模糊查询。        |


## 响应

### 响应示例
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "totalNum": 14,
        "deviceList": [
            {
                "instanceId": "cpm-hdak5rif",
                "zoneId": 1000800001,
                "vpcId": 1025,
                "subnetId": 1,
				"unVpcId": "vpc-k7j1t2q1",
                "unSubnetId": "subnet-lmh5tcwi"
                "lanIp": "10.6.100.48",
                "alias": "name1",
                "idcId": 2555,
                "rckName": "M201-F15",
                "posCode": "22",
                "switchName": "M201-F14-02/M201-F15-01",
                "deliverTime": "2017-04-14 18:09:26",
                "deadline": "2017-05-14 18:09:26"
            },
            {
                "instanceId": "cpm-arjcc2n9",
                "zoneId": 1000800001,
                "vpcId": 1104,
                "subnetId": 1022,
				"unVpcId": "vpc-k7j1t2q1",
                "unSubnetId": "subnet-lmh5tcwi"
                "lanIp": "10.30.0.16",
                "alias": "name2",
                "idcId": 2555,
                "rckName": "M202-H12",
                "posCode": "16",
                "switchName": "M202-H11-01/M202-H12-01",
                "deliverTime": "2017-04-13 21:41:40",
                "deadline": "2017-05-13 21:41:40"
            }
        ]
    }
}
```

### 响应参数
响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括服务器等信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 包含返回的设备总数和设备信息。具体结构描述如data结构所示。          |

data结构

| 参数名称       | 类型            | 描述                                    |
| ---------- | ------------- | ------------------------------------- |
| totalNum   | Int           | 设备总数。                                 |
| deviceList | Array(Object) | 对象数组。数组元素为设备信息，具体结构描述如deviceList结构所示。 |

deviceList结构

| 参数名称        | 类型     | 描述      |
| ----------- | ------ | ------- |
| instanceId  | String | 设备ID。 |
| zoneId      | Int    | 可用区ID。  |
| vpcId       | Int    | 私有网络ID。 |
| subnetId    | Int    | 私有子网ID。 |
| unVpcId       | String    | 私有网络ID, 字符串唯一ID |
| unSubnetId    | String    | 私有子网ID, 字符串唯一ID |
| lanIp       | String | 业务IP。   |
| alias       | String | 设备别名。   |
| idcId       | Int    | 所在机房ID。   
| rckName     | String | 机架名称。   |
| posCode     | String | 机位。     |
| switchName  | String | 交换机名称。  |
| deliverTime | String | 设备交付时间。 |
| deadline    | String | 过期时间。   |


## 错误码

| 错误码  | 英文提示                  | 错误描述    |
| ---- | --------------------- | ------- |
| 9001 | InternalError.DbError | 操作数据库错误 |


## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDevicePosition
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Region=bj
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
	&offset=1
	&limit=30
	&unVpcId=vpc-xew3x33d
    &instanceIds.0=cpm-34xw423x
    &instanceIds.1=cpm-34xw234y
	&alias=实例名
	
```

### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "totalNum": 14,
        "deviceList": [
            {
                "instanceId": "cpm-hdak5rif",
                "zoneId": 1000800001,
                "vpcId": 1025,
                "subnetId": 1,
				"unVpcId": "vpc-8e0ypm3z",
        		"unSubnetId" : "subnet-34xt45as",
                "lanIp": "10.6.100.48",
                "alias": "name1",
                "idcId": 2555,
                "rckName": "M201-F15",
                "posCode": "22",
                "switchName": "M201-F14-02/M201-F15-01",
                "deliverTime": "2017-04-14 18:09:26",
                "deadline": "2017-05-14 18:09:26"
            },
            {
                "instanceId": "cpm-arjcc2n9",
                "zoneId": 1000800001,
                "vpcId": 1104,
                "subnetId": 1022,
				"unVpcId": "vpc-8e0ypm3z",
        		"unSubnetId" : "subnet-34xt45as",
                "lanIp": "10.30.0.16",
                "alias": "name2",
                "idcId": 2555,
                "rckName": "M202-H12",
                "posCode": "16",
                "switchName": "M202-H11-01/M202-H12-01",
                "deliverTime": "2017-04-13 21:41:40",
                "deadline": "2017-05-13 21:41:40"
            }
        ]
    }
}
```