## 功能描述

DescribeDeviceOperationLog接口用来获取设备的操作日志。

接口访问域名：bm.api.qcloud.com

## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDeviceOperationLog
	&<公共请求参数>
	&Region=bj
	&instanceId=<设备ID>
	&startTime=<起始日期>
	&endTime=<结束日期>
	&offset=<起始位置>
	&limit=<待返回的数据个数>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为DescribeDeviceOperationLog。

| 参数名称       | 必选   | 类型     | 描述                         |
| ---------- | ---- | ------ | -------------------------- |
| instanceId | 是    | String | 设备ID。                   |
| startTime  | 否    | 年与日型   | 起始日期，默认为7天前，例如：2014-08-02。 |
| endTime    | 否    | 年与日型   | 结束日期，默认为当天，例如：2014-08-09。  |
| offset     | 否    | Int    | 起始位置。                      |
| limit      | 否    | Int    | 待返回的数据个数。                  |

## 响应

### 响应示例

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "logs": [
            {
                "id": "6958",
                "instanceId": "cpm-d1pryrrb",
                "taskId": "10033",
                "appId": "0",
                "taskName": "bindEip",
                "taskCName": "绑定EIP",
                "startTime": "2016-10-11 19:54:37",
                "endTime": "2016-10-11 19:54:37",
                "status": "1",
                "opUin": "1307774067",
                "memo": "绑定EIP"
            },
            {
                "id": "6957",
                "instanceId": "cpm-d1pryrrb",
                "taskId": "10031",
                "appId": "0",
                "taskName": "unbindEip",
                "taskCName": "解绑EIP",
                "startTime": "2016-10-11 19:53:10",
                "endTime": "2016-10-11 19:53:10",
                "status": "1",
                "opUin": "1307774067",
                "memo": "解绑EIP"
            }
        ],
        "totalCount": 2
    }
}
```

### 响应参数

响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括log等信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 返回的logs实例信息。具体结构描述如data结构所示。             |

data结构

| 参数名称       | 类型            | 描述                         |
| ---------- | ------------- | -------------------------- |
| logs       | Array(Object) | 返回的log实例数组，具体数据结构如log结构所示。 |
| totalCount | Int           | 返回的log实例数组总数。              |


log结构

| 参数名称       | 类型     | 描述                           |
| ---------- | ------ | ---------------------------- |
| id         | Int    | log id。                      |
| instanceId | String | 设备ID。                     |
| taskId     | String | 任务ID。                        |
| appId      | Int    | 用户appId。                     |
| taskName   | String | 操作任务名称。                      |
| startTime  | 年与日型   | 起始日期，例如：2014-08-02。          |
| endTime    | 年与日型   | 结束日期，例如：2014-08-09。          |
| status     | Int    | 状态，0: 正在执行中；1：任务成功； 2: 任务失败。 |
| opUin      | String | 操作者uin。                      |
| memo       | String | 备注。                          |


## 错误码
| 错误码   | 英文提示                  | 错误描述    |
| ----- | --------------------- | ------- |
| 9001  | InternalError.DbError | 操作数据库错误 |
| 10001 | InvalidParameter      | 参数错误    |

## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDeviceOperationLog
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Region=bj
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
	&instanceId=cpm-d1pryrrb
	&startTime=2016-08-02
	&endTime=2016-10-12
	&offset=0&limit=10
```
### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "logs": [
            {
                "id": "6958",
                "instanceId": "cpm-d1pryrrb",
                "taskId": "10033",
                "appId": "0",
                "taskName": "bindEip",
                "taskCName": "绑定EIP",
                "startTime": "2016-10-11 19:54:37",
                "endTime": "2016-10-11 19:54:37",
                "status": "1",
                "opUin": "1307774067",
                "memo": "绑定EIP"
            },
            {
                "id": "6957",
                "instanceId": "cpm-d1pryrrb",
                "taskId": "10031",
                "appId": "0",
                "taskName": "unbindEip",
                "taskCName": "解绑EIP",
                "startTime": "2016-10-11 19:53:10",
                "endTime": "2016-10-11 19:53:10",
                "status": "1",
                "opUin": "1307774067",
                "memo": "解绑EIP"
            }
        ],
        "totalCount": 2
    }
}
```

