## 功能描述

DescribeDeviceHardwareInfo接口用来查询设备的硬件配置信息，如CPU型号，内存大小，磁盘大小和个数。

接口访问域名：bm.api.qcloud.com


## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=DescribeDeviceHardwareInfo
	&<公共请求参数>	
	&instanceIds.0=<设备ID1>
	&instanceIds.1=<设备ID2>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为DescribeDevicePosition。

| 参数名称        | 必选   | 类型            | 描述                |
| instanceIds | 是    | Array(String) | 设备ID列表。           |


## 响应

### 响应示例
```
{
  "code": 0,
  "message": "",
  "codeDesc": "Success",
  "data": [
    {
      "instanceId": "cpm-1nk36wcj",
      "deviceClass": "Y0-BS05",
      "cpuId": 1,
      "mem": 64,
      "haveRaidCard": 0,
      "diskTypeId1": 5,
      "diskNum1": 10,
      "cpuDesc": "E5-2620v3 (6核)  * 2",
      "memDesc": "64G",
      "diskDesc": "10*HDD-SATA-4T",
      "nicDesc": "10G*2",
      "raidDesc": "不支持",
      "goodsDetail": {
        "pid": 10947,
        "bm_elastic_Y0-BS05": 1,
        "bm_elastic_SATA_4T_7200RTM": 10,
        "bm_elastic_MEM_32G": 2,
        "deviceClass": "Y0-BS05"
      }
    },
    {
      "instanceId": "cpm-cjm505sb",
      "deviceClass": "TS60",
      "cpuDesc": "E5-2620v3(6核)*2",
      "memDesc": "64GB",
      "diskDesc": "12*2T(SATA) +1*80G(SSD)",
      "nicDesc": "10G * 2",
      "raidDesc": "不支持",
      "goodsDetail": {
        "pid": "10842",
        "deviceClass": "TS60"
      }
    }
  ]
}
```

### 响应参数
响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括服务器等信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 包含返回的设备总数和设备信息。具体结构描述如data结构所示。          |

data结构

| 参数名称       | 类型            | 描述                                    |
| ---------- | ------------- | ------------------------------------- |
| instanceId   | String           | 设备实例ID。                       |
| deviceClass | String | 腾讯内部设备类型。 |
| cpuId | Int | 自定义机型，cpu型号ID。 |
| mem | Int | 自定义机型，内存大小, 单位G |
| haveRaidCard | Int | 是否有RAID卡，0:没有RAID卡； 1:有RAID卡 |
| diskTypeId1 | Int | 自定义机型，第一种规格磁盘ID |
| diskNum1 | Int | 自定义机型，第一种规格磁盘个数 |
| diskTypeId2 | Int | 自定义机型，第二种规格磁盘ID |
| diskNum2 | Int | 自定义机型，第二种规格磁盘个数 |
| cpuDesc | String | cpu型号描述 |
| memDesc | String | 内存描述 |
| diskDesc | String | 磁盘描述 |
| nicDesc | String | 网卡描述 |
| raidDesc | String | 是否支持raid的描述 |
|goodsDetail| Array | 计费相关的ID，可以不用关注|


## 错误码

| 错误码  | 英文提示                  | 错误描述    |
| ---- | --------------------- | ------- |
| 9001 | InternalError.DbError | 操作数据库错误 |


## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
Action=DescribeDeviceHardwareInfo
&Nonce=1187296601&Region=bj
&Timestamp=1508763150
&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
&instanceIds.0=cpm-cjm505sb
&instanceIds.1=cpm-1nk36wcj
&Signature=XynD%2FHNX7Aj42SiMU18L7gIOVZQ%3D
	
```

### 输出

```
{
  "code": 0,
  "message": "",
  "codeDesc": "Success",
  "data": [
    {
      "instanceId": "cpm-1nk36wcj",
      "deviceClass": "Y0-BS05",
      "cpuId": 1,
      "mem": 64,
      "haveRaidCard": 0,
      "diskTypeId1": 5,
      "diskNum1": 10,
      "cpuDesc": "E5-2620v3 (6核)  * 2",
      "memDesc": "64G",
      "diskDesc": "10*HDD-SATA-4T",
      "nicDesc": "10G*2",
      "raidDesc": "不支持",
      "goodsDetail": {
        "pid": 10947,
        "bm_elastic_Y0-BS05": 1,
        "bm_elastic_SATA_4T_7200RTM": 10,
        "bm_elastic_MEM_32G": 2,
        "deviceClass": "Y0-BS05"
      }
    },
    {
      "instanceId": "cpm-cjm505sb",
      "deviceClass": "TS60",
      "cpuDesc": "E5-2620v3(6核)*2",
      "memDesc": "64GB",
      "diskDesc": "12*2T(SATA) +1*80G(SSD)",
      "nicDesc": "10G * 2",
      "raidDesc": "不支持",
      "goodsDetail": {
        "pid": "10842",
        "deviceClass": "TS60"
      }
    }
  ]
}
```