## 功能描述

ReloadDeviceOs接口用来重装服务器的操作系统。

接口访问域名：bm.api.cloud.tencent.com

## 请求

### 请求示例

```
https://bm.api.cloud.tencent.com/v2/index.php?
	Action=ReloadDeviceOs
	&<公共请求参数>
	&instanceId=<设备ID>
	&passwd=<密码>
	&osTypeId=<操作系统类型ID>
	&raidId=<RAID类型ID>
	&agentIds.0=<安装agent服务1>
	&agentIds.1=<安装agent服务2>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为ReloadDeviceOs。

操作系统和raid类型可以不填，若不填将用机器当前的操作系统和raid类型。
磁盘分区也可以不填，默认会按照上次分区方式机型分区。
agentIds为空，表示不安装监控和安全agent。


| 参数名称               | 必选   | 类型         | 描述                                       |
| ------------------ | ---- | ---------- | ---------------------------------------- |
| instanceId         | 是    | String     | 设备ID。 通过接口[查询服务器(DescribeDeviceList)](/doc/api/456/6728)获取设备信息。 |
| passwd             | 是    | String     | 密码。 密码需要8-16个字符，至少包含英文、数字和符号!@#$%&^*()中的2种。 |
| osTypeId           | 否    | Int        | 操作系统类型ID。通过接口[查询操作系统列表(DescribeOs)](/doc/api/456/6727)获取操作系统信息。 |
| raidId             | 否    | Int        | RAID类型ID。通过接口[查询机型RAID方式以及系统盘大小(DescribeDeviceClassPartition)](/document/product/386/7370)获取RAID信息。 |
| agentIds           | 否    | Array(Int) | 指示安装哪些agent服务。2：监控agent<br/>；3：安全agent。<br/> |
| sysRootSpace       | 否    | Int        | 系统盘根分区大小，默认是10G。系统盘的大小参考接口 [查询机型RAID方式以及系统盘大小(DescribeDeviceClassPartition)](/document/product/386/7370) 。 |
| sysSwaporuefiSpace | 否    | Int        | 系统盘swap分区或/boot/efi分区的大小。  若是uefi启动的机器，分区为/boot/efi ,且此值是默认是2G。 普通机器为swap分区，可以不指定此分区。 机型是否是uefi启动，参考接口 [查询设备型号(DescribeDeviceClass)](/doc/api/456/6636) |
| sysDataSpace       | 否    | Int        | /data分区的大小。如果系统盘还有剩余大小，会分配给/data分区。(特殊情况：如果剩余空间不足10G,并且没有指定/data分区，则剩余空间会分配给Root分区。) |
| isZoning           | 否    | Int        | 是否格式化数据盘。0: 不格式化；1：格式化（默认值）。             |
| unVpcId              | 否    | String        | 是否重装到新的vpc。如果改变vpc子网，则要求与unSubnetId同时传参，否则可不填。 通过接口[查询私有网络列表(DescribeBmVpcEx)](/doc/api/456/6646)获取私有网络信息, 取unVpcId字段，如vpc-8e0ypm3z|
| unSubnetId           | 否    | String        | 是否重装到新的子网。如果改变vpc子网，则要求与sunVpcId同时传参，否则可不填。 通过接口[查询子网列表(DescribeBmSubnetEx)](/doc/api/456/6648)获取私有子网信息, 取unSubnetId字段，如subnet-34xt45as |
| lanIp              | 否    | String     | 重装时指定的IP地址。                              |
| hyperThreading     | 否    | Int        | 指定是否开启超线程。 0：关闭超线程；1：开启超线程（默认值）。         |


## 响应

### 响应示例

```
{
  "code": 0,
  "message": "OK",
  "data": {
       “taskId”: 101
   }
}
```

### 响应参数

响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括异步操作的ID等信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功，其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 返回异步操作的ID信息，具体结构描述如data结构所示。             |

data结构

| 参数名称   | 类型   | 描述                        |
| ------ | ---- | ------------------------- |
| taskId | Int  | 以taskId为key，对应的值为异步操作的ID。 |

## 错误码
| 错误码   | 英文提示                                    | 错误描述           |
| ----- | --------------------------------------- | -------------- |
| 9001  | InternalError.DbError                   | 操作数据库错误        |
| 9005  | InternalError.RbmqError                 | 操作系统队列错误       |
| 10001 | InvalidParameter                        | 参数错误           |
| 12002 | OperationDenied.IncorrectInstanceStatus | 设备不能被重装        |
| 12003 | OperationDenied.RaidNotSupport          | 设备不支持指定的RAID类型 |


## 实际案例

### 输入

```
https://bm.api.cloud.tencent.com/v2/index.php?
	Action=ReloadDeviceOs
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Region=bj
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
	&instanceId=cpm-34xs43xs
	&passwd=34x@#23A
	&osTypeId=2
	&raidId=4
	&agentIds.0=2
	&agentIds.1=3
```
### 输出

```
{
  "code": 0,
  "message": "OK",
  "data": {
       “taskId”: 101
   }
}
```
