## 功能描述
本接口（CreateBmSubnet）用于创建黑石私有网络子网。

接口访问域名: bmvpc.api.qcloud.com

1) 创建子网前必须创建好 VPC。
2) 子网创建成功后，子网网段不能修改。子网网段必须在VPC网段内，可以和VPC网段相同（VPC有且只有一个子网时），建议子网网段在VPC网段内，预留网段给其他子网使用。
3) 你可以创建的最小网段子网掩码为28（有16个IP地址），最大网段子网掩码为16（65,536个IP地址）。
3) 同一个VPC内，多个子网的网段不能重叠。
4) 子网创建后会自动关联到默认路由表。
5）子网绑定的VLANID，默认为5。虚拟机子网VLANID取值范围2000-2999。

 

## 请求

### 请求示例

```
GET https://bmvpc.api.qcloud.com/v2/index.php?
  &Action=CreateBmSubnet
  &<公共请求参数>
  &unVpcId=<VPC实例ID>
  &subnetSet.0.subnetName=<子网名称>
  &subnetSet.0.cidrBlock=<子网CIDR段>
  &vlanId=<VLAN的ID>

```

### 请求参数
 以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/229/6976" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为CreateBmSubnet。

| 参数名称 | 描述 | 类型 | 必选 |
|---------|---------|---------|---------|
| unVpcId | 系统分配的私有网络ID，例如：vpc-kd7d06of。可通过DescribeBmVpcEx接口查询。 | String | 是 |
| subnetSet.n | 子网信息数组，创建VPC时可以同时创建子网，可选项。 | Array | 是 |
| subnetSet.n.subnetName | 子网名称，可任意命名，但不得超过60个字符。 | String | 是 |
| subnetSet.n.cidrBlock | 子网网段，子网网段必须在VPC网段内，相同VPC内子网网段不能重叠。 | String | 是 |
| subnetSet.n.distributedFlag | 是否开启子网分布式网关，默认传1，传0为关闭子网分布式网关。关闭分布式网关子网用于虚拟化子网，此子网中只能有一台物理机，同时此物理机及其上子机只能在此子网中。 | Int | 否 |
| subnetSet.n.dhcpEnable | 是否开启dhcp relay ，关闭为0，开启为1。默认为0。 | Int | 否 |
| subnetSet.n.dhcpServerIp | DHCP SERVER 的IP地址数组。IP地址为相同VPC的子网内分配的IP。 | Array | 否 |
| subnetSet.n.ipReserve | 预留的IP个数。从该子网的最大可分配IP倒序分配N个IP 用于DHCP 动态分配使用的地址段。 | Int | 否 |
| vlanId | 子网绑定的vlanId，默认为5。虚拟机子网VLANID取值范围2000-2999。 | Int | 否 |

 

## 响应

### 响应示例

```

{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "subnetSet": [
        {
            "subnetId": <子网ID>,
            "unSubnetId": <子网唯一ID>,
            "subnetName": <子网名称>,
            "cidrBlock": <子网网段>,
            "zoneId": <子网所在Zone的ID>
        }
    ]
}

```
### 响应参数

| 参数名称 | 描述 | 类型 |
|---------|---------|---------|
| code | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href="/document/product/386/6725" title="公共错误码">公共错误码</a>。| Int |
| message | 模块错误信息描述，与接口相关。| String |
| subnetSet.n | 子网信息，同时添加了子网时才会返回。| Array |
| subnetSet.n.subnetId | 系统分配的子网ID，示例:subnetId_GZ_23。| String |
| subnetSet.n.unSubnetId | 系统分配的子网统一ID，由子网ID升级而来，为了兼容这两种ID系统都支持，示例:subnet-5gu2jxf4。| String |
| subnetSet.n.subnetName | 子网名称。| String |
| subnetSet.n.cidrBlock | 子网网段，示例:192.168.0.0/25。| String |
| subnetSet.n.zoneId | 子网所在可用区ID,示例:1000800001。| String |
| subnetSet.n.distributedFlag | 子网分布式开关参数，1为开启，0为关闭。| Int |
| subnetSet.n.dhcpEnable | 是否开启dhcp relay ，关闭为0，开启为1。默认为0。| Int |
| subnetSet.n.dhcpServerIp | DHCP SERVER 的IP地址数组。IP地址为相同VPC的子网内分配的IP。| Array |
| subnetSet.n.ipReserve | 预留的IP个数。从该子网的最大可分配IP倒序分配N个IP 用于DHCP 动态分配使用的地址段。| Int |

## 错误码
 
| 错误代码 |英文提示| 描述 |
|--------|---------|---------|
| -3047  | InvalidBmVpc.NotFound | 无效的VPC,VPC资源不存在，请再次核实您输入的资源信息是否正确。 |
| -3001  | InvalidInputParams | 输入参数不符合指定格式，例如名字只支持最多60个字符。 |
| -3046  | BmVpc.SubnetCidr.Conflict | 子网网段与VPC内其他子网网段冲突。。 |
| -3240  | BmVpc.VlanId.Conflict | 子网VLANID重复。 |
| -3058  | BmVpc.SubnetLimitExceeded | 指定区域子网资源申请数量上限。 |
| -3055  | BmVpc.InvalidSubnetCidr | 子网CIDR不合法或者不在VPC网段内。 |
| -3246  | BmVpc.InvalidDhcpServer | DHCP SERVER IP地址不合法或者IP地址个数超过限制。 |
| -3247  | BmVpc.DhcpReserveIpLimit | 没有足够的IP地址可分配用于DHCP动态使用。 |

## 实际案例

### 输入
```

GET https://bmvpc.api.qcloud.com/v2/index.php?Action=CreateBmSubnet
    &SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
    &Nonce=6791
    &Timestamp=1507777243
    &Region=bj
    &Signature=RLfmJ0mnkm2Fla4zbTGABkRA%2Ft4%3D
    &unVpcId=vpc-kd7d06of
    &subnetSet.0.subnetName=tttt
    &subnetSet.0.cidrBlock=10.0.200.0/24
    &vlanId=2000
```

### 输出
```

{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "subnetSet": [
        {
            "subnetId": "gz_subnet_8949",
            "unSubnetId": "subnet-gvt14y8u",
            "subnetName": "tttt",
            "cidrBlock": "10.10.30.0/24",
            "zoneId": 1000800001
        }
    ]
}

```

