## 功能描述 
 
本接口（DescribeBmSubnetEx）用于查询黑石子网列表。

接口访问域名: bmvpc.api.qcloud.com

## 请求

### 请求示例

```
GET https://bmvpc.api.qcloud.com/v2/index.php?
  &Action=DescribeBmSubnetEx
  &<公共请求参数>
  &unVpcId=<VPC实例ID>&unSubnetId=<子网ID>

```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/229/6976" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为DescribeBmSubnetEx。

| 参数名称 | 描述 | 类型 | 必选 |
|---------|---------|---------|---------|
| unVpcId | 子网所属的私有网络ID值，例如：vpc-kd7d06of，可通过<a href="https://cloud.tencent.com/document/api/386/6646" title="DescribeBmVpcEx">DescribeBmVpcEx</a>接口查询。 | String | 否 |
| unSubnetId | 系统分配的子网ID，例如：subnet-3lzrkspo,可通过DescribeBmSubnetEx接口查询。| String | 否 |
| subnetName | 子网名称，支持模糊查询。 | String | 否 |
| zoneIds | 可用区ID，详见<a href="https://cloud.tencent.com/document/api/386/6633">VPC可用区说明</a>。 | Array | 否 |
| offset | 初始行的偏移量，默认为0。 | Int | 否 |
| limit | 每页行数，默认为20。 | Int | 否 |
| orderField | 按某个字段排序，目前仅支持createTime,subnetName排序，默认按createTime排序。 | String | 否 |
| orderDirection | 升序（asc）还是降序（desc），默认：asc。 | String | 否 |
| vlanId | 子网的vlanid。 | Int | 否 |

## 响应

### 响应示例

```

{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "totalCount": 1,
    "data": [
        {
            "vpcId":<私有网络ID>,
            "unVpcId":<私有网络唯一ID>,
            "vpcName":<私有网络名称>,
            "vpcCidrBlock":<私有网络网段>,
            "subnetId": <子网ID>,
            "unSubnetId": <子网唯一ID>,
            "subnetName": <子网名称>,
            "cidrBlock": <子网网段>,
            "zoneId": <子网所在Zone的ID>,
            "cpmNum": <子网中物理机个数>,
            "vlanId": <子网的VLANID>,
            "dhcpEnable": <是否开启DHCP>,
            "dhcpServerIp": [ <DHCP服务器IP> ],
            "ipReserve": <预留的IP个数>,
            "availableIpNum": <可用IP的个数>,
            "totalIpNum": <总共的IP个数>,
            "subnetCreateTime": <子网创建时间>,
			"distributedFlag":<是否开启子网分布式网关>
        }
    ]
}

```
### 响应参数

| 参数名称 | 描述| 类型 |
|---------|---------|---------|
| code| 错误码，0: 成功，其他值: 失败。 | Int |
| message | 错误信息。 | String |
| totalCount | 子网总数量。 | Int |
| data | 返回的数组。 | Array |
| data.n.vpcId | 系统分配的vpcId，例如：10001。| Int |
| data.n.unVpcId | 系统分配的新vpcID，由子网ID升级而来，推荐使用新vpcId，示例:vpc-5gu2jxf4。| String |
| data.n.subnetId | 系统分配的子网ID，示例:23。| Int |
| data.n.unSubnetId | 系统分配的新子网ID，由子网ID升级而来，推荐使用新子网ID，示例:subnet-5gu2jxf4。| String |
| data.n.subnetName | 子网名称。| String |
| data.n.cidrBlock | 子网网段，示例:192.168.0.0/25。| String |
| data.n.zoneId | 子网所在可用区ID,示例:200001。| String |
| data.n.vlanId | 子网的vlanid。| Int |
| data.n.dhcpEnable | 是否开启dhcp relay ，关闭为0，开启为1。默认为0。| Int |
| data.n.dhcpServerIp | DHCP SERVER 的IP地址数组。IP地址为相同VPC的子网内分配的IP。| Array |
| data.n.ipReserve | 预留的IP个数。从该子网的最大可分配IP倒序分配N个IP 用于DHCP 动态分配使用的地址段。| Int |
| data.n.distributedFlag | 是否开启分布式网关 ，关闭为0，开启为1。| Int |

## 错误码
 
| 错误代码 |英文提示| 描述 |
|--------|---------|---------|
| -3047 | InvalidBmVpc.NotFound | 无效的VPC。VPC资源不存在，请再次核实您输入的资源信息是否正确，可通过<a href="https://cloud.tencent.com/document/api/386/6646" title="DescribeBmVpcEx">DescribeBmVpcEx</a>接口查询VPC。 |
| -3030 | InvalidBmSubnet.NotFound | 无效的子网。子网资源不存在，请再次核实您输入的资源信息是否正确，可通过<a href="https://cloud.tencent.com/document/api/386/6648" title="DescribeBmSubnetEx">DescribeBmSubnetEx</a>接口查询子网。 |

## 实际案例

### 输入

```

GET https://bmvpc.api.qcloud.com/v2/index.php?Action=DescribeBmSubnetEx
    &SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
    &Nonce=6791
    &Timestamp=1507777243
    &Region=bj
    &Signature=RLfmJ0mnkm2Fla4zbTGABkRA%2Ft4%3D
    &unVpcId=vpc-34cxlz7z
    &unSubnetId=subnet-jv24ivq0
```

### 输出
```

{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "totalCount": 1,
    "data": [
        {
            "vpcId": 4097,
            "unVpcId": "vpc-34cxlz7z",
            "vpcName": "test",
            "vpcCidrBlock": "10.10.0.0/16",
            "subnetId": 8946,
            "unSubnetId": "subnet-jv24ivq0",
            "subnetName": "vm",
            "cidrBlock": "10.10.0.0/24",
            "zoneId": 1000800001,
            "cpmNum": 7,
            "vlanId": 5,
            "dhcpEnable": 0,
			"distributedFlag":1,
            "dhcpServerIp": [],
            "ipReserve": 0,
            "availableIpNum": 246,
            "totalIpNum": 253,
            "subnetCreateTime": "2017-05-03 19:48:59"
        }
    ]
}

```