## 功能描述
DescribeBmVpcEx 用于查询黑石私有网络列表。

接口请求域名：bmvpc.api.qcloud.com。

本接口不传参数时，返回默认排序下的前20条VPC信息。


## 请求

### 请求示例
```
GET https://bmvpc.api.qcloud.com/v2/index.php?Action=DescribeBmVpcEx
    &<公共请求参数>
    &unVpcId=<VPC网络唯一ID>
    &vpcName=<私有网络名称>
    &offset=<初始行的偏移量>
    &limit=<每页行数>
    &orderField=<排序字段>
    &orderDirection=<升降序>
    &zoneIds=<可用区数组>
    &vpcStatus=<VPC当前状态>
```
### 请求参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/372/4153" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为DescribeBmVpcEx。

| 参数名称 | 描述 | 类型 | 必选  |
|---------|---------|---------|---------|
| unVpcId | 系统分配的私有网络ID，支持传入DescribeBmVpcEx接口查询列表返回的unVpcId字段的值。 | String | 否 |
| vpcName | 私有网络名称，支持模糊搜索。 | String | 否 |
| offset | 初始行的偏移量，默认为0。 | Int | 否 |
| limit | 每页行数，默认为20。 | Int | 否 |
| orderField | 按某个字段排序，目前仅支持createTime,vpcName排序，默认按createTime排序。 | String | 否 |
| orderDirection | 升序（asc）还是降序（desc），默认：asc。 | String | 否 |
| zoneIds | 可用区数组，按可用区搜索，详细信息请查看<a href="https://cloud.tencent.com/document/api/386/6634" title="DescribeRegions">DescribeRegions</a>接口。例如：1000800001 | Array | 否 |
| vpcStatus | VPC当前状态，0表示运行中、 1表示创建失败、2表示创建中、3表示删除中。 | Int | 否 |


## 响应

### 响应示例
```
{
    "code": 0,
    "message": "",
        "totalCount":10,
        "data":[
        {
            "vpcId":<私有网络ID>,
            "unVpcId":<私有网络唯一ID>,
            "vpcName":<私有网络名称>,
            "cidrBlock":<私有网络网段>,
            "subnetNum":<私有网络子网个数>,
            "zoneId":<私有网络所在Zone的ID>,
            "productionStatus":<私有网络状态>,
            "createTime":<私有网络创建时间>
        }
   ]
}
```
### 响应参数

| 参数名称 | 描述 |  类型 |
|---------|---------|---------|
| code | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href="https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81" title="公共错误码">公共错误码</a>。| Int |
| message | 模块错误信息描述，与接口相关。| String |
| totalCount | 开发商VPC总数。| Int |
| data.n | VPC信息组。| Array |
| data.n.vpcId | 系统分配的vpcId，例如：10001| Int |
| data.n.unVpcId | 系统分配的VPC唯一ID，例如：vpc-8e0ypm3z| String |
| data.n.vpcName | 私有网络名称。| String |
| data.n.cidrBlock | 私有网络网段，例如：192.168.0.1/24。| String |
| data.n.subnetNum | VPC下子网个数。| Int |
| data.n.productionStatus | VPC当前状态。| Int |
| data.n.zoneId | VPC所属可用区。| Int |
| data.n.createTime | VPC创建时间。| String |

## 错误码

| 错误代码 |英文提示| 描述 |
|--------|---------|---------|
| -3047  | InvalidBmVpc.NotFound | 无效的VPC,VPC资源不存在，请再次核实您输入的资源信息是否正确。 |


## 实际案例
### 输入
```
GET https://bmvpc.api.qcloud.com/v2/index.php?
    Action=DescribeBmVpcEx
    &SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
    &Nonce=6791
    &Timestamp=1507777243
    &Region=bj
    &Signature=RLfmJ0mnkm2Fla4zbTGABkRA%2Ft4%3D
    &unVpcId=vpc-2ari9m7h
    &offset=0
    &limit=1
    &orderDirection=desc
```

### 输出
```

{
    "code": 0,
    "message": "",
        "totalCount":10,
        "data":[
        {
            "vpcId":10001,
            "unVpcId":"vpc-8e0ypm3z",
            "vpcName":"alblack.bbb",
            "cidrBlock":"10.0.0.0/24",
            "subnetNum":0,
            "zoneId":0,
            "productionStatus":0,
            "createTime":"2015-08-24 15:05:16"
        }
   ]
}
```
