## 功能描述

GetUserCmdTaskList接口用来获取脚本执行任务列表。

接口访问域名：bm.api.qcloud.com

## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=GetUserCmdTaskList
	&<公共请求参数>
	&offset=<偏移量>
	&limit=<查询返回任务的数量>
	&orderBy=<排序字段>
	&orderType=<排序方式>
```

### 请求参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为GetUserCmdTaskList。

| 参数名称              | 必选   | 类型            | 描述                                       |
| ----------------- | ---- | ------------- | ---------------------------------------- |
| offset            | 否    | Int           | 偏移量，默认为0。                        |
| limit             | 否    | Int           | 查询返回任务的数量，默认为20。                        |
| orderBy           | 否    | String        | 排序字段，支持： runBeginTime，runEndTime，status。                                 |
| orderType          | 否    | Int           | 排序方式，1倒序，0顺序，默认倒序。                                 |


## 响应

### 响应示例
```
{
  "code": 0,
  "message": "",
  "data": {
    "list": [
      {
        "taskId": "cmdtask-2yzwn8kr",
        "status": 0,
        "cmdAlias": "php_while_true",
        "cmdId": "cmd-o9o03bk8",
        "instanceCount": "1",
        "successCount": "0",
        "failureCount": "1",
        "runBeginTime": "2017-10-19 18:04:02",
        "runEndTime": "2017-10-19 18:08:09"
      },
      {
        "taskId": "cmdtask-7e3tarqd",
        "status": 0,
        "cmdAlias": "php_while_true",
        "cmdId": "cmd-o9o03bk8",
        "instanceCount": "1",
        "successCount": "0",
        "failureCount": "1",
        "runBeginTime": "2017-10-19 17:55:16",
        "runEndTime": "2017-10-19 17:59:23"
      }
    ],
    "totalNum": 16
  }
}
```

### 响应参数
响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括任务等信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 任务列表，具体结构描述如data结构所示。                    |


data结构

| 参数名称       | 类型            | 描述                                    |
| ---------- | ------------- | ------------------------------------- |
| totalNum   | Int           | 任务总数                                  |
| list | Array(Object) | 对象数组。数组元素为任务信息，具体结构描述如list结构所示。 |

list结构

| 参数名称          | 类型     | 描述                                       |
| ------------- | ------ | ---------------------------------------- |
| taskId        | String | 任务ID。                                  |
| status        | Int    | 任务状态。-1：进行中。0：结束。        |
| runBeginTime  | 日期时间 | 任务开始时间。                                  |
| runEndTime    | 日期时间 | 任务结束时间。                     |
| cmdAlias  | String  | 脚本名称。                |
| cmdId    | String  | 脚本ID。 |
| instanceCount       | Int | 运行脚本设备的数量。                                    |
| successCount         | Int | 运行脚本成功的设备数量。                                    |
| failureCount         | Int | 运行脚本失败的设备数量。                                    |

## 错误码

| 错误码   | 英文提示                  | 错误描述    |
| ----- | --------------------- | ------- |
| 9001  | InternalError.DbError | 操作数据库错误 |
| 10001 | InvalidParameter      | 参数错误    |
| 18021 | OrderByInvalid        | 无效的order by类型 |
| 18022 | OrderTypeInvalid      | 无效的order type类型 |


## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
	Action=GetUserCmdTaskList
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Region=bj
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
```

### 输出

```
{
  "code": 0,
  "message": "",
  "data": {
    "list": [
      {
        "taskId": "cmdtask-2yzwn8kr",
        "status": 0,
        "cmdAlias": "php_while_true",
        "cmdId": "cmd-o9o03bk8",
        "instanceCount": "1",
        "successCount": "0",
        "failureCount": "1",
        "runBeginTime": "2017-10-19 18:04:02",
        "runEndTime": "2017-10-19 18:08:09"
      },
      {
        "taskId": "cmdtask-7e3tarqd",
        "status": 0,
        "cmdAlias": "php_while_true",
        "cmdId": "cmd-o9o03bk8",
        "instanceCount": "1",
        "successCount": "0",
        "failureCount": "1",
        "runBeginTime": "2017-10-19 17:55:16",
        "runEndTime": "2017-10-19 17:59:23"
      }
    ],
    "totalNum": 16
  }
}
```