## 功能描述

GetUserCmdTaskDetailList接口用来获取脚本执行任务的详细结果列表。

接口访问域名：bm.api.qcloud.com

## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=GetUserCmdTaskDetailList
	&<公共请求参数>
	&taskId=<任务ID>
	&offset=<偏移量>
	&limit=<查询返回任务的数量>
	&orderBy=<排序字段>
	&orderType=<排序方式>
	&searchKey=<设备ID或名称>
```

### 请求参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为GetUserCmdTaskDetailList。

| 参数名称              | 必选   | 类型            | 描述                                       |
| ----------------- | ---- | ------------- | ---------------------------------------- |
| taskId            | 是    | String           | 任务ID。                                |
| offset            | 否    | Int           | 偏移量，默认为0。                        |
| limit             | 否    | Int           | 查询返回任务的数量，默认为20。                        |
| orderBy           | 否    | String        | 排序字段，支持： runBeginTime，runEndTime，status。                                 |
| orderType          | 否    | Int           | 排序方式，1倒序，0顺序，默认倒序。                                 |
| searchKey       | 否    | String        | 模糊匹配设备ID或名称。 |


## 响应

### 响应示例
```
{
  "code": 0,
  "message": "",
  "data": {
    "totalNum": 1,
    "list": [
      {
        "autoId": "437",
        "taskId": "cmdtask-i3a09t1h",
        "runBeginTime": "2017-10-19 18:45:11",
        "runEndTime": "2017-10-19 18:49:21",
        "status": "1",
        "instanceName": "nine-自定义命令",
        "instanceId": "tcpm-busqskcl",
        "vpcName": "test",
        "vpcId": "4097",
        "unVpcId": "vpc-34cxlz7z",
        "vpcCidrBlock": "10.10.0.0/16",
        "subnetName": "subnet-1so5ae8m111111",
        "subnetId": "3",
        "unSubnetId": "subnet-1so5ae8m",
        "subnetCidrBlock": "10.10.1.0/24",
        "lanIp": "10.10.1.6",
        "cmdContent": "IyEvYmluL2Jhc2gKCmVjaG8gImhlbGxvIg==",
        "cmdParam": "",
        "cmdResult": "c2hlbGwgMTAwLjczLjQ2LjIxNiwtMSwwLCdhZ2VudOi/lOWbnumUmeivr+S/oeaBry7nlKjmiLfpqozor4HlpLHotKUhJw==",
        "appId": "251000873",
        "lastShellExit": -1
      }
    ]
  }
}
```

### 响应参数
响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括任务详细信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 任务列表，具体结构描述如data结构所示。                    |


data结构

| 参数名称       | 类型            | 描述                                    |
| ---------- | ------------- | ------------------------------------- |
| totalNum   | Int           | 设备总数                                  |
| list | Array(Object) | 对象数组。数组元素为任务信息，具体结构描述如list结构所示。 |

list结构

| 参数名称          | 类型     | 描述                                       |
| ------------- | ------ | ---------------------------------------- |
| autoId        | String | 自动编号，可忽略。                                  |
| taskId        | String | 任务ID。                                  |
| runBeginTime  | 日期时间 | 任务开始时间。                                  |
| runEndTime    | 日期时间 | 任务结束时间。                     |
| status        | Int    | 任务状态。-1：进行中。0：成功。>0：失败，其值为错误码。其他值无效。        |
| instanceName  | String  | 设备别名。                |
| instanceId    | String  | 设备ID。 |
| vpcName       | String | VPC名称。                                    |
| vpcId         | String | VPC ID。                                    |
| unVpcId       | String | VPC唯一ID。                                  |
| vpcCidrBlock   | String | VPC网段。                                  |
| subnetName    | String | 子网名称。                                  |
| subnetId      | String | 子网ID。                 |
| unSubnetId   | String | 子网唯一ID。                                    |
| subnetCidrBlock | String | 子网网段。                                    |
| lanIp | String | 局域网IP地址。                                    |
| cmdContent | String | 脚本内容，base64编码后的值。                                    |
| cmdParam | String | 脚本参数，base64编码后的值。                                    |
| cmdResult | String | 脚本执行结果，base64编码后的值。 |
| appId  | String | 用户appId。 |
| lastShellExit  | Int | 用户执行脚本结束退出的返回值，没有返回值为-1。 |

## 错误码

| 错误码   | 英文提示                  | 错误描述    |
| ----- | --------------------- | ------- |
| 9001  | InternalError.DbError | 操作数据库错误 |
| 10001 | InvalidParameter      | 参数错误    |
| 18010 | CmdNotExist           | 无效的用户自定义脚本的运行任务ID |
| 18021 | OrderByInvalid        | 无效的order by类型 |
| 18022 | OrderTypeInvalid      | 无效的order type类型 |


## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
	Action=GetUserCmdTaskDetailList
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Region=bj
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
	&taskId=cmdtask-i3a09t1h
```

### 输出

```
{
  "code": 0,
  "message": "",
  "data": {
    "totalNum": 1,
    "list": [
      {
        "autoId": "437",
        "taskId": "cmdtask-i3a09t1h",
        "runBeginTime": "2017-10-19 18:45:11",
        "runEndTime": "2017-10-19 18:49:21",
        "status": "1",
        "instanceName": "nine-自定义命令",
        "instanceId": "tcpm-busqskcl",
        "vpcName": "test",
        "vpcId": "4097",
        "unVpcId": "vpc-34cxlz7z",
        "vpcCidrBlock": "10.10.0.0/16",
        "subnetName": "subnet-1so5ae8m111111",
        "subnetId": "3",
        "unSubnetId": "subnet-1so5ae8m",
        "subnetCidrBlock": "10.10.1.0/24",
        "lanIp": "10.10.1.6",
        "cmdContent": "ZWNobyAkMQplY2hvICQyCuS9oOWlvQ==",
        "cmdParam": "",
        "cmdResult": "c2hlbGwgMTAwLjczLjQ2LjIxNiwtMSwwLCdhZ2VudOi/lOWbnumUmeivr+S/oeaBry7nlKjmiLfpqozor4HlpLHotKUhJw==",
        "appId": "251000873",
        "lastShellExit": -1
      }
    ]
  }
}
```