## 功能描述

GetUserCmdList接口用来获取脚本列表。

接口访问域名：bm.api.qcloud.com

## 请求

### 请求示例
```
https://bm.api.qcloud.com/v2/index.php?
	Action=GetUserCmdList
	&<公共请求参数>
	&offset=<偏移量>
	&limit=<查询返回脚本的数量>
	&orderBy=<排序字段>
	&orderType=<排序方式>
	&searchKey=<脚本ID或名称>
```

### 请求参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，其它参数参见[公共请求参数](/doc/api/456/6718)页面。其中，此接口的Action字段为GetUserCmdList。

| 参数名称              | 必选   | 类型            | 描述                                       |
| ----------------- | ---- | ------------- | ---------------------------------------- |
| offset            | 否    | Int           | 偏移量，默认为0。                        |
| limit             | 否    | Int           | 查询返回脚本的数量，默认为20。                        |
| orderBy           | 否    | String        | 排序字段，支持： osType，createTime，modifyTime。                                 |
| orderType          | 否    | Int           | 排序方式，1倒序，0顺序，默认倒序。                                 |
| searchKey       | 否    | String        | 模糊匹配脚本ID和名称。 |


## 响应

### 响应示例
```
{
  "code": 0,
  "message": "",
  "data": {
    "list": [
      {
        "cmdId": "cmd-m9nkiu4o",
        "alias": "ian_xss_test",
        "osType": "linux",
        "createTime": "2017-10-17 10:40:14",
        "modifyTime": "2017-10-18 09:27:37"
      },
      {
        "cmdId": "cmd-20iqih72",
        "alias": "shell输入",
        "osType": "linux",
        "createTime": "2017-10-16 23:21:30",
        "modifyTime": "2017-10-16 23:21:30"
      }
    ],
    "totalNum": 31
  }
}
```

### 响应参数
响应参数部分包含两层结构，外层展示接口的响应结果，内层展示具体的接口内容，包括脚本信息。

| 参数名称    | 类型     | 描述                                       |
| ------- | ------ | ---------------------------------------- |
| code    | Int    | 错误码，0：成功， 其他值：失败，具体含义参见[错误码](/doc/api/456/6725)。 |
| message | String | 错误信息。                                    |
| data    | Object | 脚本列表，具体结构描述如data结构所示。                    |


data结构

| 参数名称       | 类型            | 描述                                    |
| ---------- | ------------- | ------------------------------------- |
| totalNum   | Int           | 脚本总数                                  |
| list | Array(Object) | 对象数组。数组元素为脚本信息，具体结构描述如list结构所示。 |

list结构

| 参数名称          | 类型     | 描述                                       |
| ------------- | ------ | ---------------------------------------- |
| cmdId        | String | 脚本ID。                                  |
| alias        | String | 脚本名称。                                  |
| osType  | String | 适用系统。                                  |
| createTime  | 日期时间 | 脚本创建时间。                                  |
| modifyTime    | 日期时间 | 脚本修改结束时间。                     |

## 错误码

| 错误码   | 英文提示                  | 错误描述    |
| ----- | --------------------- | ------- |
| 9001  | InternalError.DbError | 操作数据库错误 |
| 10001 | InvalidParameter      | 参数错误    |
| 18021 | OrderByInvalid        | 无效的order by类型 |
| 18022 | OrderTypeInvalid      | 无效的order type类型 |


## 实际案例

### 输入

```
https://bm.api.qcloud.com/v2/index.php?
	Action=GetUserCmdList
	&SecretId=AKID52SKw5uMEy3jhpMUBqSylEBJBby6E0KC
	&Nonce=48476
	&Timestamp=1476436689
	&Signature=afRlJQ0disdT97B7uIfVB4v2KWo%3D
	&limit=2
```

### 输出

```
{
  "code": 0,
  "message": "",
  "data": {
    "list": [
      {
        "cmdId": "cmd-m9nkiu4o",
        "alias": "ian_xss_test",
        "osType": "linux",
        "createTime": "2017-10-17 10:40:14",
        "modifyTime": "2017-10-18 09:27:37"
      },
      {
        "cmdId": "cmd-20iqih72",
        "alias": "shell输入",
        "osType": "linux",
        "createTime": "2017-10-16 23:21:30",
        "modifyTime": "2017-10-16 23:21:30"
      }
    ],
    "totalNum": 31
  }
}
```