Common request parameters are needed for all APIs. These parameters will not be discussed in the document for each API unless necessary. However, **these parameters are required in each request for the request to be initiated successfully**. The first letter of each common request parameter is in uppercase so that the parameters can be differentiated from API request parameters.

Here's a list of common request parameters:

| Name | Type | Description | Required |
|---|---|---|---|
| Action | String | The name of the API for the desired operation. For example, if you want to call the API of Query EIP List [DescribeEipBm](/doc/api/456/6671), the Action parameter is DescribeEipBm. | Yes |
| Region | String | Region parameter, used to identify the region to which the instance you want to operate belongs. The parameter values for regions are as follows:<br>Beijing: ap-beijing, Guangzhou: ap-guangzhou, Shanghai: ap-shanghai. <br><B>Note: Generally, this parameter is required, unless otherwise indicated in the relevant API. </B>| No |
| Timestamp | UInt | The current UNIX timestamp that records the time at which the API request was initiated. | Yes |
| Nonce | UInt | A random positive integer that is used in conjunction with Timestamp to prevent replay attacks. | Yes |
| SecretId | String | SecretId for identifying identity that is applied for on [Cloud API Key](https://console.cloud.tencent.com/capi). A SecretId corresponds to a unique SecretKey, which is used to generate the request Signature. For more information, please see [Signature Method](/document/product/386/6714). | Yes |
| Signature | String | Request signature used to verify the legitimacy of the request and automatically generated by system according to input parameters. For more information, please see <ahref="/doc/api/372/4214"title="Signature Method">Signature Method</a>. | Yes |

For example, if a user wants to query the CVM instance list for Guangzhou, the request link may be as follows:

```
https://eip.api.qcloud.com/v2/index.php?
Action=DescribeInstances
&SecretId=xxxxxxx
&Region=ap-shanghai
&Timestamp=1465055529
&Nonce=59485
&Signature=mysignature
&<API Request Parameter>
```

A complete request needs two types of request parameters: common request parameters and API request parameters. Only six common request parameters are listed above. For more information on API request parameters, please see [API Request Parameters](/document/product/386/6719) section.
