## 功能描述
 
CreateBmForwardListeners 提供了创建黑石负载均衡七层监听器功能。负载均衡七层监听器提供了转发用户请求的具体规则，包括端口、协议等参数。

接口请求域名：bmlb.api.qcloud.com

黑石负载均衡监听器的配置规则：
1) 七层监听器指协议类型为HTTP/HTTPS的监听器，四层监听器指协议类型为TCP/UDP的监听器。
2) 公网（有日租）负载均衡和内网负载均衡都支持协议类型为TCP和UDP的四层监听器。
3) 公网负载均衡支持协议类型为HTTP/HTTPS的七层监听器；内网负载均衡支持协议类型为HTTP的七层监听器。
4) 在同一个负载均衡中，对于七层监听器和协议类型为TCP的四层监听器，一个负载均衡端口只能对应其中一种。
5) 在同一个负载均衡中，一个负载均衡监听器可以对应多个物理服务器端口。
6) 在同一个负载均衡中，一个物理服务器的一个端口不能对应相同协议的不同的四层监听器。

## 请求
### 请求示例

```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=CreateBmForwardListeners
	&<公共请求参数>
	&loadBalancerId=<负载均衡实例ID>
	&listeners.0.loadBalancerPort=<七层监听器端口>
	&listeners.0.protocol=<七层监听器协议类型>
	&listeners.0.listenerName=<七层监听器名称>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数页面](/document/product/386/6718)。其中，此接口的Action字段为 CreateBmForwardListeners。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| loadBalancerId | 是 | String |   负载均衡实例ID，可通过接口[DescribeBmLoadBalancers](/document/product/386/9306)查询。|
| listeners | 是 | Array | 七层监听器信息数组，可以创建多个七层监听器。目前一个负载均衡下面最多允许创建50个七层监听器。|

listeners描述当前监听器的具体信息，n为下标，listeners包含字段如下

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
|listeners.n.loadBalancerPort|是|Int|七层监听器端口，可选值1~65535。|
|listeners.n.protocol|是|String|七层监听器协议类型，可选值：http,https。|
|listeners.n.listenerName|是|String|七层监听器名称。|
|listeners.n.SSLMode|否|Int|认证方式：0（不认证，用于http），1（单向认证，用于https），2（双向认证，用于https）。|
|listeners.n.certId|否|String|服务端证书ID。|
|listeners.n.certName|否|String|服务端证书名称。|
|listeners.n.certContent|否|String|服务端证书内容。|
|listeners.n.certKey|否|String|服务端证书密钥。|
|listeners.n.certCaId|否|String|客户端证书ID。|
|listeners.n.certCaName|否|String|客户端证书名称。|
|listeners.n.certCaContent|否|String|客户端证书内容。|
|listeners.n.bandwidth|否|Int|用于计费模式为固定带宽计费，指定监听器最大带宽值，可选值：0-1000，单位：Mbps。|



## 响应
### 响应示例

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
}
```

### 响应参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 错误码。0表示成功，其他值表示失败。详见错误码页面的[公共错误码](/document/product/386/6725)。|
| message | String | 错误信息描述，与接口相关。|
| codeDesc | String | 返回码信息描述。|
| listenerIds | Array | 新建的负载均衡七层监听器的唯一ID列表。|

## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |
| 11041 | InvalidParameter.CCDBLBNotExist | CCDB中不存在该负载均衡记录信息 |
| 12003 | IncorrectStatus.LBWrongStatus | 该负载均衡状态不正确,无法执行当前操作 |
| 12014 | InvalidResource.ListenerNumberOverLimit | 该负载均衡的七层监听器数量超过限制 |
| -12013 | InvalidParameter.VportIsDuplicate | 该负载均衡已经存在该端口的监听器 |
| -20002 | InvalidParameter.InvalidCertContent | 证书内容不合法 |
| -20000 | InvalidResource.CertPlatformErr | 访问证书平台异常 |
| -12020 | InvalidParameter.certNotInValidTime | 证书不在合法使用时段 |


## 实际案例
 
### 输入
 

```
https://bmlb.api.qcloud.com/v2/index.php?Action=CreateBmForwardListeners
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=24763
	&Timestamp=1507714922
	&Region=bj
	&loadBalancerId=lb-abcdefgh
	&listeners.0.loadBalancerPort=1234
	&listeners.0.protocol=http
	&listeners.0.listenerName=http-listener
	&Signature=AySJsE6Zq3knXwPSzxlYUl%2FrM90%3D
```

### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "listenerIds" : ["lbl-abcdefg"]
}

```