## 功能描述
 
DescribeBmLocationBackends 提供了获取黑石负载均衡七层转发路径绑定的主机列表功能。

接口请求域名：bmlb.api.qcloud.com


## 请求
### 请求示例

```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmLocationBackends
	&<公共请求参数>
	&loadBalancerId=<负载均衡实例ID>
	&listenerId=<七层监听器实例ID>
	&domainId=<转发域名实例ID>
	&locationId=<转发路径实例ID>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数页面](/document/product/386/6718)。其中，此接口的Action字段为 DescribeBmLocationBackends。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| loadBalancerId | 是 | String |   负载均衡实例ID，可通过接口[DescribeBmLoadBalancers](/document/product/386/9306)查询。|
| listenerId | 是 | String | 七层监听器实例ID，可通过接口[DescribeBmForwardListeners](/document/product/386/9283)查询。|
| domainId | 是 | String | 转发域名实例ID，可通过接口[DescribeBmForwardRules](/document/product/386/9285)查询。|
| locationId | 是 | String | 转发路径实例ID，可通过接口[DescribeBmForwardRules](/document/product/386/9285)查询。|
| offset | 否 | Int | 偏移位置。|
| limit | 否 | Int | 返回数量。|


## 响应
### 响应示例

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": [
        {
            "bindType": 0,
            "rsPort": 1234,
            "weight": 10,
            "instanceId": "cpm-abcdefgh",
            "alias": "XXX测试",
            "lanIp": "1.1.1.1",
            "mgtIp": "2.2.2.2",
            "operates": [
                "modifyDeviceAlias",
                "renewDevice",
                "shutdownDevice",
                "rebootDevice",
                "reloadDeviceOs",
                "resetPasswd",
                "bindEip",
                "unbindEip",
                "isolateDevice",
                "offlineDevice",
                "bindLb",
                "unbindLb"
            ],
            "status": "Dead"
        }
    ]
}
```

### 响应参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 错误码。0表示成功，其他值表示失败。详见错误码页面的[公共错误码](/document/product/386/6725)。|
| message | String | 错误信息描述，与接口相关。|
| codeDesc | String | 返回码信息描述。|
| data | Array | 返回的绑定关系列表。|

data每一个子项目包含字段如下

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| bindType | Int | 绑定类别（0代表黑石物理机，1代表虚机IP）。|
| rsPort | Int | 主机端口。|
| weight | Int | 权重。|
| status | String | 当前绑定关系的健康检查状态（Dead代表不健康，Alive代表健康）。|

当bindType为0时包含以下字段

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| instanceId | String | 黑石物理机的主机ID。|
| alias | String | 黑石物理机的别名。|
| lanIp | String | 黑石物理机的内网IP。|
| mgtIp | String | 黑石物理机的管理IP。|
| operates | Array | 黑石物理机当前可以执行的操作。|

当bindType为1时包含以下字段

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| lanIp | String | 虚机IP。|



## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |
| 11041 | InvalidParameter.CCDBLBNotExist | CCDB中不存在该负载均衡记录信息 |
| 11060 | InternalError.TGWAbnormal | TGW 服务异常 |
| 14100 | InternalError.BmApiAbnormal | bmApi服务异常 |


## 实际案例
 
### 输入

```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmLocationBackends
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=24763
	&Timestamp=1507714922
	&Region=bj
	&loadBalancerId=lb-abcdefgh
	&listenerId=lbl-abcdefgh
	&domainId=dm-abcdefgh
	&locationId=loc-abcdefgh
	&Signature=AySJsE6Zq3knXwPSzxlYUl%2FrM90%3D
```

### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": [
        {
            "bindType": 0,
            "rsPort": 1234,
            "weight": 10,
            "instanceId": "cpm-abcdefgh",
            "alias": "XXX测试",
            "lanIp": "1.1.1.1",
            "mgtIp": "2.2.2.2",
            "operates": [
                "modifyDeviceAlias",
                "renewDevice",
                "shutdownDevice",
                "rebootDevice",
                "reloadDeviceOs",
                "resetPasswd",
                "bindEip",
                "unbindEip",
                "isolateDevice",
                "offlineDevice",
                "bindLb",
                "unbindLb"
            ],
            "status": "Dead"
        }
    ]
}

```