## 功能描述
 
ModifyBmListener 提供了修改黑石负载均衡四层监听器功能。

接口请求域名：bmlb.api.qcloud.com

## 请求
### 请求示例
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=ModifyBmListener
	&<公共请求参数>
	&loadBalancerId=<负载均衡实例ID>
	&listenerId=<四层监听器ID>
	&listenerName=<四层监听器名称>
	&healthSwitch=<是否开启健康检查>
	&timeOut=<健康检查响应超时时间>
	&intervalTime=<健康检查间隔>
	&healthNum=<健康阀值>
	&unhealthNum=<不健康阀值>
	&sessionExpire=<会话保持时间>
	&bandwidth=<监听器最大带宽值>
	&customHealthSwitch=<是否开启自定义健康检查>
	&inputType=<探测内容类型>
	&lineSeparatorType=<换行替换方式>
	&healthRequest=<自定义探测请求内容>
	&healthResponse=<自定义探测返回内容>
	&toaFlag=<是否开启toa>
```
### 请求参数

以下请求参数列表仅列出了接口请求参数，其它参数见[公共请求参数](/document/product/386/6718)页面。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| loadBalancerId | 是 | String |   负载均衡实例ID，可通过接口[DescribeBmLoadBalancers](/document/product/386/9306)查询。|
| listenerId | 是 | String | 四层监听器ID。可通过接口[DescribeBmListeners](/document/product/386/9296)查询。|
| listenerName|否|String|四层监听器名称。|
| sessionExpire|否|Int|会话保持时间，单位：秒。可选值：900~3600。|
| healthSwitch|否|Int|是否开启健康检查：1（开启）、0（关闭）。默认值0，表示关闭。|
| timeOut|否|Int|健康检查的响应超时时间，可选值：2-60，默认值：2，单位:秒。<br><font color="red">响应超时时间要小于检查间隔时间。</font>|
| intervalTime|否|Int|健康检查间隔，默认值：5，可选值：5-300，单位：秒。|
| healthNum|否|Int|健康阀值，默认值：3，表示当连续探测三次健康则表示该转发正常，可选值：2-10，单位：次。|
| unhealthNum|否|Int|不健康阀值，默认值：3，表示当连续探测三次不健康则表示该转发不正常，可选值：2-10，单位：次。|
| bandwidth | 否 | Int | 监听器最大带宽值，用于计费模式为固定带宽计费。可选值：0-1000，单位：Mbps。|
| customHealthSwitch | 否 | Int | 是否开启自定义健康检查：1（开启）、0（关闭）。默认值0，表示关闭。（该字段在健康检查开启的情况下才生效）|
| inputType | 否 | String | 自定义健康探测内容类型，可选值：text（文本）、hexadecimal（十六进制）。|
| lineSeparatorType | 否 | Int | 探测内容类型为文本方式时，针对请求文本中换行替换方式。可选值：1（替换为LF）、2（替换为CR）、3（替换为LF+CR）。|
| healthRequest | 否 | String | 自定义探测请求内容。|
| healthResponse | 否 | String | 自定义探测返回内容。|
| toaFlag | 否 | Int | 是否开启toa。可选值：0（关闭）、1（开启），默认关闭。（该字段在负载均衡为fullnat类型下才生效）|

## 响应

### 响应示例
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "requestId" : <异步任务ID>
}
```

### 响应参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码。0表示成功，其他值表示失败。详见错误码页面的[公共错误码](/document/product/386/6725)。|
| message | String | 模块错误信息描述，与接口相关。|
| codeDesc | String | 返回码信息描述。|
| requestId | Int | 任务ID。该接口为异步任务，可根据本参数调用[DescribeBmLoadBalancersTaskResult](/document/product/386/9308)接口来查询任务操作结果|


## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |
| 11041 | InvalidParameter.CCDBLBNotExist | CCDB中不存在该负载均衡记录信息 |
| 12003 | IncorrectStatus.LBWrongStatus | 该负载均衡状态不正确,无法执行当前操作 |
| -21001 | InvalidStatus.LBInvalidStatus | 当前负载均衡状态不允许此操作 |
| -12023 | InvalidL4Listener.NotExist | CCDB中不存在该四层监听器 |
| -12021 | IncorrectStatus.L4ListenerWrongStatus | 该负载均衡四层监听器状态不正确,无法执行当前操作 |


## 实际案例
### 输入
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=ModifyBmListener
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=61431
	&Timestamp=1507728683
	&Region=bj
	&loadBalancerId=lb-abcdefgh
	&listenerId=lbl-abcdefgh
	&listenerName=tcp-listener
	&healthSwitch=1
	&timeOut=6
	&intervalTime=10
	&healthNum=8
	&unhealthNum=8
	&sessionExpire=1000
	&bandwidth=5
	&customHealthSwitch=1
	&inputType=text
	&lineSeparatorType=3
	&healthRequest=GET / HTTP/1.1\r\nHost:a.com\r\n\r\n
	&healthResponse=HTTP/1.1 200 OK
	&toaFlag=1
	&Signature=umZFAAWKzjXEQp4ySgrWAoWOHKI%3D
```

### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "requestId" : 1234
}

```
