## 功能描述
 
DescribeBmListeners 用来获取黑石负载均衡四层监听器。

接口请求域名：bmlb.api.qcloud.com

## 请求
### 请求示例
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmListeners
	&<公共请求参数>
	&loadBalancerId=<负载均衡实例ID>
	&listenerIds.0=<四层监听器实例ID>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数页面](/document/product/386/6718)。其中，此接口的Action字段为 DescribeBmListeners。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| loadBalancerId | 是 | String |  负载均衡实例ID，可通过接口[DescribeBmLoadBalancers](/document/product/386/9306)查询。|
| listenerIds.n | 否 | Array | 四层监听器实例ID数组，可通过接口[DescribeBmListeners](/document/product/386/9296)查询。|


## 响应

### 响应示例

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "listenerSet": [
        {
            "listenerId": <监听器实例ID>
            "listenerName": <监听器名称>
            "protocol": <监听器协议类型>
            "loadBalancerPort": <监听器端口>
            "bandwidth": <监听器最大带宽值>
            "listenerType": <监听器类别>
            "sessionExpire": <会话保持时间>
            "healthSwitch": <健康检查是否开启>
            "timeOut": <健康检查响应超时时间>
            "intervalTime": <健康检查间隔>
            "healthNum": <监听器健康阀值>
            "unhealthNum": <监听器不健康阀值>
            "customHealthSwitch": <自定义健康探测内容类型>
            "inputType": <自定义健康探测内容类型>
            "lineSeparatorType": <文本中换行替换方式>
            "healthRequest": <自定义探测请求内容>
            "healthResponse": <自定义探测返回内容>
            "toaFlag": <是否开启toa>
            "status": <监听器当前状态>
            "addTimestamp": <创建时间>
        }
    ],
    "totalCount": <listenerSet数组中包含监听器的个数>
}

```

### 响应参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码。0表示成功，其他值表示失败。详见错误码页面的[公共错误码](/document/product/386/6725)。|
| message | String | 模块错误信息描述，与接口相关。|
| codeDesc | String | 返回码信息描述。|
| listenerSet | Array | 监听器信息数组。|
| totalCount | Int | listenerSet数组中包含监听器的个数。|

listenerSet是一描述了当前负载均衡实例下的监听器信息的数组，包含字段如下

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| listenerId | String | 监听器ID。|
| listenerName | String | 用户自定义的监听器名称。|
| protocol | String | 负载均衡实例监听器协议类型，可选值tcp，udp。|
| loadBalancerPort | Int | 负载均衡监听器的监听接口，可选值1~65535。|
| bandwidth | Int | 用于计费模式为固定带宽计费，指定监听器最大带宽值，可选值：0-1000，单位：Mbps。|
| listenerType | String | 监听器的类别：L4Listener（四层监听器），L7Listener（七层监听器）。|
| sessionExpire | Int | 会话保持时间。单位：秒|
| healthSwitch | Int | 是否开启了检查：1（开启）、0（关闭）。|
| timeOut | Int | 响应超时时间，单位：秒。|
| intervalTime | Int | 检查间隔，单位：秒。|
| healthNum | Int | 负载均衡监听器健康阀值，默认值：3，表示当连续探测三次健康则表示该转发正常，可选值：2-10，单位：次。|
| unhealthNum | Int | 负载均衡监听器不健康阀值，默认值：3，表示当连续探测三次不健康则表示该转发不正常，可选值：2-10，单位：次。|
| customHealthSwitch | Int | 是否开启自定义健康检查：1（开启）、0（关闭）。默认值0，表示关闭。（该字段在健康检查开启的情况下才生效）|
| inputType | String | 自定义健康探测内容类型，可选值：text（文本）、hexadecimal（十六进制）。|
| lineSeparatorType | Int | 探测内容类型为文本方式时，针对请求文本中换行替换方式。可选值：1（替换为LF）、2（替换为CR）、3（替换为LF+CR）。|
| healthRequest | String | 自定义探测请求内容。|
| healthResponse | String | 自定义探测返回内容。|
| toaFlag | Int | 是否开启toa：1（开启）、0（关闭）。|
| status | Int | 监听器当前状态（0代表创建中，1代表正常运行，2代表创建失败，3代表删除中，4代表删除失败）。|
| addTimestamp | String | 创建时间戳。|


## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |
| 11041 | InvalidParameter.CCDBLBNotExist | CCDB中不存在该负载均衡记录信息 |


## 实际案例
### 输入
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmListeners
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=61431
	&Timestamp=1507728683
	&Region=bj
	&loadBalancerId=lb-abcdefgh
	&listenerIds.0=lbl-abcdefgh
	&Signature=umZFAAWKzjXEQp4ySgrWAoWOHKI%3D
```


### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "listenerSet": [
        {
            "listenerId": "lbl-abcdefgh",
            "listenerName": "test-tcp",
            "protocol": "tcp",
            "loadBalancerPort": 1234,
            "bandwidth": 0,
            "listenerType": "L4Listener",
            "sessionExpire": 900,
            "healthSwitch": 1,
            "timeOut": 2,
            "intervalTime": 5,
            "healthNum": 3,
            "unhealthNum": 3,
            "customHealthSwitch": 0,
            "inputType": "",
            "lineSeparatorType": 0,
            "healthRequest": "",
            "healthResponse": "",
            "toaFlag": 0,
            "status": 1,
            "addTimestamp": "2017-04-19 22:07:11"
        }
    ],
    "totalCount": 1
}

```