## 功能描述
 
DescribeBmListenerInfo 提供了查找绑定了某主机或者指定监听器名称的黑石负载均衡四层监听器功能。

接口请求域名：bmlb.api.qcloud.com

## 请求
### 请求示例
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmListenerInfo
	&<公共请求参数>
	&loadBalancerId=lb-abcdefgh
	&searchKey=a
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，其它参数见[公共请求参数](/document/product/386/6718)页面。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| loadBalancerId | 是 | String |   负载均衡实例ID，可通过接口[DescribeBmLoadBalancers](/document/product/386/9306)查询。|
| searchKey | 否 | String | 查找的键值，可用于模糊查找该名称的监听器。|
| instanceIds.n | 否 | Array | 主机ID或虚机IP列表，可用于获取绑定了该主机的监听器。|

## 响应

### 响应示例
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "listenerSet": [
        {
            "listenerId": <监听器实例ID>
            "listenerName": <监听器名称>
            "listenerType": <监听器类别>,
            "protocol": <监听器协议类型>
            "loadBalancerPort": <监听器端口>
            "status": <监听器当前状态>
            "sessionExpire": <会话保持时间>
            "bandwidth": <监听器最大带宽值>
            "healthSwitch": <健康检查是否开启>
            "healthNum": <监听器健康阀值>
            "unhealthNum": <监听器不健康阀值>
            "intervalTime": <健康检查间隔>
            "timeOut": <健康检查响应超时时间>
            "addTimestamp": <创建时间>
        }
    ]
}
```
### 响应参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码。0表示成功，其他值表示失败。详见错误码页面的[公共错误码](/document/product/386/6725)。|
| message | String | 模块错误信息描述，与接口相关。|
| codeDesc | String | 返回码信息描述。|
| listenerSet | Array | 返回的四层监听器列表。|

listenerSet每一个子项目包含字段如下

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| listenerId | String | 监听器ID。|
| listenerName | String | 用户自定义的监听器名称。|
| protocol | String | 负载均衡实例监听器协议类型，可选值tcp，udp。|
| loadBalancerPort | Int | 负载均衡监听器的监听接口，可选值1~65535。|
| bandwidth | Int | 用于计费模式为固定带宽计费，指定监听器最大带宽值，可选值：0-1000，单位：Mbps。|
| listenerType | String | 监听器的类别：L4Listener（四层监听器），L7Listener（七层监听器）。|
| sessionExpire | Int | 会话保持时间。单位：秒|
| healthSwitch | Int | 是否开启了检查：1（开启）、0（关闭）。|
| timeOut | Int | 响应超时时间，单位：秒。|
| intervalTime | Int | 检查间隔，单位：秒。|
| healthNum | Int | 负载均衡监听器健康阀值，默认值：3，表示当连续探测三次健康则表示该转发正常，可选值：2-10，单位：次。|
| unhealthNum | Int | 负载均衡监听器不健康阀值，默认值：3，表示当连续探测三次不健康则表示该转发不正常，可选值：2-10，单位：次。|
| status | Int | 监听器当前状态（0代表创建中，1代表正常运行，2代表创建失败，3代表删除中，4代表删除失败）。|
| addTimestamp | String | 创建时间戳。|


## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |
| 11041 | InvalidParameter.CCDBLBNotExist | CCDB中不存在该负载均衡记录信息 |


## 实际案例
### 输入
 
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmListenerInfo
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=61431
	&Timestamp=1507728683
	&Region=bj
	&loadBalancerId=lb-abcdefgh
	&searchKey=a
	&Signature=umZFAAWKzjXEQp4ySgrWAoWOHKI%3D
```

### 输出

```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "listenerSet": [
        {
            "listenerId": "lbl-abcdefgh",
            "listenerName": "aaa",
            "listenerType": "L4Listener",
            "protocol": "tcp",
            "loadBalancerPort": 1234,
            "status": 1,
            "sessionExpire": 900,
            "bandwidth": 0,
            "healthSwitch": 1,
            "healthNum": 3,
            "unhealthNum": 3,
            "intervalTime": 5,
            "timeOut": 2,
            "addTimestamp": "2017-04-19 22:07:11"
        }
    ]
}

```