## 功能描述
CreateBmLoadBalancer 接口用来创建黑石负载均衡。为了使用黑石负载均衡服务，您必须要创建一个或者多个负载均衡实例。通过成功调用该接口，会返回负载均衡实例的唯一ID。用户可以购买的黑石负载均衡实例类型分为：公网类型、内网类型。公网类型负载均衡对应一个BGP VIP，可用于快速访问公网负载均衡绑定的物理服务器；内网类型负载均衡对应一个腾讯云内部的VIP，不能通过Internet访问，可快速访问内网负载均衡绑定的物理服务器。

接口请求域名：bmlb.api.qcloud.com

## 请求
### 请求示例
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=CreateBmLoadBalancer
	&<公共请求参数>
	&unVpcId=<负载均衡实例所属的私有网络ID>
	&loadBalancerType=<负载均衡类型>
	&goodsNum=<负载均衡实例数量>
	&payMode=<计费模式>
```

### 请求参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](/document/product/386/6718)页面。其中，此接口的Action字段为CreateBmLoadBalancer。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| unVpcId | 是 | String | 黑石负载均衡实例所属的私有网络ID。|
| unSubnetId | 否 | String | 在私有网络内购买内网负载均衡实例的时候需要指定子网ID，内网负载均衡实例的VIP将从这个子网中产生。其他情况不用填写该字段。|
| projectId | 否 | Int | 负载均衡所属项目ID。不填则属于默认项目。|
| loadBalancerType | 是 | String | 负载均衡的类型，取值为open或internal。open表示公网(有日租)，internal表示内网。|
| goodsNum | 否 | Int | 购买黑石负载均衡实例的数量。默认值为1, 最大值为20。|
| payMode | 否 | String | 黑石负载均衡的计费模式，取值为flow和bandwidth，其中flow模式表示流量模式，bandwidth表示带宽模式。默认值为flow。|
| tgwSetType | 否 | String | 负载均衡对应的TGW集群类别，取值为tunnel或fullnat。tunnel表示隧道集群，fullnat表示FULLNAT集群。默认值为fullnat。如需获取client ip，请选择tunnel模式。|
 

## 响应

### 响应示例
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "loadBalancerIds": <负载均衡实例ID列表>
}
```

### 响应参数


| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 错误码, 0: 成功, 其他值: 失败，具体含义可以参考[错误码](/document/product/386/6725)。|
| message | String | 模块错误信息描述，与接口相关。|
| loadBalancerIds | Array | 创建的黑石负载均衡实例ID|

## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |
| 12010 | InvalidResource.LBNumberOverOrderLimit | 该订单购买的负载均衡实例数量超过限制 |
| 12011 | InvalidResource.LBNumberOverTotalLimit | 购买的负载均衡实例数量超过限制 |
| 20002 | InvalidParameter.VpcIdSubnetIdNotExist | 该账户在该地域并不存在该VPC和子网信息 |

## 实际案例
### 输入
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=CreateBmLoadBalancer
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=61431
	&Timestamp=1507728683
	&Region=bj
	&unVpcId=vpc-xxxx
	&loadBalancerType=open
	&goodsNum=2
	payMode=flow
	&Signature=umZFAAWKzjXEQp4ySgrWAoWOHKI%3D
```


### 输出
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "loadBalancerIds": [
        "lb-abcdefgh",
        "lb-abcdefge"
    ]
}
```