## 功能描述
DescribeBmLoadBalancers 接口用来于获取黑石负载均衡实例列表。可以根据您输入的参数来返回满足条件的黑石负载均衡实例。输入的过滤参数可以为负载均衡实例的名称、类型、公网VIP。如果不指定任何参数，则返回账户下所有负载均衡实例。

接口访问域名：bmlb.api.qcloud.com

## 请求
### 请求示例
```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmLoadBalancers
	&<公共请求参数>
	&loadBalancerType=<负载均衡类型>
	&tgwSetType=<负载均衡对应的TGW集群类别>
	&unVpcId=<负载均衡所在的unVpcId>
```

### 请求参数

以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见[公共请求参数](/document/product/386/6718)页面。其中，此接口的Action字段为DescribeBmLoadBalancers。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
|loadBalancerIds.n|否|Array|负载均衡实例ID。|
|loadBalancerType|否|String|负载均衡的类型，取值为open或internal。open表示公网(有日租)，internal表示内网。|
|loadBalancerName|否|String|负载均衡器名称。|
|domain|否|String|负载均衡域名。规则：1-60个小写英文字母、数字、点号“.”或连接线“-”。内网类型的负载均衡不能配置该字段|
|loadBalancerVips.n|否|Array|负载均衡获得的公网IP地址,支持多个。|
|offset|否|Int|数据偏移量，默认为0。|
|limit|否|Int|返回数据长度，默认为20。|
|searchKey|否|String|模糊查找名称、域名、VIP。|
|orderBy|否|String|排序字段，支持:loadBalancerName，createTime，domain，loadBalancerType。|
|orderType|否|Int|1倒序，0顺序，默认值为顺序。|
|projectId|否|Int|项目ID。|
|exclusive|否|Int|是否独占TGW集群。|
|tgwSetType|否|String|负载均衡对应的TGW集群类别，取值为tunnel或fullnat。tunnel表示隧道集群，fullnat表示FULLNAT集群。|
|unVpcId|否|String|负载均衡所在的unVpcId。|

## 响应

### 响应示例
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "loadBalancerSet": <负载均衡实例数组>
    "totalCount": <负载均衡实例数组条目个数>
}
```

### 响应参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 错误码, 0: 成功, 其他值: 失败，具体含义可以参考[错误码](/document/product/386/6725)。|
| message | String | 模块错误信息描述，与接口相关。|
| loadBalancerSet | Array | 返回的负载均衡实例数组。|
| totalCount | Int | 满足过滤条件的负载均衡实例总数。|
 
loadBalancerSet结构

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| loadBalancerId | String | 负载均衡实例的唯一ID。|
| loadBalancerName | String | 负载均衡实例的名称。|
| loadBalancerType | String | 负载均衡实例的类型。 open表示公网类型，internal表示内网类型。|
| domain | String | 负载均衡实例的域名，内网类型负载均衡实例没有域名。|
| loadBalancerVips | Array | 负载均衡实例的 VIP 列表。|
| status | Int | 负载均衡实例的状态，包括0:创建中，1:正常运行。|
| createTime | String | 负载均衡实例的创建时间。|
| statusTime | String | 负载均衡实例的上次状态转换时间。|
| unVpcId | String | 黑石私有网络vpc的唯一ID。|
| unSubnetId | String | 黑石私有网络子网的唯一ID。|
| vpcId | Int | 黑石私有网络整形ID。|
| subnetId | Int | 私有网络的子网 ID的数字部分, 0 表示默认子网。|
| projectId | Int | 项目ID。|
| latestPayMode | String | 负载均衡实例的最近一次的计费模式，取值为flow和bandwidth，其中flow模式表示流量模式，bandwidth表示带宽模式。|
| payMode | String | 负载均衡实例的当前计费模式。|
| bandwidth | Int | 带宽大小，当计费模式为flow时，该值为0。|
| tgwSetType | String | 负载均衡对应的TGW集群类别。|




## 错误码

| 错误代码 | 英文提示 | 错误描述 |
|------|------|------|
| 9003 | InvalidParameter | 参数错误 |
| 9006 | InternalError.CCDBAbnormal | CCDB 服务异常 |

## 实际案例

### 输入

```
GET https://bmlb.api.qcloud.com/v2/index.php?Action=DescribeBmLoadBalancers
	&SecretId=AKIDlfdHxN0ntSVt4KPH0xXWnGl21UUFNoO5
	&Nonce=61431
	&Timestamp=1507728683
	&Region=bj
	&loadBalancerType=open
	&tgwSetType=fullnat
	&unVpcId=vpc-abcdefgh
	&Signature=umZFAAWKzjXEQp4ySgrWAoWOHKI%3D
```

### 输出
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "loadBalancerSet": [
        {
            "loadBalancerId": "lb-abcdefgh",
            "loadBalancerName": "XXX",
            "loadBalancerType": "open",
            "domain": "abc.hslb.myqcloud.com",
            "loadBalancerVips": [
                "115.115.115.115"
            ],
            "status": 1,
            "createTime": "2017-03-08 15:38:00",
            "statusTime": "2017-04-25 21:03:40",
            "unVpcId": "vpc-abcdefgh",
            "unSubnetId": "0",
            "vpcId": 1000,
            "subnetId": 0,
            "projectId": 0,
            "latestPayMode": "flow",
            "payMode": "flow",
            "bandwidth": 0,
            "tgwSetType": "fullnat"
        }
    ],
    "totalCount": 1
}
```