## 1. 说明

开发者使用人脸识别功能之前，需要先注册腾讯云账号，并创建图片空间，添加密钥，具体操作步骤如下：

 1)	前往[腾讯云·万象优图控制台](http://console.cloud.tencent.com/image/imgguide)控制台注册账号；如果已经注册账号，请跳过此步骤；
![](https://mc.qcloudimg.com/static/img/82462b3d201bee1dd02265a3d477e219/1.png)
2)	在[腾讯云·万象优图控制台](http://console.cloud.tencent.com/image/imgguide)创建一个图片空间，获取空间名称（bucket）和项目ID；如果已创建过图片空间，请跳过此步骤；
![](https://mc.qcloudimg.com/static/img/69e14001e3f8a6cbcdffd3421021ebf1/2.png)
3)	在[腾讯云·万象优图控制台](http://console.cloud.tencent.com/image/imgguide)项目设置中添加密钥，获取SecretID和SecretKey；如果已经添加过密钥，请跳过此步骤。
![](https://mc.qcloudimg.com/static/img/e404ca7488e2803674c9fd806621e26d/3.png)

**基本概念：**

| 概念        | 解释                                       |
| --------- | ---------------------------------------- |
| appid     | 项目ID, 用于唯一标识接入项目                         |
| bucket    | 开发者添加的空间名称                               |
| group_id  | 个体(person)以组（group）的形式存储，一个组可以包含多个个体，一个个体也可以存在于多个组。group_id即用来标识group。组(group)没有专门的创建接口，创建个体(person)时，指定group_id则会自动创建。 |
| person_id | 人脸以个体（person）的形式存储，一个个体下可以存储多张人脸。person_id即用来标识person |
| face_id   | 标识每张人脸的id                                |

 **说明：**如果开发者使用的是V1版本，appid为其当时生成的appid

## 2. 人脸识别CGI

人脸识别接口采用http协议，支持指定图片URL和 上传本地图片文件两种方式进行识别。
限制说明：
(1) 一个appid下建立的group_id数量限制为5000个。
(2) 一个group_id下建立的person_id数量限制为10000个。
(3) 一个person_id下建立的人脸数量限制为20个。
(4) 每个请求的包体大小限制为1.5MB。
(5) 所有接口都为POST方法。
(6) 不支持 .gif这类的动图。

协议头部：所有请求都要求含有下表列出的头部信息

| 参数名            | 值                                     | 描述                                       |
| -------------- | ------------------------------------- | ---------------------------------------- |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                                |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）                 |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                                 |
| Authorization  | 鉴权签名                                  | 用于鉴权的签名，[详情](https://cloud.tencent.com/doc/product/275/3805) |

### 2.1      个体创建

1) 接口
http://service.image.myqcloud.com/face/newperson
2) 描述
创建一个Person，并将Person放置到group_ids指定的组当中，不存在的group_id会自动创建。
3) 参数
使用image则使用 multipart/form-data格式
不使用image则使用 application/json格式

| 参数名         | 是否必须 | 类型            | 参数说明                                  |
| ----------- | ---- | ------------- | ------------------------------------- |
| appid       | 必须   | String        | 项目ID                                  |
| bucket      | 必须   | string        | 空间名称                                  |
| group_ids   | 必须   | Array(String) | 加入到组的列表                               |
| person_id   | 必须   | String        | 指定的个体id                               |
| image       | 可选   | Binary        | 图片内容                                  |
| url         | 可选   | String        | 图片的url, image和url只提供一个即可,如果都提供,只使用url |
| person_name | 可选   | String        | 名字                                    |
| tag         | 可选   | String        | 备注信息                                  |

4) 返回值说明

| 字段              | 类型            | 说明               |
| --------------- | ------------- | ---------------- |
| data.session_id | String        | 相应请求的session标识符  |
| data.suc_group  | Int           | 成功被加入的group数量    |
| data.suc_face   | Int           | 成功加入的face数量      |
| data.person_id  | String        | 相应person的id      |
| data.face_id    | String        | 创建所用图片生成的face_id |
| data.group_ids  | Array(String) | 加入成功的组id         |
| code            | Int           | 返回码              |
| message         | String        | 返回错误消息           |

5) 样例

使用url的请求包:

```
POST /face/newperson HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 187
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "group_ids":[ "tencent", "qq" ],
  "person_id":"person0",
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}

```

使用image的请求包:

```
POST /face/newperson HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 735
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="bucket";

test
----------------acebdf13572468
Content-Disposition: form-data; name="group_ids[0]";

tencent
----------------acebdf13572468
Content-Disposition: form-data; name="group_ids[1]";

qq
----------------acebdf13572468
Content-Disposition: form-data; name="person_id";

person0
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 204
Content-Type: application/json

{
  "data":{
    "person_id":"person0",
    "suc_group":2,
    "suc_face":1,
    "session_id":"",
    "face_id":"1009550071676600319",
    "group_ids":["tencent", "qq"]
  },
  "code":0,
  "message":"OK"
}

```

### 2.2      删除个体

1) 接口
http://service.image.myqcloud.com/face/delperson

2) 描述
删除一个Person。

3) 参数

使用 application/json格式

| 参数名       | 是否必须 | 类型     | 参数说明    |
| --------- | ---- | ------ | ------- |
| appid     | 必须   | String | 项目ID    |
| bucket    | 必须   | String | 空间名称    |
| person_id | 必须   | String | 待删除个体ID |

4) 返回值说明

| 字段              | 类型     | 说明              |
| --------------- | ------ | --------------- |
| data.session_id | String | 相应请求的session标识符 |
| data.person_id  | String | 成功删除的person_id  |
| data.deleted    | Int    | 成功删除的Person数量   |
| code            | Int    | 返回状态码           |
| message         | String | 返回错误消息          |

5) 样例

请求包:

```
POST /face/delperson HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 66
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person0"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 114
Content-Type: application/json

{
  "data":{
    "deleted": 1,
    "person_id": "person0",
    "session_id":""
  },
  "code":0,
  "message":"OK"
}

```

### 2.3      增加人脸

1) 接口
http://service.image.myqcloud.com/face/addface

2) 描述
将一组Face加入到一个Person中。注意，一个Face只能被加入到一个Person中。 一个Person最多允许包含20个Face；加入几乎相同的人脸会返回错误。

3) 参数

使用image则使用 multipart/form-data格式；不使用image则使用 application/json格式

| 参数名       | 是否必须 | 类型            | 参数说明                                     |
| --------- | ---- | ------------- | ---------------------------------------- |
| appid     | 必须   | String        | 项目ID                                     |
| bucket    | 必须   | String        | 空间名称                                     |
| person_id | 必须   | String        | 待增加人脸的个体id                               |
| images    | 可选   | Array(Binary) | 图片内容                                     |
| urls      | 可选   | String        | 图片的urls, images 和urls只提供一个就可以了,如果都提供,只使用urls |
| tag       | 可选   | String        | 备注信息                                     |

4) 返回值说明

| 字段              | 类型            | 说明              |
| --------------- | ------------- | --------------- |
| data.session_id | String        | 相应请求的session标识符 |
| data.added      | Int           | 成功加入的face数量     |
| data.face_ids   | Array(String) | 增加的人脸ID列表       |
| data.ret_codes  | Array(Int)    | 每张图片增加人脸的返回码    |
| code            | Int           | 返回状态码           |
| message         | String        | 返回错误消息          |

5) 样例

使用url的请求包:

```
POST /face/addface HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 191
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person0",
  "urls":[
    "http://test-123456.image.myqcloud.com/face1.jpg",
    "http://test-123456.image.myqcloud.com/face2.jpg"
  ]
}

```

使用image的请求包:

```
POST /face/addface HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 641
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="bucket";

test
----------------acebdf13572468
Content-Disposition: form-data; name="person_id";

person0
----------------acebdf13572468
Content-Disposition: form-data; name="images[0]"; filename="face1.jpg"
Content-Type: image/jpeg

yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
----------------acebdf13572468
Content-Disposition: form-data; name="images[1]"; filename="face2.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 168
Content-Type: application/json

{
  "data":{
    "added":2,
    "session_id":"",
    "face_ids":["1009550071676600319","109387462576600319"],
    "ret_codes":[0, 0]
  },
  "code":0,
  "message":"OK"
}

```

### 2.4      删除人脸

1) 接口
http://service.image.myqcloud.com/face/delface

2) 描述
删除一个person下的face，包括特征，属性和face_id。

3) 参数

使用 application/json格式

| 参数名       | 是否必须 | 类型            | 参数说明            |
| --------- | ---- | ------------- | --------------- |
| appid     | 必须   | String        | 项目ID            |
| bucket    | 必须   | String        | 空间名称            |
| person_id | 必须   | String        | 待删除人脸的person ID |
| face_ids  | 必须   | Array(String) | 删除人脸id的列表       |

4) 返回值说明

| 字段              | 类型            | 说明              |
| --------------- | ------------- | --------------- |
| data.session_id | String        | 相应请求的session标识符 |
| data.deleted    | Int           | 成功删除的face数量     |
| data.face_ids   | Array(String) | 成功删除的face_id列表  |
| code            | Int           | 返回状态码           |
| message         | String        | 返回错误消息          |

5) 样例

请求包:

```
POST /face/delface HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 125
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person0",
  "face_ids":[
    "199d1efd19ce4ee67a7ec7655f859b1a"
  ]
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 150
Content-Type: application/json

{
  "data":{
    "deleted": 1,
    "face_ids":[
      "199d1efd19ce4ee67a7ec7655f859b1a"
    ],
    "session_id":""
  },
  "code":0,
  "message":"OK"
}

```

### 2.5      设置信息

1) 接口
http://service.image.myqcloud.com/face/setinfo

2) 描述
设置Person的name。

3) 参数

使用 application/json格式

| 参数名         | 是否必须 | 类型     | 参数说明        |
| ----------- | ---- | ------ | ----------- |
| appid       | 必须   | String | 项目ID        |
| bucket      | 必须   | String | 空间名称        |
| person_id   | 必须   | String | 相应person的id |
| person_name | 可选   | String | 新的name      |
| tag         | 可选   | String | 备注信息        |

4) 返回值说明

| 字段              | 类型     | 说明              |
| --------------- | ------ | --------------- |
| data.session_id | String | 相应请求的session标识符 |
| data.person_id  | String | 相应person的id     |
| code            | Int    | 返回状态码           |
| message         | String | 返回错误消息          |

5) 样例

请求包:

```
POST /face/setinfo HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 97
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person0",
  "person_name":"NicolasCage"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 96
Content-Type: application/json

{
  "data":{
    "person_id": "person0",
    "session_id":""
  },
  "code":0,
  "message":"OK"
}

```

### 2.6      获取信息

1) 接口
http://service.image.myqcloud.com/face/getinfo

2) 描述
获取一个Person的信息, 包括name, id, tag, 相关的face, 以及groups等信息。

3) 参数

使用 application/json格式

| 参数名       | 是否必须 | 类型     | 参数说明     |
| --------- | ---- | ------ | -------- |
| appid     | 必须   | String | 项目ID     |
| bucket    | 必须   | String | 空间名称     |
| person_id | 必须   | String | 待查询个体的ID |

4) 返回值说明

| 字段               | 类型            | 说明              |
| ---------------- | ------------- | --------------- |
| data.person_name | String        | 相应person的name   |
| data.person_id   | String        | 相应person的id     |
| data.face_ids    | Array(String) | 包含的人脸列表         |
| data.group_ids   | Array(String) | 包含此个体的组id       |
| data.session_id  | String        | 相应请求的session标识符 |
| data.tag         | String        | 为此个体设置的备注信息     |
| code             | Int           | 返回状态码           |
| message          | String        | 返回错误消息          |

5) 样例

请求包:

```
POST /face/getinfo HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 66
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person0"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 293
Content-Type: application/json

{
  "data":{
    "person_id": "person0",
    "person_name": "NicolasCage",
    "face_ids": [
      "199d1efd19ce4ee67a7ec7655f859b1a",
      "19321efd19ce4ee67a7127655f85934a"
    ],
    "group_ids":[
      "tencent"
    ],
    "tag":"",
    "session_id":""
  },
  "code":0,
  "message":"OK"
}

```

### 2.7      获取组列表

1) 接口
http://service.image.myqcloud.com/face/getgroupids

2) 描述
获取一个AppId下所有group列表。

3) 参数

使用 application/json格式

| 参数名    | 是否必须 | 类型     | 参数说明 |
| ------ | ---- | ------ | ---- |
| appid  | 必须   | String | 项目ID |
| bucket | 必须   | String | 空间名称 |

4) 返回值说明

| 字段             | 类型            | 说明                 |
| -------------- | ------------- | ------------------ |
| data.group_ids | Array(String) | 相应appid的group_id列表 |
| code           | Int           | 返回状态码              |
| message        | String        | 返回错误消息             |

5) 样例

请求包:

```
POST /face/getgroupids HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 41
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 136
Content-Type: application/json

{
  "data":{
    "group_ids": [
      "tencent",
      "tencent-beijing",
      "tencent-shanghai"
]
  },
  "code":0,
  "message":"OK"
}

```

### 2.8      获取人列表

1) 接口
http://service.image.myqcloud.com/face/getpersonids

2) 描述
获取一个组Group中所有person列表。

3) 参数

使用 application/json格式

| 参数名      | 是否必须 | 类型     | 参数说明 |
| -------- | ---- | ------ | ---- |
| appid    | 必须   | String | 项目ID |
| bucket   | 必须   | String | 空间名称 |
| group_id | 必须   | String | 组id  |

4) 返回值说明

| 字段              | 类型            | 说明            |
| --------------- | ------------- | ------------- |
| data.person_ids | Array(String) | 相应person的id列表 |
| code            | Int           | 返回状态码         |
| message         | String        | 返回错误消息        |

5) 样例

请求包:

```
POST /face/getpersonids HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 65
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "group_id":"tencent"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 120
Content-Type: application/json

{
  "data":{
    "person_ids": [
      "person0",
      "person1",
      "person2"
]
  },
  "code":0,
  "message":"OK"
}

```

### 2.9      获取人脸列表

1) 接口
http://service.image.myqcloud.com/face/getfaceids

2) 描述
获取一个组person中所有face列表。

3) 参数

使用 application/json格式

| 参数名       | 是否必须 | 类型     | 参数说明 |
| --------- | ---- | ------ | ---- |
| appid     | 必须   | String | 项目ID |
| bucket    | 必须   | String | 空间名称 |
| person_id | 必须   | String | 个体id |

4) 返回值说明

| 字段            | 类型            | 说明          |
| ------------- | ------------- | ----------- |
| data.face_ids | Array(String) | 相应face的id列表 |
| code          | Int           | 返回状态码       |
| message       | String        | 返回错误消息      |

5) 样例

请求包:

```
POST /face/getfaceids HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 66
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person1"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 154
Content-Type: application/json

{
  "data":{
    "face_ids": [
      "1005338790489817087",
      "1005338790489817088",
      "1005338790489817089"
]
  },
  "code":0,
  "message":"OK"
}

```

### 2.10    获取人脸信息

1) 接口
http://service.image.myqcloud.com/face/getfaceinfo

2) 描述
获取一个face的相关特征信息。

3) 参数

使用 application/json格式

| 参数名     | 是否必须 | 类型     | 参数说明 |
| ------- | ---- | ------ | ---- |
| appid   | 必须   | String | 项目ID |
| bucket  | 必须   | string | 空间名称 |
| face_id | 必须   | String | 人脸id |

4) 返回值说明

| 字段             | 类型       | 说明     |
| -------------- | -------- | ------ |
| data.face_info | FaceItem | 人脸信息   |
| code           | Int      | 返回状态码  |
| message        | String   | 返回错误消息 |

FaceItem说明

| 字段         | 类型     | 说明                                 |
| ---------- | ------ | ---------------------------------- |
| face_id    | String | 人脸标识                               |
| x          | Int    | 人脸框左上角x                            |
| y          | Int    | 人脸框左上角y                            |
| width      | Float  | 人脸框宽度                              |
| height     | Float  | 人脸框高度                              |
| gender     | Int    | 性别 [0(female)~100(male)]           |
| age        | Int    | 年龄 [0~100]                         |
| expression | Int    | 微笑[0(normal)~50(smile)~100(laugh)] |
| glass      | Bool   | 是否有眼镜 [true,false]                 |
| pitch      | Int    | 上下偏移[-30,30]                       |
| yaw        | Int    | 左右偏移[-30,30]                       |
| roll       | Int    | 平面旋转[-180,180]                     |

5) 样例

请求包:

```
POST /face/getfaceinfo HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 76
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "face_id":"1005338790489817087"
}

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 313
Content-Type: application/json

{
  "data":{
    "face_info": {
      "face_id": "1005338790489817087",
      "x": 44,
      "y": 33,
      "height": 64.0,
      "width": 64.0,
      "pitch": 5,
      "roll": 0,
      "yaw": 6,
      "age": 37,
      "gender": 99,
      "glass": true,
      "expression": 6
}
  },
  "code":0,
  "message":"OK"
}

```

### 2.11 人脸验证

1) 接口
http://service.image.myqcloud.com/face/verify

2) 描述
给定一个图片和一个Person，检查是否是同一个人。

3) 参数

使用image则使用 multipart/form-data格式

不使用image则使用 application/json格式

| **参数名**   | **是否必须****** | **类型****** | **参数说明******                             |
| --------- | ------------ | ---------- | ---------------------------------------- |
| appid     | 必须           | String     | 项目ID                                     |
| bucket    | 必须           | string     | 空间名称                                     |
| person_id | 必须           | String     | 待验证的Person                               |
| image     | 可选           | Binary     | 图片内容                                     |
| url       | 可选           | String     | 图片的url, image 和url只提供一个就可以了,如果都提供,只使用url |

4) 返回值说明

| **字段******      | **类型****** | **说明******              |
| --------------- | ---------- | ----------------------- |
| data.session_id | String     | 相应请求的session标识符，可用于结果查询 |
| data.confidence | float      | 两个人的相似度                 |
| data.ismatch    | Bool       | 两个输入是否为同一人的判断           |
| code            | Int        | 返回状态码                   |
| message         | String     | 返回错误消息                  |

5) 样例

使用url的请求包:

```
POST /face/verify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 123
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "person_id":"person1",
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}

```

使用image的请求包:

```
POST /face/verify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 460
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="bucket";

test
----------------acebdf13572468
Content-Disposition: form-data; name="person_id";

Person1
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 409
Content-Type: application/json

{
  "data":{
    "session_id":"session_id",
"confidence":90.0,
"ismatch":true
  },
  "code":0,
  "message":"OK"
}

```

### 2.12   人脸检索

1) 接口
http://service.image.myqcloud.com/face/identify

2) 描述
对于一个待识别的人脸图片，在一个Group中识别出最相似的Top5 Person作为其身份返回，返回的Top5中按照相似度从大到小排列。

3) 参数

使用image则使用 multipart/form-data格式

不使用image则使用 application/json格式

| 参数名      | 是否必须 | 类型     | 参数说明                                     |
| -------- | ---- | ------ | ---------------------------------------- |
| appid    | 必须   | String | 项目ID                                     |
| bucket   | 必须   | string | 空间名称                                     |
| group_id | 必须   | String | 候选人组id                                   |
| image    | 可选   | Binary | 图片内容                                     |
| url      | 可选   | String | 图片的url, image 和url只提供一个就可以了,如果都提供,只使用url |

4) 返回值说明

| 字段              | 类型                  | 说明                      |
| --------------- | ------------------- | ----------------------- |
| data.session_id | String              | 相应请求的session标识符，可用于结果查询 |
| data.candidates | Array(IdentifyItem) | 识别出的top5候选人             |
| code            | Int                 | 返回状态码                   |
| message         | String              | 返回错误消息                  |

IdentifyItem说明

| 字段         | 类型     | 说明           |
| ---------- | ------ | ------------ |
| person_id  | String | 候选者person_id |
| face_id    | String | 候选者face_id   |
| confidence | Float  | 候选者的置信度      |
| tag        | String | 人脸备注信息       |

5) 样例

使用url的请求包:

```
POST /face/identify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 123
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "group_id":"tencent",
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}

```

使用image的请求包:

```
POST /face/identify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 460
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="bucket";

test
----------------acebdf13572468
Content-Disposition: form-data; name="group_id";

tencent
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 409
Content-Type: application/json

{
  "data":{
    "session_id":"session_id",
    "candidates":[
      {
        "person_id":"person3",
        "face_id":"1031567119985213439",
        "confidence":54.90695571899414,
        "tag":"new tag"
      },
      {
        "person_id":"person1",
        "face_id":"1031587105968553983",
        "confidence":54.86775207519531,
        "tag":"new tag"
      }
    ]
  },
  "code":0,
  "message":"OK"
}

```

### 2.13   人脸比对

1) 接口
http://service.image.myqcloud.com/face/compare

2) 描述
计算两个Face的相似性以及五官相似度。

3) 参数

使用image则使用 multipart/form-data格式

不使用image则使用 application/json格式

| 参数名    | 是否必须 | 类型     | 参数说明                                     |
| ------ | ---- | ------ | ---------------------------------------- |
| appid  | 必须   | String | 项目ID                                     |
| bucket | 必须   | string | 空间名称                                     |
| imageA | 可选   | Binary | A图片内容                                    |
| imageB | 可选   | Binary | B图片内容                                    |
| urlA   | 可选   | String | A图片的url, image 和url只提供一个就可以了,如果都提供,只使用url |
| urlB   | 可选   | String | B图片的url, image 和url只提供一个就可以了,如果都提供,只使用url |

4) 返回值说明

| 字段              | 类型     | 说明                        |
| --------------- | ------ | ------------------------- |
| data.session_id | String | 相应请求的session标识符           |
| data.similarity | float  | 两个face的相似度                |
| data.fail_flag  | Int    | 标志失败图片，1为第一张，2为第二张（失败时返回） |
| code            | Int    | 返回码                       |
| message         | String | 返回错误消息                    |

5) 样例

使用url的请求包:

```
POST /face/identify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 123
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "urlA":"http://test-123456.image.myqcloud.com/testA.jpg",
  "urlB":"http://test-123456.image.myqcloud.com/testB.jpg"
}

```

使用image的请求包:

```
POST /face/identify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 460
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="bucket";

test
----------------acebdf13572468
Content-Disposition: form-data; name="imageA"; filename="testA.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468
Content-Disposition: form-data; name="imageB"; filename="testB.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--

```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 109
Content-Type: application/json

{
  "data":{
    "similarity":100.0,
    "session_id":""
  },
  "code":0,
  "message":"OK"
}

```

## 3.  返回码

| 错误码   | 含义                       |
| ----- | ------------------------ |
| 3     | 错误的请求                    |
| 4     | 签名为空                     |
| 5     | 签名串错误                    |
| 6     | 签名中的appid/bucket与操作目标不匹配 |
| 9     | 签名过期                     |
| 10    | appid不存在                 |
| 11    | secretid不存在              |
| 12    | appid和secretid不匹配        |
| 13    | 重放攻击                     |
| 14    | 签名校验失败                   |
| 15    | 操作太频繁，触发频控               |
| 16    | Bucket不存在                |
| 21    | 无效参数                     |
| 23    | 请求包体过大                   |
| 107   | 鉴权服务不可用                  |
| 108   | 鉴权服务不可用                  |
| 213   | 内部错误                     |
| -1101 | 人脸检测失败                   |
| -1102 | 图片解码失败                   |
| -1103 | 特征处理失败                   |
| -1104 | 提取轮廓错误                   |
| -1105 | 提取性别错误                   |
| -1106 | 提取表情错误                   |
| -1107 | 提取年龄错误                   |
| -1108 | 提取姿态错误                   |
| -1109 | 提取眼镜错误                   |
| -1200 | 特征存储错误                   |
| -1300 | 图片为空                     |
| -1301 | 参数为空                     |
| -1302 | 个体已存在                    |
| -1303 | 个体不存在                    |
| -1304 | 参数过长                     |
| -1305 | 人脸不存在                    |
| -1306 | 组不存在                     |
| -1307 | 组列表不存在                   |
| -1308 | url图片下载失败                |
| -1309 | 人脸个数超过限制                 |
| -1310 | 个体个数超过限制                 |
| -1311 | 组个数超过限制                  |
| -1312 | 对个体添加了几乎相同的人脸            |
| -1400 | 非法的图片格式                  |
| -1403 | 图片下载失败                   |

 