## 1	签名与鉴权
腾讯移动服务通过签名来验证请求的合法性。开发者通过将签名授权给客户端，使其具备上传下载及管理指定资源的能力。签名分为多次有效签名和单次有效签名。
多次有效签名：签名中绑定或者不绑定文件fileid，需要设置大于当前时间的有效期，有效期内此签名可多次使用，有效期最长可设置三个月。
单次有效签名：签名中绑定文件fileid，有效期必须设置为0，此签名只可使用一次，且只能应用于被绑定的文件。
具体适用场景参见签名适用场景。密钥的获取及签名的生成方法如下：
### 1.1	申请应用密钥
1)	登录 http://console.cloud.tencent.com/image/bucket, 进入图片空间页面；
2)	空间名称签名有“APP”字样的小图标，为V1版本开发者创建的应用，此时空间名称为AppID、SecretID、SecretKey。
### 1.2	生成签名
签名的生成，推荐使用我们提供的各语言签名函数，参见[签名样例下载](#1.4-.E7.AD.BE.E5.90.8D.E6.A0.B7.E4.BE.8B.E4.B8.8B.E8.BD.BD)
如果用户要自己实现签名算法，以删除文件请求为例，请求参数为：
Appid： 2011541224
图片资源URL： url=`http://web.image.myqcloud.com/2011541224/123456/442d8ddf-59a5-4dd4-b5f1-e38499fb33b4`
Userid：123456
文件 fileid：442d8ddf-59a5-4dd4-b5f1-e38499fb33b4
如何生产签名可以用三步来表示：
#### 1.2.1	step 1. 创建应用
请到移[动服务控制台——应用管理](http://app.qcloud.com/)创建应用，获取到AppID 、SecretID和SecretKey，这里假设分别是：
AppID =2011541224，
SecretID= AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP
SecretKey=ckKU7P4FwB4PBZQlnB9hfBAcaKZMeUge
#### 1.2.2	step 2.拼接签名串
拼接多次有效签名串：
a=2011541224&k=AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP&e=1432970065&t=1427786065&r=270494647&u=123456&f= 
拼接单次有效签名串：
a=2011541224&k=AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP&e=0&t=1427786065&r=270494647&u=123456&f=442d8ddf-59a5-4dd4-b5f1-e38499fb33b4 
a为用户的AppID
k为用户的SecretID
e为此签名的凭证有效期，是一个符合UNIX Epoch时间戳规范的数值，单位为秒；文件删除、复制类签名必须置为0，表示此签名只生效一次。
t为当前时间戳，是一个符合UNIX Epoch时间戳规范的数值，单位为秒，上传时e应大于t；
r为随机串，无符号10进制整数，用户需自行生成，最长10位。
f为绑定的资源fileid（在上传时移动服务平台会返回给用户，文件的唯一标识）
u为开发者业务系统的用户标识,没有请置空（如果此处填写了userid，在使用此签名上传或管理资源时，也需要将userid设置为与此处一致）
注：
拼接单次有效签名的签名串时，过期时间e必须设置为0，以保证此签名只能只能针对固定资源且只能使用一次；
删除和复制文件必须使用单次有效签名；
上传必须使用多次有效签名；
具体适用场景参见[签名适用场景](#1.3-.E7.AD.BE.E5.90.8D.E9.80.82.E7.94.A8.E5.9C.BA.E6.99.AF)。
#### 1.2.3	step 3. 生成签名串
1.	移动服务使用 HMAC-SHA1 算法对请求进行签名
2.	签名串需要使用 Base64 编码
根据签名方法Sign= Base64(HMAC-SHA1(SecretKey, orignal) + original)，其中SecretKey在step1中获取，orignal为step2中拼接好的签名串，对orignal使用HMAC-SHA1算法进行签名，然后将orignal附加到签名结果的末尾，再进行Base64编码，得到最终的sign。
注：此处使用的是标准的Base64编码，不是urlsafe的Base64编码，请注意。
 以 PHP 语言为例:
 

```
$secretKey = 'ckKU7P4FwB4PBZQlnB9hfBAcaKZMeUge';

$srcStr='a=2011541224&k=AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP&e=1432970065&t=1427786065&r=270494647&u=
 
123456&f=';

$srcStrOnce='a=2011541224&k=AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP&e=0&t=1427786065&r=270494647&u=123456
 
&f=442d8ddf-59a5-4dd4-b5f1-e38499fb33b4';

$signStr = base64_encode(hash_hmac('sha1', $srcStr, $secretKey, true).$srcStr);

$signStrOnce=base64_encode(hash_hmac('sha1',$srcStrOnce,$secretKey, true).$srcStrOnce);

echo $signStr."\n"; 

echo $signStrOnce."\n";
```
这里得到的多次有效签名为:

```
NXogk/3r9yDHchVGhpEcglU99gFhPTIwMTE1NDEyMjQmaz1BS0lEMlprT1hGeURSS

FpSbGJQbzkzU010elZZNzlrcEFkR1AmZT0xNDMyOTcwMDY1JnQ9MTQyNzc4NjA2NS

ZyPTI3MDQ5NDY0NyZ1PTEyMzQ1NiZmPQ==
```
这里得到的单次有效签名为:

```
t/EBzsvcPx1aaB+V+Vm/RrRPGARhPTIwMTE1NDEyMjQmaz1BS0lEMlprT1hGeURSSFp

SbGJQbzkzU010elZZNzlrcEFkR1AmZT0wJnQ9MTQyNzc4NjA2NSZyPTI3MDQ5NDY0NyZ1PT

EyMzQ1NiZmPTQ0MmQ4ZGRmLTU5YTUtNGRkNC1iNWYxLWUzODQ5OWZiMzNiNA==
```
使用其它程序设计语言开发时, 可用上面示例中的原文进行签名验证, 得到的签名串与例子中的一致即可。
#### 1.2.4	使用签名串
删除文件只能使用单次有效签名，因此使用如下语法进行图片删除请求：

```
POST web.image.myqcloud.com/photos/v1/2011541224/123456/442d8ddf-59a5-4dd4-b5f1-e38499fb33b4/del  HTTP/1.1

Host: web.image.myqcloud.com

Authorization: t/EBzsvcPx1aaB+V+Vm/RrRPGARhPTIwMTE1NDEyMjQmaz1BS0lEMlprT1hGeURSS

FpSbGJQbzkzU010elZZNzlrcEFkR1AmZT0wJnQ9MTQyNzc4NjA2NSZyPTI3MDQ5NDY0NyZ1PTEyMzQ1NiZmP

TQ0MmQ4ZGRmLTU5YTUtNGRkNC1iNWYxLWUzODQ5OWZiMzNiNA==

```
### 1.3	签名适用场景
万象优图对签名的适用场景做了如下限制：

| 场景 | 适用签名 |
|---------|---------|
|查询	|不验证签名|
|下载（无防盗链）|不验证签名 |
|上传|	多次有效签名|
|下载（开启防盗链，不绑定资源）|多次有效签名|
|下载（开启防盗链，绑定资源）|多次有效签名|
|复制	|单次有效签名|
|删除|单次有效签名|
注：上表中，下载（开启防盗链，绑定资源）使用的单次签名只是绑定了资源，只能下载绑定的资源，但是次数不限。
### 1.4	签名样例下载
我们提供以下几种语言的签名样例代码下载： [php](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/doc/img-qcloud-php-sign-server-v1.0.2.zip), [python](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/doc/img-qcloud-python-sign-server-v1.0.2.zip),[ java](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/doc/img-qcloud-java-sign-server-v1.0.2.zip), [c++](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/doc/img-qcloud-cpp-sign-server-v1.0.0.zip), [nodejs](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/doc/img-qcloud-node-sign-server-v1.0.1.zip)

