## 1 基本架构及业务流程

### 1.1基本架构

数据安全是云存储的重中之重，为了保护开发者的数据安全，腾讯云·万象优图的上传、复制、删除和下载（如果设置了防盗链）服务需要鉴权签名；鉴权签名的生成需要用到SecretKey，所以签名的生成需要在可信任的环境中进行，绝不能在客户端进行，否则会带来密钥泄漏的风险，危害开发者数据。腾讯云·万象优图推荐使用以下的服务器架构设计：

![](//qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/fuwuqijiagou.png)

主要包括三个部分：

**1 腾讯云·万象优图**

提供高成功率、高可靠、高速的图片存储服务，以及强大的图像处理技术；

**2. 开发者服务器**

开发者服务器至少提供如下3个功能：

1)生成签名。签名的生成不能在终端上进行，否则会产生极大的安全隐患；
2)使用数据库管理用户信息、图片资源信息；
3)响应终端的业务请求；

另外，开发者服务器还可以直接与腾讯云·万象优图通信对图片进行管理操作。

**3. 终端**

通常既上传图片也下载图片。在展示图片前，通常先从开发者服务器获取要展示的图片信息，比如图片的url；在上传图片前，通常先从开发者服务器获取签名，然后带着签名请求腾讯云·万象优图。

### 1.2 业务流程

#### 1.2.1 图片上传

终端上传图片前先请求开发者服务器获取上传签名，然后再请求腾讯云·万象优图，腾讯云·万象优图会对上传签名进行验证，无效的签名会返回签名认证错误等信息。图片上传流程根据开发者是否设置回调可分为两种方案。

方案一：无回调设置

![](//qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/shangchuanliucheng1.png)

上传流程主要包括三个步骤：

1. 终端访问开发者服务器，获取签名（注意：签名的创建不能在终端上进行，否则可能会导致用户信息泄露等安全隐患）；
2. 终端上传图片，腾讯云·万象优图验证签名、存储图片，生成文件ID，URL等信息返回给终端；
3. 终端将图片信息和用户信息反馈给开发者服务器。

方案二：有回调设置

如果有设置回调，则上传完成时腾讯云·万象优图会自动向开发者服务器发起设置的回调url请求。

![](//qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/shangchuanliucheng2.png)

上传流程主要包括四个步骤：

1. 终端访问开发者服务器，获取签名（注意：签名的创建不能在终端上进行，否则可能会导致用户信息泄露等安全隐患）；
2. 终端上传图片，腾讯云·万象优图验证签名、存储图片，生成文件ID，URL等信息通过回调url传给开发者服务器；
3. 业务服务存储相应的图片信息，并将处理结果返还给腾讯云·万象优图；
4. 腾讯云·万象优图根据开发者服务器返回的处理信息返还给终端结果。

#### 1.2.2 图片下载

图片下载使用图片上传成功后返回的的下载url直接访问，即直接访问download_url。

如果设置了Token防盗链，则使用下载url加签名的方式直接访问，即：download_url?sign=[签名]

## 2 接入服务

根据开发者业务的现有情况可将服务接入分为两种类型：回源镜像和一般接入。其中回源镜像适用于开发者的历史图片没有存储在腾讯云·万象优图，而要使用腾讯云·万象优图的下载（和其他服务，如果开发者希望接入）服务；一般接入是指开发者没有或者不考虑历史图片，使用腾讯云·万象优图对图片进行上传、下载和其他操作。

>注：回源镜像可以用作开发者图片数据的灾备；也可以让开发者一键试用服务，方便快捷。

### 2.1 回源镜像

**2.1.1 注册账号**

前往[腾讯云·万象优图控制台](http://console.cloud.tencent.com/image/imgguide)注册账号。

>注：以下称图片空间为bucket。

**2.1.2 场景接入**

腾讯云·万象优图根据开发者的源站类型和所需服务，将回源镜像划分为四个场景。

>注意： 腾讯云·万象优图针对四个场景分别进行了优化，请根据自身的情况选择合适场景接入，获取最优的服务体验。

[场景一：使用万象优图下载，回源到其他云存储厂商](/doc/product/275/回源到其他云存储厂商)

[场景二：使用万象优图下载，回源到自己站点](/doc/product/275/回源到自己站点)

[场景三：使用万象优图上传和下载，历史图片回源到其他云存储厂商](/doc/product/275/历史数据回源到其他云存储厂商)

[场景四：使用万象优图上传和下载，历史图片回源到自己站点](/doc/product/275/历史数据回源到自己站点)

### 2.2 一般接入

由2.1.1 基本架构章节可知，开发者如需接入腾讯云·万象优图服务，为了保护数据的安全，开发者需要在自己开发者服务器上面部署鉴权服务；终端需要向开发者服务器请求的签名，然后进行相应的服务操作，例如进行图片的上传，复制，删除，下载等。

#### 2.2.1 接入流程

接入腾讯云·万象优图只需以下三步：

1 注册腾讯云·万象优图；

2 终端部署示例；

3 鉴权服务部署示例。

下面分别介绍终端部署简单示例，鉴权服务部署简单示例，以及终端和开发者服务器交互签名的过程。

>说明：
1. 文档中终端和开发者服务器的签名交互过程只是一个简单的例子，开发者需要根据自己业务需求开发交互过程。
2. 如果开发者想使用本文档提供的例子进行简单测试，请确保终端和服务端的项目信息一致，如项目ID，空间名称，SecretID和SecretKey等。

**2.2.1.1 注册腾讯云·万象优图**

1. 前往[腾讯云·万象优图控制台](http://console.cloud.tencent.com/image/imgguide)注册账号；如果已经注册账号，请跳过此步骤；

2. 在[腾讯云·万象优图控制台](http://console.cloud.tencent.com/image/bucket)创建一个图片空间，获取空间名称（bucket）和项目ID；如果已创建过图片空间，请跳过此步骤；

3. 在[腾讯云·万象优图控制台项目设置](http://console.cloud.tencent.com/image/project)中添加密钥，获取SecretID和SecretKey；如果已经添加过密钥，请跳过此步骤。

**2.2.1.2 终端部署示例**

腾讯云·万象优图提供了丰富的Restful API接口，开发者可以参考Restful API部署和开发终端。
同时腾讯云·万象优图还为开发者提供了功能丰富的移动端SDK，以及web端部署示例。开发者也可是使用移动端SDK开发自己的服务，下面简单介绍使用终端SDK部署服务的简单示例，开发者需要根据自身业务情况开发相应的代码：

[终端部署示例-Android](/doc/product/275/Android部署示例)

[终端部署示例-iOS](/doc/product/275/iOS部署示例)

[web端部署示例](/doc/product/275/web端部署示例)

移动端SDK的详细文档说明请参见[移动端SDK文档](/doc/product/275/SDK文档)。

**2.2.1.3 鉴权服务部署示例**

以下为鉴权服务部署的简单示例(使用了服务端SDK)，开发者可以简单参考，开发自身业务鉴权服务，并集成到自身服务器中：
>注意：下面的文档只是简单的示例，展示了服务端为终端提供签名的简单用法，开发者务必根据自身业务开发相应的鉴权服务逻辑，并集成到自身服务器中。

[鉴权服务部署示例-Java](/doc/product/275/Java鉴权服务部署示例)

[鉴权服务部署示例-PHP](/doc/product/275/PHP鉴权服务部署示例)

[鉴权服务部署示例-Python](/doc/product/275/Python鉴权服务部署示例)

[鉴权服务部署示例-Nodejs](/doc/product/275/Nodejs鉴权服务部署示例)

[鉴权服务部署示例-GO](/doc/product/275/GO鉴权服务部署示例)

如需使用服务端更多功能，请参见[服务端SDK文档](/doc/product/275/SDK文档#3.-.E6.9C.8D.E5.8A.A1.E5.99.A8sdk.E6.96.87.E6.A1.A3)。
## 3 历史数据迁移

在使用万象优图以前，您的图片数据可能存在服务器本地文件系统、分布式文件系统以及其他云存储等，我们提供迁移工具，方便您将这些历史图片迁移到万象，目前支持3种存储方式的迁移：
1.	图片在服务器本地存储，直接将某目录下的所有文件上传到万象优图。
2.	指定URL列表文件，文件中每一行是一张图片的URL。工具会下载列表文件中的每一张图片并上传到万象优图。
3.	指定七牛云存储的账号和空间名，迁移该指定空间中的所有文件或部分文件到万象优图。
本工具目前支持类Unix操作系统。推荐在Linux或Mac OS X下使用Python 2.7运行。

### 3.1	迁移工具下载地址

https://github.com/tencentyun/Cloud-Image-Migration-Tool 

### 3.2	迁移工具安装使用方法

从github上通过git获取，或者下载压缩包解压到linux服务器上，然后进入工具目录

```
cd Cloud-Image-Migration-Tool/bin
```

#### 3.2.1	启动迁移

运行start.sh脚本，工具会按照配置文件中的配置开始运行.启动前请[修改配置](#3.3-.E4.BF.AE.E6.94.B9.E9.85.8D.E7.BD.AE)，否则会运行失败。如果要迁移的文件较多，可后台运行，运行命令：

```
./start.sh &
```

上传完成后再次运行start.sh会重试失败的任务。

start.sh脚本首先扫描待上传的任务提交到任务列表，然后开始上传。如果第一个过程被打断，下次运行start.sh会重新扫描待上传的任务；如果第二个过程被打断，下次运行start.sh会继续上传。如果需要强制刷新任务列表请运行以下命令：

```
./start.sh -f &
```

#### 3.2.2	查看迁移进度

启动后可查看迁移状态，运行stat.sh脚本，会在屏幕上持续输出迁移状态，按Ctrl+c退出查看。

```
./stat.sh
```

该脚本输出内容如下图：

数字有三列，第一列：失败的文件数；第二列：成功迁移的文件数；第三列：要迁移的文件总数

![](//qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/lishishujuqianyijindu.png)

#### 3.2.3	停止迁移

若启动后想做配置调整或任何异常发生，可停止迁移，运行stop.sh。

```
./stop.sh
```

在迁移过程中运行stop.sh脚本停止迁移，这一过程可能需要等待几秒钟的时间以保证已经开始的任务正常结束并写入日志。如果需要强制停止，运行stop.sh -f。

停止迁移之后如果没有清空日志并且没有修改配置信息，再次启动迁移会继续上次的迁移任务，重试所有失败记录但已经迁移成功的文件不会重传。

#### 3.2.4	获取失败信息

获取迁移失败的文件列表及信息，运行view_failed.sh。

```
./view_failed.sh
```

#### 3.2.5	清除日志

若想开始一次新迁移，可清空之前的日志信息，运行clean.sh。请慎用，因为日志文件会作为增量断点续传的参考信息，删除后再执行相同任务所有文件会重新上传。

### 3.3	修改配置
 
配置文件为config.ini位于conf目录, 配置文件中section name和option name不区分大小写。

```
vi Cloud-Image-Migration-Tool/conf/config.ini
```

#### 3.3.1	迁移类型设置
设置migrate.type 为

Local  表示迁移linux本地文件系统的文件
URLList  表示迁移url列表文件中所有url指向的文件
Qiniu  表示迁移七牛某空间的文件

```
[MigrateInfo]
migrate.type = Local
```

**3.3.1.1	本地文件系统**

若迁移类型为Local，则需要配置上传的本地根目录位置，必须为绝对路径。上传后的file id不包含根目录。例如：

```
[Local]
local.image_root_path = /root/data/images/
```

迁移后图片的访问路径：

http: //上传的万象空间域名/图片相对于所配置的根目录的相对路径 

比如，设置的本地目录：/data/web/images 有一张图片路径为：/data/web/images/2015/07/17/abc.jpg，上传后访问路径：http: //上传的万象空间域名/2015/07/17/abc.jpg

#### 3.3.2	URL列表文件

若迁移类型为URLList，则需要配置URL列表文件的位置，必须为绝对路径。例如：

```
[URLList]
url.url_list_file_path = /data/url_list
```

迁移后图片的访问路径：

http: //上传的万象空间域名/原url的url路径 

比如，原url为http: //www .xxx.yyy .com/2015/07/17/abc.jpg，上传后访问路径：http: //上传的万象空间域名/2015/07/17/abc.jpg

>>注意：若原url中有参数，上传后的文件名是去掉参数后的，比如，原url为http:// www .xxx. yyy. com/2015/07/17/abc.jpg?width=1024&height=1024，上传后访问路径：http: //上传的万象空间域名/2015/07/17/abc.jpg

#### 3.3.3	七牛

若迁移类型为Qiniu，则需要配置七牛云存储账号相关信息。

qiniu.bucket填写被迁移的空间名；qiniu.domain为七牛域名，需要包含协议类型（如http:// ）； 若只迁移一部分则需要提供qiniu.start_offset和qiniu.total_num，qiniu.start_offset从0计；若空间开启了防盗链，需要在qiniu.referer中指定访问来源域名，同样需要包含协议类型（如http:// ）； 如果是私有空间，将qiniu.isprivate设置为True，否则设置为False。

```
[Qiniu]
[Qiniu]
qiniu.bucket = my_bucket_name
qiniu.AccessKey = _17terLxP-ZK7tma9jXgm7MuEOk72yP9OZBIP35G
qiniu.SecretKey = PFw6JivhTAdNKRojaguUkC6tlFHAI9SBrjVYdfya
qiniu.domain = http://abcde.com1.fg.glb.clouddn.com/
qiniu.referer = 
qiniu.isprivate = False
```

迁移后图片的访问路径：

http: //上传的万象空间域名/原七牛key 

比如，原图片下载路径为http:// 7x3m4e .com 1.z0.glb.clouddn.com /2015/07/17/abc.jpg， 上传后访问路径：http: //上传的万象空间域名/2015/07/17/abc.jpg

#### 3.3.4	万象优图账号信息

从万象优图图片空间中查看项目ID和空间名称，分别填写到appinfo.appid和appinfo.bucket；

从万象优图项目设置中查看Secret ID和Secret Key分别填写到appinfo.secretID和appinfo.secretKey。

![](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/wanxiangyoutuzhanghaoxinxi-1.png)

```
[AppInfo]
appinfo.appid = 
appinfo.secretID = 
appinfo.secretKey = 
appinfo.bucket =
```

#### 3.3.5	上传设置
Concurrency控制同时运行的上传进程数目，请根据上行带宽和机器配置适当调整该数值。必须提供一个大于0的整数。

db.commit.interval控制上传结果写回日志的时间间隔，单位为秒，应该提供一个合法的正整数或浮点数或正无穷（inf）。如果进程意外结束，未写回的日志将丢失。此值设置过小将严重影响性能，一般情况下使用默认值即可。

jobqueue.capacity、jobqueue.reload.threshold、buffer.size是控制任务队列和内存缓冲区的选项，一般情况下使用默认值即可。

```
[ToolConfig]
concurrency = 10
jobqueue.capacity = 2000
jobqueue.reload.threshold = 0.4
buffer.size = 100000
db.commit.interval = 3
```

fileid.ignore.if使工具在提交任务时忽略file id符合指定条件的任务。

fileid.ignore.unless使工具在提交任务时忽略file id不符合指定条件的任务。

error.ignore.if使工具在重试出错任务时忽略错误日志符合指定条件的任务。

以上三个选项若启用则应提供一个正则表达式，否则留空，语法参考[Python re Module Reference](https://docs.python.org/2/library/re.html)。如果同时提供了fileid.ignore.if和fileid.ignore.unless，并且某个file id同时符合两个正则表达式，那么它会被忽略。

如忽略OS X操作系统下的.DS_Store文件，不重试错误码为-1886的任务：

```
[Advanced]
fileid.ignore.if = .*.DS_Store
fileid.ignore.unless = 
error.ignore.if = .*code: -1886.*
```
