## 简介
本接口用于对用户上传的照片进行身份校验。根据用户的身份证号、姓名，将用户上传的图像与从公安部获得的图像进行人脸相似度对比。
人脸核身服务现已开放申请，您可以[点此进行申请](https://cloud.tencent.com/act/event/face-in.html)。

## 计费说明
请查看[计费说明](/document/product/460/6970)。


## 说明
| 概念     | 解释               |
| ------ | ---------------- |
| appid  | 项目ID, 接入项目的唯一标识 |
><font color="#0000cc">**注意：** </font>
 如果开发者使用的是 V1 版本，则 appid 为其当时生成的 appid。

## 调用URL
`http://service.image.myqcloud.com/face/idcardcompare`

## 请求包header
人脸核身接口采用 http 协议，支持指定图片 URL 和上传本地图片文件两种方式。
所有请求都要求含有下表列出的头部信息：

| 参数名            | 值                                        | 描述                                       |
| -------------- | ---------------------------------------- | ---------------------------------------- |
| Host           | service.image.myqcloud.com               | 服务器域名                                |
| Content-Length | 包体总长度                                    | 整个请求包体内容的总长度，单位：字节（Byte）                 |
| Content-Type   | application/json  或者  multipart/form-data | 根据不同接口选择                                 |
| Authorization  | 鉴权签名                                     | 用于[**鉴权**](/doc/product/460/6968)的签名 |

><font color="#0000cc">**注意：** </font>
 (1) 每个请求的包体大小限制为 6MB。
 (2) 所有接口都为 POST 方法。
 (3) 不支持 .gif 这类的动图。

## 请求参数
使用 image 则使用 multipart/form-data 格式，不使用 image 则使用 application/json 格式。

| 参数名           | 是否必须 | 类型     | 说明                                  |
| ------------- | ---- | ------ | ------------------------------------- |
| appid         | 必须   | string | 项目ID                                  |
| idcard_number | 必须   | string | 用户身份证号码                               |
| idcard_name   | 必须   | string | 用户身份证姓名                               |
| image         | 可选   | binary | 图片内容                                  |
| url           | 可选   | string | 图片的 image 和 url 只提供一个即可，如果都提供，只使用 url |
| session_id    | 可选   | string | 相应请求的 session 标识符，可用于结果查询               |

## 返回内容
| 字段              | 类型     | 说明                        |
| --------------- | ------ | ------------------------- |
| data.session_id | string | 相应请求的 session 标识符           |
| data.similarity | float  | 用户上传的图像与从公安部获取的带网纹图像的 face 相似度，取值范围[0.0, 100.0]，推荐相似度大于75.0时可判断为同一人，可根据具体场景自行调整阈值 |
| code            | int    | 错误码                       |
| message         | string | 错误描述                    |


## 示例
### 使用 url 的请求包:

```
POST /face/idcardcompare HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 187
Content-Type: application/json

{
  "appid":"123456",
  "idcard_number":"110110199909090909",
  "idcard_name":"张三",
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}
```

### 使用 image 的请求包:

```
POST /face/idcardcompare HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 735
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="idcard_number";

110110199909090909
----------------acebdf13572468
Content-Disposition: form-data; name="idcard_name";

张三
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--
```

### 回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 204
Content-Type: application/json

{
  "data":{
    "similarity":100.0,
    "session_id":"",
  },
  "code":0,
  "message":"OK"
}
```

## 错误码
| **错误码** | **含义**                   |
| ------- | ------------------------ |
| 3       | 错误的请求                    |
| 4       | 签名为空                     |
| 5       | 签名串错误                    |
| 6       | 签名中的 appid/bucket 与操作目标不匹配 |
| 9       | 签名过期                     |
| 10      | appid 不存在                 |
| 11      | secretid 不存在              |
| 12      | appid 和 secretid 不匹配        |
| 13      | 重放攻击                     |
| 14      | 签名校验失败                   |
| 15      | 操作太频繁，触发频控               |
| 16      | Bucket 不存在                |
| 21      | 无效参数                     |
| 23      | 请求包体过大                   |
| 107     | 鉴权服务不可用                  |
| 108     | 鉴权服务不可用                  |
| 213     | 内部错误                     |
| -4006   | 视频中自拍照特征提取失败             |
| -4007   | 视频中自拍照之间对比失败             |
| -4009   | Card 照片提取特征失败            |
| -4010   | 自拍照与Card照片相似度计算失败        |
| -4015   | 自拍照人脸检测失败                |
| -4016   | 自拍照解码失败                  |
| -4017   | Card 照片人脸检测失败             |
| -4018   | Card 照片解码失败               |
| -5001   | 视频无效                     |
| -5002   | 唇语失败                     |
| -5005   | 自拍照解析照片不足                |
| -5007   | 视频没有声音                   |
| -5008   | 声音识别失败                   |
| -5009   | 视频人脸检测失败，没有嘴或者脸          |
| -5010   | 唇动失败                     |
| -5011   | 活体检测失败(活体其他错误都归类到里面)     |
| -5012   | 视频中噪声太大                  |
| -5013   | 视频里的声音太小                 |
| -5014   | 活体检测 level 参数无效            |
| -5015   | 视频像素太低，最小 320*480         |
| -5801   | 请求缺少身份证号码或身份证姓名          |
| -5802   | 服务器内部错误，服务暂时不可用          |
| -5803   | 身份证姓名与身份证号码不一致           |
| -5804   | 身份证号码无效                  |
| -5805   | 用户未输入图像或者 url 下载失败         |
| -5806   | 身份证号码或者身份证姓名格式错误         |
| -5807   | 查询身份证信息错误         |

更多其他 API 错误码请看[**错误码说明**](/document/product/460/8523) 。









