## 个体创建
### 简介
创建一个 Person，并将 Person 放置到 group_ids 指定的组当中，不存在的 group_id 会自动创建。
### 接口形式
接口：`http://service.image.myqcloud.com/face/newperson`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
###  请求

**请求包的 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**
- 使用 image 则使用 multipart/form-data 格式；
- 使用非 image 则使用 application/json 格式

| 参数名         | 是否必须 | 类型            | 参数说明                                  |
| ----------- | ---- | ------------- | ------------------------------------- |
| APPID       | 必须   | String        | 项目 ID                                  |
| group_ids   | 必须   | Array(String) | 加入到组的列表                               |
| person_id   | 必须   | String        | 指定的个体 id                               |
| image       | 可选   | Binary        | 图片内容                                  |
| url         | 可选   | String        | 图片的 url ,  image 和 url 只提供一个即可,如果都提供,只使用url |
| person_name | 可选   | String        | 名字                                    |
| tag         | 可选   | String        | 备注信息                                  |

### 返回内容

| 字段              | 类型            | 说明               |
| --------------- | ------------- | ---------------- |
| data.session_id | String        | 相应请求的 session 标识符  |
| data.suc_group  | Int           | 成功被加入的 group 数量    |
| data.suc_face   | Int           | 成功加入的 face 数量      |
| data.person_id  | String        | 相应 person 的 id      |
| data.face_id    | String        | 创建所用图片生成的 face_id |
| data.group_ids  | Array(String) | 加入成功的组 id         |
| code            | Int           | 返回码              |
| message         | String        | 返回错误消息           |

### 示例

**使用 url 的请求包:**
```
POST /face/newperson HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 187
Content-Type: application/json

{
  "appid":"123456",
  "group_ids":[ "tencent", "qq" ],
  "person_id":"person0",
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}
```

**使用 image 的请求包:**
```
POST /face/newperson HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 735
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="group_ids[0]";

tencent
----------------acebdf13572468
Content-Disposition: form-data; name="group_ids[1]";

qq
----------------acebdf13572468
Content-Disposition: form-data; name="person_id";

person0
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 204
Content-Type: application/json

{
  "data":{
    "person_id":"person0",
    "suc_group":2,
    "suc_face":1,
    "session_id":"",
    "face_id":"1009550071676600319",
    "group_ids":["tencent", "qq"]
  },
  "code":0,
  "message":"OK"
}
```

## 删除个体
### 简介
删除一个 Person。
### 接口形式
接口：`http://service.image.myqcloud.com/face/delperson`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求

**请求包的 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json 或者 Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**

使用 application/json 格式

| 参数名       | 是否必须 | 类型     | 参数说明    |
| --------- | ---- | ------ | ------- |
| appid     | 必须   | String | 项目 ID    |
| person_id | 必须   | String | 待删除个体 ID |

### 返回内容

| 字段              | 类型     | 说明              |
| --------------- | ------ | --------------- |
| data.session_id | String | 相应请求的 session 标识符 |
| data.person_id  | String | 成功删除的 person_id  |
| data.deleted    | Int    | 成功删除的 Person 数量   |
| code            | Int    | 返回状态码           |
| message         | String | 返回错误消息          |

### 示例
**请求包:**
```
POST /face/delperson HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 66
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person0"
}
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 114
Content-Type: application/json

{
  "data":{
    "deleted": 1,
    "person_id": "person0",
    "session_id":""
  },
  "code":0,
  "message":"OK"
}
```

## 增加人脸
### 简介
将一组 Face 加入到一个 Person 中。一个 Person 最多允许包含 20 个 Face ；
><font color="#0000cc">**注意：** </font>
加入几乎相同的人脸会返回错误。
### 接口形式
接口：`http://service.image.myqcloud.com/face/addface`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json 或者 Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |
**请求包 http body**
- 使用 image 则使用 multipart/form-data 格式；
- 使用非 image 则使用 application/json 格式；

| 参数名       | 是否必须 | 类型            | 参数说明                                     |
| --------- | ---- | ------------- | ---------------------------------------- |
| appid     | 必须   | String        | 项目 ID                                     |
| person_id | 必须   | String        | 待增加人脸的个体 id                               |
| images    | 可选   | Array(Binary) | 图片内容                                     |
| urls      | 可选   | String        | 图片的 urls , images 和 urls 只提供一个就可以了,如果都提供,只使用 urls |
| tag       | 可选   | String        | 备注信息                                     |

### 返回内容

| 字段              | 类型            | 说明              |
| --------------- | ------------- | --------------- |
| data.session_id | String        | 相应请求的 session 标识符 |
| data.added      | Int           | 成功加入的 face 数量     |
| data.face_ids   | Array(String) | 增加的人脸 ID 列表       |
| data.ret_codes  | Array(Int)    | 每张图片增加人脸的返回码    |
| code            | Int           | 返回状态码           |
| message         | String        | 返回错误消息          |

### 示例
**使用 url 的请求包:**
```
POST /face/addface HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 191
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person0",
  "urls":[
    "http://test-123456.image.myqcloud.com/face1.jpg",
    "http://test-123456.image.myqcloud.com/face2.jpg"
  ]
}
```
**使用 image 的请求包:**
```
POST /face/addface HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 641
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="person_id";

person0
----------------acebdf13572468
Content-Disposition: form-data; name="images[0]"; filename="face1.jpg"
Content-Type: image/jpeg

yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
----------------acebdf13572468
Content-Disposition: form-data; name="images[1]"; filename="face2.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 168
Content-Type: application/json

{
  "data":{
    "added":2,
    "session_id":"",
    "face_ids":["1009550071676600319","109387462576600319"],
    "ret_codes":[0, 0]
  },
  "code":0,
  "message":"OK"
}
```
## 删除人脸
### 简介
删除一个 person 下的 face ，包括特征、属性和 face_id。
### 接口形式
接口：`http://service.image.myqcloud.com/face/delface`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json 或者 Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**
使用 application/json 格式

| 参数名       | 是否必须 | 类型            | 参数说明            |
| --------- | ---- | ------------- | --------------- |
| appid     | 必须   | String        | 项目 ID            |
| person_id | 必须   | String        | 待删除人脸的 person ID |
| face_ids  | 必须   | Array(String) | 删除人脸 id 的列表       |

### 返回内容

| 字段              | 类型            | 说明              |
| --------------- | ------------- | --------------- |
| data.session_id | String        | 相应请求的 session 标识符 |
| data.deleted    | Int           | 成功删除的 face 数量     |
| data.face_ids   | Array(String) | 成功删除的 face_id 列表  |
| code            | Int           | 返回状态码           |
| message         | String        | 返回错误消息          |

### 示例
**请求包:**
```
POST /face/delface HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 125
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person0",
  "face_ids":[
    "199d1efd19ce4ee67a7ec7655f859b1a"
  ]
}
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 150
Content-Type: application/json

{
  "data":{
    "deleted": 1,
    "face_ids":[
      "199d1efd19ce4ee67a7ec7655f859b1a"
    ],
    "session_id":""
  },
  "code":0,
  "message":"OK"
}
```

## 设置信息
### 简介
设置 Person 的 name 。
### 接口形式
接口： `http://service.image.myqcloud.com/face/setinfo`
请求方式： POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json 或者 Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**
使用 application/json 格式

| 参数名         | 是否必须 | 类型     | 参数说明        |
| ----------- | ---- | ------ | ----------- |
| appid       | 必须   | String | 项目 ID        |
| person_id   | 必须   | String | 相应 person 的 id |
| person_name | 可选   | String | 新的 name      |
| tag         | 可选   | String | 备注信息        |

### 返回内容

| 字段              | 类型     | 说明              |
| --------------- | ------ | --------------- |
| data.session_id | String | 相应请求的 session 标识符 |
| data.person_id  | String | 相应 person 的 id     |
| code            | Int    | 返回状态码           |
| message         | String | 返回错误消息          |

### 示例
**请求包:**
```
POST /face/setinfo HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 97
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person0",
  "person_name":"NicolasCage"
}
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 96
Content-Type: application/json

{
  "data":{
    "person_id": "person0",
    "session_id":""
  },
  "code":0,
  "message":"OK"
}
```

## 获取信息
### 简介
获取一个 Person 的信息, 包括 name , id , tag , 相关的 face , 以及 groups 等信息。
### 接口形式
接口：`http://service.image.myqcloud.com/face/getinfo`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**
使用 application/json 格式

| 参数名       | 是否必须 | 类型     | 参数说明     |
| --------- | ---- | ------ | -------- |
| appid     | 必须   | String | 项目 ID     |
| person_id | 必须   | String | 待查询个体的 ID |

### 返回内容

| 字段               | 类型            | 说明              |
| ---------------- | ------------- | --------------- |
| data.person_name | String        | 相应 person 的 name   |
| data.person_id   | String        | 相应 person 的 id     |
| data.face_ids    | Array(String) | 包含的人脸列表         |
| data.group_ids   | Array(String) | 包含此个体的组 id       |
| data.session_id  | String        | 相应请求的 session 标识符 |
| data.tag         | String        | 为此个体设置的备注信息     |
| code             | Int           | 返回状态码           |
| message          | String        | 返回错误消息          |

### 示例
**请求包:**
```
POST /face/getinfo HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 66
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person0"
}
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 293
Content-Type: application/json

{
  "data":{
    "person_id": "person0",
    "person_name": "NicolasCage",
    "face_ids": [
      "199d1efd19ce4ee67a7ec7655f859b1a",
      "19321efd19ce4ee67a7127655f85934a"
    ],
    "group_ids":[
      "tencent"
    ],
    "tag":"",
    "session_id":""
  },
  "code":0,
  "message":"OK"
}
```
## 获取组列表
### 简介
获取一个 APPID 下所有 group 列表。
### 接口形式
接口：`http://service.image.myqcloud.com/face/getgroupids`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包http body**
使用 application/json 格式

| 参数名    | 是否必须 | 类型     | 参数说明 |
| ------ | ---- | ------ | ---- |
| appid  | 必须   | String | 项目 ID |

### 返回内容

| 字段             | 类型            | 说明                 |
| -------------- | ------------- | ------------------ |
| data.group_ids | Array(String) | 相应 APPID 的 group_id 列表 |
| code           | Int           | 返回状态码              |
| message        | String        | 返回错误消息             |

### 示例
**请求包:**
```
POST /face/getgroupids HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 41
Content-Type: application/json

{
  "appid":"123456"
}
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 136
Content-Type: application/json

{
  "data":{
    "group_ids": [
      "tencent",
      "tencent-beijing",
      "tencent-shanghai"
]
  },
  "code":0,
  "message":"OK"
}
```
## 获取人列表
### 简介
获取一个组 Group 中所有 person 列表。
### 接口形式
接口：`http://service.image.myqcloud.com/face/getpersonids`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**
使用 application/json 格式

| 参数名      | 是否必须 | 类型     | 参数说明 |
| -------- | ---- | ------ | ---- |
| appid    | 必须   | String | 项目 ID |
| group_id | 必须   | String | 组 id  |

### 返回内容

| 字段              | 类型            | 说明            |
| --------------- | ------------- | ------------- |
| data.person_ids | Array(String) | 相应 person 的 id 列表 |
| code            | Int           | 返回状态码         |
| message         | String        | 返回错误消息        |

### 示例
**请求包:**
```
POST /face/getpersonids HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 65
Content-Type: application/json

{
  "appid":"123456",
  "group_id":"tencent"
}
```

**回包:**

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 120
Content-Type: application/json

{
  "data":{
    "person_ids": [
      "person0",
      "person1",
      "person2"
]
  },
  "code":0,
  "message":"OK"
}
```
## 获取人脸列表
### 简介
获取一个组 person 中所有 face 列表。
### 接口形式
接口：`http://service.image.myqcloud.com/face/getfaceids`
请求方式： POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |
**请求包 http body**
使用 application/json 格式

| 参数名       | 是否必须 | 类型     | 参数说明 |
| --------- | ---- | ------ | ---- |
| appid     | 必须   | String | 项目 ID |
| person_id | 必须   | String | 个体 id |

### 返回内容

| 字段            | 类型            | 说明          |
| ------------- | ------------- | ----------- |
| data.face_ids | Array(String) | 相应 face 的 id 列表 |
| code          | Int           | 返回状态码       |
| message       | String        | 返回错误消息      |

### 示例
**请求包:**
```
POST /face/getfaceids HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 66
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person1"
}
```
**回包:**
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 154
Content-Type: application/json

{
  "data":{
    "face_ids": [
      "1005338790489817087",
      "1005338790489817088",
      "1005338790489817089"
]
  },
  "code":0,
  "message":"OK"
}
```

## 获取人脸信息
### 简介
获取一个 face 的相关特征信息。
### 接口形式
接口：`http://service.image.myqcloud.com/face/getfaceinfo`
请求方式：POST

说明：该接口的费用可查看 [计费说明](/doc/product/460/6970)，按使用量进行月结。
### 请求
**请求包 http header**

| 参数名            | 值                                     | 描述                                   |
| -------------- | ------------------------------------- | ------------------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                            |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte）             |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                             |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/doc/product/460/6968) |

**请求包 http body**

使用 application/json 格式

| 参数名     | 是否必须 | 类型     | 参数说明 |
| ------- | ---- | ------ | ---- |
| appid   | 必须   | String | 项目 ID |
| face_id | 必须   | String | 人脸 id |

### 返回内容

| 字段             | 类型       | 说明     |
| -------------- | -------- | ------ |
| data.face_info | FaceItem | 人脸信息   |
| code           | Int      | 返回状态码  |
| message        | String   | 返回错误消息 |

FaceItem 说明

| 字段         | 类型     | 说明                                 |
| ---------- | ------ | ---------------------------------- |
| face_id    | String | 人脸标识                               |
| x          | Int    | 人脸框左上角 x                            |
| y          | Int    | 人脸框左上角 y                            |
| width      | Float  | 人脸框宽度                              |
| height     | Float  | 人脸框高度                              |
| gender     | Int    | 性别 [0(female)~100(male)]           |
| age        | Int    | 年龄 [0~100]                         |
| expression | Int    | 微笑[0(normal)~50(smile)~100(laugh)] |
| glass      | Bool   | 是否有眼镜 [true,false]                 |
| pitch      | Int    | 上下偏移[-30,30]                       |
| yaw        | Int    | 左右偏移[-30,30]                       |
| roll       | Int    | 平面旋转[-180,180]                     |

### 示例
**请求包:**
```
POST /face/getfaceinfo HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 76
Content-Type: application/json

{
  "appid":"123456",
  "face_id":"1005338790489817087"
}
```

**回包:**

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 313
Content-Type: application/json

{
  "data":{
    "face_info": {
      "face_id": "1005338790489817087",
      "x": 44,
      "y": 33,
      "height": 64.0,
      "width": 64.0,
      "pitch": 5,
      "roll": 0,
      "yaw": 6,
      "age": 37,
      "gender": 99,
      "glass": true,
      "expression": 6
}
  },
  "code":0,
  "message":"OK"
}
```

## 错误码说明

| **错误码** | **含义**                   |
| ------- | ------------------------ |
| 3       | 错误的请求                    |
| 4       | 签名为空                     |
| 5       | 签名串错误                    |
| 6       | 签名中的 APPID /存储桶与操作目标不匹配 |
| 9       | 签名过期                     |
| 10      |  APPID 不存在                 |
| 11      |  SecretId 不存在              |
| 12      |  APPID 和 SecretId 不匹配        |
| 13      | 重放攻击                     |
| 14      | 签名校验失败                   |
| 15      | 操作太频繁，触发频控               |
| 16      | 存储桶不存在                |
| 21      | 无效参数                     |
| 23      | 请求包体过大                   |
| 107     | 鉴权服务不可用                  |
| 108     | 鉴权服务不可用                  |
| 213     | 内部错误                     |
| -1101   | 人脸检测失败                   |
| -1102   | 图片解码失败                   |
| -1103   | 特征处理失败                   |
| -1104   | 提取轮廓错误                   |
| -1105   | 提取性别错误                   |
| -1106   | 提取表情错误                   |
| -1107   | 提取年龄错误                   |
| -1108   | 提取姿态错误                   |
| -1109   | 提取眼镜错误                   |
| -1200   | 特征存储错误                   |
| -1300   | 图片为空                     |
| -1301   | 参数为空                     |
| -1302   | 个体已存在                    |
| -1303   | 个体不存在                    |
| -1304   | 参数过长                     |
| -1305   | 人脸不存在                    |
| -1306   | 组不存在                     |
| -1307   | 组列表不存在                   |
| -1308   |  url 图片下载失败                |
| -1309   | 人脸个数超过限制                 |
| -1310   | 个体个数超过限制                 |
| -1311   | 组个数超过限制                  |
| -1312   | 对个体添加了几乎相同的人脸            |
| -1400   | 非法的图片格式                  |
| -1403   | 图片下载失败                   |

 
