## 简介
检测给定图片中的所有人脸( Face )的位置和相应的面部属性，位置包括(x, y, w, h)，面部属性包括性别( gender ), 年龄( age ), 表情( expression ), 魅力( beauty ), 眼镜( glass )和姿态 (pitch，roll，yaw )。
## 接口形式
接口：`http://service.image.myqcloud.com/face/detect`
## 请求
><font color="#0000cc">**注意：** </font>
使用 image 则使用 multipart/form-data 格式
使用非image 则使用 application/json 格式

| **参数名** | 是否必须 | 类型     | 参数说明                                     |
| ------- | ---- | ------ | ---------------------------------------- |
| appid   | 必须   | String | 项目 ID                                     |
| mode    | 可选   | Int    | 检测模式：0-所有人脸，1-最大的人脸                      |
| image   | 可选   | Binary | 图片内容                                     |
| url     | 可选   | String | 图片的 url ,  image 和 url 只提供一个就可以了,如果都提供,只使用 url |

## 返回内容

| 字段                | 类型              | 说明                      |
| ----------------- | --------------- | ----------------------- |
| data.session_id   | String          | 相应请求的 session 标识符，可用于结果查询 |
| data.image_width  | Int             | 请求图片的宽度                 |
| data.image_height | Int             | 请求图片的高度                 |
| data.face         | Array(FaceItem) | 检测出的人脸信息列表              |
| code              | Int             | 返回状态码                   |
| message           | String          | 返回错误消息                  |

FaceItem 说明

| 字段         | 类型     | 说明                                 |
| ---------- | ------ | ---------------------------------- |
| face_id    | String | 人脸标识                               |
| x          | Int    | 人脸框左上角 x                            |
| y          | Int    | 人脸框左上角 y                            |
| width      | Float  | 人脸框宽度                              |
| height     | Float  | 人脸框高度                              |
| gender     | Int    | 性别 [0(female)~100(male)]           |
| age        | Int    | 年龄 [0~100]                         |
| expression | Int    | 微笑[0(normal)~50(smile)~100(laugh)] |
| glass      | Bool   | 是否有眼镜 [true,false]                 |
| pitch      | Int    | 上下偏移[-30,30]                       |
| yaw        | Int    | 左右偏移[-30,30]                       |
| roll       | Int    | 平面旋转[-180,180]                     |
| Beauty     | Int    | 魅力[0~100]                          |

## 示例

### 使用 url 的请求包
```
POST /face/detect HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 123
Content-Type: application/json

{
  "appid":"123456",
  "mode":1,
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}
```
###  使用 image 的请求包
```
POST /face/detect HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 460
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="mode";

1
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--
```

### 回包
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 313
Content-Type: application/json

{
  "data":{
    "session_id": "",
    "image_height": 200,
    "image_width": 200,
    "face": [{
      "face_id": "1005338790489817087",
      "x": 44,
      "y": 33,
      "height": 64.0,
      "width": 64.0,
      "pitch": 5,
      "roll": 0,
      "yaw": 6,
      "age": 37,
      "gender": 99,
      "glass": true,
      "expression": 6
      "beauty": 80
}]
  },
  "code":0,
  "message":"OK"
}
```
