# 1. 说明

开发者使用功能之前，需要先注册腾讯云账号，并创建bucket，添加密钥。

# 2. 认证接口

认证接口采用http协议，POST方法。

协议头部

所有请求都要求含有下表列出的头部信息

| 参数名            | 值                                        | 描述                                       |
| -------------- | ---------------------------------------- | ---------------------------------------- |
| Host           | service.image.myqcloud.com               | 万象优图服务器域名                                |
| Content-Length | 包体总长度                                    | 整个请求包体内容的总长度，单位：字节（Byte）                 |
| Content-Type   | Application/json  或者  Multipart/form-data | 根据不同接口选择                                 |
| Authorization  | 鉴权签名                                     | 用于鉴权的签名，使用多次有效签名。[**详情**](https://cloud.tencent.com/doc/product/275/3805) |

 

## 2.1      身份认证

1) 接口
`http://service.image.myqcloud.com/auth/idcard`

2) 描述
认证提供的身份信息是否正确。

3) 参数

使用 application/json格式

| 参数名           | 是否必须 | 类型     | 参数说明        |
| ------------- | ---- | ------ | ----------- |
| appid         | 必须   | String | 项目ID        |
| bucket        | 必须   | string | 空间名称        |
| idcard_number | 必选   | string | 身份证号        |
| idcard_name   | 必选   | String | 姓名（UTF-8编码） |

4) 返回值说明

| 字段              | 类型     | 说明              |
| --------------- | ------ | --------------- |
| data.session_id | String | 相应请求的session标识符 |
| code            | Int    | 返回码             |
| message         | String | 返回错误消息          |

5) 样例

```
POST /auth/idcard HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 187
Content-Type: application/json

{
  "appid":"123456",
  "bucket":"test",
  "idcard_number":"110101xxxxxxxxxxxx",
  "idcard_name":"张三"
}
```

回包:

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 44
Content-Type: application/json

{
  "data":{
    "session_id":"",
  },
  "code":0,
  "message":"OK"
}
```

 

# 3.  返回码

| 错误码   | 含义                       |
| ----- | ------------------------ |
| 3     | 错误的请求                    |
| 4     | 签名为空                     |
| 5     | 签名串错误                    |
| 6     | 签名中的appid/bucket与操作目标不匹配 |
| 9     | 签名过期                     |
| 10    | appid不存在                 |
| 11    | secretid不存在              |
| 12    | appid和secretid不匹配        |
| 13    | 重放攻击                     |
| 14    | 签名校验失败                   |
| 15    | 操作太频繁，触发频控               |
| 16    | Bucket不存在                |
| 21    | 无效参数                     |
| 23    | 请求包体过大                   |
| 24    | 没有权限                     |
| 25    | 您购买的资源已用完                |
| 107   | 鉴权服务不可用                  |
| 108   | 鉴权服务不可用                  |
| 213   | 内部错误                     |
| -5803 | 身份证号码与姓名不匹配              |
| -5804 | 身份证号码无效                  |
| -5806 | 身份证号码或者姓名格式错误            |
| -5807 | 查询身份证信息失败                |

 

 
