## 简介
本接口用于对用户上传的图片进行鉴黄处理。开发者可以使用[用户体验平台](http://cloud.tencent.com/event/pd)体验智能鉴黄的效果（用户体验平台不需要注册账号）。

## 计费说明
请查看[计费说明](/document/product/460/6970)。


## 说明
| 概念     | 解释               |
| ------ | ---------------- |
| appid  | 项目ID, 接入项目的唯一标识 |
><font color="#0000cc">**注意：** </font>
 如果开发者使用的是 V1 版本，则 appid 为其当时生成的 appid。

## 调用URL
`http://service.image.myqcloud.com/detection/porn_detect`

## 请求包header
智能鉴黄接口采用 http 协议，支持上传多 URL 和多本地图片文件，每个请求最多支持 20 张图片或 url 。

| 参数名            | 值                                        | 描述                                       |
| -------------- | ---------------------------------------- | ---------------------------------------- |
| Host           | service.image.myqcloud.com               | 万象优图服务器域名                                |
| Content-Length | 包体总长度                                    | 整个请求包体内容的总长度，单位：字节（Byte）                 |
| Content-Type   | application/json | 标准 application/json                                 |
| Authorization  | 鉴权签名                                     | 用于[**鉴权**](/doc/product/275/3805)的签名 |

## 图片 URL 鉴黄
### 请求参数
使用 application/json 格式。



| 参数     | 是否必须 | 类型     | 说明      |
| ------ | ---- | ------ | ------- |
| appid  | 必须    | string | 业务 id    |
| url_list    | 必须    | string 数组 | 图片 url 列表 |

### 返回内容
| 字段          | 类型   | 说明           |
| ----------- | ------ | ------------ |
| result_list | json 数组 | 具体查询数据，内容见下表 |

**result_list（ json 数组）中每一项的具体内容**

| 字段      | 类型     | 说明           |
| ------- | ------ | ------------ |
| code    | int    | 错误码，0 为成功  |
| message | string | 错误描述     |
| url     | string | 当前图片的 url     |
| data    | object      | 具体查询数据，具体见下表 |

**data 字段具体内容：**

| 字段            | 类型     | 说明                                       |
| ------------- | ------ | ---------------------------------------- |
| result        | int    | 供参考的识别结果，0 正常，1 黄图，2 疑似图片                   |
| confidence    | double | 识别为黄图的置信度，范围 0-100；是 normal_score , hot_score , porn_score的综合评分 |
| normal_score  | double | 图片为正常图片的评分                               |
| hot_score     | double | 图片为性感图片的评分                               |
| porn_score    | double | 图片为色情图片的评分                               |
| forbid_status | int    | 封禁状态，0 表示正常，1 表示图片已被封禁（只有存储在万象优图的图片才会被封禁）  |

><font color="#0000cc">**注意：** </font></br> 1. 当 result=0 时，表明图片为正常图片；</br>2. 当 result=1 时，表明该图片是系统判定的 100% 为违禁的图片；如果该图片存储在万象优图，则会直接被封禁掉；</br>3. 当 result=2 时，表明该图片是疑似图片，即为黄图的可能性很大（目前 confidence 大于等于 83 小于 91 定为疑似图片）。


### 示例
#### 请求包

```
POST /detection/porn_detect HTTP/1.1
Authorization: FCHXddYbhZEBfTeZ0j8mn9Og16JhPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJiUkp3Sk5zbTN3V1lEeHN1JnQ9MTQ2ODQ3NDY2MiZyPTU3MiZ1PTAmYj10ZXN0YnVja2V0JmU9MTQ3MTA2NjY2Mg==
Host: service.image.myqcloud.com
Content-Length: 238
Content-Type: "application/json"

{
    "appid": 10000379,
    "url_list": [
        "http://www.bz55.com/uploads/allimg/140805/1-140P5162300-50.jpg",
        "http://img.taopic.com/uploads/allimg/130716/318769-130G60P30462.jpg"
    ]
}
```

#### 回包

```
{
    "result_list": [
        {
            "code": 0,
            "message": "success",
            "url": "http://www.bz55.com/uploads/allimg/140805/1-140P5162300-50.jpg",
            "data": {
                "result": 0,
                "forbid_status": 0,
                "confidence": 12.509,
                "hot_score": 87.293,
                "normal_score": 12.707,
                "porn_score": 0.0
            }
        },
        {
            "code": 0,
            "message": "success",
            "url": "http://img.taopic.com/uploads/allimg/130716/318769-130G60P30462.jpg",
            "data": {
                "result": 0,
                "forbid_status": 0,
                "confidence": 14.913,
                "hot_score": 99.997,
                "normal_score": 0.003,
                "porn_score": 0.0
            }
        }
    ]
}
```
## 图片文件鉴黄
图片文件鉴黄是使用 HTML 表单上传一个或多个文件，文件内容通过多重表单格式（ multipart/form-data ）进行编码。

### 请求参数
| 参数     | 是否必须 | 类型         | 说明                                       |
| ------ | ---- | ---------- | ---------------------------------------- |
| appid | 必须    | uint       | 业务 id                                     |
| image  | 必须    | image/jpeg | 图片文件，支持多个。参数名须为 “image[0]”、“image[1]”等，每张图片需指定 filename |

### 返回内容
| 字段          | 类型     | 说明           |
| ----------- | ------ | ------------ |
| result_list | json 数组 | 具体查询数据，内容见下表 |

**result_list（json数组）中每一项的具体内容**

| 字段       | 类型     | 说明                            |
| -------- | ------ | ----------------------------- |
| code     | int    | 服务器错误码，0 为成功                   |
| message  | string | 服务器返回的信息                      |
| filename | string | 当前图片的 filename，与请求包中 filename 一致 |
| data     | object | 具体查询数据，内容见下表                  |

**data 字段具体内容**

| 字段            | 类型     | 说明                                       |
| ------------- | ------ | ---------------------------------------- |
| result        | int    | 供参考的识别结果，0 正常，1 黄图，2 疑似图片                   |
| confidence    | double | 识别为黄图的置信度，范围 0-100 ；是 normal_score ,  hot_score ,  porn_score 的综合评分 |
| normal_score  | double | 图片为正常图片的评分                               |
| hot_score     | double | 图片为性感图片的评分                               |
| porn_score    | double | 图片为色情图片的评分                               |
| forbid_status | int    | 封禁状态，0 表示正常，1 表示图片已被封禁（只有存储在万象优图的图片才会被封禁）  |
><font color="#0000cc">**注意：** </font></br>1. 当 result=0 时，表明图片为正常图片；</br>2. 当 result=1 时，表明该图片是系统判定的违禁的图片；</br>3. 当 result=2 时，表明该图片是疑似图片，即为黄图的可能性很大（目前 confidence 大于等于 83 小于 91 定为疑似图片）。

### 示例
#### 请求包

```
POST /detection/ porn_detect HTTP/1.1
Content-Type:multipart/form-data;boundary=-------------------------acebdf13572468
Authorization:FCHXddYbhZEBfTeZ0j8mn9Og16JhPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJiUkp3Sk5zbTN3V1lEeHN1JnQ9MTQ2ODQ3NDY2MiZyPTU3MiZ1PTAmYj10ZXN0YnVja2V0JmU9MTQ3MTA2NjY2Mg==
Host: service.image.myqcloud.com
Content-Length: 61478

---------------------------acebdf13572468
Content-Disposition: form-data; name="appid";

10000379
---------------------------acebdf13572468
Content-Disposition: form-data; name="image[0]"; filename="1.jpg"
Content-Type: image/jpeg

<@INCLUDE *D:\185839ggh0oedgnog04g0b.jpg.thumb.jpg*@>
---------------------------acebdf13572468
Content-Disposition: form-data; name="image[1]"; filename="2.jpg"
Content-Type: image/jpeg

<@INCLUDE *D:\200132svnmybmhbmmgbmga.jpg.thumb.jpg*@>
---------------------------acebdf13572468
```

#### 回包
```
{
    "result_list": [
        {
            "code": 0,
            "message": "success",
            "filename": "1.jpg",
            "data": {
                "result": 1,
                "forbid_status": 0,
                "confidence": 96.853,
                "hot_score": 0.0,
                "normal_score": 0.0,
                "porn_score": 100.0
            }
        },
        {
            "code": 0,
            "message": "success",
            "filename": "2.jpg",
            "data": {
                "result": 0,
                "forbid_status": 0,
                "confidence": 41.815,
                "hot_score": 19.417,
                "normal_score": 0.077,
                "porn_score": 80.506
            }
        }
    ]
}
```

## 错误码
| **错误码** | **含义**                              |
| ------- | ----------------------------------- |
| 3       | 错误的请求                               |
| 4       | 签名为空                                |
| 5       | 签名串错误                               |
| 6       |  APPID /存储桶/ url 不匹配                 |
| 7       | 签名编码失败（内部错误）                        |
| 8       | 签名解码失败（内部错误）                        |
| 9       | 签名过期                                |
| 10      |  APPID 不存在                            |
| 11      |  SecretId 不存在                         |
| 12      |  APPID 不匹配                            |
| 13      | 重放攻击                                |
| 14      | 签名失败                                |
| 15      | 操作太频繁，触发频控                          |
| 16      | 内部错误                                |
| 17      | 未知错误                                |
| 200     | 内部打包失败                              |
| 201     | 内部解包失败                              |
| 202     | 内部链接失败                              |
| 203     | 内部处理超时                              |
| -1300   | 图片为空                                |
| -1308   | url 图片下载失败                           |
| -1400   | 非法的图片格式                             |
| -1403   | 图片下载失败                              |
| -1404   | 图片无法识别                              |
| -1505   | url 格式不对                             |
| -1506   | 图片下载超时                              |
| -1507   | 无法访问 url 对应的图片服务器                     |
| -5062   | url 对应的图片已被标注为不良图片，无法访问（专指存储于腾讯云的图片） |

更多其他 API 错误码请看[**错误码说明**](/document/product/460/8523) 。









