说明：该接口的费用可查看[文档](/document/product/460/6970)。按使用量进行月结。

## 1. 基本概念

| 概念        | 解释                                       |
| --------- | ---------------------------------------- |
| appid     | 项目ID, 用于唯一标识接入项目                         |
| group_id  | 个体(person)以组（group）的形式存储，一个组可以包含多个个体，一个个体也可以存在于多个组。group_id即用来标识group。组(group)没有专门的创建接口，创建个体(person)时，指定group_id则会自动创建。 |
| person_id | 人脸以个体（person）的形式存储，一个个体下可以存储多张人脸。person_id即用来标识person |
| face_id   | 标识每张人脸的id                                |

 **说明：**如果开发者使用的是V1版本，appid为其当时生成的appid

## 2. 描述

给定一个图片和一个Person，检查是否是同一个人。

**接口：**http://service.image.myqcloud.com/face/verify

**方法：**POST

Group信息管理接口如下：

| 接口                                       | 描述                                       |
| ---------------------------------------- | ---------------------------------------- |
| [创建个体](https://cloud.tencent.com/document/product/460/6896#1-.E4.B8.AA.E4.BD.93.E5.88.9B.E5.BB.BA) | 创建一个Person，并将Person放置到group_ids指定的组当中，不存在的group_id会自动创建。 |
| [删除个体](https://cloud.tencent.com/document/product/460/6896#2.-.E5.88.A0.E9.99.A4.E4.B8.AA.E4.BD.93) | 删除一个Person。                              |
| [增加人脸](https://cloud.tencent.com/document/product/460/6896#3.-.E5.A2.9E.E5.8A.A0.E4.BA.BA.E8.84.B8) | 将一组Face加入到一个Person中。注意，一个Face只能被加入到一个Person中。 一个Person最多允许包含20个Face；加入几乎相同的人脸会返回错误。 |
| [删除人脸](https://cloud.tencent.com/document/product/460/6896#4-.E5.88.A0.E9.99.A4.E4.BA.BA.E8.84.B8) | 删除一个person下的face，包括特征，属性和face_id。        |
| [设置信息](https://cloud.tencent.com/document/product/460/6896#5.-.E8.AE.BE.E7.BD.AE.E4.BF.A1.E6.81.AF) | 设置Person的name。                           |
| [获取信息](https://cloud.tencent.com/document/product/460/6896#6.-.E8.8E.B7.E5.8F.96.E4.BF.A1.E6.81.AF) | 获取一个Person的信息, 包括name, id, tag, 相关的face, 以及groups等信息。 |
| [获取组列表](https://cloud.tencent.com/document/product/460/6896#7.-.E8.8E.B7.E5.8F.96.E7.BB.84.E5.88.97.E8.A1.A8) | 获取一个AppId下所有group列表。                     |
| [获取人列表]()                                | 获取一个组Group中所有person列表。                   |
| [获取人脸列表](https://cloud.tencent.com/document/product/460/6896#9.-.E8.8E.B7.E5.8F.96.E4.BA.BA.E8.84.B8.E5.88.97.E8.A1.A8) | 获取一个组person中所有face列表。                    |
| [获取人脸信息](https://cloud.tencent.com/document/product/460/6896#10.-.E8.8E.B7.E5.8F.96.E4.BA.BA.E8.84.B8.E4.BF.A1.E6.81.AF) | 获取一个face的相关特征信息。                         |

> 限制说明：
>
> 1. 一个appid下建立的group_id数量限制为5000个。
> 2. 一个group_id下建立的person_id数量限制为10000个。
> 3. 一个person_id下建立的人脸数量限制为20个。
> 4. 每个请求的包体大小限制为1.5MB。
> 5. 不支持 .gif这类的动图。

## 3. 请求内容

使用image则使用 multipart/form-data格式

不使用image则使用 application/json格式

| 参数名       | 是否必须 | **类型****** | **参数说明******                             |
| --------- | ---- | ---------- | ---------------------------------------- |
| appid     | 必须   | String     | 项目ID                                     |
| person_id | 必须   | String     | 待验证的Person                               |
| image     | 可选   | Binary     | 图片内容                                     |
| url       | 可选   | String     | 图片的url, image 和url只提供一个就可以了,如果都提供,只使用url |

## 4. 返回内容

| **字段******      | **类型****** | **说明******              |
| --------------- | ---------- | ----------------------- |
| data.session_id | String     | 相应请求的session标识符，可用于结果查询 |
| data.confidence | float      | 两个人的相似度                 |
| data.ismatch    | Bool       | 两个输入是否为同一人的判断           |
| code            | Int        | 返回状态码                   |
| message         | String     | 返回错误消息                  |

## 5. 示例

### 5.1 使用url的请求包

```
POST /face/verify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 123
Content-Type: application/json

{
  "appid":"123456",
  "person_id":"person1",
  "url":"http://test-123456.image.myqcloud.com/test.jpg"
}
```

### 5.2 使用image的请求包

```
POST /face/verify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 460
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="person_id";

Person1
----------------acebdf13572468
Content-Disposition: form-data; name="image"; filename="test.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--

```

### 5.3 回包

```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 409
Content-Type: application/json

{
  "data":{
    "session_id":"session_id",
"confidence":90.0,
"ismatch":true
  },
  "code":0,
  "message":"OK"
}
```