## 1 签名与鉴权
腾讯移动服务通过签名来验证请求的合法性。开发者通过将签名授权给客户端，使其具备上传下载及管理指定资源的能力。
签名分为多次有效签名和单次有效签名。
多次有效签名：签名中绑定或者不绑定文件fileid，需要设置大于当前时间的有效期，有效期内此签名可多次使用，有效期最长可设置三个月。
单次有效签名：签名中绑定文件fileid，有效期必须设置为0，此签名只可使用一次，且只能应用于被绑定的文件。
具体适用场景参见签名适用场景。

## 2 签名算法
### 2.1	获取签名所需信息
生成签名所需信息包括项目ID（appid），空间名称（bucket,图片资源的组织管理单元），项目的Secret ID和Secret Key。获取这些信息的方法如下：
1) 登录 万象优图, 选择要管理的Bucket，进入【Bucket配置】页面；

![ID](https://mc.qcloudimg.com/static/img/af8930cfb9f5afcef34f73edaf9ab61b/Buckety+ID.png)
2) 如当前项目无Bucket，可添加后，获取项目ID（appid），空间名称（bucket）

3) 进入密钥管理页面，获取密钥：

![密钥](https://mc.qcloudimg.com/static/img/282f9231ea43d1590256f6583099208a/image.png)

### 2.2	拼接签名串
拼接多次有效签名串：
a=[appid]&b=[bucket]&k=[SecretID]&e=[expiredTime]&t=[currentTime]&r=[rand]&u=[userid]&f=[fileid]
拼接单次有效签名串：
a=[appid]&b=[bucket]&k=[SecretID]&e=[expiredTime]&t=[currentTime]&r=[rand]&u=[userid]&f=[fileid]
注意：多次有效签名串中fileid为可选参数，为空不绑定资源，例如上传签名和下载签名（不绑定资源）；不为空，则为绑定资源，例如绑定资源的下载，只能对绑定的资源进行下载。
签名串中各字段含义如下：

| 字段   | 解释                                       |
| ---- | ---------------------------------------- |
| a    | 开发者的项目ID，接入万象优图创建空间时系统生成的唯一标示项目的项目ID     |
| b    | 图片空间名称bucket                             |
| k    | 项目的Secret ID                             |
| e    | 签名的有效期，是一个符合UNIX Epoch时间戳规范的数值，单位为秒；单次签名时，e必须设置为0 |
| t    | 当前时间戳，是一个符合UNIX Epoch时间戳规范的数值，单位为秒，多次签名时，e应大于t |
| r    | 随机串，无符号10进制整数，用户需自行生成，最长10位              |
| u    | 历史遗留字段，请填写为0                             |
| f    | 资源存储的唯一标识，单次签名必填；多次签名选填，如填写则会验证与当前操作的文件路径是否一致。 |
注：
拼接单次有效签名的签名串时，过期时间e必须设置为0，以保证此签名只能只能针对固定资源且只能使用一次；
删除和复制文件必须使用单次有效签名；
上传必须使用多次有效签名；
具体适用场景参见[签名适用场景](#4-.E7.AD.BE.E5.90.8D.E9.80.82.E7.94.A8.E5.9C.BA.E6.99.AF)。
### 2.3	生成签名
1. 万象优图使用 HMAC-SHA1 算法对请求进行加密（SHA1算法加密后的输出必须是原始的二进制数据，否则签名失败）；
2. 签名串需要使用 Base64 编码。
   即生成签名的公式如下：
   SignTmp = HMAC-SHA1(SecretKey, orignal)
   Sign = Base64(SignTmp.orignal)
   其中SecretKey为项目密钥SecretKey，orignal为2.2节中拼接好的签名串，首先对orignal使用HMAC-SHA1算法进行签名，然后将orignal附加到签名结果的末尾，再进行Base64编码，得到最终的sign。
   注：此处使用的是标准的Base64编码，不是urlsafe的Base64编码，请注意。
## 3 PHP签名实例
本节介绍生成签名的算法实例，实例中使用PHP语言，如果开发者使用其他与开发，请使用对应的算法。
### 3.1 获取签名所需信息
获取得到的签名所需信息如下。
项目ID：10001290
空间名称（bucket）：tencentyun
Secret ID： AKIDgaoOYh2kOmJfWVdH4lpfxScG2zPLPGoK
Secret Key： nwOKDouy5JctNOlnere4gkVoOUz5EYAb
### 3.2 拼接签名串
拼接的多次有效签名串如下(不绑定资源)：
a=1252821871&b=tencentyun&k=AKIDgaoOYh2kOmJfWVdH4lpfxScG2zPLPGoK&e=1438669115&t=1436077115&r=11162&u=0&f=
拼接的多次有效签名串如下(绑定资源)：
a=1252821871&b=tencentyun&k=AKIDgaoOYh2kOmJfWVdH4lpfxScG2zPLPGoK&e=1438669115&t=1436077115&r=11162&u=0&f=tencentyunSignTest
拼接的单次有效签名串如下：
a=1252821871&b=tencentyun&k=AKIDgaoOYh2kOmJfWVdH4lpfxScG2zPLPGoK&e=0&t=1436077115&r=11162&u=0&f=tencentyunSignTest

```
$appid = "1252821871";
$bucket = "tencentyun";
$secret_id = "AKIDgaoOYh2kOmJfWVdH4lpfxScG2zPLPGoK";
$secret_key = "nwOKDouy5JctNOlnere4gkVoOUz5EYAb";
$expired = time() + 2592000;
$onceExpired = 0;
$current = time();
$rdm = rand();
$userid = "0";
$fileid = "tencentyunSignTest";

$srcStr = 'a='.$appid.'&b='.$bucket.'&k='.$secret_id.'&e='.$expired.'&t='.$current.'&r='.$rdm.'&u='
.$userid.'&f=';

$srcWithFile = 'a='.$appid.'&b='.$bucket.'&k='.$secret_id.'&e='.$expired.'&t='.$current.'&r='.$rdm.'&u='
.$userid.'&f='.$fileid;

$srcStrOnce= 'a='.$appid.'&b='.$bucket.'&k='.$secret_id.'&e='.$onceExpired .'&t='.$current.'&r='.$rdm
.'&u='.$userid.'&f='.$fileid;
```
### 3.3 生成签名
SHA1算法加密后的输出必须是原始的二进制数据，否则签名失败。

```
$signStr = base64_encode(hash_hmac('SHA1', $srcStr, $secret_key, true).$srcStr);

$srcWithFile = base64_encode(hash_hmac('SHA1', $srcWithFile , $secret_key, true).$srcWithFile );

$signStrOnce = base64_encode(hash_hmac('SHA1',$srcStrOnce,$secret_key, true).$srcStrOnce);

echo $signStr."\n"; 

echo $srcWithFile ."\n";

echo $signStrOnce."\n";
```
最终得到的多次有效签名为(不绑定资源)：

```
p2Y5iIYyBmQNfUvPe3e1sxEN/rZhPTEyNTI4MjE4NzEmYj10ZW5jZW50eXVuJms9QUtJRGdhb09ZaDJrT21KZldWZEg0bHBmeFNjRzJ6UExQR29LJmU9MTQzODY2OTExNSZ0PTE0MzYwNzcxMTUmcj0xMTE2MiZ1PTAmZj0=
```

最终得到的多次有效签名为(绑定资源)：

```
Tt9IYBG4j1TpO/9M6M9TokVJrKhhPTEyNTI4MjE4NzEmYj10ZW5jZW50eXVuJms9QUtJRGdhb09ZaDJrT21KZldWZEg0bHBmeFNjRzJ6UExQR29LJmU9MTQzODY2OTExNSZ0PTE0MzYwNzcxMTUmcj0xMTE2MiZ1PTAmZj10ZW5jZW50eXVuU2lnblRlc3Q=
```

单次有效签名为：

```
ewXflzgpQON2bmrX6uJ5Yr0zuOphPTEyNTI4MjE4NzEmYj10ZW5jZW50eXVuJms9QUtJRGdhb09ZaDJrT21KZldWZEg0bHBmeFNjRzJ6UExQR29LJmU9MCZ0PTE0MzYwNzcxMTUmcj0xMTE2MiZ1PTAmZj10ZW5jZW50eXVuU2lnblRlc3Q=
```


## 4. JAVA签名生成示例

```
/*
 * Copyright 2017, Tencent Inc
 * All rights reserved.
 * 
 * Created on 2017年9月12日
 */
package sign;

import java.util.Base64;
import java.util.Random;

import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;

public class Sign {

	/**
	 * 生成Authorization签名字段
	 * 
	 * @param appId
	 * @param secretId
	 * @param secretKey
	 * @param bucketName
	 * @param expired
	 * @return
	 * @throws Exception
	 */
	public static String appSign(long appId, String secretId, String secretKey, String bucketName,
			long expired) throws Exception {
		long now = System.currentTimeMillis() / 1000;
		int rdm = Math.abs(new Random().nextInt());
		String plainText = String.format("a=%d&b=%s&k=%s&t=%d&e=%d&r=%d", appId, bucketName,
				secretId, now, now + expired, rdm);
		byte[] hmacDigest = HmacSha1(plainText, secretKey);
		byte[] signContent = new byte[hmacDigest.length + plainText.getBytes().length];
		System.arraycopy(hmacDigest, 0, signContent, 0, hmacDigest.length);
		System.arraycopy(plainText.getBytes(), 0, signContent, hmacDigest.length,
				plainText.getBytes().length);
		return Base64Encode(signContent);
	}

	/**
	 * 生成base64编码
	 * 
	 * @param binaryData
	 * @return
	 */
	public static String Base64Encode(byte[] binaryData) {
		String encodedstr = Base64.getEncoder().encodeToString(binaryData);
		return encodedstr;
	}

	/**
	 * 生成hmacsha1签名
	 * 
	 * @param binaryData
	 * @param key
	 * @return
	 * @throws Exception
	 */
	public static byte[] HmacSha1(byte[] binaryData, String key) throws Exception {
		Mac mac = Mac.getInstance("HmacSHA1");
		SecretKeySpec secretKey = new SecretKeySpec(key.getBytes(), "HmacSHA1");
		mac.init(secretKey);
		byte[] HmacSha1Digest = mac.doFinal(binaryData);
		return HmacSha1Digest;
	}

	/**
	 * 生成hmacsha1签名
	 * 
	 * @param plainText
	 * @param key
	 * @return
	 * @throws Exception
	 */
	public static byte[] HmacSha1(String plainText, String key) throws Exception {
		return HmacSha1(plainText.getBytes(), key);
	}

}
```

## 5. 签名适用场景

万象优图对签名的适用场景做了如下限制：

| 场景                                    | 适用签名                                     |
| ------------------------------------- | ---------------------------------------- |
| 文件管理类（上传、查询、复制、删除等）                   | [查看文档](https://cloud.tencent.com/document/product/436/6054#.E5.93.AA.E4.BA.9B.E5.9C.BA.E6.99.AF.E9.9C.80.E8.A6.81.E7.94.A8.E5.88.B0.E7.AD.BE.E5.90.8D.EF.BC.9F) |
| 下载（无防盗链）                              | 不验证签名                                    |
| 下载（开启防盗链，绑定资源）                        | 多次有效签名                                   |
| 下载（开启防盗链，不绑定资源）                       | 多次有效签名                                   |
| 图片鉴黄                                  | 多次有效签名                                   |
| OCR识别（身份证识别、名片识别）                     | 多次有效签名                                   |
| 人脸识别（人脸检测与分析、五官定位、人脸比对与验证、人脸检索、人脸核身等） | 多次有效签名                                   |
| 图片标签                                  | 多次有效签名                                   |

