腾讯云•优图人脸识别通过签名来验证请求的合法性。开发者通过将签名授权给客户端，使其具备上传下载及管理指定资源的能力。签名分为多次有效签名和单次有效签名：

多次有效签名：签名中不绑定文件fileid，需要设置大于当前时间的有效期，有效期内此签名可多次使用，有效期最长可设置三个月。

单次有效签名：签名中绑定文件fileid，有效期必须设置为0，此签名只可使用一次，且只能应用于被绑定的文件。

## 1 申请密钥
1.登录[腾讯云项目密钥管理](https://console.cloud.tencent.com/capi/project)页面
2.点击新建密钥
3.选择需要生成密钥的项目

## 2 生成签名

签名生成后放入http请求的头部,并以Authorization为key；签名的生成，推荐使用我们提供的各语言签名函数，我们提供以下几种语言的签名样例代码下载：

| 开发语言 | github 地址 | 下载 |
|---------|---------|---------|
| PHP | https://github.com/TencentYouTu/php_sdk | [点击下载](https://mc.qcloudimg.com/static/archive/fd63523a1fdfca73badcba9696810135/php_sdk-master.zip) |
| Python | https://github.com/TencentYouTu/python_sdk | [点击下载](https://mc.qcloudimg.com/static/archive/c7e9e4f950e82da770fc2f03d238e413/python_sdk-master.zip) |
| C++ | https://github.com/TencentYouTu/Cplusplus_sdk | [点击下载](https://mc.qcloudimg.com/static/archive/f0828bfa8f6ddaa5ddc863f90b8bfdf0/Cplusplus_sdk-master.zip) |

如果用户要自己实现签名算法，以人脸检测接口说明如下：

人脸检测接口的URL为`http://api.youtu.qq.com/youtu/api/facedetect`

授权需要AppID、SecretID和SecretKey；这里假设分别是：
        
```
AppID =2011541224
SecretID= AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP
SecretKey=ckKU7P4FwB4PBZQlnB9hfBAcaKZMeUge
```

### 2.1 拼接有效签名串

```
u=10000&a=2011541224&k=AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP&e=1
432970065&t=1427786065&r=270494647&f=
```

v为API版本

u为开发者业务系统的用户标识

a为用户的AppID

k为用户的SecretID

t为当前时间戳，是一个符合UNIX Epoch时间戳规范的数值，单位为秒

e为此签名的凭证有效期，是一个符合UNIX Epoch时间戳规范的数值，单位为秒, e应大于t, 生成的签名在 t 到 e 的时间内 都是有效的. 如果是0, 则生成的签名只有再t的时刻是有效的

r为随机串，无符号10进制整数，用户需自行生成，最长10位

f为空

拼接有效签名串的结果,下文称之为orignal

### 2.2 生成签名串

腾讯优图开放平台 使用 HMAC-SHA1 算法对请求进行签名。签名串需要使用 Base64 编码。

根据签名方法Sign= Base64(HMAC-SHA1(SecretKey, orignal) + original)，其中orignal为上一步拼接好的签名串，对orignal使用HMAC-SHA1算法进行签名，然后将orignal附加到签名结果的末尾，再进行Base64编码，得到最终的sign。 注：此处使用的是标准的Base64编码，不是urlsafe的Base64编码。 

以 PHP 语言为例,其他语言参见SDK下载链接。

```
$SecretID = 'AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP';
$secretKey = 'ckKU7P4FwB4PBZQlnB9hfBAcaKZMeUge';
$orignal='u=10000&a=2011541224&k=AKID2ZkOXFyDRHZRlbPo93SMtzVY79kpAdGP&e=1432970065&t=1427786065&r=270494647&f=';
$signStr = base64_encode(hash_hmac('sha1', $srcStr, $secretKey, true).$srcStr);
echo $signStr."\n";
```

使用其它程序设计语言开发时, 可用上面示例中的原文进行签名验证, 得到的签名串与例子中的一致即可。
## 3 使用签名串

以PHP语言为例, 使用如下语法进行人脸检测请求：

```
// 需要检测的人脸图片数据
$image = file_get_contents('test.jpg');
// 请求数据,是JSON格式的, 文件等二进制数据 需要转换成 base64 编码
$post_data = json_encode(
array(
"app_id" =>  2011541224,
"image" =>  base64_encode($image),
));
// 生成的签名 添加在请求头部的 Authorization 字段里面
$req = array(
'url' => 'http://http://api.youtu.qq.com/youtu/api/facedetect?v=v1&u=10000&a=2011541224',
'method' => 'post',
'timeout' => 10,
'data' => $post_data,
'header' => array(
'Authorization: '.$sign,
),
);
// 向服务端发送请求
$rsp  = Http::send($req);
```
Http::send为SDK里面定义的方法，具体参见示例
