## 表
EasyCount 系统处理的基本单元是“表”，也就是说需要有明确的 schema 定义的结构化数据。不过相对于传统数据库的表中的字段定义，EasyCount 中的表支持 map，list，struct 以及 binary 等复杂数据类型。根据数据表的功能，EasyCount 系统中的表分为四种，流水表、维表、结果表、临时表。
- 流水表是一组（无穷）元素的集合。流水表上的每个元素都属于同一个 schema。每个元素都和逻辑时间有关，即流包含了元组和时间的双重属性。流水表与传统数据表不同，传统数据表的计算是针对整张表数据进行的，而流水表数据的计算只针对当前时间的数据进行的，最多针对截止到当前时间的所有数据进行计算。流水表数据的统计是实时进行的，根据我们大多数应用需求场景，流水表一般都是按照某个小的时间粒度进行数据统计的，例如 10 s，1 min，5 min 等。因此，EasyCount 系统在进行实时计算的时候，要求数据中必须有一个时间字段作为协调。如果数据中确实没有时间字段，那么 EasyCount 系统就按照接收到数据的时间进行协调。流水表是 EasyCount 实时计算系统的重要数据源,目前系统支持的流水表有 kafka 和 hippo。
- 维表是指静态数据表。用户在实际应用过程中往往需要新增或更改配置需求。所以流水表中的信息是不完全的，在实际的统计中需要关联一些配置信息，之后再进行数据统计。EasyCount 系统将这类数据表抽象为维表，维表数据一般存储在 KV 系统中。如果维表数据量较小，也可以存储到 DB，甚至以配置文件的方式抽象为内存表，直接从内存中关联。维表目前支持以下几种：hbase、MySQL。
- 结果表是用来存储计算结果的表。结果表可以是类似 kafka、hippo 的流水表，	也可以是类似 hbase 的 KV 表，还可以是类似 MySQL 的 db。具体的计算结果流向由业务根据计算结果的数据量及使用情况做权衡。
- 临时表是供计算逻辑临时使用的表。当多组计算逻辑使用同一结构的数据集时可以将该数据集使用 WITH 关键字定义为临时表。
## 窗口
窗口（window）是流处理中解决事件的无边界性和流动性的一种重要手段，它把事件流在某一时刻变成静态的视图，以便进行类似数据库表的各种查询操作。EasyCount 系统中的窗口需要和聚合函数配合使用。传统 SQL 对于聚合函数的定义都是针对整张数据表进行的，然而对于实时计算，数据是流式进入的，聚合统计只能做到对当前某个时间段的数据进行。因此这里定义了聚合窗口（AGGR INTERVAL）的概念，是指进行数据聚合所采用的时间粒度。假设聚合窗口为 60 s，那就表示每一分钟进行一次聚合计算，聚合计算的结果是针对这 1 分钟数据进行的。这里提到时间窗口，那么这个时间是按照什么标准进行协调的呢，默认情况下，如果不使用 coordinate by 子句的话，系统按照接收到数据时的系统时间进行协调，如果用户指定了 coordinate by 子句的话，就按照用户指定的字段进行协调。注意，用户指定的字段必须是一个毫秒数，如果不是的话可以通过函数转化为毫秒数。
EasyCount SQL 窗口有三种类型，聚合窗口、滑动窗口和累加窗口。累加窗口和滑动窗口，这两个窗口和聚合窗口一样是两个聚合时间粒度。不过这里要求累加窗口和滑动窗口必须是聚合窗口的整数倍。
1）普通聚合：和传统聚合函数一致，对每个聚合窗口进行一次聚合计算。
2）累加聚合：在累加窗口内的每个聚合窗口进行一次聚合计算，不过计算的数据是针对从累加窗口起始直到当前聚合窗口的聚合值。如下图所
示：
![累加窗口聚合](//mc.qcloudimg.com/static/img/5b4ec6524ed5bbbe359846539c543d4b/image.png)
3）滑动窗口聚合：在每个聚合窗口结束的时候计算，从当前聚合窗口向前推到滑动窗口大小内的数据进行聚合计算。如下图所示：
![滑动窗口聚合](//mc.qcloudimg.com/static/img/6542dd76b821b3b17fbf6c77161cbeaa/image.png)
累加聚合和滑动窗口聚合的具体实现是比较耗费资源的，因此一般累加窗口和滑动窗口不要比聚合窗口大太多。但是在某些场景下，统计任务又无法实现，因此提供了一个新的全局累加功能（ACCUGLOBAL）。这个功能是一个累加聚合功能，区别是启动这个功能以后，所有的聚合函数都是被设置为累加功能，并且同一条子查询中的滑动窗口聚合的功能被关闭。
## 表达式
表达式是符号和运算符的一种组合。EasyCount 解析引擎处理表达式以获取单个值。简单表达式可以是常量、变量或者函数，可以用运算符将两个或者多个简单表达式联合起来构成更复杂的表达式。
