## 登录流程图
![1](//mc.qcloudimg.com/static/img/53daad8ba9074c63c1115135dc62ab50/image.png)
>**注意：**
>在用户登录流程中，获取 api ticket 请求的 user_id 为必填参数，type 为 NONCE。

## 详细步骤
### 获取 access token
URL：`https://ics.webank.com/ems-abac/oauth2/access_token`
方法：推荐使用 get

| 请求参数：name | comment | value |
|---------|---------|---------|
| app_id | 分配的 app_id  | 由云客服平台分配 |
|secret |app_id 的密钥 |由云客服平台分配 |
| grant_type  | 授权类型   | client_credential  |
|version  |版本号  |1.0.0  |
响应：
```
{
	"code":"0","msg":"请求成功",
	"transactionTime":"20151022043831",
	"access_token":"accessToken_string",
	"expire_time":"1445496039972",
	"expire_in":"7200"
}
```
>**注意：**
>1. code 不是 0 是表示获取失败，可以根据 code 和 msg 字段定位和调试。
>2. expire_time 为 access_token 失效的绝对时间戳，单位毫秒。 
>3. expire_in 为 access_token 的最大生存时间，单位秒。 
>4. 修改 secret 之后，该 app_id 生成的 access_token 和 ticket 都失效。 

### 获取 api ticket
ticket 用于对请求数据签名或加密。
URL：`https://ics.webank.com/ems-abac/oauth2/api_ticket`
方法：推荐使用 get
请求参数：

| name | comment | value |
|---------|---------|---------|
| app_id | 分配的 app_id  | 由云客服平台分配 |
|access_token |app_id 的访问令牌 |见 2.1 |
| type  | ticket 类型   | NONCE   |
|version  |版本号  |1.0.0  |
|user_id   |当前使用用户的唯一标识   | <br/>  |
响应：

```
{
	"code":"0",
	"msg":"请求成功",
	"transactionTime":"20151022044027", 
	"tickets":[
		{"value":"ticket_string",
		"expire_in":"120"，
		"expire_time":"1445496039972"}
	]
｝
```
>**注意：**
>1. code 不是 0 是表示获取失败，可以根据 code 和 msg 字段定位和调试。 
>2. 不同的 type 的 ticket 在 List 中依次排列 
>3. expire_in 为 ticket 的最大生存时间，单位秒 
>4. expire_time 为 ticket 失效的绝对时间戳，单位毫秒 
>5. access_token 失效时，该 access_token 生成的 ticket 都失效 

### 生成签名（sign）
1. 生成一个 32 位的随机字符串 nonceStr（登录时也要用到），将 app_id、user_id、version 连同 ticket、nonceStr 两个参数进行字典序排序 
2. 将排序后的所有参数字符串拼接成一个字符串进行 SHA1 编码 
3. SHA1 编码后的 40 位字符串作为签名（sign）
4. 示例代码及用法 
签名代码：

```
public static String sign(List<String> values, String ticket) {
	if (values == null) {
		throw new NullPointerException("values is null");
	}
	
	values.removeAll(Collections.singleton(null));// remove null 
	values.add(ticket);
	java.util.Collections.sort(values);

	StringBuilder sb = new StringBuilder();
	for (String s : values) {
		sb.append(s);
	}
	return Hashing.sha1().hashString(sb, Charsets.UTF_8).toString().toUpperCase();
}
```

>**注意：**
>Hashing 使用的的是 com.google.common.hash.Hashing，版本是 guava-18.0

用法：首先获取 token 和 ticket 再用 ticket 对数据进行签名
```
String accessToken = client.getAccessToken();//http请求 S
tring ticket = client.getTicket(accessToken); //http请求 
String sign = SignUtils.sign(data, ticket); 
```
**实例：** 
请求参数：
```
appId = 10000005 
userId= LsjijIWJIjiWJIWJ9WJ 
nonceStr = 98765sddv21 (实际使用中应为32位) 
version = 1.0.0 
ticket = QIHuhuiwhieWQ 
```
字典排序后的参数为： 
[1.0.0,10000005, 987654321, LsjijIWJIjiWJIWJ9WJ, QIHuhuiwhieWQ] 
拼接后的字符串为： 
1.0.010000005987654321LsjijIWJIjiWJIWJ9WJQIHuhuiwhieWQ 
计算 SHA1 得到： 
CA99CB951F1A3E17C35263CE97DA906AA6EFCB1F 
该字串就是最终生成的签名，不区分大小写。 
### 登录
详细请见 SDK 接入说明
附录2：通用响应码列表
```
(0, "请求成功"), 
(999999, "服务内部错误"), 
(400100, "不合法的请求"), 
(400101, "不合法的 APPID"), 
(400102, "不合法的 OPENID"), 
(400103, "不合法或过期的refresh token"), 
(400104, "不合法或过期的access token"), 
(400105, "不合法或过期的code"), 
(400106, "服务器拒绝访问此接口"), 
(400107, "身份验证不通过"), 
(400108, "不合法的grant tpye"), 
(400201, "ticket不存在"), 
(400210, "签名不正确"), 
(400211, "uri不正确") 
```