## 简介
计算两个 Face 的相似性以及五官相似度。
## 接口形式
接口：`http://service.image.myqcloud.com/face/compare`

说明：该接口的费用可查看 [计费说明](/document/product/641/12397)，按使用量进行月结。
## 请求

**请求包的 http header**

| 参数名            | 值                                     | 描述                       |
| -------------- | ------------------------------------- | ------------------------ |
| Host           | service.image.myqcloud.com            | 万象优图服务器域名                |
| Content-Length | 包体总长度                                 | 整个请求包体内容的总长度，单位：字节（Byte） |
| Content-Type   | Application/json或者Multipart/form-data | 根据不同接口选择                 |
| Authorization  | 鉴权签名                                  | 鉴权签名，详见 [签名与鉴权](/document/product/641/12409)|

**请求包 http body**
><font color="#0000cc">**注意：** </font>
>使用 image 则使用 multipart/form-data 格式。
>使用非 image 则使用 application/json 格式。

| 参数名    | 是否必须 | 类型     | 参数说明                                     |
| ------ | ---- | ------ | ---------------------------------------- |
| APPID  | 必须   | String | 项目 ID                                    |
| imageA | 可选   | Binary | A 图片内容                                   |
| imageB | 可选   | Binary | B 图片内容                                   |
| urlA   | 可选   | String | A 图片的 url , image 和 url 只提供一个就可以了,如果都提供,只使用url |
| urlB   | 可选   | String | B 图片的 url , image 和 url 只提供一个就可以了,如果都提供,只使用 url |

## 返回内容

| 字段              | 类型     | 说明                          |
| --------------- | ------ | --------------------------- |
| data.session_id | String | 相应请求的 session 标识符           |
| data.similarity | float  | 两个 face 的相似度                |
| data.fail_flag  | Int    | 标志失败图片，1 为第一张，2 为第二张（失败时返回） |
| code            | Int    | 返回码                         |
| message         | String | 返回错误消息                      |

## 示例

### 使用 url 的请求包

```
POST /face/identify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 123
Content-Type: application/json

{
  "appid":"123456",
  "urlA":"http://test-123456.image.myqcloud.com/testA.jpg",
  "urlB":"http://test-123456.image.myqcloud.com/testB.jpg"
}
```
### 使用 image 的请求包

```
POST /face/identify HTTP/1.1
Authorization: FCHXdPTEwMDAwMzc5Jms9QUtJRGVRZDBrRU1yM2J4ZjhRckJi==
Host: service.image.myqcloud.com
Content-Length: 460
Content-Type: multipart/form-data;boundary=--------------acebdf13572468

----------------acebdf13572468
Content-Disposition: form-data; name="appid";

123456
----------------acebdf13572468
Content-Disposition: form-data; name="imageA"; filename="testA.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468
Content-Disposition: form-data; name="imageB"; filename="testB.jpg"
Content-Type: image/jpeg

xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
----------------acebdf13572468--
```

### 回包
```
HTTP/1.1 200 OK
Connection: keep-alive
Content-Length: 109
Content-Type: application/json

{
  "data":{
    "similarity":100.0,
    "session_id":""
  },
  "code":0,
  "message":"OK"
}
```
## 错误码说明

| **错误码** | **含义**                  |
| ------- | ----------------------- |
| 3       | 错误的请求                   |
| 4       | 签名为空                    |
| 5       | 签名串错误                   |
| 6       | 签名中的 APPID /存储桶与操作目标不匹配 |
| 9       | 签名过期                     |
| 10      |  APPID 不存在                 |
| 11      |  SecretId 不存在              |
| 12      |  APPID 和 SecretId 不匹配        |
| 13      | 重放攻击                     |
| 14      | 签名校验失败                   |
| 15      | 操作太频繁，触发频控               |
| 16      | 存储桶不存在                |
| 21      | 无效参数                     |
| 23      | 请求包体过大                   |
| 107     | 鉴权服务不可用                  |
| 108     | 鉴权服务不可用                  |
| 213     | 内部错误                     |
| -1101   | 人脸检测失败                   |
| -1102   | 图片解码失败                   |
| -1103   | 特征处理失败                   |
| -1104   | 提取轮廓错误                   |
| -1105   | 提取性别错误                   |
| -1106   | 提取表情错误                   |
| -1107   | 提取年龄错误                   |
| -1108   | 提取姿态错误                   |
| -1109   | 提取眼镜错误                   |
| -1200   | 特征存储错误                   |
| -1300   | 图片为空                     |
| -1301   | 参数为空                     |
| -1302   | 个体已存在                    |
| -1303   | 个体不存在                    |
| -1304   | 参数过长                     |
| -1305   | 人脸不存在                    |
| -1306   | 组不存在                     |
| -1307   | 组列表不存在                   |
| -1308   |  url 图片下载失败                |
| -1309   | 人脸个数超过限制                 |
| -1310   | 个体个数超过限制                 |
| -1311   | 组个数超过限制                  |
| -1312   | 对个体添加了几乎相同的人脸            |
| -1400   | 非法的图片格式                  |
| -1403   | 图片下载失败                   |


更多其他 API 错误码请看[**错误码说明**](/document/product/641/12410) 。
