## 关键词检索服务

关键词检索服务，可以帮助您从语音文件中检索出业务关注的词语。您可以同时提交最多 200 个关键词，服务会在语音文件中检索关注的关键词，并给时间偏移量和置信度。相比于使用语音转文字服务后进行关键词的匹配，关键词检索服务具备更优的效率和更高的关键词召回率。适合应用于客服语音质检、APP 音频审核、直播鉴黄等场景。

##  对象存储 + 关键词检索服务

### 技术原理
技术框架对应四个主要的流程：
1) 首先需要在智能语音控制台创建关键词检索服务模板，选择输入 Bucket 及请求响应方式（写入对象存储或者回调通知）。
2) 用户上传语音文件到腾讯云对象存储 COS 输入源 Bucket。
2) COS 回调语音数据给关键词检索服务，触发语音自动检索。
3) 如果响应方式是写入对象存储，那么关键词检索服务将检索结果，即文本文件上传到 COS 目的 Bucket。
4) 如果响应方式是回调通知，那么会通过回调方式，将检索结果传送给用户。
对象存储 COS + 关键词检索整体技术框架示意图如下：
![1](https://mc.qcloudimg.com/static/img/4269c37ec3464f3b9b36172310861142/guanjianci.png)
### 检索结果回调
当关键词检索服务完成识别后，如果响应方式为回调方式，结果会通过 HTTP POST 请求的形式通知到用户，用户需要在自身业务服务器上搭建服务接收回调。

####  请求结构
关键词检索服务通过回调接口形式将识别结果回调通知客户，接口 Body 各字段说明如下：

| 字段         |  类型          | 说明      | 
| ------------- | ------------- | ---------- |
| code |  Int32 | 任务状态，0：成功；其他：失败 | 
| message |  String | 成功或者失败原因文字描述 | 
| requestId |Unit64 | 请求 ID，与后台任务 ID 一一对应 | 
| APPID |  Unit64 | 腾讯云应用 ID |
| projecteId |Unit64 | 腾讯云项目 ID |
| cosAppId | Unit64 | 用户 COS 业务 ID |
| audioBucket | String | 用户 COS 的 bucket 名称|
| audioUrl | String | 语音下载 url |
| text | String | 关键词检索的结果文本 |
| audioTime |  double | 语音总时长 |

>**注意：**
>为了防止某些字段中，出现诸如 “&” 等特殊字符，导致解包失败，所有字段的 value 值都将进行 url_encode 之后发送给业务服务器。业务服务器获取 value 之后，需要先对 value 进行 url_decode 以获取原始 value 值。

#### 用户返回结果

用户业务服务器在接收到关键词检索服务发起的 HTTP POST 回调请求后，需要按照如下约定，返回结果：

| 参数名称 | 类型 | 说明 |
|---------|---------|---------|
|   code |  Int   |   服务器错误码，0 为成功，其他值代表失败  |
|  message   |  String   |  失败原因说明，比如业务服务器过载。 如果用户返回失败，会间隔一段时间重新通知    |

#### 示例
接口样例如下所示：
```
POST http://xx.yy.com/ code=code&message=message&requestId=requestId &appid=appid& projectid = projectid & cosAppid=cosAppid&audioBucket=audioBucket&audioUrl = audioUrl &text=text& audioTime = audioTime
```
关键词检索服务发起请求，收到请求后，用户侧需要以 json 格式回以响应：
```
{
  "code" : 0, 
  "message" : "成功"
}
```

