签名本质上是一个加密的字符串，加密字符串的原文由多个参数按照一定规则拼接而成，再利用加密算法对字符串进行加密处理生成签名。腾讯云的鉴权系统对签名进行验证，签名有效，则允许用户访问智能语音服务，若签名无效，则返回 Authorization 错误消息。本文详细介绍生成签名的流程，并提供了签名示例。

## 获取签名所需信息

生成签名时，用户需要提前获取以下信息：腾讯云应用 ID（APPID），腾讯云项目 ID（ProjectId），安全凭证 SecretId 和 SecretKey。其中APPID、 SecretId 和 SecretKey可以在官网控制台获取。如下图：
![1](//mc.qcloudimg.com/static/img/0727c55969eabe8d2b0aba7b0e0e796c/image.png)

## 生成签名串

### 参数排序

首先对 URL 中所有请求参数按参数名做字典序升序排列，所谓字典序升序排列，直观上就如同在字典中排列单词一样排序，按照字母表或数字表里递增顺序的排列次序，即先考虑第一个“字母”，在相同的情况下考虑第二个“字母”，依此类推。

### 拼接请求字符串

此步骤生成请求字符串。

将上一步排序好的请求参数格式化成 “参数名称” = “参数值” 的形式，然后将格式化后的各个参数用 “&” 拼接在一起。其中，“参数值”为原始值而非 URL 编码后的值。

### 拼接签名原文字符串

此步骤生成签名原文字符串。
签名原文字符串由以下几个参数构成：
1) 请求方法：支持 POST 和 GET 方式，这里使用 POST 请求，注意方法为全大写。
2) 请求主机：智能语音服务为 ``aai.qcloud.com``。
3) 请求路径：以语音识别为例，请求路径为 /asr/v1/appid。
4) 请求字符串：即上一步生成的请求字符串。

签名原文串的拼接规则为：

请求方法(大写) + 请求主机 + 请求路径 + ? + 请求字符串

拼接结果则为：
```
POSTaai.qcloud.com/asr/v1/appid?请求字符串 
```

### 生成签名串

此步骤生成签名串。
对上一步中获得的签名原文字符串，先以 SecretKey 作为算法的 key 进行 HMAC-SHA1 进行加密，然后对密文进行 Base64 编码，获得最终的签名串。

## 签名示例

假如，以某语音识别子服务为例，该服务的 URL 请求参数各字段说明和示例数值如下所示。注意，这里的参数名称、参数数值、APPID 只是示例，用户根据具体服务及子服务的 URL 请求构成生成签名。

| 参数名称| 类型   | 数值|
| --- | --- | ---|
| param_a | uint| 0 |
| param_b | uint| 1 |
| param_c | uint |2 |
| param_d | uint |3 |

这里以< appid > = 1252077802，为例拼接签名原文，则拼接的签名原文为：
```
POSTaai.qcloud.com/asr/v1/1252077802?param_a=0&param_b=1&param_c=2
```
对原文进行加密处理：
```
Base64Encode(HmacSha1(签名原文, SecretKey)) 
```
最终得到签名串。