# 快速搭建移动应用传输服务

## 背景

&nbsp; &nbsp; 移动互联网时代，APP作为移动互联网服务的基础设施，往往需要上传和下载大量的数据，数据的安全性和可靠性都给开发者带来了不少的麻烦。现在开发者可以将数据存储相关的问题交给[腾讯云COS服务](https://cloud.tencent.com/product/cos)，而自己只需要关心自己应用的业务逻辑即可，减少了很多的工作量。

&nbsp; &nbsp; 本文主要介绍如何快速搭建一个基于COS的应用传输服务，将应用数据的上传下载交给腾讯云COS服务，只有自己的业务和临时密钥的生成和管理走用户服务器。


## 架构

**整体架构图如下所示：**

![cos接入cam框架图](http://mc.qcloudimg.com/static/img/b1e187a9ec129ffc766c07a733ef4dd6/image.jpg)

下面对图中的4个组成部分进行简要介绍：

- 应用APP：即为用户手机上的APP。
- COS：[腾讯云对象存储](https://cloud.tencent.com/product/cos)，负责存储APP上传的数据。
- CAM：[腾讯云访问管理](https://cloud.tencent.com/product/cam)，用于生成COS的临时密钥。
- 应用服务器：用户自己的后台服务器，这里用于向CAM请求临时密钥，并返回给应用APP。

## 步骤

1. 应用向用户的应用服务器发送一个获取临时密钥的请求。

  用户APP在向COS发送请求时，必须通过密钥对请求进行签名（[具体签名算法](https://cloud.tencent.com/document/product/436/7778)），直接将用户的永久密钥放在终端上会存在很大的泄密风险，因此必须将您的永久密钥放在您的应用服务器上，然后由应用服务器向腾讯云CAM申请临时密钥，并最终返回给终端对请求进行签名。

2. 应用服务器收到请求后，向CAM申请临时密钥。
 
 我们认为用户的应用服务器是可信任的，可以直接配置用户的永久密钥用于向CAM申请临时密钥。同时，在服务端您可以配置临时密钥的有效期以及策略（Policy）。

3. CAM返回临时密钥给应用服务器。
4. 应用服务器返回临时密钥给应用APP。
  
  我们对数据的返回格式没有做具体的要求，这里建议直接返回CAM的JSON数据即可。
 
5. 应用APP向COS发送请求（如上传文件等）。

  应用APP获取到临时密钥后，通过我们的SDK可以很容易的对请求进行签名，来使用我们的COS服务。
  


## 示例

### 搭建一个应用服务器

本文中的示例采用python编写，您可以在[这里下载](http://rickenwang-1253653367.cosgz.myqcloud.com/resources/signer-release.zip)，根目录下有config.py目录，可以来配置以下参数：

```
class Config(object):

    def __init__(self):
        pass

    # 用户昵称，非必选
    NAME = "WANG"
    # 策略
    POLICY = COMMON_POLICY
    # 临时证书有效期
    DURATION_SECOND = 1800
    # 用户的secret id
    SECRET_ID = "你的secret id"
    # 用户的secret key
    SECRET_KEY = "你的secret key"
```

示例中提供的是一个有账户下所有资源读写权限的策略，如果您想配置更细化的策略，请参考[CAM COS相关案例](https://cloud.tencent.com/document/product/598/11083)。

**返回的JSON数据解析**

```
{
    "code":0,"message":"","codeDesc":"Success",
    "data":
    {
        "credentials":
        {
            "sessionToken":"42f8151428b3960b1226f421b8f271c6242ad02c3",
            "tmpSecretId":"AKIDtd9QSGWBIDuMaYFp57tSmrhJgohLtvpT",
            "tmpSecretKey":"ZfV5PVLvFLCvPefPt76qKYXIo56tSmrg"
        },
        "expiredTime":1508400619
    }
}
```


下面详细介绍如何在腾讯云CVM ubuntu上搭建一个简单的临时密钥服务。

**第一步：登录腾讯云CVM**

&nbsp; &nbsp; 购买CVM示例后，可以直接在控制台用浏览器登录，或者终端直接ssh登录。

**第二步：ubuntu环境下配置python开发环境**

```
sudo apt-get update
sudo apt-get install python-dev python-pip python-virtualenv
```
**第三步：下载源码并解压**

```
wget http://rickenwang-1253653367.cosgz.myqcloud.com/resources/signer-release.zip
unzip signer-release.zip
```
下载后直接解压，解压后需要修改根目录下的```secret_key```和```secret_id```配置，具体值可以在控制台上查询。

**第四步：激活virtualenv环境并进行配置**

- 激活virtualenv环境

```
cd 到flask项目目录
vitualenv venv
source venv/bin/activate
```
- 配置环境

```
pip install gunicorn
pip install flask
pip install flask-script
```

**第五步：用supervisor管理服务**

```
pip install supervisor
echo_supervisord_conf > supervisor.conf
vi supervisor.conf
```
在<code>supervisor.conf</code>文件的底部添加

```
[program:manage]
command=./venv/bin/gunicorn -w4 -b0.0.0.0:5000 manage:app    
directory=./                                             
startsecs=0   
stopwaitsecs=0    
autostart=false                                                                        
autorestart=false                                                             
stdout_logfile=./log/gunicorn.log                          
stderr_logfile=./log/gunicorn.err                     
```

最后使用如下命令启动服务：

```
supervisord -c supervisor.conf
supervisorctl -c supervisor.conf start manage
```

应用服务器启动后，直接用浏览器访问 <code>http://ip:5000/sign</code> 地址，如果返回了临时密钥JSON字符串，则说明应用服务器临时密钥服务正常运行。

> 这里访问时ip请修改为自己服务器的ip或者域名，默认的端口是5000，可以自己在supervisor.conf文件中修改。 

### 应用APP接入应用服务器临时密钥服务 

&nbsp; &nbsp; 若您对腾讯云COS服务有一些基本的了解，那么您可以很容易的使用我们COS XML终端SDK，并将您的应用服务器的临时密钥服务接入进来，下面以Android为例：

> 您在使用我们的SDK前，需要了解一些基本的名词术语，如appid，bucket，secret id，secret key等，术语说明参见[这里](https://cloud.tencent.com/document/product/436/7751)。

**一共分为三步**：

第一步：定义<code>MySessionCredentialProvider</code>类继承抽象类<code>BasicLifecycleCredentialProvider</code>，并实现其fetchNewCredentials()方法，具体如下：

```

public class MySessionCredentialProvider extends BasicLifecycleCredentialProvider {

    @Override
    protected QCloudLifecycleCredentials fetchNewCredentials() throws QCloudClientException {
        
        SessionQCloudCredentials credentials;
        String tempSecretId = "";
        String tempSecretKey = "";
        String sessionToken = "";
        long expireTime;
        
        // 1、访问应用服务器获取临时密钥api，获取临时密钥JSON字符串
        // ...
        
        
        // 2、解析JSON字符串，初始化tempSecretId, tempSecretKey, sessionToken, expiredTime四个参数
        // ...
        
        
        // 3、返回SessionQCloudCredentials
        return new SessionQCloudCredential(tempSecretId, tempSecreKey, sessionToken, expireTime);
        
    }

}

```

第二步：用<code>MySessionCredentialProvider</code>来初始化<code>CosXmlService</code>即可。

```
// 您的账户信息
String appid = "对象存储 的服务APPID";
String region = "存储桶 所在的地域";

// 创建 CosXmlServiceConfig 对象
CosXmlServiceConfig serviceConfig = new CosXmlServiceConfig.Builder()
       .setAppidAndRegion(appid, region)
       .build();

// 初始化CosXmlService
CosXmlService cosXmlService = new CosXmlService(getApplicationContext(), cosXmlServiceConfig,
                    new MySessionCredentialProvider());
 
```
第三步：现在您就可以通过<code>cosXmlService</code>对象的各种接口来访问COS服务了，下面以简单上传为例：

```
String bucket = "存储桶名称";
String cosPath = "远端路径，即存储到cos上的绝对路径"; //格式如 cosPath = "/test.txt";
String srcPath = "本地文件的绝对路径"; // 如 srcPath = Environment.getExternalStorageDirectory().getPath() + "/test.txt";
long signDuration = 600; //签名的有效期，单位为秒

PutObjectRequest putObjectRequest = new PutObjectRequest(bucket, cosPath, srcPath);

putObjectRequest.setSign(signDuration,null,null);

/*
 * 设置进度显示
 * 实现QCloudProgressListener.onProgress(long progress, long max)方法，
 * progress已上传的大小， max表示文件的总大小
 */
putObjectRequest.setProgressListener(new QCloudProgressListener() {

    @Override
    public void onProgress(long progress, long max) {
        float result = (float) (progress * 100.0/max);
        Log.w("TEST","progress =" + (long)result + "%");
    }
});

//使用同步方法上传
try {
    PutObjectResult putObjectResult = cosXmlService.putObject(putObjectRequest);
    Log.w("TEST","success: " + putObjectResult.accessUrl);
    
    } catch (CosXmlClientException e) {
	   //抛出异常
       Log.w("TEST","CosXmlClientException =" + e.toString());
    } catch (CosXmlServiceException e) {
	   //抛出异常
       Log.w("TEST","CosXmlServiceException =" + e.toString());
}

```


更详细的SDK使用说明请参见：
[COS XML Android SDK](https://cloud.tencent.com/document/product/436/11238)、[COS XML IOS SDK](https://cloud.tencent.com/document/product/436/11280)。


