## 适用场景

您可以直接发起请求获取 COS 中的对象，获取对象支持以下功能：

- 获取完整的单个对象：直接发起 GET 请求即可获取完整的对象数据。
- 获取单个对象的部分内容：可在 GET 请求中传入 `Range` 请求头部，支持检索一个特定的字节范围。不支持检索多个范围。

对象的元数据将会作为 HTTP 响应头部随对象内容一同返回，GET 请求支持使用 URL 参数的方式覆盖响应的部分元数据值，例如 `Content-Dispositon` 的响应值。支持修改的响应头部包括：

- Content-Type
- Content-Language
- Expires
- Cache-Control
- Content-Disposition
- Content-Encoding

##使用方法

### 使用 REST API

您可以直接使用 REST API 发起一个获取对象请求，可参考 [GET Object 文档说明](https://cloud.tencent.com/document/product/436/7753)。

### 使用 Java SDK

COS 的 Java SDK 中提供了此方法，可参考 [Java SDK 接口文档 GET Object 部分](https://cloud.tencent.com/document/product/436/12263#get-object)。

#### 步骤说明

1. 初始化客户端 cosclient
2. 执行 XXX 方法获取数据流，需要提供存储桶名称和对象键名称
3. 执行 XXX 方法将获取的数据流保存为本地文件

#### 代码示例

以下代码演示了简单获取对象的步骤：

```java
AmazonS3 s3Client = new AmazonS3Client(new ProfileCredentialsProvider());        
S3Object object = s3Client.getObject(
                  new GetObjectRequest(bucketName, key));
InputStream objectData = object.getObjectContent();
// Process the objectData stream.
objectData.close();
```

`GetObjectRequest` 支持指定要从对象检索的数据字节范围，以下代码演示了指定字节的方法：

```java
AmazonS3 s3Client = new AmazonS3Client(new ProfileCredentialsProvider());        

GetObjectRequest rangeObjectRequest = new GetObjectRequest(
		bucketName, key);
rangeObjectRequest.setRange(0, 10); // retrieve 1st 11 bytes.
S3Object objectPortion = s3Client.getObject(rangeObjectRequest);

InputStream objectData = objectPortion.getObjectContent();
// Process the objectData stream.
objectData.close();
```

检索对象时还可以用 `ResponseHeaderOverrides` 对象并设置相应的请求属性来替换响应头部值，以下是该方法的示例：

```java
GetObjectRequest request = new GetObjectRequest(bucketName, key);
            
ResponseHeaderOverrides responseHeaders = new ResponseHeaderOverrides();
responseHeaders.setCacheControl("No-cache");
responseHeaders.setContentDisposition("attachment; filename=testing.txt");

// Add the ResponseHeaderOverides to the request.
request.setResponseHeaders(responseHeaders);
```

### 使用 Python SDK

#### 步骤说明

#### 代码示例

### 使用 JavaScript SDK

#### 步骤说明

#### 代码示例

### 使用 PHP SDK

#### 步骤说明

#### 代码示例

### 使用 C++ SDK

#### 步骤说明

#### 代码示例