缓存过期配置是指配置 CDN 加速节点在缓存您的业务内容时遵循的一套过期规则。

CDN 节点上缓存的用户资源都面临“过期”问题。若资源处于未过期状态，当用户请求到达节点后，节点会将此资源直接返回给用户，提升获取速度；当资源处于过期状态（即超过了设置的有效时间），此时用户请求会由节点发送至源站，重新获取内容并缓存至节点，同时返回给用户。

腾讯云 CDN 支持各维度的缓存时间设置、支持自定义优先级调整、支持 cache 继承策略（高级缓存配置）。合理的配置缓存时间，能够有效的提升命中率，降低回源率，节省您的带宽。

## 配置说明
登录 [CDN 控制台](https://console.cloud.tencent.com/cdn)，选择左侧菜单栏的【域名管理】，单击您所要编辑的域名右侧的【管理】。
![](https://mc.qcloudimg.com/static/img/f2f50e0d81eb0a8c0dcb61d2ee37e6c9/manage.png)
单击【缓存配置】，您可以看到 **缓存过期配置** 模块。
![](https://mc.qcloudimg.com/static/img/920146d5571474dd223d2daa8578e2d5/cache.png)

### 默认配置
在域名接入时，默认配置如下：
- 自有源域名接入：所有文件默认 30 天缓存过期时间，常规动态文件（如.php .jsp .asp .aspx）默认缓存过期时间为0，对此类动态文件请求会直接回源。
- COS 源域名接入：所有文件默认 30 天缓存过期时间。
- 默认关闭高级缓存过期设置。

### 自定义配置
> **配置须知**：
> 1. 配置缓存时间时可填入多项，每项用“;”隔开，内容区分大小写。
> 2. 文件类型必须是以“.”开头的文件后缀，如“.jpg”。文件夹类型必须以“/”开头，不能以“/”结尾，如“/12345/test”。
> 3. 缓存时间设置最大值不能超过365天，如果设置为“0”，则表示不缓存。
> 4. 设置全路径文件缓存规则时，仅支持“*”匹配某一类型文件，暂时不支持其他正则匹配。
> 5. 设置全路径文件缓存规则时，暂不支持以“/”结尾的首页类型的缓存设置。

单击【新增缓存配置】可以添加缓存配置，您可以根据自身业务需求，在默认配置上添加缓存时间配置，CDN 支持三种方式的缓存过期时间设置：
#### 1. 按文件类型设置缓存过期时间
您可以填充文件类型后缀，根据类型来设置缓存时间，如下所示。
![](https://mc.qcloudimg.com/static/img/02a73594ebfd16c27e9efc9f27ac20ed/cache-filetype.png)
若您添加的缓存配置为：
> .jpg;.png 300秒

则设置完成后，域名下所有匹配 .jpg 或 .png 的图片资源，在节点的缓存有效时间均为 300 秒。
#### 2. 按文件夹设置缓存过期时间
您可以填充文件夹路径，根据文件夹来设置缓存时间，如下所示。
![](https://mc.qcloudimg.com/static/img/5f6eef99f07eefbe019fc8b3ffceba70/cache-file.png)
若您添加的缓存配置为：
> /test;/test2 300秒

则设置完成后，假设域名为 ```www.test.com```，则 ```www.test.com/test/``` 和 ```www.test.com/test2/``` 两个路径下的所有资源，在节点的缓存有效时间均为 300 秒。
#### 3. 全路径文件设置缓存过期时间
您可以为某一具体文件设置缓存时间，如下所示。
![](https://mc.qcloudimg.com/static/img/3c483784cf3ad9ceda121ca53dc18119/cache-path.png)
若您添加的缓存配置为：
> /test/1.jpg 300秒

则设置完成后，假设域名为 ```www.test.com```，则该资源 ```www.test.com/test/1.jpg``` 缓存时间为 300 秒。
您也可以为某一类具体文件设置缓存时间，如下所示。
![](https://mc.qcloudimg.com/static/img/5c177f66d230e93c2654461523a391b2/cache-path2.png)
若您添加的缓存配置为：
> /test/*.jpg 300秒

则设置完成后，假设域名为 ```www.test.com```，则 ```www.test.com/test/``` 路径下所有 jpg 格式的资源缓存时间均为 300 秒。

### 优先级
#### 优先级说明
当设置了多条缓存策略时，相互之间会有重复，配置项列表底部优先级高于顶部优先级。假设某域名配置了如下缓存配置：
> 所有文件 30天
> .php .jsp .aspx 0秒
> .jpg .png .gif 300秒
> /test/*.jpg 400秒
> /test/abc.jpg 200秒

假设域名为 ```www.test.com```，资源为 ```www.test.com/test/abc.jpg```，其匹配方式如下：
1. 匹配第一条所有文件，命中，此时缓存时间为 30 天。
2. 匹配第二条，未命中。
3. 匹配第三条，命中，此时缓存时间为 300 秒。
4. 匹配第四条，命中，此时缓存时间为 400 秒。
5. 匹配第五条，命中，此时缓存时间为 200 秒。

因此最终缓存时间为 200 秒，以最后一次匹配生效。
#### 优先级调整
单击【调整优先级】可以添加缓存配置，您可以根据业务情况自定义调整已经添加的缓存过期配置顺序。
![](https://mc.qcloudimg.com/static/img/8c8fc7733fcd46e1cb467ca3d9f69047/priority.png)
使用右侧上下箭头调整缓存过期时间配置的顺序，单击【保存】即可完成调整。
![](https://mc.qcloudimg.com/static/img/b593a10b8fbb7725b48beab711ea025a/priority_change.png)
### 缓存继承
当用户请求您某一业务资源时，源站对应的 Response HTTP Header 中存在 Cache-Control 字段，此时默认策略如下：
- Cache-Control 字段为 max-age，对该资源的缓存时间以配置的缓存时间为主，不继承 max-age 指定时间。
- Cache-Control 字段为 no-cache 或者 no-store，此时 CDN 节点对此资源不做缓存。

## 高级缓存配置
在缓存过期配置模块中可以找到 **高级缓存过期设置** 开关，单击即可打开。
![](https://mc.qcloudimg.com/static/img/253949748892d15c5340f341b99af32f/advanced_cache.png)
当您开启了高级缓存过期设置开关后，会达到如下效果。
用户请求源站某资源时 Response HTTP Header 中带有 Cache-Control 字段，且值为 max-age=xxxx，此时节点对该资源的缓存时间取配置的过期时间与 max-age 中的最小值：
- 若用户源站配置 /index.html 的 max-age 为 200 秒，CDN对应配置的缓存时间为 600 秒，则文件实际过期时间为 200 秒。
- 若用户源站配置 /index.html 的 max-age 为 800 秒，CDN对应的缓存时间为 600 秒，则文件实际过期时间为 600 秒。

> **注意：**若您的源站 Response Header 中无 Cache-Control 字段，则 CDN 会默认添加：Cache-Control: max-age=600 头部。

## 状态码缓存说明
CDN 节点请求源站资源时，除上述缓存策略外，还会根据状态码按照如下默认缓存策略进行：
+ 2XX：按照正常缓存策略进行。
+ 3XX：默认不缓存。
+ 4XX：404缓存10s，其他默认不缓存。
+ 5XX：默认不缓存。