## 1 What is CDN?

When talking about the role of CDN, I would like to compare it to the changes to railway tickets purchasing in the past 8 years: 

Eight years ago, there is no railway ticket outlets, let alone 12306.cn. At that time, the railway ticket can only be purchased in the ticket hall of train station. But I lived in a small town where no train has run. To buy a railway ticket, I had to go to the city's railway station, which is a 4 hours round trip with additional queuing for tickets. It is just a waste of time doing so. Later, we had a railway ticket outlet in my town where we could buy railway tickets directly. It brings us much convenience by sparing the time spent on transport and queuing in the city's railway station.

CDN can be compared to the railway ticket outlets distributed in each town. When users browse the website, CDN will choose the nearest CDN edge node to respond to the user's request, so that mobile user's request from Hainan will not be forwarded to the server far away in the data center of Beijing Telecom (assuming the origin server is deployed in the data center of Beijing Telecom).

The CDN has obvious advantages: (1) the CDN nodes address the problem with cross-carrier and cross-regional access, greatly reducing the access latency; (2) since most requests are handled at the CDN edge nodes, the CDN works well in traffic diversion, thus reducing the origin server's load.

## What is cache? 

Instead of the cutting-edge architecture or the global traffic scheduling of CDN, we will focus on how the data is cached with CDN. Caching is an example of using space to exchange time, which exists everywhere. By using extra space, we can get faster speed.

First, let's look at how user's browser interacts with the server without CDN:

![](https://mccdn.qcloud.com/img5680ff1936127.png)

When a user browses the website, its browser can save locally the pictures or copies of other files from the website. Thus, the browser will no longer have to download these files when the user browses the website again. This will reduce downloads and speed up the page loading.

If a CDN is included, the interaction between the user's browser and the server is as follows:

![](https://mccdn.qcloud.com/img5680ff0b3dfc4.png)
​         
The client browser will first check whether the local cache is out of date. If the cache expires, it will send a request to the CDN edge node. The CDN edge node will then check whether the cache of the user request data is out of date. If not, it will respond directly to the user request, and this will end a complete HTTP request. If the cached data has expired, the CDN will send to its origin server a back-to-origin request to pull the latest data. The typical topology of CDN is as follows:

![](https://mccdn.qcloud.com/img5680ff38c14d6.png)

Image Source:http://grefr.iteye.com/blog/2004248

It shows that in the presence of the CDN scenario, data will be cached in two stages by the client (browser) and the CDN edge node. Let's dig deeper into the two cache stages.

## 3 Client (Browser) Cache

### 3.1 Shortcomings of Client Cache 

The client cache reduces the request to the server and avoid repeated loading of files, thus significantly improving the user experience. However, when the website is updated (such as its css, js and image files are replaced), the browser still retains the old version of these files, resulting in unpredictable consequences.

Once, when a page is loaded, its elements were not in correct position and buttons were not functional. The front-end support at the time would habitually ask, "is cache cleared?" Just press Ctrl+F5, and everything is OK. But sometimes, the problem could not be solved by simply pressing Enter in your address bar of the browser or pressing F5 to refresh. Do you know these actions will determine different cache refresh policies?

How does the browser determine whether to use local files or new files on the server? Now, let's see several ways.

### 3.2 Browser Cache Policy

**Expires **

Expires:Sat, 24 Jan 2015 20:30:54 GMT

![](https://mccdn.qcloud.com/img5680ff7d3e717.png)

If Expires is set in the HTTP response message, the connection to the server will be avoided before the expiration time set in Expires. In this way, the browser does not need to send a request to the web server but only to judge whether its cached data expires or not, without extra burden imposed on the server.

**Cache-control: max-age**

![](https://mccdn.qcloud.com/img5680ff8dd9482.png)

Expires works well in this way. But we have to calculate every time a precise time. The max-age tag allows us to manage expiration time more easily. We can simply set that this data is available for you within one week.

Max-age is measured in seconds, for example:
Cache-Control:max-age=645672
indicates the page will expire after 645672 seconds (7.47 days).

**Last-Modified**

In order to notify the browser of the current version of the files, the server will send a tag indicating the last modified time, for example:

![](https://mccdn.qcloud.com/img5680ffb4a230f.png)

In this way, the browser will know the creation time of its received files and verify these files in subsequent request according to the following rules:

1. Browser: "Hey, I need the jquery.min.js file. If it was modified after Tue, 06 Jan 2015 08:26:32 GMT, please send it to me."

2. Server: (Checking the last modification time of the file)

3. Server: "Hey, this file has not been modified after that time. You already have the latest version."

4. Browser: "Great, then I will show it to the user."

In this case, the server only returns a 304 response header, resulting in reduced data volume to return and faster response time. For 304 response, please refer to:
http://www.cnblogs.com/ziyunfei/archive/2012/11/17/2772729.html

The following figure is the 304 response header returned by the page when F5 is pressed to refresh the page.

 ![](https://mccdn.qcloud.com/img5680ffd7cc31e.png)

**ETag **

Generally, it is possible to compare files by their modification times. But this is not feasible in certain circumstances, such as an error to the server clock, modified server clock, or delayed update to server time during daylight saving time (DST).

ETag can be used to address this problem. ETag is the unique identifier of a file. Like a hash or a fingerprint, each file has a separate tag. As long as the file has changed, the tag will change accordingly.

The server returns the ETag:
ETag:"39001d-1762a-50bf790757e00"

![](https://mccdn.qcloud.com/img5680fff60b4db.png)

The access is conducted as follows:

1. Browser: "Hey, I need the jquery.min.js file. Is there any version mismatching with the string '39001d-1762a-50bf790757e00'?"

2. Server: (Checking ETag...)

3. Server: "Hey, my version is also '39001d-1762a-50bf790757e00'. You already have the latest version."

4. Browser: "Good, then I will use the local cache."

As with Last-Modified, ETag can also solve the issue on file version comparison. But the level of ETag is simply higher than that of Last-Modified.

**Extra Tags**

Cache tags will never stop working, but sometimes we need to have some control over the content that has been cached.

l  Cache-control: public indicates that the cached version can be recognized by the proxy server or other intermediate servers.

l  Cache-control: private indicates that this file varies for different users. A user can only cache such file by its own browser, rather than the public proxy server.

l  Cache-control: no-cache indicates that the contents of the file should not be cached. This is useful in searching or paging, as the same URL may lead to different contents.

![](https://mccdn.qcloud.com/img5681002ad726c.png)

**Browser Cache Refresh** 

**1. Enter the URL in the address bar and press Enter or click Go button**

The browser gets the web data with the least number of requests. The browser will use the local cache directly for all content that has not expired, thereby reducing the requests to the server. So, Expires and max-age are only valid for this way.

**2. Press F5 or click browser's Refresh button**

The browser will add necessary cache negotiation to the request, but the browser is not allowed to use the local cache directly. This allows the Last-Modified and ETag to function, but not the Expires.

**3. Press Ctrl+F5, or click Refresh button while pressing and holding Ctrl**

This will force a refresh and always send a new request, without using any cached data.

## 4 CDN Cache 

When the browser's local cache expires, the browser will initiate a request to the CDN edge node. As with the browser cache, CDN edge node also has a set of cache mechanism.

### 4.1 Shortcomings of CDN Cache 

The traffic diversion of CDN can reduce the user's access latency and the load on the origin server. But there are also obvious shortcomings: when the website is updated and the data on CDN node is not updated in time, user access exception will occur due to the fact that the latest data is not synchronized to the CDN node, even if the user uses the Ctrl + F5 to refresh and disable the browser cache.

### 4.2 CDN Cache Policy 

The cache policy of CDN edge node varies with different service providers, but will generally be subject to the HTTP protocol to set its data cache time through the HTTP response header Cache-control: max-age field.

When the client requests data from the CDN node, the CDN node will determine whether the cache data is out of date. If not, the cache data will be returned directly to the client; otherwise, the CDN node will send to the origin server a back-to-origin request to pull the latest data from the origin server, update the local cache, and return the latest data to the client.

Generally, CDN service providers will enable functions to specify the CDN cache time based on multiple dimensions such as the file suffix and directory, to provide users with more refined cache management.

CDN cache time will have a direct impact on the "back-to-origin rate". With a shorter CDN cache time, the CDN edge node data will often become invalid, resulting in not only a frequent back-to-origin and a higher load on the origin server, but also higher access latency; if CDN cache time is too long, this will lead to slower data updating. Developers need to conduct tailored data caching time management for specific business.

### 4.3 CDN Cache Refresh

The CDN edge node is transparent to developers. In contrast with using the Ctrl+F5 for a forced refresh to bypass the browser local cache, developers can use "cache refresh" API provided by the CDN service provider to clean up the cache on their CDN edge node. In this way, the "cache refresh" function can be used to force the data cache on CDN node to expire after data is updated by developers, to ensure that the browser pulls the latest data when accessing by the client.
