You can configure HTTPS certificate for a domain name that has been connected to DSA. You can upload your existing certificate for deployment, or directly deploy the certificate hosted or issued by [SSL Certificate Management](https://console.cloud.tencent.com/ssl) platform.

<font color="red">You can apply for a free third-party certificate from TrustAsia on SSL Certificate Management page.</font>

## Configuring Certificate

If you already have a certificate, you can upload it directly to the DSA page for configuration. Log in to [DSA Console](https://console.cloud.tencent.com/dsa) and go to **Certificate Management** page, click "Configure Certificate":
![](https://mc.qcloudimg.com/static/img/b64e40647dd3620d4c8a33ffca071df3/1.png)

### 1. Select a Domain Name
Select the accelerated domain name for which you want to configure a certificate. Note:

+ The domain name is required to be connected to DSA and with a status of **Deploying** or **Activated**. You cannot deploy certificate for a domain name with the Deactivated status;

![](https://mc.qcloudimg.com/static/img/9472c2c418ea9250f3744e1140d53518/2.png)

### 2. Select a Certificate
#### 2.1 Use self-owned certificate

Select "Own Certificate", and paste the certificate content and private key to the corresponding text boxes. You can optionally add a remark for identifying the certificate.

![](https://mc.qcloudimg.com/static/img/142d57d4588e9629c03a1a5b83ee32ad/3%281%29.png)

+ Certificate content must be in PEM format. For non-PEM certificates, please refer to the instructions below for format conversion;
+ If your certificate has a certificate chain, please convert its content into PEM format, and upload it with the certificate content. The instructions on completing certificate chain is described later in this document.

#### 2.2 Use Tencent Cloud Hosted Certificate
You can apply for a free third-party certificate from TrustAsia on [SSL Certificate Management](https://console.cloud.tencent.com/ssl) page or trust an existing certificate to Tencent Cloud to use it for cloud products such as DSA, Cloud Load Balance.

Select "Tencent Cloud Hosted Certificate" to see the list of certificates available for the domain name in SSL Certificate Management:

![](https://mc.qcloudimg.com/static/img/5513fe83992c769dc4f45069bd0e74b4/4.png)

+ Select the certificate to use from the certificate list;
+ The certificates are displayed as Certificate IDs (Remark) in the list . You can learn more about the certificates by going to [SSL Certificate Management](https://console.cloud.tencent.com/ssl).

### 3. Origin-Pull Method
After the certificate is configured, you can select the origin-pull method by which DSA nodes acquire resources from the origin server:

+ When HTTP origin-pull configuration is selected, requests sent from users to DSA nodes support HTTPS/HTTP, and requests sent from DSA nodes to the origin server all use HTTP;
+ If protocol following is selected, the origin server is required to be already configured with a certificate, otherwise origin-pull may fail. If successfully configured, origin-pull requests from DSA nodes will be HTTP when requests sent from users to DSA nodes are HTTP. While origin-pull requests from DSA nodes will be HTTPS when requests sent from users to DSA nodes are HTTPS;
+ For the configuration of HTTPS, your origin server is required to have no port constraint or to be configured with port 443, otherwise the configuration may fail.

#### 4. Finish Configuration

Once the configuration is finished, you can see the domain name and certificate that have been configured on the "Certificate Management" page:

![](https://mc.qcloudimg.com/static/img/53f2625c39950e529fa3d6579792ec78/5.png)



## Editing Certificate
For certificates that have been successfully configured, you can seamlessly update the certificates by using the "Edit" button:

![](https://mc.qcloudimg.com/static/img/b47e2cc3660fd92f488e2cf116c5f59d/6.png)

+ You can seamless switch between self-owned certificate and Tencent Cloud hosted certificate;
+ Once the edited certificate is submitted, it will be deployed by seamlessly overwriting the original one without affecting your business.


### PEM Certificate Format

The certificate issued by Root CA are in PEM format as shown below:

![](https://mc.qcloudimg.com/static/img/ad4ef7cc7f853c7db24f612070676a4c/10.png)

- [--- BEGIN CERTIFICATE ---, --- END CERTIFICATE ---] are the beginning and end, which should be uploaded with the content;

- Each line contains 64 characters, and the last line can contain less than 64 characters;

Certificate chain issued by intermediate CA:

>---BEGIN CERTIFICATE---
>---END CERTIFICATE---
>---BEGIN CERTIFICATE---
>---END CERTIFICATE---
>---BEGIN CERTIFICATE---
>---END CERTIFICATE---

Rules for certificate chain:

- No blank line is allowed between certificates;
- Each certificate shall comply with the certificate format rules described in Item 1;

### PEM Private Key Format

RSA private key can include all private keys (RSA and DSA), public keys (RSA and DSA), and (x509) certificates. It stores DER data encoded with Base64 and is enclosed by ascii header, thus it is suitable for textual transfer between systems. Example:

![](https://mc.qcloudimg.com/static/img/67d77239ec4acfb4b36d2e18a655a117/11.png)

RSA private key rules:

- [---BEGIN RSA PRIVATE KEY---, ---END RSA PRIVATE KEY---] are the beginning and end, which should be uploaded with the content;
- Each line contains 64 characters, and the last line can contain less than 64 characters;

If the private key is not generated using the above method and has a format of [--- BEGIN PRIVATE KEY ---, --- END PRIVATE KEY ---], you can convert the format as follows:

```
openssl rsa -in old_server_key.pem -out new_server_key.pem
```

Then upload the content of new_server_key.pem along with the certificate.

### PEM Format Conversion

Currently, CDN only supports certificates with a PEM format. Any non-PEM certificates are required to be converted to PEM format before being uploaded to Cloud Load Balance. It is recommended to use openssl tool for the conversion. Here are some common methods for converting the certificate format to PEM.

#### Converting DER to PEM
DER format usually appears on Java platforms.

Certificate conversion:

```
openssl x509 -inform der -in certificate.cer -out certificate.pem`
```

Private key conversion:

```
openssl rsa -inform DER -outform PEM -in privatekey.der -out privatekey.pem
```

#### Converting P7B to PEM

P7B format usually appears in Windows Server and Tomcat.

Certificate conversion:

```
openssl pkcs7 -print_certs -in incertificat.p7b -out outcertificate.cer
```

Obtain [--- BEGIN CERTIFICATE ---, --- END CERTIFICATE ---] content in outcertificat.cer as a certificate for upload.

Private key conversion: no private key

#### Converting PFX to PEM

PFX format usually appears in Windows Server.

Certificate conversion:

```
openssl pkcs12 -in certname.pfx -nokeys -out cert.pem
```

Private key conversion:

```
openssl pkcs12 -in certname.pfx -nocerts -out key.pem -nodes
```



### Completing Certificate Chain

During configuration using self-owned certificate, if "Completion of Certificate Chain is Required" appears:

![](https://mc.qcloudimg.com/static/img/ac460acbaa7e1d8916b50c643b75f0bc/7%281%29.png)

CA mainly provides the following three types of certificates:

![](https://mc.qcloudimg.com/static/img/b6aa91178ad952913f2a797b2f52bc93/cer_type.png)

CDN uses **Nginx**. Select the certificates with an extension of .crt or .key under **Nginx** folder. A certificate of PEM format can be directly opened with text editor. Simply copy and upload it:

![](https://mc.qcloudimg.com/static/img/a282abe9154c5e78b2ba771289e52c7f/cer_nginx.png)

You can also complete the certificate chain by pasting the content of CA certificate (PEM format) to the bottom of domain certificate (PEM format):

![](https://mc.qcloudimg.com/static/img/53927ba56ceba5d0a3ed0c5d80257c8a/cer_add.png)

