## 功能说明
将本地目录下的子文件和子目录同步到 COS 上。
### 实现机制
COS 本地同步工具会获取用户本地的文件列表，执行上传并将上传的结果记录在本地。每次运行工具都会重新拉取本地文件列表，并与已成功的本地数据库进行比对和同步（上传或删除）。
## 使用限制
只适用于 COS V4 V5 版本
## 使用环境
### 系统环境
Linux 或 Windows 系统
### 软件依赖
JDK 1.7 或 1.8  
#### 安装与配置
具体安装与配置说明请参考 [Java 安装与配置](/doc/product/436/10865)。
## 使用方法
### 获取工具包
下载链接：[本地同步工具](https://github.com/tencentyun/cos_sync_tools_v5)

解压缩工具包并进入工具包路径：
- **Windows：** 
解压并保存到 `C:\Users\Administrator\Downloads\cos_sync`
- **Linux:**
```
unzip cos_sync_tools_v5-master.zip && cd cos_sync_tools_v5-master
```

<span id="配置说明"></span>
### 配置说明
配置文件位于  `conf/config.ini`，修改配置示例如下，请根据自己实际情况进行修改，
```
# appid 信息(可在 https://console.cloud.tencent.com/capi 查看)
appid=12500000
# 用户的秘钥 secret_id (可在 https://console.cloud.tencent.com/capi 查看)
secret_id=XXXXXXXXXXXXXXXXXXXXXXXX
# 用户的秘钥 secret_key  (可在 https://console.cloud.tencent.com/capi 查看)
secret_key=YYYYYYYYYYYYYYYYYYYYYYYYY
# 用户的bucket名称
bucket=mybucket
# bucket的region信息. COS地域的简称请参照 https://cloud.tencent.com/document/product/436/6224
region=ap-beijing-1
# 存储类型, 标准(standard), 低频(standard_ia), 近线(nearline)
storage_class=standard
# 本地路径
local_path=/mydata/
# cos路径
cos_path=/mycospath
# 是否使用HTTPS传输(传输速度较慢，适用于对传输安全要求高的场景), 1开启, 0关闭
enable_https=0
```
配置信息说明：

| 名称              | 描述                                       | 有效值      |
| --------------- | ---------------------------------------- | -------- |
| appid          | 需要进行操作的 APPID，可从控制台获取，参考 [基本概念](/doc/product/436/6225) | APPID 数字 |
| secret_id       | APPID 对应的秘钥 ID，可从控制台获取，参考 [基本概念](/doc/product/436/6225) | 字符串      |
| secret_key      | APPID 对应的秘钥 Key，可从控制台获取，参考 [基本概念](/doc/product/436/6225) | 字符串      |
| bucket          | 指定要同步的存储桶名称， 需要提前在控制台建立，参考 [创建存储桶](/doc/api/436/6232) | 字符串      |
| enable_https    | 启用 https 进行传输。1：使用 https；0：使用 http    | 数字       |
| region          | 存储桶所属地域。枚举值为 [可用地域](/doc/product/436/6224) 中适用于 XML API 的地域简称，如 ap-beijing 等。 | 字符串      |
| local_path      | 需要同步的本地绝对路径。Windows 路径需用双斜线 “\\\” 分割。<br>Linux 范例：/home/user/dir；Windows 范例：C:\\\document\\\dir | 字符串      |
| cos_path        | 同步到 COS 的目的路径，需以 / 为结尾以表示目录，根目录为 /      | 字符串      |
> <font color="#0000cc">**注意：** </font>
Windows 路径使用“\\\”进行分割。 因为如果使用“\”，配置文件中某些特殊字符会被当做被转义，整个文件不是一个有效的 json。

### 使用软件
执行同步工具：
 **Windows：** 请双击 【start_cos_sync.bat】。
**Linux:**
```
sh start_cos_sync.sh
```
执行完成后，会输出创建和删除成功与失败的统计，以及全部执行的时间。

## 问题与帮助
### 常见问题
**同步完成后，在 COS 上不小心删除了文件，再运行工具会上传吗？**
不会。工具对于已同步的文件列表是记录在本地的，不会从 COS 拉取文件列表。

**已同步记录的数据库保存在哪？删除了再运行工具会发生什么？**
同步结果记录会保存在 db 目录下的数据文件里。如果删除了再运行工具，工具会试图将本地文件全量再上传到 COS，如果 COS 上已存在文件则会进行覆盖。

**是否支持中文文件名和目录？**
支持。目前支持所有 UTF-8 编码的路径或文件。

如果有偶发的失败问题，可以重跑同步程序, 不会重复上传已经成功上传的文件.

### 其他错误
请 [提交工单](https://console.cloud.tencent.com/workorder/category)。并告知同步工具的 config.json 相关配置(不用提供密钥) 以及打包的 log 目录。
