This section provides major concepts and terms required to use COS effectively. These concepts and terms are displayed in the order you'll most likely encounter them.

## Appid

A unique resource ID of each project when a developer accesses COS services. It is generated by the system automatically after you apply for COS. The default Appid is a default project. You can get it by clicking the "Get API Key" button on top of the Bucket List on the Console.

## SecretID / SecretKey

SecretID/SecretKey is a project signature key owned by the developer. It is automatically generated by the system after you activate COS. Users who share an APPID may use a pair of SecretID/SecretKey to access all projects under the APPID. After creating a bucket, you can view the SecretID/SecretKey under the APPID by clicking the "Key Management" on the Console.

## Bucket

Bucket is a container used to store data in COS, and the first-level directory stored under Appid by a user. Each object is stored in a Bucket. Each Bucket has its own access domains (default, accelerated), access control permissions (public, private), back-to-origin settings, hotlink protection settings and other attribute configuration items.

You can create, configure, and add objects to a Bucket. For details, refer to [Bucket](https://cloud.tencent.com/document/product/436/6245).

## Object (File)

Object is a specific file stored in COS. It is the basic entity that is stored. Object is composed of data and metadata. The data refers to the content of"file". The metadata is a set of key-value pairs that describe the object, including some file information and HTTP header information (such as Content-Type, etc). You can specify some metadata information. For more information, refer to [HTTP Header Settings](https://cloud.tencent.com/document/product/436/6258).

You can upload objects in the Bucket via Console, API and SDK, and set access permission for these objects. For details, refer to [Object](https://cloud.tencent.com/document/product/436/6259).

## CDN Accelerated Access Address

After the user uploads the object and activates CDN acceleration, Tencent Cloud will automatically create the following access address for the object:

`http://workfile-1250000001.file.myqcloud.com/a.doc`

(Wherein: appid is 1250000001; Bucket name is workfile; and a.doc file is uploaded in Bucket root directory.)

By combining CDN Accelerated ID with Appid, Bucket name, and object name, you can uniquely address any object in COS via CDN Accelerated Access Address. This download address is used to accelerates access by transferring files through 500+ CDN nodes, which may lower the unit prices of **CDN back-to-origin traffic** and **CDN bandwidth**. For details, refer to [CDN Accelerated Domain Name](https://cloud.tencent.com/document/product/436/6252).

## Default Domain (Private/Public Network Access)

After the user uploads the object, Tencent Cloud will automatically create the following access address for the object:

`http://workfile-1250000001.cosgz.myqcloud.com/a.doc`

(Wherein: Appid is 1250000001; Bucket name is workfile; Region ID is cosgz; and a.doc file is uploaded in the Bucket root directory.)

By combining COS Region ID with Appid, Bucket name, and object name, you can uniquely address the object in COS via accessing the address. This address is used to get the file directly from the Tencent Cloud data center located in the region of COS, which may cause high unit price of **public network access traffic** and cannot accelerate. For details, refer to [Public Network Access Address](https://cloud.tencent.com/document/product/436/6252).


