## 基本概念

腾讯云对象存储服务 COS 是一种基于 HTTP 协议的文件存储和访问协议。

控制台是帮助用户使用 COS 的界面之一。通过 COS 控制台，您可以直接对 COS 存储进行操作，无需编写代码或运行程序。

为了更方便您的理解，以下列出了 COS 基本资源和对应传统文件系统的解释：

- COS：使用 HTTP 协议来进行 I/O 操作的互联网分布式文件系统。
- Bucket：类似 /dev/sda1 或 C:\ 这样的独立分区，创建后无法移动或重命名。
- Object：实际存储的文件，文件可通过 URL 访问，类似传统的文件路径。
- 文件夹：通过 / 来区分存放在不同路径的文件。

## Bucket

### 概述

由于 COS 是一种基于 HTTP 协议的文件存储服务，在存储任何文件（Object）之前都需要先创建存储桶（Bucket），用户可以使用腾讯云控制台创建存储桶并上传对象。

### 属性配置

腾讯云 COS 支持各种存储桶的属性配置。例如，用户可以配置存储桶用于静态网站托管、自定义配置存储桶的访问路径、配置存储桶的访问权限等。

### 相关限制

- Bucket 数量上限是200个（不区分地区）。但是 Bucket下目录、文件数量没有限制。
- Bucket 创建于项目下，一个 Bucket 只能属于一个项目，支持切换项目。
- 腾讯云 COS 中，同一个 APPID 的所有项目下 Bucket 名称是唯一的，不能重名。
- Bucket一旦创建后，将无法重命名，建议您在上传文件之前，定义好您的 Bucket 名称。
- 创建 Bucket 时候可以选择所在地区， 地区一旦设置后将无法修改。 

### 命名规则

- Bucket 名称的长度不能超过40字节。
- Bucket 名称仅可以包含小写字母和数字的组合。
- Bucket 名称不可以使用符号及下划线。

以下示例是有效的存储桶名称：

`mynewbucket`

`newproject1`

## Object

### 概述

Object是腾讯云 COS 中存储的具体内容，使用 key-value 存储方式，专门用于存储任意多的数据。Object必须存储在一个或多个存储桶中，由以下基本内容组成：

- 键（Key）：Object 名称。在 Bucket 中唯一标识一个 Object，每个  Bucket 都支持无限个数的文件存储。


- 值（Value）：根据您指定的 Key 可将本地任意类型的文件上传至 Bucket 中。单文件上传最大支持 50 GB，单文件存储最大支持 500 G。


- 元数据（Metadata）：一组键值对，可用于存储有关Object的信息。

### 路径概念

不同于计算机文件系统，COS 并不提供树状的索引结构，这也是 COS 能支持高并发请求的基本原因之一。但用户仍可以使用 COS 创建文件夹， COS 通过使用表示文件夹结构的地址来请求一个逻辑上的索引关系，但其实它们没有任何物理上的分层结构。

例如，在 Bucket 根目录下中具有三个文件或文件夹：文件`test.jpg`、文件夹`photos/2015` 、文件夹`photos/2016` ，在`photos/2016` 文件夹中有名为`me.jpg`的图片。

腾讯云 COS 将构建类似 `/test.jpg` 和 `/photos/2016/me.jpg` 的相对路径进行对象请求。

为延续用户查看习惯，在 COS 控制台中，还是以文件夹的方式显示索引结构。

### 命名规则

腾讯云 COS 中上传的 Object 需具有合法的名称，它在 Bucket 中唯一地标识该 Object。Object 名称将采用 Unicode 字符，虽然可以在名称中使用任何 UTF-8 字符，但是每个应用程序对特殊字符的分析方式可能不同。以下原则有助于最大程度符合 DNS、Web 安全字符、XML 分析器和其他 API 的要求。

以下字符集通常可安全地用于键名称：

| 类型     | 内容                |
| ------ | ----------------- |
| 字母数字字符 | [0-9 , a-z , A-Z] |
| 特殊字符   | `!`、`-`、`_`、`.`   |

以下是安全的 Object 名称示例：

`my-organization`

`my.great_photos-2016/01/me.jpg`

`videos/2016/birthday/video1.wmv`

需要注意的是，COS 的底层实现逻辑不存在文件夹层次结构；但是用户可以在 COS 中创建文件夹，并以分隔符标识文件层级结构。假设 Bucket 中包含具有以下名称的文件：

Videos/mybday.mp4

Document/lesson1.mp4

report.pdf

控制台使用名称前缀（Videos/、Document/）和分隔符（“/”）呈现FolderVideos和Document，而 report.pdf Object名没有前缀，因此这个Object在 Bucket 的根目录出现。

### 访问地址

Object 的访问地址都是基于 Bucket 的访问地址和 Object 名称的，COS 的 Object 访问地址构成为 `Bucket 域名 + “/“ + Object 名称`，有关 Bucket 的域名可以参考 [Bucket 域名管理](/doc/product/436/6252)。

历史版本控制台，请点击查看[历史版本文档](/document/product/430/5904)
