## 基本概念

跨域访问（CORS: Cross-Origin Resource Sharing）是指发起请求的资源所在域不同于该请求所指向资源所在的域的 HTTP 请求。

对象存储服务针对跨域访问，支持响应 OPTIONS 请求，并根据开发者设定的规则向浏览器返回具体设置的规则。但服务端**并不会校验**随后发起的跨域请求是否符合规则。

更多详细资料可以参考 [Mozilla Developer Network 关于 HTTP 访问控制的说明](https://developer.mozilla.org/zh-CN/docs/Web/HTTP/Access_control_CORS)。

## 配置说明

控制台提供了响应 OPTIONS 请求的配置，支持多条规则。

![](//mccdn.qcloud.com/static/img/1c81e76fb6bb7bf350777e99e525a232/image.jpg)

### Allow-Origin

许可的访问来源，支持一条规则中匹配多个来源域名，每行填写一行域名。

例如：`http://image.qq.com` 或 `http://*.qq.com`

也支持单条通配符 `*` 这样将许可所有来源的请求。当 Origin 配置许可所有来源时，Allow-Credentials 选项不可以勾选为 True。

### Allow-Method

指明资源可以被请求的方式有哪些（一个或者多个）。

例如：`PUT` 和 `POST`

### Allow-Credentials

用于告知客户端，当请求中包含 Credentials 为 True 时，响应带凭证（HTTP Cookies 和验证信息）的请求，否则响应会被忽略。

当来源 Origin 不限时（即配置为 `*`）则不应当勾选该选项。

### Allow-Headers

在发送 OPTIONS 请求时告知服务端，接下来的请求可以使用哪些自定义的 HTTP 请求头部。

例如：`x-cos-meta-md5`

### Expose-Headers

设置浏览器可以接收到的来自服务器端的自定义头部信息。

例如：`x-cos-acl`

### Max-Age

设置 OPTIONS 请求得到结果的有效期。

例如：`600`

## 示例

### 简单请求

当配置了 Allow-Origin 为 * 时，试图发出一个 GET 请求和得到的回应情况。

```http
<
GET /resources/public-data/ HTTP/1.1
Host: bar.other
Connection: keep-alive
Referer: http://foo.example/examples.html
Origin: http://foo.example
>
HTTP/1.1 200 OK
Connection: Keep-Alive
Access-Control-Allow-Origin: *
[data]
```

### 预请求

当请求具备以下条件之一时，会被当做预请求处理，此时会先发出一个 OPTIONS 请求给服务器以确认是否可以进行跨域操作：

- 请求以 GET, HEAD 或者 POST **以外**的方法发起请求
- 使用 POST，但请求数据为 `application/x-www-form-urlencoded` 、`multipart/form-data` 或 `text/plain` 以外的数据类型
- 使用自定义请求头

以试图发送一个跨域 POST 请求，内容为 text/xml 为例：

```http
<
OPTIONS /resources/post-here/ HTTP/1.1
Host: bar.other
Origin: http://foo.example
Connection: keep-alive
Access-Control-Request-Method: POST
Access-Control-Request-Headers: X-PINGOTHER
>
HTTP/1.1 200 OK
Date: Mon, 01 Dec 2008 01:15:39 GMT
Access-Control-Allow-Origin: http://foo.example
Access-Control-Allow-Methods: POST, GET, OPTIONS
Access-Control-Allow-Headers: X-PINGOTHER
Access-Control-Max-Age: 1728000
Connection: Keep-Alive
Content-Type: text/plain
<
POST /resources/post-here/ HTTP/1.1
Host: bar.other
Connection: keep-alive
X-PINGOTHER: pingpong
Content-Type: text/xml; charset=UTF-8
Referer: http://foo.example/examples/preflightInvocation.html
Content-Length: 55
Origin: http://foo.example
[data]
```

## 参考资料

跨域配置及详细规则，可参考外部资料 [Mozilla Developer Network 关于 HTTP 访问控制的说明](https://developer.mozilla.org/zh-CN/docs/Web/HTTP/Access_control_CORS)。