## 1. 接口描述
本接口(CreateSubnet)用于创建子网。
接口请求域名：<font style="color:red">vpc.api.qcloud.com</font> 

1) 创建子网前必须创建好 VPC。
2) 子网创建成功后，子网网段不能修改。子网网段必须在VPC网段内，可以和VPC网段相同（VPC有且只有一个子网时），建议子网网段在VPC网段内，预留网段给其他子网使用。
3) 你可以创建的最小网段子网掩码为28（有16个IP地址），最大网段子网掩码为16（65,536个IP地址）。
3) 同一个VPC内，多个子网的网段不能重叠。
4) 子网创建后会自动关联到默认路由表。
 

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/372/4153" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为CreateSubnet。

| 参数名称 | 是否必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| vpcId | 是 | String | 子网所属的私有网络ID值，可使用vpcId或unVpcId，建议使用unVpcId。可通过<a href="http://cloud.tencent.com/doc/api/245/%E6%9F%A5%E8%AF%A2%E7%A7%81%E6%9C%89%E7%BD%91%E7%BB%9C%E5%88%97%E8%A1%A8" title="DescribeVpcEx">DescribeVpcEx</a>接口查询。 |
| subnetSet.n | 否 | Array | 子网信息数组，创建VPC时可以同时创建子网，可选项。|
| subnetSet.n.subnetName | 是 | String | 子网名称，取值：1-25个中文、英文大小写的字母、数字和下划线分隔符，同一个VPC下子网名称不可重复。|
| subnetSet.n.cidrBlock | 是 | String | 子网网段，子网网段必须在VPC网段内，相同VPC内子网网段不能重叠。|
| subnetSet.n.zoneId | 是 | Int | 子网所在的可用区ID，不同子网选择不同可用区可以做跨可用区灾备，取值详见<a href="">VPC可用区说明</a>。 |
 

## 3. 输出参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href="https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81" title="公共错误码">公共错误码</a>。|
| message | String | 模块错误信息描述，与接口相关。|
| subnetSet.n | Array | 子网信息，同时添加了子网时才会返回。|
| subnetSet.n.subnetId | String | 系统分配的子网ID，示例:subnetId_GZ_23。|
| subnetSet.n.unSubnetId | String | 系统分配的子网统一ID，由子网ID升级而来，为了兼容这两种ID系统都支持，示例:subnet-5gu2jxf4。|
| subnetSet.n.subnetName | String | 子网名称。|
| subnetSet.n.cidrBlock | String | 子网网段，示例:192.168.0.0/25。|
| subnetSet.n.routeTableId | String | 子网绑定的默认路由表ID，示例:gz_rtb_8751。|
| subnetSet.n.zoneId | String | 子网所在可用区ID,示例:200001。|

 ## 4. 错误码表
 以下错误码表仅列出了该接口的业务逻辑错误码，更多公共错误码详见<a href="https://cloud.tencent.com/doc/api/245/4924" title="VPC错误码">VPC错误码</a>。
 
| 错误码 | 描述 |
|---------|---------|
| InvalidVpc.NotFound | 无效的VPC，VPC资源不存在，请再次核实您输入的资源信息是否正确，可通过<a href="http://cloud.tencent.com/doc/api/245/%E6%9F%A5%E8%AF%A2%E7%A7%81%E6%9C%89%E7%BD%91%E7%BB%9C%E5%88%97%E8%A1%A8" title="DescribeVpcEx">DescribeVpcEx</a>接口查询VPC。 |
| InvalidSubnetName | 子网名称不合法，子网名称取值范围：1-60个中文、英文大小写的字母、数字和下划线分隔符。 |
| InvalidSubnetName.InUse | 子网名称已被VPC下其他子网使用，同一个VPC内子网名称不能重复。 |
| InvalidSubnetCidr | 子网CIDR不合法或者不在VPC网段内，子网CIDR取值范围：10.0.0.0/16、172.16.0.0/16和192.168.0.0/16及它们包含的子网。 |
| InvalidSubnet.Conflict | 子网网段与VPC内其他子网网段冲突。 |
| SubnetLimitExceeded | 您已经达到指定区域子网资源申请数量上限，如果需要更多资源，请联系客服申请。更多VPC资源限制信息详见<a href="https://cloud.tencent.com/doc/product/215/537" title="VPC使用限制">VPC使用限制</a>。 |
| InvalidZone.NotFound | 无效的可用区ID，您输入的可用区不存在或者该可用区不支持私有网络，更多可用区信息参见<a href="">私有网络可用区说明</a>。 |


## 5. 示例
 
输入
```
  https://vpc.api.qcloud.com/v2/index.php?Action=CreateSubnet
	&<公共请求参数>
  &vpcId=vpc-kd7d06of
  &subnetSet.0.subnetName=tttt
  &subnetSet.0.cidrBlock=10.0.200.0/24
  &subnetSet.0.zoneId=800001
```

输出
```
{
    "code": 0,
    "message": "",
    "subnetSet": [
        {
            "subnetId": "gz_subnet_18748",
            "unSubnetId": "subnet-3lzrkspo",
            "routeTableId": "gz_rtb_359",
            "unRouteTableId": null,
            "subnetName": "tttt",
            "cidrBlock": "10.0.200.0\/24",
            "zoneId": 800001
        }
    ]
}

```

