## 1. 接口描述

本接口(DescribeNetworkInterfaces)用于查询弹性网卡信息。
接口请求域名：<font style="color:red">vpc.api.qcloud.com</font>

## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href="/doc/api/372/4153" title="公共请求参数">公共请求参数</a>页面。其中，此接口的Action字段为DescribeNetworkInterfaces。

| 参数名称 | 必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| vpcId | 否 | String | 弹性网卡对应的私有网络ID，例如：vpc-7t9nf3pu |
| networkInterfaceId | 否 | String | 系统分配的弹性网卡ID，例如：eni-m6dyj72l |
| eniName | 否 | String | 弹性网卡名称，支持模糊搜索 |
| eniDescription | 否 | String | 弹性网卡描述，支持模糊搜索 |
| instanceId |  否 |String | 云主机实例ID，例如：ins-xx44545f |
| offset | 否 | Int | 初始行的偏移量，默认为0 |
| limit | 否 | Int | 每页行数，默认为20 |
| orderField | 否 | String | 按某个字段排序。<br>支持字段：eniName,createTime，默认按createTime |
| orderDirection | 否 | String | 升序（asc）或降序（desc），默认：asc |

## 3. 输出参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 错误码。0：成功，其他值：失败 |
| message | String | 错误信息 |
| totalCount | Int | 弹性网卡总数量 |
| data.n | Array | 弹性网卡信息数组 |
**data数组：**

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| data.n.vpcId | String | 弹性网卡对应的私有网络ID。例如：vpc-8e0ypm3z | 
| data.n.subnetId | String | 弹性网卡对应的子网ID。例如：subnet-0ap8nwca | 
| data.n.zoneId | int | 弹性网卡对应的子网所在的可用区ID。例如：200001 | 
| data.n.eniName | String | 弹性网卡名称 | 
| data.n.eniDescription | String | 弹性网卡描述 | 
| data.n.networkInterfaceId | String | 弹性网卡ID。例如：eni-m6dyj72l | 
| data.n.primary | Bool | 是否为主网卡。true：主网卡；false：普通网卡 | 
| data.n.macAddress | String | 弹性网卡mac地址。例如：02:81:60:cb:27:37 | 
| data.n.privateIpAddressesSet | Array | 弹性网卡绑定的 IP 信息 | 
| data.n.instanceSet | Array | 弹性网卡绑定的云主机信息 | 
| data.n.groupSet | Array | 弹性网卡绑定的安全组信息 | 

**privateIpAddressesSet信息数组：**

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| privateIpAddress | String | IP地址 |
| primary | Bool | 是否为主IP，true：是；false：否 |
| wanIp | String | 公网IP |
| eipId | String | 弹性公网IP ID |

**instanceSet信息数组：**

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| instanceId | String | 腾讯云主机实例ID，例如：ins-xx44545f | 
| attachTime | String | 绑定时间，例如：2016-02-15 19:20:54 | 

**groupSet信息数组：**

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| sgId | String | 安全组ID，例如：sg-dfg1df54 | 
| sgName | String | 安全组名称 | 

## 4. 错误码表
以下错误码表仅列出了该接口的业务逻辑错误码，更多公共错误码详见<a href="https://cloud.tencent.com/doc/api/245/4924" title="VPC错误码">VPC错误码</a>。

| 错误码 | 描述 |
|---------|---------|
| InvalidVpc.NotFound | 无效的VPC，VPC资源不存在。请再次核实您输入的资源信息是否正确，可通过<a href="http://cloud.tencent.com/doc/api/245/%E6%9F%A5%E8%AF%A2%E7%A7%81%E6%9C%89%E7%BD%91%E7%BB%9C%E5%88%97%E8%A1%A8" title="DescribeVpcEx">DescribeVpcEx</a>接口查询VPC |
| InvalidNetworkInterface.NotFound | 无效的弹性网卡，弹性网卡资源不存在。请再次核实您输入的资源信息是否正确，可通过<a href="https://cloud.tencent.com/doc/api/245/%e6%9f%a5%e8%af%a2%e5%bc%b9%e6%80%a7%e7%bd%91%e5%8d%a1%e4%bf%a1%e6%81%af?viewType=preview" title="DescribeNetworkInterfaces">DescribeNetworkInterfaces</a>接口查询弹性网卡 |

## 5. 示例
输入
```
https://vpc.api.qcloud.com/v2/index.php?Action=DescribeNetworkInterfaces
&<公共请求参数>
&vpcId=vpc-7t9nf3pu
```
输出
```
{
    "code":"0",
    "message":"",
    "totalCount":1,
    "data":[
        {
            "vpcId":"vpc-7t9nf3pu",
            "subnetId":"subnet-0ap8nwca",
	    "zoneId":200001,
            "eniName":"eni",
            "eniDescription":"eni示例",
            "networkInterfaceId":"eni-m6dyj72l",
            "primary":false,
            "macAddress":"02:81:60:cb:27:37",
            "privateIpAddressesSet":[
                 {
                     "privateIpAddress":"10.0.0.2",
                     "primary":true,
                     "wanIp":"183.23.0.2",
                     "eipId":"eip-dgd545ef"
                  }
	           ],
             "instanceSet":[
                  {
                       "instanceId":"ins-xx44545f",
                       "attachTime":"2016-02-15 19:20:54"
                  }
            ],
            "groupSet":[
                 {
                      "sgId":"sg-dfg1df54",
                      "sgName":"安全组1"
                  }
            ]
        }
    ]
}
```

