为了帮助您快速使用负载均衡 API，这里给出一个使用示例。使用API之前请先在两台云服务器上部署TCP服务，并监听80端口，服务返回字符串"hello world"。通过创建负载均衡实例，使得通过负载均衡的VIP来访问云服务器的服务。
## 1. 购买公网(有日租)负载均衡实例
在使用负载均衡服务之前，我们首先购买一个公网(有日租)的负载均衡实例，有关购买负载均衡实例的详细信息请参考[购买负载均衡实例](/doc/api/244/1254)页面。

这里我们创建了一个公网(有日租)的负载均衡实例，其公共请求参数的Action字段为CreateLoadBalancer，接口请求参数如下表：

| 参数名称 | 描述 | 取值 |
|---------|---------|---------|
| loadBalancerType | 负载均衡实例的类型 | 2，由于通过外网访问，所以创建公网(有日租)类型的负载均衡实例。  |
| loadBalancerName | 负载均衡实例的名称 | 用户自定义，这里取名 test。 |


结合公共请求参数和接口请求参数，最终得到的请求形式如下：

```
https://lb.api.qcloud.com/v2/index.php?Action=CreateLoadBalancer
&Region=gz
&Timestamp=1465750149
&Nonce=46364
&SecretId=AKIDxxxxugEY
&Signature=5umi9gUWpTTyk18V2g%2FYi56hqls%3D
&loadBalancerType=2
&loadBalancerName=test
```
上述请求的返回结果如下：

```
{
    "code" : 0,
    "message" : "",
    "unLoadBalanceIds":[
        "lb-abcdefgh"
    ],
    "dealIds":[
        121
    ]
}
```
其中 lb-abcdefgh 为刚刚购买的负载均衡实例的唯一ID。根据[查询负载均衡实例列表](/doc/api/244/1261) 接口来查询该负载均衡实例是否创建成功，成功后进行第二步。

## 2. 创建负载均衡监听器
有了负载均衡实例的唯一ID，我们就可以创建负载均衡监听器了，有关创建负载均衡监听器的详细信息请参考[创建负载均衡监听器](/doc/api/244/1255)页面。

该示例中创建负载均衡监听器的接口请求参数如下表。

| 参数名称 | 描述 | 取值 |
|---------|---------|---------|
| loadBalancerId | 负载均衡实例唯一ID | 取刚刚创建的负载均衡实例的唯一ID，lb-abcdefgh |
| listeners.1.loadBalancerPort | 负载均衡监听器的监听端口 | 80 |
| listeners.1.instancePort | 负载均衡监听器后端云服务器监听端口 | 80 |
| listeners.1.protocol | 负载均衡监听器监听的协议， 1:HTTP，2:TCP，3:UDP，4:HTTPS | 本例中取值 2，监听TCP协议 |
| listeners.1.healthSwitch | 负载均衡监听器的健康检查，1:开启，0:关闭。默认为开启 | 本例中取值 1，开启健康检查 |
| listeners.1.listenerName | 负载均衡监听器的名字，该字段为可选字段，如果不填写则采用默认值 | 本例中取值 listenerTest |


结合公共请求参数和接口请求参数，最终得到的请求形式如下：

```
https://lb.api.qcloud.com/v2/index.php?Action=CreateLoadBalancerListeners
&Region=gz
&Timestamp=1465750149
&Nonce=46364
&SecretId=AKIDxxxxugEY
&Signature=5umi9gUWpTTyk18V2g%2FYi56hqls%3D
&loadBalancerId=lb-abcdefgh
&listeners.1.loadBalancerPort=80
&listeners.1.instancePort=80
&listeners.1.protocol=2
&listeners.1.healthSwitch=1
&listeners.1.listenerName=listenerTest
  
```
上述请求的返回结果如下：
```
{
  "code" : 0,
  "message" : "",
  "requestId" : 123
}
```
可以根据[查询负载均衡任务状态](/doc/api/244/4007)异步接口查询API来查看该requestId对应的任务是否成功。

## 3. 绑定后端云服务器到负载均衡实例上
创建完监听器后再将云服务器绑定到负载均衡实例上，具体绑定后端云服务器到负载均衡信息见[绑定后端服务器到负载均衡](/doc/api/244/1265)页面。

这里我们将两台云服务器绑定到上面创建的负载均衡实例上，其中两台云服务器的唯一ID分别为：ins-5678test，ins-1234test。公共请求参数的Action字段为RegisterInstancesWithLoadBalancer，接口请求参数如下表。

| 参数名称 | 描述 | 取值 |
|---------|---------|---------|
| loadBalancerId | 负载均衡实例唯一ID | 取刚刚创建的负载均衡实例的唯一ID，lb-abcdefgh |
| backends.1.instanceId | 绑定到负载均衡实例上的云服务器的唯一ID  | 本例中取第一台云服务器唯一ID，ins-5678test |
| backends.1.weight | 绑定到负载均衡实例上的云服务器的权重 | 本例中取默认值 10 |
| backends.2.instanceId | 绑定到负载均衡实例上的云服务器的唯一ID  | 本例中取第一台云服务器唯一ID，ins-1234test |
| backends.2.weight | 绑定到负载均衡实例上的云服务器的权重 | 本例中取默认值 10 |


结合公共请求参数和接口请求参数，最终的请求形式如下：
```
https://lb.api.qcloud.com/v2/index.php?Action=CreateLoadBalancerListeners
&Region=gz
&Timestamp=1465750149
&Nonce=46364
&SecretId=AKIDxxxxugEY
&Signature=5umi9gUWpTTyk18V2g%2FYi56hqls%3D
&loadBalancerId=lb-abcdefgh
&backends.1.instanceId=ins-5678test
&backends.1.weight=10
&backends.2.instanceId=ins-1234test
&backends.2.weight=10
```
上述请求的返回结果如下：
```
{
  "code" : 0,
  "message" : "",
  "requestId" : 1234
}
```
可以根据[查询负载均衡任务状态](/doc/api/244/4007)异步接口查询API来查看该requestId对应的任务是否成功。

## 4. 查询负载均衡实例并使用
最后查询一下该负载均衡实例的VIP 或者域名，具体的查询负载均衡实例列表的接口详见接口[查询负载均衡实例列表](/doc/api/244/1261)。

公共请求参数的Action字段为 DescribeLoadBalancers，接口请求参数如下表。

| 参数名称 | 描述 | 取值 |
|---------|---------|---------|
| loadBalancerIds.1 | 负载均衡实例唯一ID | 本例中取刚刚创建的负载均衡实例的唯一ID，lb-abcdefgh |

结合公共请求参数和接口请求参数，最终的请求形式如下：
```
https://lb.api.qcloud.com/v2/index.php?Action=DescribeLoadBalancers
&Region=gz
&Timestamp=1465750149
&Nonce=46364
&SecretId=AKIDxxxxugEY
&Signature=5umi9gUWpTTyk18V2g%2FYi56hqls%3D
&loadBalancerIds.1=lb-abcdefgh
```

输出
```
{
  "code" : 0,
  "message" : "",
  "totalCount" : 1,
  "loadBalancerSet":[
 	{
            "loadBalancerId": "qlb5feb7941833ca285c65ff7528393173e",
            "unLoadBalancerId": "lb-abcdefgh",
            "loadBalancerName": "test",
            "loadBalancerType": 2,
            "domain": "20de02-0.gz.1251000011.clb.myqcloud.com",
            "loadBalancerVips": [
                "203.195.128.180"
            ],
            "status": 1,
            "createTime": "2016-09-01 16:08:24",
            "statusTime": "2016-09-02 16:04:59",
            "sessionExpire": 0,
            "vpcId": 0,
            "subnetId": 0,
            "projectId": 0,
            "openBgp": false
        }
   ]
}
```

根据查询结果，可以利用负载均衡实例的VIP ： 203.195.128.180 或者域名 20de02-0.gz.1251000011.clb.myqcloud.com 来将请求根据负载均衡监听器的规则转发到后端绑定的云服务器上，实现了负载均衡服务。
