## 1. 接口描述

本接口 (DescribeInstances) 用于获取一个或多个实例的详细信息。

接口请求域名：<font style="color:red">cvm.api.qcloud.com</font>

 
* 可根据实例ID，实例名称或者实例状态作过滤条件, 来获取实例列表。
* 如果参数为空，返回当前用户一定数量（limit所指定，默认为20）的实例。
* 实例存在状态的概念，状态列表如下：

| 状态ID | 状态名|
|---------|---------|
| 1 |故障 |
| 2 |运行中 
| 3 |创建中 
| 4 |已关机 
| 5 |已退还
| 6 |退还中  
| 7 |重启中 
| 8 |开机中
| 9 |关机中
| 10|密码重置中
| 11|格式化中
| 12|镜像制作中
| 13|带宽设置中
| 14|重装系统中
| 15|域名绑定中
| 16|域名解绑中
| 17|负载均衡绑定中
| 18|负载均衡解绑中
| 19|升级中
| 20|秘钥下发中
| 21|维护中(不能对实例进行操作<br>但不影响正常运行)

## 2. 输入参数

以下请求参数列表仅列出了接口请求参数，其它参数见[公共请求参数](https://cloud.tencent.com/doc/api/229/1230)页面。

| 参数名称 | 是否必选  | 类型 | 描述 |
|---------|---------|---------|---------|
| instanceIds.n| 否| String|过滤条件：按照一个或者多个实例ID过滤；可通过 [DescribeInstances](https://cloud.tencent.com/doc/api/229/831) API返回值中的 unInstanceId 获取（此接口支持同时传入多个ID。此参数的具体格式可参考API[简介](https://cloud.tencent.com/doc/api/229/568)的`id.n`一节）。
| lanIps.n| 否| String| 过滤条件：按照一个或者多个实例的内网（或公网）IP过滤（此接口支持同时传入多个ID。此参数的具体格式可参考API[简介](https://cloud.tencent.com/doc/api/229/568)的`id.n`一节）。
| searchWord| 否| String| 过滤条件：按照实例名过滤。|
| status| 否| Int| 过滤条件：实例的状态，状态的列举见上。
| projectId| 否| Int| 过滤条件：[项目ID](https://cloud.tencent.com/doc/api/403/%E5%88%9B%E5%BB%BA%E9%A1%B9%E7%9B%AE)。|
| zoneId| 否| Int| 过滤条件：[可用区ID](https://cloud.tencent.com/doc/api/404/%E6%9F%A5%E8%AF%A2%E5%8F%AF%E7%94%A8%E5%8C%BA)。|
| offset| 否| Int| 偏移量，默认为0。
| limit| 否| Int| 返回数量，默认 20，最大值 100。|



## 3. 输出参数

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码。0表示成功，其他值表示失败。详见错误码页面的[公共错误码](https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。|
| message | String | 模块错误信息描述，与接口相关。详见错误码页面的[模块错误码](https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#2.E3.80.81.E6.A8.A1.E5.9D.97.E9.94.99.E8.AF.AF.E7.A0.81)。|
| totalCount| Int| 返回实例数量。|
| instanceSet| Array| 返回实例信息数组。|

其中 instanceSet 包含了多个实例信息，每个实例信息的数据结构如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| instanceName| String| 实例名称。
| unInstanceId| String| 实例ID，命名格式为“ins-xxxxxxxx”。
| uuid| String| 实例UUID。已废弃，推荐使用unInstanceId替代。
| lanIp| String| 内网IP。
| wanIpSet| Array| 公网IP列表。
| cpu| Int| 核数。
| mem| Int| 内存大小(G)。
| bandwidth| Int| 带宽大小(Mbps)。
| deviceClass| String| 设备类型。
| unImgId| String| 镜像ID，命名格式为“img-xxxxxxxx”。
| status| Int| 实例状态。
| Region| String| 实例所属地域。
| createTime| String| 创建时间。
| deadlineTime| String| 实例到期时间。如果是按量计费实例，则为“0000-00-00 00：00”。
| autoRenew| Int| [自动续费标识](https://cloud.tencent.com/doc/api/229/1746)，0为不自动续费，1：自动续费，2：不再续费。
| projectId| Int| [项目ID](https://cloud.tencent.com/doc/api/229/1335)。
| os| String| 系统名称。
| cvmPayMode| String| 实例计费模式。<br>0：按月结算的后付费<br>1：包年包月 <br>2：按量计费
| networkPayMode| String| 网络计费模式。<br> 0：按月结算的后付费<br>1：包年包月<br> 2：按流量<br> 3：按带宽
| zoneId| Int| 可用区ID。
| zoneName| String| 可用区名称。
| vpcId| String|私有网络ID。
| subnetId| String| 子网ID。
| isVpcGateway| String| 是否是VPC的[网关](https://cloud.tencent.com/doc/product/215/1682)。
| diskInfo| Array| 磁盘信息集合。

diskInfo 包含了多个磁盘信息，单个磁盘信息的数据结构如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| storageId| String| 磁盘ID。
| storageType| Int| 磁盘类型。<br>1：本地盘<br> 2：云盘
| storageSize| Int| 磁盘大小。
| rootId| String| 系统盘ID。
| rootSize| Int| 系统盘大小。|
| rootType| Int| 系统盘类型。<br>1：本地盘<br> 2：云盘


## 4. 示例

输入：

```
 https://cvm.api.qcloud.com/v2/index.php?Action=DescribeInstances
 &instanceIds.1=ins-xxxxxxxx
 &instanceIds.2=ins-xxxxxxxx
 &<公共请求参数>
```

输出：

```
{
    "code" : 0,
    "message" : "",
    "totalCount" : 2,
    "instanceSet" : [
        {
            "instanceName" : "测试实例1",
            "instanceId": "qcvm12345",
            "uuid" : "00049c1d-b817-4ce8-b96e-3ffff23606a0",
            "lanIp" : "10.0.0.1",
            "wanIpSet" : ["168.0.0.1"],
            "cpu"   : 2,
            "mem"   : 16,
            "diskInfo" : {"storageSize" : 0,"storageType" : 1,"storageId" : 0},
            "bandwidth" : 100,
            "deviceClass" : "VSELF",
            "imageId" : 2,
            "unImgId" : "img-d4tetest",
            "unInstanceId" : "ins-flp1test",
            "status" : 2,
            "Region" : "gz",
            "createTime" : "2014-07-29 15:08:39", 
            "statusTime" : "2014-08-05 17:37:56",
            "deadlineTime" : "0000-00-00 00:00:00",
            "autoRenew" : 1
            "zoneId" : 800001
            "zoneName" : "广州一区"
            "vpcId" : "gz_vpc_1"
            "subnetId" : "gz_subnet_24"
            "isVpcGateway" : 0
        },
        {
            "instanceName" : "测试实例2",
            "instanceId": "qcvm23456",
            "uuid" : "00049c1d-b817-4ce8-b96e-3ffff23606a1",
            "lanIp" : "10.0.0.2",
            "wanIpSet" : ["168.0.0.3"],
            "cpu"   : 2,
            "mem"   : 16,
            "diskInfo" : {"storageSize" : 0,"storageType" : 1,"storageId" : 0},
            "bandwidth" : 100,
            "deviceClass" : "VSELF",
            "imageId" : 0,
            "unImgId" : "img-d4tesyhs",
            "unInstanceId" : "ins-1234test",
            "status" : 2,
            "Region" : "gz",
            "createTime" : "2014-07-29 15:08:39", 
            "statusTime" : "2014-08-05 17:37:56",
            "deadlineTime" : "0000-00-00 00:00:00",
            "autoRenew" : 1
            "zoneId" : 800001
            "zoneName" : "广州一区"
            "vpcId" : "gz_vpc_2"
            "subnetId" : "gz_subnet_100"
            "isVpcGateway" : 0
        }
    ]
}
```






