## 1. 接口描述
本接口（InquiryMongoDBReplSetPrice）用于获取复制集实例价格(包年包月),支持新购、续费、升级实例时价格查询。
接口请求域名：<font style='color:red'>mongodb.api.qcloud.com </font>



## 2. 输入参数
以下请求参数列表仅列出了接口请求参数，正式调用时需要加上公共请求参数，见<a href='/doc/api/260/1753' title='公共请求参数'>公共请求参数</a>页面。其中，此接口的Action字段为InquiryMongoDBReplSetPrice。

不同的产品输入参数也不一样。具体是：

#### 2.1 新购实例时查询价格

| 参数名称 | 是否必选  | 类型 | 描述 |
|:---------|---------|---------|---------|
| operation | 是 | String | 必须填newmongodb，表示新购实例 |
| zoneId | 是 | Int | 可用区ID，请使用查询可创建规格（支持可用区、配置自定义）接口获取可创建的可用区 |
| typeId | 是 | String | 实例类型英文名称。 GIO：高IO版；TGIO：高IO万兆 |
| memory | 是 | Int | 实例内存大小，每一个内存值对应一个可选的磁盘大小范围，单位：MB |
| diskSize | 是 | Int | 实例磁盘大小，单位：GB |
| secondaryNum | 是 | Int | 复制集从节点个数，暂时只支持节点数为1、2 |
| version | 是 | Int | 数据库版本号，比如：MONGO_3_MMAP、MONGO_3_WT |
| goodsNum | 是 | Int | 一次购买的实例数 |
| period | 是 | Int | 购买时长, 单位：月， 取值范围 [1,2,3,4,5,6,7,8,9,10,11,12,24,36]|

#### 2.2 续费实例时查询价格

| 参数名称 | 是否必选  | 类型 | 描述 |
|:---------|---------|---------|---------|
| operation | 是 | String | 必须填renewmongodb，表示续费实例 |
| instanceId | 是 | String | 待操作的实例ID，可通过 DescribeMongoDBReplSet 接口返回值中的 instanceId 获取。|
| period | 是 | Int | 续费时长，单位：月， 取值范围 [1,2,3,4,5,6,7,8,9,10,11,12,24,36] |

#### 2.3 升级实例时查询价格

| 参数名称 | 是否必选  | 类型 | 描述 |
|:---------|---------|---------|---------|
| operation | 是 | String | 必须填upgrademongodb，表示升级实例 |
| instanceId | 是 | String | 待操作的实例ID，可通过 DescribeMongoDBReplSet 接口返回值中的 instanceId 获取。 |
| memory | 是 | Int | 升级后的实例内存大小，每一个内存值对应一个可选的磁盘大小范围，单位：MB |
| diskSize | 是 | Int | 升级后的实例磁盘大小，单位：GB |

## 3. 输出参数
| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| code | Int | 公共错误码, 0表示成功，其他值表示失败。详见错误码页面的<a href='https://cloud.tencent.com/doc/api/372/%E9%94%99%E8%AF%AF%E7%A0%81#1.E3.80.81.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81' title='公共错误码'>公共错误码</a>。|
| message | String | 错误信息描述, 成功时，该值为空 |
| codeDesc | String | 业务侧错误码英文描述。成功时返回Success，错误时返回具体业务错误原因。 |
| data | Object | 实例价格内容 |

其中，data 表示实例价格内容，其参数构成如下：

| 参数名称 | 类型 | 描述 |
|---------|---------|---------|
| data.price | Int | 实例的价格，单位：分（人民币） | 

## 4. 错误码
以下错误码表列出了该接口的业务逻辑错误码。

| 错误代码 | 英文提示 | 错误描述 |
|---------|---------|---------|
|11050|InvalidParameter|业务参数错误|
|11060|ServiceUnavailable|请求的区域暂时不提供服务|
|11071|UserNotInWhiteList|用户不在白名单中|
|11062|MemSizeExceedMaxLimit|请求的内存容量超过最大上限|
|11063|MemSizeIllegal|请求的内存内存不是1024的整数倍|
|11064|MemSizeNotInRange|请求的内存容量不在售卖范围内|
|11065|DiskSizeIllegal|请求的请求的磁盘非整数|
|11066|DiskSizeNotInRange|请求的磁盘不在售卖范围内|
|11067|PeriodNotInRange|请求的时长不在售卖范围内|
|11072|SecondaryNumNotInRange|复制集模式下，从节点个数不在售卖范围内|
|11056|InstanceNotExists|没有找到对应实例|
|11051|InstanceDeleted|实例到期已被回收|
|11068|UpgradeNotAllowedOnZoneId|该区域不支持升级实例|
|11069|DiskSizeLessThanRealSize|请求的磁盘容量小于实际值|
|11070|MemSizeLessThanRealSize|请求的内存容量小于实际值|

## 5. 示例
输入
<pre>
https://mongodb.api.qcloud.com/v2/index.php?Action=InquiryMongoDBReplSetPrice
&<<a href="https://cloud.tencent.com/doc/api/229/6976">公共请求参数</a>>
&operation=newmongodb
&zoneId=100002
&typeId=GIO
&memory=8192
&diskSize=245
&secondaryNum=2
&version=MONGO_3_MMAP
&goodsNum=1
&period=1
</pre>
输出
```
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "data": {
        "price": 188800
    }
}
```