### Notes
Tencent Cloud MongoDB provides two user names "rwuser" and "mongouser" by default to support the "MONGODB-CR" and "SCRAM - SHA - 1" authentication respectively. The connecting URI for the two types of authentication are formed differently. For more information, please see [Connection Examples](https://cloud.tencent.com/doc/product/240/3563).

In PHP, [Two Series of Drivers](https://docs.mongodb.com/ecosystem/drivers/php/) can be used to connect with and operate MongoDB. They are:
- "mongodb"([PHP Official Document](http://php.net/manual/en/set.mongodb.php))  - MongoDB recommends "mongodb" officially, but PHP version 5.4 or above is required.
- "mongo"([PHP Official Document](http://php.net/manual/en/book.mongo.php)) - "mongo" is older than "mongodb", but still can be used. Please choose version 1.6 to use.

Both drivers are used below to demonstrate the process of connecting with Tencent Cloud MongoDB and perform read and write operation.
 
### Using the Driver "mongodb"
Please see [Here](http://php.net/manual/zh/mongodb.installation.php) for how to install "mongodb".
**Driver "mongodb" support "MONGODB-CR" and "SCRAM-SHA-1" authentication**. For more information, please see[Connection Examples](https://cloud.tencent.com/doc/product/240/3563).

Sample codes:
```
<?php
// Form the connecting URI
$uri = 'mongodb://mongouser:thepasswordA1@10.66.187.127:27017/admin';
$manager = new MongoDB\Driver\Manager($uri);

// Prepare to write data
$document1 = [
    'username' => 'lily',
    'age'      => 34,
    'email'    => 'lily@qq.com'
];

// The driver preprocesses data. You can find that the "_id" of MongoDB is generated by the driver.
$bulk = new MongoDB\Driver\BulkWrite;
$_id1 = $bulk->insert($document1);

$result = $manager->executeBulkWrite('tsdb.table1', $bulk);

// Or include the following codes when necessary to ensure data is written to most nodes
// $writeConcern = new MongoDB\Driver\WriteConcern(MongoDB\Driver\WriteConcern::MAJORITY, 1000);
// $result = $manager->executeBulkWrite('testdb.testcollection', $bulk, $writeConcern);

// Query
$filter = ['_id' => $_id1];
$query = new MongoDB\Driver\Query($filter);
$rows = $manager->executeQuery('tsdb.table1', $query); // You also have the option to read data from the slave library first. Please see relevant documentation for more information.
foreach($rows as $r){
   print_r($r);
}


```
**Output:**
```
stdClass Object
(
    [_id] => MongoDB\BSON\ObjectID Object
        (
            [oid] => 582c001618c90a16363abc31
        )

    [username] => lily
    [age] => 34
    [email] => lily@qq.com
)
```


### Using driver "mongo"
**Driver "mongo" only support "MONGODB-CR" authentication**, and thus connect the database through "rwuser". Please see[Connection Examples](https://cloud.tencent.com/doc/product/240/3563).

Sample codes:

```
<?php
// It is recommended to use URI for connection. Either of the two URI's is OK
$uri = "mongodb://rwuser:thepasswordA1@10.66.187.127:27017/admin?authMechanism=MONGODB-CR";
$uri = "mongodb://rwuser:thepasswordA1@10.66.187.127:27017/?authMechanism=MONGODB-CR&authSource=admin";
$connection = new MongoClient($uri);

/*
// Or you can use the following codes
$connection = new MongoClient("mongodb://10.66.116.103:27017/admin",
    array(
        "username" => "rwuser",
        "password" => "password",
        "authMechanism" => "MONGODB-CR"
    )
);
*/
$db = $connection->tsdb;
$collection = $db->table1;

$q = array(
    'id' => 1,
    'test1' => 'xxx',
    'ss' => 'xxxxxxxx',
);
$collection->save($q);
$one = $collection->findOne();
var_dump($one);
```

### It is recommended to use library PHPLIB (encapsulated on the basis of driver "mongodb")
It is recommended to use driver "mongdb" with [PHPLIB](http://php.net/manual/zh/mongodb.tutorial.library.php). For more information, please [see relevant documentation](http://mongodb.github.io/mongo-php-library/tutorial/crud/).
Please see [Here](http://mongodb.github.io/mongo-php-library/getting-started/) for how to install PHPLIB. Please note the dependencies of PHPLIB on the driver "mongodb".

Sample codes:
```
<?php
require_once __DIR__ . "/vendor/autoload.php";

// Initialization
$mongoClient = new MongoDB\Client('mongodb://mongouser:thepasswordA1@10.66.187.127:27017/admin');

// Use "users" collection under the library "demo"
$collection = $mongoClient->demo->users;

// Write a piece of data
$insertOneResult = $collection->insertOne(['name' => 'gomez']);

printf("Inserted %d document(s)\n", $insertOneResult->getInsertedCount());
var_dump($insertOneResult->getInsertedId());

// Query data
$document = $collection->findOne(['name' => 'gomez']);

var_dump($document);

```
Output
```
Inserted 1 document(s)
object(MongoDB\BSON\ObjectID)#11 (1) {
  ["oid"]=>
  string(24) "57e3bf20bf605714a53e69c1"
}
object(MongoDB\Model\BSONDocument)#16 (1) {
  ["storage":"ArrayObject":private]=>
  array(2) {
    ["_id"]=>
    object(MongoDB\BSON\ObjectID)#14 (1) {
      ["oid"]=>
      string(24) "57e3bf20bf605714a53e69c1"
    }
    ["name"]=>
    string(5) "gomez"
  }
}

```

