## 1 PHP版本

PHP MongoDB驱动文档:

http://cn2.php.net/manual/en/book.mongo.php

https://docs.mongodb.org/ecosystem/drivers/php/

PHP示例代码:

```
<?php
$connection = new MongoClient("mongodb://10.66.116.103:27017",
    array(
        "username" => "rwuser",
        "password" => "password",
        "authMechanism" => "MONGODB-CR",
    )
);
$db = $connection->tsdb;
$collection = $db->table1;

$q = array(
    'id' => 1,
    'test1' => 'xxx',
    'ss' => 'xxxxxxxx',
);

$collection->save($q);

$one = $collection->findOne();

var_dump($one);
?>
```

**输出：**


```
array(4) {
  ["_id"]=>
  object(MongoId)#7 (1) {
    ["$id"]=>
    string(24) "5673beed041ee2b1458b4567"
  }
  ["id"]=>
  int(1)
  ["test1"]=>
  string(3) "xxx"
  ["ss"]=>
  string(8) "xxxxxxxx"
}
```

## 2 Node.js版本

Node.js MongoDB驱动文档:

https://docs.mongodb.org/ecosystem/drivers/node-js/

Shell:

```
npm install mongodb sprintf-js --save
( 如遇安装不成功可以尝试更换源，npm config set registry http://registry.cnpmjs.org )
npm init
```

**Node.js示例代码:**

```
'use strict';

var mongoClient = require('mongodb').MongoClient,
    sprintf = require("sprintf-js").sprintf,
    assert = require('assert');

var username = 'rwuser',
    password = '1234567a',
    host     = '10.66.117.214',
    port     = '27017',
    dbName   = 'havefun';

// 拼接URI， 注意需要使用鉴权参数 authMechanism=MONGODB-CR
var url = sprintf('mongodb://%s:%s@%s:%d/%s?authMechanism=MONGODB-CR', username, password, host, port, dbName);
console.info("url:", url);

mongoClient.connect(url, function(err, db) {
    assert.equal(null, err);
    console.log("Connected correctly to server");

    // 连接成功，选择一个集合(表)
    var col = db.collection('demoCol');

    // 插入数据
    col.insertOne(
        {
            a: 1,
            something: "yy"
        }, 
        //可选参数
        //{
        //    w: 'majority' // 开启 “大多数”模式，保证数据写入Secondary节点
        //}, 
        function(err, r) {
            assert.equal(null, err);
            // 断言写入成功
            assert.equal(1, r.insertedCount);
    
            // 查询数据
            col.find().toArray(function(err, docs) {
                assert.equal(null, err);
                console.info("docs:", docs);
                db.close();
            });   

        }
    );

});
```

**输出:**

```
[root@VM_2_167_centos node]# node index.js 
url: mongodb://rwuser:1234567a@10.66.117.214:27017/havefun?authMechanism=MONGODB-CR
Connected correctly to server
docs: [ { _id: 567a1bf26773935b3ff0b42a, a: 1, something: 'yy' } ]
```

## 3 Java版本
Java MongoDB驱动文档
http://mongodb.github.io/mongo-java-driver/3.0/driver/getting-started/
Java Jar包下载
https://oss.sonatype.org/content/repositories/releases/org/mongodb/mongo-java-driver/
请选择3.0以上版本下载

**Java示例代码:**
```
package mongodbdemo;

import org.bson.*;
import com.mongodb.*;
import com.mongodb.client.*;

public class MongodbDemo {

    public static void main(String[] args) {
        String mongoUri = "mongodb://rwuser:1234567a@10.66.122.28:27017/admin?authMechanism=MONGODB-CR";
        MongoClientURI connStr = new MongoClientURI(mongoUri);
        MongoClient mongoClient = new MongoClient(connStr);
        try {
            // 使用名为 someonedb 的数据库
            MongoDatabase database = mongoClient.getDatabase("someonedb");
            // 取得集合/表 someonetable 句柄
            MongoCollection<Document> collection = database.getCollection("someonetable");

            // 准备写入数据
            Document doc = new Document();
            doc.append("key", "value");
            doc.append("username", "jack");
            doc.append("age", 31);

            // 写入数据
            collection.insertOne(doc);
            System.out.println("insert document: " + doc);

            // 读取数据
            BsonDocument filter = new BsonDocument();
            filter.append("username", new BsonString("username"));
            MongoCursor<Document> cursor = collection.find(filter).iterator();
            while (cursor.hasNext()) {
                System.out.println("find document: " + cursor.next());
            }

        } finally {
            //关闭连接
            mongoClient.close();
        }
    }
}
```

**输出:**

```
INFO: Opened connection [connectionId{localValue:2, serverValue:67621}] to 10.66.122.28:27017
insert document: Document{{key=value, username=jack, age=31, _id=56a6ebb565b33b771f9826dd}}
find document: Document{{_id=56a3189565b33b2e7ca150ba, key=value, username=jack, age=31}}
Jan 26, 2016 11:44:53 AM com.mongodb.diagnostics.logging.JULLogger log
INFO: Closed connection [connectionId{localValue:2, serverValue:67621}] to 10.66.122.28:27017 because the pool has been closed.
```