## Performance Monitor
PostgreSQL provides various performance monitoring options to make it easy for users to view and obtain the operation information of instances. You can check the information in "Instance Management" -> "System Monitoring" in the PostgreSQL console.

## `pg_stat_statements`
You can view detailed performance metrics of pg from the [`pg_stat_statements`](https://www.postgresql.org/docs/9.4/static/pgstatstatements.html) view.

## Available Monitor Metrics
| Metric Name | Metric Name | Metric Description | Unit |
| CPU utilization | cpu | CPU utilization of the instance. This may go beyond 100% due to flexible CPU limitation strategies when idle | % |
| Occupied storage | storage | Available disk space occupied by the instance | GB |
| Disk IOPS | iops | IOPS (number of requests per second) of the instance | times/sec |
| Input flow | in_flow | Input flow generated by data read/write operations for the instance | KB/sec |
| Output flow | out_flow | Output flow generated by data read/write operations for the instance | KB/sec |
| Number of connections | connections | Historical trend for the number of active connections of the instance | count |
| Number of requests | read_write_calls | Total number of read/write requests (add, delete, modify, query) per minute | times/min |
| Number of read requests | read_calls | Total number of read requests per minute | times/min |
| Number of write requests | write_calls | Total number of write requests per minute | times/min |
| Number of other requests | other_calls | Total number of requests other than read/write requests (such as Drop), accumulated by the minute | times/min |
| Cache hit rate | hit_percent | Data cache hit rate | % |
| Average execution latency | sql_runtime_avg | Average execution time for all SQL requests (SQL in transactions not included). | ms |
| TOP 10 longest execution latencies | sql_runtime_avg | Average execution latency for the top 10 longest SQL requests | ms |
| TOP 10 shortest execution latencies | sql_runtime_min | Average execution latency for the top 10 shortest SQL requests | ms |
| Number of remaining XID | remain_xid | Number of remaining Transaction IDs. There are a maximum of 2^32 Transaction IDs, it is suggested to execute "vacuum full" manually if the number falls below 1,000,000. | count |
| Synchronization difference between master/slave XLOG | xlog_diff | (Sample is taken every minute) synchronization difference between master XLOG and slave XLOG. This represents synchronization delay, the smaller the better. | byte |



