## 1.数据导入概述
由于分布式数据库的分布式架构对用户透明，一般情况下，只需要预先建好表结构。可以使用mysqldump、或其他Navicat、SQLyog等MySQL客户端进行迁移。笔者对迁移步骤总结如下：

1. 第一步：准备导入导出环境
2. 第二步：导出源表的表结构和数据
3. 第三步：修改建表语句并在目的表中创建表结构
4. 第四步：导入数据

## 2.准备导入导出环境
准备迁移数据前，您需要准备好入下环境：

- 云服务器
	- 建议配置CPU 2核，内存8GB，磁盘500GB以上（取决于数据量大小）
	- linux
	- 安装MySQL客户端
	- 如果您迁移的数据量较小(<10GB)，也可以通过外网（互联网）直接导入，无需准备
- 分布式云数据库DCDB：
	- 根据预期选择大小，并根据源库字符集，表名大小写，innodb_page_size大小进行初始化
	- 创建帐号，该帐号建议开启全局所有权限
	- 必要时开启外网IP

## 3.导出源表的表结构和数据
### 3.1 演示环境
- 操作库：caccts
- 操作表：t_acct_water_0
- 源库：单实例mysql
- 目标库：DCDB for Percona、MariaDB

### 3.2 在源库导出表结构
通过命令`mysqldump -u username -p password -d dbname tablename > tablename.sql`导出表结构

```
//命令实例
mysqldump -utest -ptest1234 -d -S /data/4003/prod/mysql.scok caccts t_acct_water_0 > table.sql
```
### 3.2 在源库导出表数据

通过命令`mysqldump -c -u username -p password dbname tablename > tablename.sql`导出表结构

```
//命令实例
mysqldump -c -t -utest -ptest1234  -S /data/4003/prod/mysql.scok caccts t_acct_water_0 > data.sql
```

>注意：导出数据必须通过mysqldump工具导出，并且加上 -c 参数，因为这样导出的数据行都带有列名字段，不带列名字段的sql会被DCDB for Percona、MariaDB拒绝掉。-t 参数的意义是不导出表结构，只导出表数据。

### 3.3 上传文件至云服务器某目录
上传前，您开启CVM外网访问地址，并请参考CVM上传文件说明：[Linux机器通过SCP上传文件](https://cloud.tencent.com/document/product/213/2133)，即可将文件上传,您至少需要上传刚刚导出的：
- 表结构sql：table.sql
- 数据sql：data.sql

## 4.修改建表语句并在目的表中创建表结构
打开刚刚导出的表结构文件 table.sql，参考如下格式语句添加主键和shardkey，并另存为 tablenew.sql。请注意[shardkey选择技巧和注意事项]()：
```CREATE TAbLE（
	列名称1 数据类型,
	列名称2 数据类型,
	列名称3 数据类型,
	....，
	PRIMARY KEY('列名称n')）
	ENGINE=INNODB DEFAULT CHARSET=xxxx 
	shardkey=keyname
```

>注意：必须要设置主键，必须指定shardkey，必须注意表名大小问题，建议删除多余注释，否则建表可能不成功。

![](https://mc.qcloudimg.com/static/img/1cd921ececbacf81226a69a0eb5b919a/image.png)

## 5.导入数据
### 5.1 连接DCDB for Percona、MariaDB实例
在CVM上使用`mysql -u username -p password -h IP -P port `登录MySQL服务器；然后使用`use dbname`进入数据库

>注意：您可能需要先创建库。

### 5.2 导入表结构
使用刚刚上传的文件，用`source`命令导入数据

1. 先导入表结构：`source /文件路径/tablenew.sql；`
2. 再导入数据：`source /文件路径/data.sql；`
3. 校验导入情况：`select  count(*) from tablename;`

> 注意：需先导入建表语句，再导入数据。也可以通过mysql的source命令直接导入sql。

## 6.其他方案
整体来说，只要能够在导入数据前，在目的表先创建对应的表结构（需指定shardkey），就可以比较顺利的导入数据。