# 分布式版本编程与使用规范
> **注意：**
> 本文未特定知名的情况下，DCDB 均指代分布式云数据库 DCDB for Percona、MariaDB。

## 概述
DCDB 是部署在腾讯云公有云上的一种兼容 MySQL 协议和语法，支持自动水平拆分的分布式数据库。分布式数据库即业务获取是完整的逻辑库表，后端却将库表均匀的拆分到多个物理分片节点。目前，DCDB 默认部署主从架构且提供了容灾、备份、恢复、监控、迁移等方面的全套解决方案，适用于 TB 或 PB 级的海量数据库场景。
DCDB 采用的水平切分的分布式方案，即根据表中的数据的逻辑关系，将同一个表中的数据按照某种条件拆分到多台数据库（主机）上面，这种切分称为数据的水平切分。

## 使用规范
### 不兼容概述
以下为暂不支持的内容：
- 跨节点的 join。
- 批量插入如果拆分到两个不同的分片，将不支持。此时仅支持 shardkey 取值一样的情况下的批量操作。
- 视图、存储过程、触发器。
-	自建分区。
- MySQL 3.4.0以下的版本、SSL、压缩协议。
关于兼容性详情请参考[兼容性说明](https://cloud.tencent.com/doc/product/237/%E5%85%BC%E5%AE%B9%E6%80%A7%E8%AF%B4%E6%98%8E)。

### 数据库连接
分布式云数据库 DCDB 仍然提供了唯一的 IP，端口供用户访问和使用，示例如下：
>**注意：**
>只有在云服务器 CVM 上才可通过内网地址进行连接，否则需要开通外网地址。

```
mysql -h10.231.136.34 -P3306 -utest12 -ptestpassword
```

### 建表
分表创建时必须指定shardkey的值（通常写作建表语句最后面），该值为表中的一个字段名字，会用于后续sql的路由选择：

```
	mysql> create table test1 ( a int, b int, c char(20),primary key (a,b),unique key u_1(a,c) ) shardkey=a;
	Query OK, 0 rows affected (0.07 sec)

```
由于在DCDB中，shardkey对应后端数据库的分区字段，因此必须是主键以及所有唯一索引的一部分，否则没法创建表：

```
	mysql> create table test1 ( a int, b int, c char(20),primary key (a,b),unique key u_1(a,c),unique key u_2(b,c) ) shardkey=a;;

	此时有一个唯一索引u_2不包含shardkey，没法创建表，会报如下错误：
	ERROR 1105 (HY000): A UNIQUE INDEX must include all columns in the table's partitioning function

	例如正确的写法：
	 create table test1 ( a int, b int, c char(20),primary key (a,b),unique key u_1(a,c) ) shardkey=a;;

```	
因为主键索引或者unique key索引意味着需要全局唯一，而要实现全局唯一索引则必须包含shard key字段



除了上面的限制外，shardkey字段还有如下要求：

	1.shardkey字段的类型必须是int,bigint,smallint/char/varchar
	2.shardkey字段的值不应该有中文，网关不会转换字符集，所以不同字符集可能会路由到不同的分区
	3.不要update shardkey字段的值
	4.shardkey=a 放在sql的最后面
	5.访问数据尽量都能带上shardkey字段，这个不是强制要求，但是不带shardkey的sql会路由到所有节点，影响性能。

### 增删查改
`select`：建议您带上分表键字段，若不带上也可以使用，但此时搜索数据需要全表扫描，然后网关进行结果集聚合，对性能有极大影响。
```
mysql> select * from test1 where a=2;
+------+------+---------+
| a     | b     | c        |
+------+------+---------+
| 2     | 3     | record2 |
| 2     | 4     | record3 |
+------+------+---------+
2 rows in set (0.00 sec)
```

`insert/replace`：字段必须包含分表键，否则会拒绝执行该sql，因为 proxy 无法确认应该插入到哪一个分片。
```
mysql> insert into test1 (b,c) values(4,"record3");
ERROR 1105 (07000): Proxy Warning - sql have no shardkey

mysql> insert into test1 (a,c) values(4,"record3");
Query OK, 1 row affected (0.01 sec)
```

`delete/update`为了安全考虑，我们要求执行该类 sql 的时候必须带有 where 条件，否则将拒绝执行该 sql 命令。
```
mysql> delete from test1;
ERROR 1005 (07000): Proxy Warning - sql is not legal,tokenizer_gram went wrong

mysql> delete from test1 where a=1;
Query OK, 1 row affected (0.01 sec)
```

### JOIN
当前 DCDB 只支持单个 shard 内的 join 操作，单个 shard 意味着在一个事务内的所有 sql 必须操作同一个 shard，因此必须指定分表键字段。
```
mysql> create table test1 ( a int , b int, c char(20) ) shardkey=a;
Query OK, 0 rows affected (1.56 sec)

mysql> create table test2 ( a int , d int, e char(20) ) shardkey=a;
Query OK, 0 rows affected (1.46 sec)

mysql> insert into test1 (a,b,c) values(1,2,"record1"),(2,3,"record2");
Query OK, 2 rows affected (0.02 sec)

mysql> insert into test2 (a,d,e) values(1,3,"test2_record1"),(2,3,"test2_record2");
Query OK, 2 rows affected (0.02 sec)

mysql> select * from test1 join test2 on test1.a=test2.a;
ERROR 1105 (07000): Proxy Warning - join shardkey error
mysql> select * from test1 join test2 on test1.a=test2.a where test1.a=1;
+------+------+---------+------+------+---------------+
| a     | b     | c        | a     | d     | e                |
+------+------+---------+------+------+---------------+
| 1     | 2     | record1 | 1    | 3      | test2_record1 |
+------+------+---------+------+------+---------------+
1 row in set (0.00 sec)
```

>**注意：**
>`mysql> select * from test1 join test2 on test1.a=test2.a;`语句在后续版本中会支持，但必须是 inner join 且 inner join 的 where 条件必须是两张表的 shardkey 字段相等。

### 事务

DCDB 支持分布式事务，为了使用分布式事务功能，在创建完集群之后连接任意一个 proxy 运行如下 sql 进行初始化。
>**注意：**
>该 sql 会创建 xa.gtid_log_t，用户在后续使用中切勿对其进行任何操作。

```
	mysql> xa init;
	Query OK, 0 rows affected (0.03 sec)
```

新增 sql 如下：
1. `select gtid()`
获取当前分布式事务的 gtid (事务的全局唯一性标识)，如果该事务不是分布式事务则返回空。
>**注意：**
>gtid 的格式：‘网关 id’-‘网关随机值’-‘序列号’-‘时间戳’-‘分区号’，例如 c46535fe-b6-dd-595db6b8-25

2. `select gtid_state(“gtid”)`
获取 gtid 的状态，可能的结果如下：
 1\. COMMIT，标识该事务已经或者最终会被提交。
 2\. ABORT，标识该事务最终会被回滚。
 3\. 空，由于事务的状态会在一个小时之后清除，因此若在一个小时以内查询，标识事务最终会被回滚。若在一个小时之后查询，标识事务状态已经清除。

3. 运维命令
`xa recover`：向后端 set 发送 xa recover 命令，并进行汇总。
`xa lockwait`：显示当前分布式事务的等待关系（可以使用 dot 命令将输出转化为等待关系图）。
`xa show`：当前网关上正在运行的分布式事务。
		
建议的 sql 编程方式如下：
```
	(python 程序)			
		db = pymysql.connect(host=testHost, port=testPort, user=testUser, password=testPassword, database=testDatabase)
		cursor = db.cursor()
        try:
            cursor.execute("begin")
			
            #为一个账户 Bob 的余额减 1
            query = "update t_user_balance set balance = balance - 1  where user='Bob' and balance>1)
            affected = cursor.execute(query)
			if affected == 0: #余额不足，回滚事务
				cursor.execute("rollback")
				return 
				
            #为一个账户 John 的余额加 1
            query = "update t_user_balance set balance = balance + 1  where user='John')
            cursor.execute(query)
			
            # 为了安全起见，建议在这里执行"select gtid()"获取当前事务的 id 值，便于后续跟踪事务的执行情况
			
			#提交事务
            cursor.execute("commit")
            except pymysql.err.MySQLError as e:
			# 发生故障，回滚事务
            cursor.execute("rollback")
```

### 预处理
sql 类型支持：
```
PREPARE Syntax
EXECUTE Syntax
```
二进制协议支持：
```
COM_STMT_PREPARE
COM_STMT_EXECUTE
```
代码示例如下：
```
	mysql> select * from test1;
	+---+------+
	| a | b    |
	+---+------+
	| 5 |    6 |
	| 3 |    4 |
	| 1 |    2 |
	+---+------+
	3 rows in set (0.03 sec)
	
	mysql> prepare ff from "select * from test1 where a=?";
	Query OK, 0 rows affected (0.00 sec)
	Statement prepared
	
	mysql> set @aa=3;
	Query OK, 0 rows affected (0.00 sec)
	
	mysql> execute ff using @aa;
	+---+------+
	| a | b    |
	+---+------+
	| 3 |    4 |
	+---+------+
	1 row in set (0.06 sec)
```

### 子查询
DCDB 子查询目前只支持带 shardkey 的 derived table。
```
	mysql> select a from (select * from test1) as t;
	ERROR 7012 (HY000): Proxy ERROR:sql should has one shardkey
	mysql> select a from (select * from test1 where a=1) as t;
	+---+
	| a |
	+---+
	| 1 |
	+---+
	1 row in set (0.00 sec)
```

### 状态查询
通过sql可以查看proxy的配置以及状态信息，目前支持如下命令：
**查看可用命令**
```
	mysql> /*proxy*/help;
	+-----------------------+-------------------------------------------------------+
	| command               | description                                           |
	+-----------------------+-------------------------------------------------------+
	| show config           | show config from conf                                 |
	| show status           | show proxy status,like route,shardkey and so on       |
	| set sys_log_level=N   | change the sys debug level N should be 0,1,2,3        |
	| set inter_log_level=N | change the interface debug level N should be 0,1      |
	| set inter_time_open=N | change the interface time debug level N should be 0,1 |
	| set sql_log_level=N   | change the sql debug level N should be 0,1            |
	| set slow_log_level=N  | change the slow debug level N should be 0,1           |
	| set slow_log_ms=N     | change the slow ms                                    |
	| set log_clean_time=N  | change the log clean days                             |
	| set log_clean_size=N  | change the log clean size in GB                       |
	+-----------------------+-------------------------------------------------------+
	10 rows in set (0.00 sec)
```
**查看配置信息**
```
	mysql> /*proxy*/show config;
	+-----------------+--------------------+
	| config_name     | value              |
	+-----------------+--------------------+
	| version         | V2R120D001         |
	| mode            | group shard        |
	| rootdir         | /shard_922         |
	| sys_log_level   | 0                  |
	| inter_log_level | 0                  |
	| inter_time_open | 0                  |
	| sql_log_level   | 0                  |
	| slow_log_level  | 0                  |
	| slow_log_ms     | 1000               |
	| log_clean_time  | 1                  |
	| log_clean_size  | 1                  |
	| rw_split        | 1                  |
	| ip_pass_through | 0                  |
	+-----------------+--------------------+
	14 rows in set (0.00 sec)
```
**查看状态信息**
```
	mysql> /*proxy*/show status;
	+-----------------------------+------------------------------------------------------------------------------+
	| status_name                 | value                                                                        |
	+-----------------------------+------------------------------------------------------------------------------+
	| cluster                     | group_1499858910_79548                                                       |
	| set_1499859173_1:ip         | 10.49.118.165:5025;10.175.98.109:5025@1@IDC_4@0,10.231.23.241:5025@1@IDC_2@0 |
	| set_1499859173_1:hash_range | 0---31                                                                       |
	| set_1499911640_3:ip         | 10.49.118.165:5026;10.175.98.109:5026@1@IDC_4@0,10.231.23.241:5026@1@IDC_2@0 |
	| set_1499911640_3:hash_range | 32---63                                                                      |
	| set                         | set_1499859173_1,set_1499911640_3                                            |
	| db_table:pavel.ff           | shardkey:a                                                                   |
```

### 全局唯一字段
DCDB 支持一定意义上的自增字段，可以保证某个字段全局唯一和有序递增，但不保证连续性，具体使用方法如下：
创建 sequence：
DCDB 创建 sequence 和 MySQL 自增字段的语法一样，示例如下：
```
	mysql> create table auto_inc (a int,b int,c int auto_increment,d int,key auto(c),primary key p(a,d)) shardkey=d;
	Query OK, 0 rows affected (0.12 sec)
```

插入 sequence：
DCDB 插入 sequence 和 MySQL 自增字段一样，用户可以不传该字段的值，或者传 0，NULL，这时 DCDB 自动分配一个全局唯一的值，示例如下：
```
	mysql> insert into shard.auto_inc ( a,b,d,c) values(1,2,3,0),(1,2,4,0);
	Query OK, 2 rows affected (0.05 sec)
	Records: 2  Duplicates: 0  Warnings: 0
	
	mysql> select last_insert_id();
	+------------------+
	| last_insert_id() |
	+------------------+
	| 1                |
	+------------------+
	1 row in set (0.00 sec)
	
	mysql> select * from shard.auto_inc;
	+---+------+---+---+
	| a | b    | c | d |
	+---+------+---+---+
	| 1 |    2 | 2 | 4 |
	| 1 |    2 | 1 | 3 |
	+---+------+---+---+
	2 rows in set (0.03 sec)

	mysql> insert into shard.auto_inc ( a,b,d,c) values(2,2,3,NULL),(2,2,4,NULL);
	mysql> insert into shard.auto_inc ( a,b,d) values(3,2,3),(3,2,4);

	mysql> select * from shard.auto_inc;
	+---+------+---+---+
	| a | b    | c | d |
	+---+------+---+---+
	| 1 |    2 | 2 | 4 |
	| 2 |    2 | 4 | 4 |
	| 3 |    2 | 6 | 4 |
	| 1 |    2 | 1 | 3 |
	| 2 |    2 | 3 | 3 |
	| 3 |    2 | 5 | 3 |
	+---+------+---+---+
	6 rows in set (0.03 sec)
```	
    
更改当前 sequence 值，示例如下：
```
	alter table auto auto_increment=100
```
注意事项：
分布式数据库因其架构特殊性，在 proxy 正常调度切换、异常重启等过程中，sequence 无法保证连续性（但全局唯一），示例如下：
```
    mysql> insert into shard.auto_inc ( a,b,d,c) values(11,12,13,0),(21,22,23,0);
    Query OK, 2 rows affected (0.03 sec)

	mysql> select * from shard.auto_inc;
	+----+------+------+----+
	| a  | b    | c    | d  |
	+----+------+------+----+
	| 21 |   22 | 2002 | 23 |
	|  1 |    2 |    2 |  4 |
	|  2 |    2 |    4 |  4 |
	|  3 |    2 |    6 |  4 |
	|  1 |    2 |    1 |  3 |
	|  2 |    2 |    3 |  3 |
	|  3 |    2 |    5 |  3 |
	| 11 |   12 | 2001 | 13 |
	+----+------+------+----+
	8 rows in set (0.03 sec)

	mysql> select last_insert_id();
	+------------------+
	| last_insert_id() |
	+------------------+
	| 2001             |
	+------------------+
```

### 两级分区

DCDB 使用 HASH 方式进行数据拆分，不利于删除特定条件的数据，如流水类型和旧的数据，为了解决这个问题，可以使用两级分区。

DCDB 支持 RANGE 格式的两级分区，具体建表语法和 MySQL 分区语法类似，示例如下：
```
	CREATE TABLE employees (
	    id INT NOT NULL,
	    fname VARCHAR(30),
	    lname VARCHAR(30),
	    hired DATE NOT NULL DEFAULT '1970-01-01',
	    separated DATE NOT NULL DEFAULT '9999-12-31',
	    job_code INT,
	    store_id INT
	)  shardkey=id 	PARTITION BY RANGE ( YEAR(hired) ) (
	    PARTITION p0 VALUES LESS THAN (1991),
	    PARTITION p1 VALUES LESS THAN (1996),
	    PARTITION p2 VALUES LESS THAN (2017)，
	    PARTITION p2 VALUES LESS THAN (2018)
	);
```
>注意：
>分区使用的是小于符号，若需存储往年的数据（例如 2016 年），需要创建 < 2017 的分区，用户只需创建到当前的时间分区，DCDB 会自动增加后续分区，默认往后创建 3 个分区，以 YEAR 为例，DCDB 会自动创建 2017，2018，2019 的分区，后续也会自动增减。

目前支持按年月日三种 RANGE 方式： RANGE(YEAR(hired)) ， RANGE (MONTH(hired)) ，RANGE(DAY(hired))，后续会支持 LIST 二级分区。

### SQL 命令限制

DCDB 目前支持的 sql 命令如下：
1. delele,update,insert,replace,select
2. alter,create,drop,truncate
3. show,describe(desc,explain),help
4. start,begin,commit,rollback,savepoint
5. set

> **注意：**
> 对于一般的查询数据库状态信息的 sql，proxy 会发往默认 shard，这样查询统计信息的话，看到的结果是单个 shard 的信息。

### 聚合函数限制
1. 如果需要`distinct`后再做聚合，那么 where 条件必须带 shardkey。
```
select count(distinct a)，sum(distinct a)，avg(distinct a) from table where sk=\*\*
```
2. 对于`distinct`、`order by`、`group by`若后面跟函数，该函数必须出现在`select`的字段中，而且必须定义别名，对应`distinct`、`order by`、`group by`后使用别名。
```
select concat(...) as substr from table where ... order by substr
```
3. `group by`的字段必须在`select`的字段中，如下`select`中必须包含字段b。
```
select count(a),b from test group by b
```

### 用户权限相关限制
暂不支持使用 sql 命令通过 proxy 进行用户权限相关的设置，请至【腾讯云管理中心】>【云数据库】>【DCDB】>【管理】进行操作。
### 支持函数
我们将在后续版本陆续支撑全部函数，这里列出当前版本已支持及不支持的函数。
**Control Flow Functions**
目前不支持 CASE 函数，全部函数列举如下：
```
	Name | Description 
	---|---|---
	CASE	|Case operator 
	IF()	|If/else construct 
	IFNULL()	|Null if/else construct
	NULLIF()	|Return NULL if expr1 = expr2
```

**String Functions**
目前不支持 SUBSTRING(str FROM pos), SUBSTRING(str FROM pos FOR len)，POSITION，TRIM，REGEXP，SOUNDS LIKE，CHAR(USING　charset) 函数,全部函数列举如下：
```
	Name | Description 
	---|---|---
	ASCII()|	Return numeric value of left-most character
	BIN()|	Return a string containing binary representation of a number
	BIT_LENGTH()|	Return length of argument in bits
	CHAR()	|Return the character for each integer passed
	CHAR_LENGTH()|	Return number of characters in argument
	CHARACTER_LENGTH()|	Synonym for CHAR_LENGTH()
	CONCAT()	|Return concatenated string
	CONCAT_WS()	|Return concatenate with separator
	ELT()	|Return string at index number
	EXPORT_SET()|	Return a string such that for every bit set in the value bits, you get an on string and for every unset bit, you get an off string
	FIELD()	|Return the index (position) of the first argument in the subsequent arguments
	FIND_IN_SET()	|Return the index position of the first argument within the second argument
	FORMAT()	|Return a number formatted to specified number of decimal places
	FROM_BASE64()	|Decode to a base-64 string and return result
	HEX()	|Return a hexadecimal representation of a decimal or string value
	INSERT()	|Insert a substring at the specified position up to the specified number of characters
	INSTR()	|Return the index of the first occurrence of substring
	LCASE()	|Synonym for LOWER()
	LEFT()	|Return the leftmost number of characters as specified
	LENGTH()|	|Return the length of a string in bytes
	LIKE	|Simple pattern matching
	LOAD_FILE()|	Load the named file
	LOCATE()|	Return the position of the first occurrence of substring
	LOWER()	|Return the argument in lowercase
	LPAD()	|Return the string argument, left-padded with the specified string
	LTRIM()	|Remove leading spaces
	MAKE_SET()|	Return a set of comma-separated strings that have the corresponding bit in bits set
	MATCH	|Perform full-text search
	MID()|	Return a substring starting from the specified position
	NOT LIKE|	Negation of simple pattern matching
	NOT REGEXP	|Negation of REGEXP
	OCT()	|Return a string containing octal representation of a number
	OCTET_LENGTH()|	Synonym for LENGTH()
	ORD()|	Return character code for leftmost character of the argument
	POSITION()	|Synonym for LOCATE()
	QUOTE()|	Escape the argument for use in an SQL statement
	REGEXP|	Pattern matching using regular expressions 
	REPEAT()	|Repeat a string the specified number of times
	REPLACE()	|Replace occurrences of a specified string
	REVERSE()|	Reverse the characters in a string
	RIGHT()|	Return the specified rightmost number of characters
	RLIKE|	Synonym for REGEXP
	RPAD()|	Append string the specified number of times
	RTRIM()|	Remove trailing spaces
	SOUNDEX()|	Return a soundex string
	SOUNDS LIKE|	Compare sounds 
	SPACE()	|Return a string of the specified number of spaces
	STRCMP()|	Compare two strings
	SUBSTR()|	Return the substring as specified
	SUBSTRING()|	Return the substring as specified
	SUBSTRING_INDEX()|	Return a substring from a string before the specified number of occurrences of the delimiter
	TO_BASE64()	|Return the argument converted to a base-64 string
	TRIM()	|Remove leading and trailing spaces
	UCASE()	|Synonym for UPPER()
	UNHEX()	|Return a string containing hex representation of a number
	UPPER()	|Convert to uppercase
	WEIGHT_STRING()	|Return the weight string for a string
```



**Numeric Functions and Operators**
目前已支持所有该类函数。
```
	Name | Description 
	---|---|---
	ABS()	|Return the absolute value
	ACOS()	|Return the arc cosine
	ASIN()	|Return the arc sine
	ATAN()	|Return the arc tangent
	ATAN2(), ATAN()	|Return the arc tangent of the two arguments
	CEIL()	|Return the smallest integer value not less than the argument
	CEILING()	|Return the smallest integer value not less than the argument
	CONV()	|Convert numbers between different number bases
	COS()	|Return the cosine
	COT()	|Return the cotangent
	CRC32()	|Compute a cyclic redundancy check value
	DEGREES()	|Convert radians to degrees
	DIV	|Integer division
	/	|Division operator
	EXP()	|Raise to the power of
	FLOOR()	|Return the largest integer value not greater than the argument
	LN()	|Return the natural logarithm of the argument
	LOG()	|Return the natural logarithm of the first argument
	LOG10()	|Return the base-10 logarithm of the argument
	LOG2()	|Return the base-2 logarithm of the argument
	-	|Minus operator
	MOD()	|Return the remainder
	%, MOD	|Modulo operator
	PI()	|Return the value of pi
	+	|Addition operator
	POW()	|Return the argument raised to the specified power
	POWER()	|Return the argument raised to the specified power
	RADIANS()	|Return argument converted to radians
	RAND()	|Return a random floating-point value
	ROUND()	|Round the argument
	SIGN()	|Return the sign of the argument
	SIN()	|Return the sine of the argument
	SQRT()	|Return the square root of the argument
	TAN()	|Return the tangent of the argument
	*	|Multiplication operator
	TRUNCATE()	|Truncate to specified number of decimal places
	-	|Change the sign of the argument
```

**Date and Time Functions**
目前不支持 ADDDATE，SUBDAT，DATE_ADD，DATE_SUB，DATE_FORMAT，TIMESTAMPADD，TIMESTAMPDIFF，SYSDATE，EXTRACT，GET_FORMAT 函数，所有函数列举如下：
```
	Name | Description 
	---|---|---
	ADDDATE()	|Add time values (intervals) to a date value
	ADDTIME()	|Add time
	CONVERT_TZ()	|Convert from one time zone to another
	CURDATE()	|Return the current date
	CURRENT_DATE(), CURRENT_DATE	|Synonyms for CURDATE()
	CURRENT_TIME(), CURRENT_TIME	|Synonyms for CURTIME()
	CURRENT_TIMESTAMP(), CURRENT_TIMESTAMP|	Synonyms for NOW()
	CURTIME()	|Return the current time
	DATE()	|Extract the date part of a date or datetime expression
	DATE_ADD()	|Add time values (intervals) to a date value
	DATE_FORMAT()	|Format date as specified
	DATE_SUB()	|Subtract a time value (interval) from a date
	DATEDIFF()	|Subtract two dates
	DAY()	|Synonym for DAYOFMONTH()
	DAYNAME()	|Return the name of the weekday
	DAYOFMONTH()	|Return the day of the month (0-31)
	DAYOFWEEK()	|Return the weekday index of the argument
	DAYOFYEAR()	|Return the day of the year (1-366)
	EXTRACT()	|Extract part of a date
	FROM_DAYS()	|Convert a day number to a date
	FROM_UNIXTIME()	|Format Unix timestamp as a date
	GET_FORMAT()	|Return a date format string
	HOUR()	|Extract the hour
	LAST_DAY	|Return the last day of the month for the argument
	LOCALTIME(), LOCALTIME	|Synonym for NOW()
	LOCALTIMESTAMP, LOCALTIMESTAMP()	|Synonym for NOW()
	MAKEDATE()	|Create a date from the year and day of year
	MAKETIME()	|Create time from hour, minute, second
	MICROSECOND()	|Return the microseconds from argument
	MINUTE()	|Return the minute from the argument
	MONTH()	|Return the month from the date passed
	MONTHNAME()	|Return the name of the month
	NOW()	|Return the current date and time
	PERIOD_ADD()	|Add a period to a year-month
	PERIOD_DIFF()	|Return the number of months between periods
	QUARTER()	|Return the quarter from a date argument
	SEC_TO_TIME()	|Converts seconds to 'HH:MM:SS' format
	SECOND()	|Return the second (0-59)
	STR_TO_DATE()	|Convert a string to a date
	SUBDATE()	|Synonym for DATE_SUB() when invoked with three arguments
	SUBTIME()	|Subtract times
	SYSDATE()	|Return the time at which the function executes
	TIME()	|Extract the time portion of the expression passed
	TIME_FORMAT()|	Format as time
	TIME_TO_SEC()|	Return the argument converted to seconds
	TIMEDIFF()	|Subtract time
	TIMESTAMP()	|With a single argument, this function returns the date or datetime expression; with two arguments, the sum of the arguments
	TIMESTAMPADD()|	Add an interval to a datetime expression
	TIMESTAMPDIFF()|	Subtract an interval from a datetime expression
	TO_DAYS()	|Return the date argument converted to days
	TO_SECONDS()|	Return the date or datetime argument converted to seconds since Year 0
	UNIX_TIMESTAMP()|	Return a Unix timestamp
	UTC_DATE()|	Return the current UTC date
	UTC_TIME()|	Return the current UTC time
	UTC_TIMESTAMP()	|Return the current UTC date and time
	WEEK()|	Return the week number
	WEEKDAY()	|Return the weekday index
	WEEKOFYEAR()|	Return the calendar week of the date (1-53)
	YEAR()	|Return the year
	YEARWEEK()|	Return the year and week
```

**其他不支持函数**
目前不支持 BINARY，CONVERT，CAST 。