全局唯一数字序列（以下简称：sequence）使用的是 unsigned long 类型，8 个字节长，使用方法与 MySQL 的 AUTO_INCREMENT 类似。目前 DCDB 可以保证 sequence 字段全局唯一和有序递增，但不保证连续性，具体使用方法如下：
### 创建 sequence
DCDB 创建 sequence 和 MySQL 自增字段的语法一样，示例如下：

```
	mysql> create table auto_inc (a int,b int,c int auto_increment,d int,key auto(c),primary key p(a,d)) shardkey=d;
	Query OK, 0 rows affected (0.12 sec)
```

### 插入 sequence
DCDB 插入 sequence 和 MySQL 自增字段一样，用户可以不传该字段的值，或者传 0，NULL，这时 DCDB 自动分配一个全局唯一的值，示例如下：

```
	mysql> insert into shard.auto_inc ( a,b,d,c) values(1,2,3,0),(1,2,4,0);
	Query OK, 2 rows affected (0.05 sec)
	Records: 2  Duplicates: 0  Warnings: 0
	
	mysql> select last_insert_id();
	+------------------+
	| last_insert_id() |
	+------------------+
	| 1                |
	+------------------+
	1 row in set (0.00 sec)
	
	mysql> select * from shard.auto_inc;
	+---+------+---+---+
	| a | b    | c | d |
	+---+------+---+---+
	| 1 |    2 | 2 | 4 |
	| 1 |    2 | 1 | 3 |
	+---+------+---+---+
	2 rows in set (0.03 sec)

	mysql> insert into shard.auto_inc ( a,b,d,c) values(2,2,3,NULL),(2,2,4,NULL);
	mysql> insert into shard.auto_inc ( a,b,d) values(3,2,3),(3,2,4);

	mysql> select * from shard.auto_inc;
	+---+------+---+---+
	| a | b    | c | d |
	+---+------+---+---+
	| 1 |    2 | 2 | 4 |
	| 2 |    2 | 4 | 4 |
	| 3 |    2 | 6 | 4 |
	| 1 |    2 | 1 | 3 |
	| 2 |    2 | 3 | 3 |
	| 3 |    2 | 5 | 3 |
	+---+------+---+---+
	6 rows in set (0.03 sec)
```	
    
### 更改当前 sequence 值
示例如下：

```
	alter table auto auto_increment=100
```

### 注意事项
分布式数据库因其架构特殊性，在 proxy 正常调度切换、异常重启等过程中，sequence 无法保证连续性（但全局唯一），示例如下：

```
    mysql> insert into shard.auto_inc ( a,b,d,c) values(11,12,13,0),(21,22,23,0);
    Query OK, 2 rows affected (0.03 sec)

	mysql> select * from shard.auto_inc;
	+----+------+------+----+
	| a  | b    | c    | d  |
	+----+------+------+----+
	| 21 |   22 | 2002 | 23 |
	|  1 |    2 |    2 |  4 |
	|  2 |    2 |    4 |  4 |
	|  3 |    2 |    6 |  4 |
	|  1 |    2 |    1 |  3 |
	|  2 |    2 |    3 |  3 |
	|  3 |    2 |    5 |  3 |
	| 11 |   12 | 2001 | 13 |
	+----+------+------+----+
	8 rows in set (0.03 sec)

	mysql> select last_insert_id();
	+------------------+
	| last_insert_id() |
	+------------------+
	| 2001             |
	+------------------+
```


