﻿# 基本操作
腾讯云数据库Greenplum采用MPP架构，提供在线并行处理大规模数据服务，基于Greenplum Database开源数据库项目发展而来，数据库相关操作基本与开源数据库Greenplum Database保持一致。这里对一些数据库基本操作进行简单介绍：

**创建数据库**
如果已成功连接实例，可使用CREATE DATABASE命令创建新数据如下：
``` python
#创建新数据库new_db
=> CREATE DATABASE new_db;
CREATE DATABASE

#列出当前所有数据库
=>\l
                   List of databases
      Name      |  Owner   | Encoding |   Access privileges   
----------------+----------+----------+-----------------------
 new_db         | testuser | UTF8     | 
 postgres       | postgres | UTF8     | 
 template0      | postgres | UTF8     | =c/postgres           
                                      : postgres=CTc/postgres
 template1      | postgres | UTF8     | =c/postgres   
 
#切换到数据库new_db
=> \c new_db   
```
**克隆已有数据库**
如果需要根据已有数据库创建新库，可使用命令：
```
=> CREATE DATABASE new_db TEMPLATE old_db;
CREATE DATABASE
```
新库new_db会包含模板库old_db的所有对象和数据。

**创建表**
Greenplum的表创建语句与PostgreSQL类似，不同的是Greenplum的所有表都是分布存储的，创建表时可以指定表分布策略（HASH分布或者随机分布），如：

```python
#HASH分布
=> CREATE TABLE products (name varchar(40), prod_id integer, supplier_id integer) DISTRIBUTED BY (prod_id);
CREATE TABLE

#随机分布
=> CREATE TABLE random_part(name varchar(40), p_id integer) DISTRIBUTED RANDOMLY;
CREATE TABLE

```
如果在创建表时没有写明DISTRIBUTED BY或者DISTRIBUTED RANDOMLY子句时，Greenplum会依次使用表主键（如果存在）或者第一个字段作为HASH分布的分布键。

**分布策略与分布键的选择**
选择表的分布策略时，可以重点考虑以下几点：

 - 平坦查询处理
  为达到更好性能，尽量让所有计算节点能处理等量的工作负载，避免负载倾斜，建议根据实际应用场景选择分布策略
 - 本地操作与分布式操作
   尽量让查询中的关联、排序、聚合等操作能够在本地节点完成，跨节点的操作会涉及到数据传输，效率远低于本地。
 - 数据均匀分布
   尽量让所有节点存储等量的数据，可以考虑使用具有唯一性的分布键，如主键

选择分布键时，尽量考虑让数据能够均分分布到各个节点。分布键选择的好坏与否，直接影响查询性能。具体选择可参考[《Greenplum 数据库最佳实践》][1]。

**选择表的存储模式**
Greenplum提供多种存储处理模式（或混合模式），例如：

 - Heap Storage（堆存储）
```python
#行存堆表是缺省的存储模式，不需要额外语法指定
=> CREATE TABLE test1(a int, b text) DISTRIBUTED BY (a);
```
 - Append-Only Storage（只追加存储）
```python
=> CREATE TABLE test2(a int, b text) WITH(appendonly=true) DISTRIBUTED BY (a);
```
 - Row-Oriented Storage（行存储）
 - Column-Oriented Storage （列存储）
```python
#使用列存的TABLE必须是AO表
=> CREATE TABLE test3(a int, b text) WITH(appendonly=true, orientation=column) DISTRIBUTED BY (a);
```
  - Using Compression (Append-Only Tables Only)（使用压缩存储，只能是AO表）
```python
#创建一张5级ZLIB压缩的AO表
=> CREATE TABLE foo (a int, b text) WITH (appendonly=true, compresstype=zlib, compresslevel=5);
```
关于存储模式的更详细的使用可以查看[《Pivotal Greenplum官方文档》][2]

**查询**
Greenplum可以并行处理数据，在所有节点同时执行查询，查询语法基本与PostgreSQL保持一致。如果需要对查询进行优化，可以使用EXPLAIN(或EXPLAIN ANALYZE)查看查询计划，例如:
```python
=> explain select * from sync_rc_flows;
                                 QUERY PLAN                                  
-----------------------------------------------------------------------------
 Gather Motion 2:1  (slice1; segments: 2)  (cost=0.00..1.01 rows=1 width=68)
   ->  Seq Scan on sync_rc_flows  (cost=0.00..1.01 rows=1 width=68)
(2 rows)
```



  [1]: http://mp.weixin.qq.com/s?spm=5176.doc35427.2.1.AIqq9h&__biz=MzA4NjQzNjUyOA==&mid=401639454&idx=1&sn=cff21ba642334f81809613785e437316&scene=2&srcid=0301SqsVBaQQPfoSSIjfXHCT&from=timeline&isappinstalled=0#wechat_redirect
  [2]: http://gpdb.docs.pivotal.io/4380/common/welcome.html?spm=5176.doc35427.2.2.gRtl2W