## 数据装载
腾讯云数据库Greenplum采用MPP架构，提供在线并行处理大规模数据服务，基于Greenplum Database开源数据库项目发展而来，Greenplum对大规模数据支持了并行装载数据的能力，您可以通过使用gpfdist和gpload两种方式来并行装载数据。

----------
### 创建可读外部表
在装载数据之前需建立好外部表，外部表允许用户像访问标准数据库表一样访问外部文件，结合Greenplum的并行文件分配程序(gpfdist)，外部表支持在装载和卸载数据时并行利用所有Segment的资源。在创建一个外部表定义时，必须指定输入文件的格式个外部数据源的位置。
示例:
```
CREATE EXTERNAL TABLE ex_part (
	p_partkey     SERIAL,
    p_name        VARCHAR(55),
    p_mfgr        CHAR(25),
    p_brand       CHAR(10),
    p_type        VARCHAR(25),
    p_size        INTEGER,
    p_container   CHAR(10),
    p_retailprice DOUBLE PRECISION,
    p_comment     VARCHAR(23)
)location ('gpfdist://host:post/part.txt') FORMAT 'TEXT' (DELIMITER '|'); 
```
其中，host，port为gpfdist文件服务器的IP地址和端口，待装载的数据文件"part.txt"是以'|'字符作为分割的。如果使用gpfdist://协议，在外部表"ex_part"指定的文件所在的host(主机)上必须运行gpfdist，该程序指向一个目录，并行为所有Segment提供外部数据文件服务。
### 启用gpfdist服务
gpfdist是Greenplum的并行文件服务器，可以使用gpfdist同时向各个计算节点传输数据，实现并行加载，比传统加载方式的速度提高数倍。gpfdist工具获取可参考[pivotal 官网][1]，详细用法可查看gpfdist帮助文档。
示例：
```
#启动gpfdist时必须指定其提供文件服务的目录以及运行的端口(缺省为端口8080)。
#后台启动gpfdist
$ gpfdist -d /var/load_data_files -p 8081 -l /log &

#若要启动多个gpfdist服务，可以这样：
$ gpfdist -d /var/load_data_files1 -p 8082 -l /log1 &
$ gpfdist -d /var/load_data_files2 -p 8083 -l /log2 &
```
### 使用外部表装载数据
创建了外部表和成功启动gpfdist服务后，即可加载数据。
示例：
```
# 快速装载全部数据到一个新表中
=> CREATE TABLE part AS SELECT * FROM ex_part;

# 只装载部分数据
=> INSERT INTO part1 SELECT * FROM ex_part where p_size > 10;
```
### 使用gpload装载
除了上述使用gpfdist方式装载数据之外，您也可以使用gpload来装载数据。gpload是Greenplum使用可读外部表和并行文件服务gpfdist装载数据的一个命令包装，通过使用装载配置文件（YAML格式定义）的方式等来创建外部表定义。gpload调用Greenplum的并行文件服务程序，创建基于定义好的数据源的外部表，然后执行INSERT、UPDATE或者MERGE操作，将源数据装载到目标数据库表中。gpload工具获取可参考[pivotal 官网][1]，详细用法可查看gpload帮助文档。

 1. 创建gpload装载控制文件
文件后缀格式为yml，模板如下：
```
VERSION: 1.0.0.1
DATABASE: <db_name>
USER: <db_username>
HOST: <master_hostname>  #这里为实例的内网地址IP
PORT: <master_port>      #这里为示例的内网地址端口
GPLOAD:
   INPUT:
    - SOURCE:
         LOCAL_HOSTNAME:
           - <hostname_or_ip>  #启用gpfdist服务的主机地址
         PORT: <http_port>     #启用gpfdist服务的主机端口
       | PORT_RANGE: [<start_port_range>, <end_port_range>]
         FILE: 
           - </path/to/input_file>  #数据文件所在目录
         SSL: true | false
         CERTIFICATES_PATH: </path/to/certificates>
    - COLUMNS:
           - <field_name>: <data_type>
    - TRANSFORM: '<transformation>' 
    - TRANSFORM_CONFIG: '<configuration-file-path>' 
    - MAX_LINE_LENGTH: <integer> 
    - FORMAT: text | csv
    - DELIMITER: '<delimiter_character>'
    - ESCAPE: '<escape_character>' | 'OFF'
    - NULL_AS: '<null_string>'
    - FORCE_NOT_NULL: true | false
    - QUOTE: '<csv_quote_character>'
    - HEADER: true | false
    - ENCODING: <database_encoding>
    - ERROR_LIMIT: <integer>
    - ERROR_TABLE: <schema>.<table_name>
    - LOG_ERRORS: true | false
   EXTERNAL:
    - SCHEMA: <schema> | '%'
   OUTPUT:
    - TABLE: <schema>.<table_name>
    - MODE: insert | update | merge
    - MATCH_COLUMNS:
           - <target_column_name>
    - UPDATE_COLUMNS:
           - <target_column_name>
    - UPDATE_CONDITION: '<boolean_condition>'
    - MAPPING:
            <target_column_name>: <source_column_name> | '<expression>'
   PRELOAD:
    - TRUNCATE: true | false
    - REUSE_TABLES: true | false
   SQL:
    - BEFORE: "<sql_command>"
    - AFTER: "<sql_command>"
```
示例：
```
#文件名：my_load.yml
VERSION: 1.0.0.1
DATABASE: testdb
USER: dbuser
HOST: 10.66.147.10
PORT: 5432
GPLOAD:
INPUT:
- SOURCE:
     LOCAL_HOSTNAME:10.66.147.11
     PORT: 8081
     FILE: /var/load/data/*
- COLUMNS:
    - p_partkey: SERIAL
    - p_name: VARCHAR(55)
    - p_mfgr: CHAR(25)
    - p_brand: CHAR(10)
    - p_type: VARCHAR(25)
    - p_size: INTEGER
    - p_container: CHAR(10)
    - p_retailprice: DOUBLE PRECISION
    - p_comment: VARCHAR(23)
    - FORMAT: text
- DELIMITER: '|'
- ERROR_LIMIT: 25
- ERROR_TABLE: err_exparts
OUTPUT:
- TABLE: parts
- MODE: INSERT
SQL:
- BEFORE: "INSERT INTO log VALUES('start', current_timestamp)"
- AFTER: "INSERT INTO log VALUES('end', current_timestamp)"
```
  2. 装载数据
通过gpload命令装载控制文件，如：
```
gpload -f my_load.yml
```

### 数据装载性能技巧

 - 装载数据前删除表索引
 在已存在数据的表上创建索引比不断的递增索引要快。若装载一张新创建的表，最快的方式是先创建表，再装载数据，然后再创建任何需要的索引。若向一个已有数据的表添加大量数据，更快的方式可能是，先删除索引，然后装载数据，然后再重新创建索引。
 - 在装载之后运行ANALYZE
在修改了表中的大部分数据之后，建议执行ANALYZE操作。
 - 在装载出错后执行VACUUM
若装载数据因为错误而终止时，错误发生前的记录是不能被访问的，但仍占据着磁盘空间，执行VACUUM命令可以回收这些浪费的空间。

  
 
  [1]: https://network.pivotal.io/products/pivotal-gpdb?spm=5176.doc43729.2.3.2rnGdl#/releases/3710/file_groups/410