## 连接实例

腾讯云数据库Greenplum采用MPP架构，提供在线并行处理大规模数据服务，基于Greenplum Database开源数据库项目发展而来。

可以使用任何PostgreSQL兼容的客户端程序连接到Greenplum，比如psql。Greenplum Database开源数据库（GPDB）基于PostgreSQL8.3分支开发，因此，完整兼容PostgreSQL的消息协议，连接实例时总是通过Master连接到GPDB，计算节点不能使用客户端连接。

可以使用如下几种方式连接腾讯云数据库Greenplum实例：
### PSQL
psql提供了交互式的命令行方式访问Greenplum Database，可在Greenplum安装目录BIN下获取到，有两种使用方式：

- 参数的方式
```
psql  -h 10.66.147.89 -p 5432 -d postgres -U dbuser
```
 - 连接串的方式
```
psql "host=10.66.147.89 port=5432 dbname=postgres user=dbuser password=dbpassword"
postgres=> select version();
                                            version                                            
-----------------------------------------------------------------------------------------------
 PostgreSQL 8.3devel (Greenplum Database 4.3.99.00 build dev) compiled on Jun 16 2016 22:48:52
(1 row)
```
 其中，"-h" 指定主机地址，"-p" 指定端口号，"-d" 指定数据库（默认是postgres），"-U" 指定数据库用户。可通过 "psql —help" 查看更多选项。psql连接后，可以执行 "\?" 查看更多psql中支持的命令。
 
关于GreenPlum Database的PSQL的更多使用方法，请参考[这里][1]。
另外也可以使用PostgreSQL的PSQL命令，请参考[这里][2]。

### pgAdminIII图形客户端
图形客户端的配置相对简单，可参考[这里][3]，客户端可以从[这里][4]下载，为了获得更好的兼容性，建议下载较低版本的pgAdminIII，例如pgAdmin 1.14.3版本。

### DB应用程序接口
若需要使用应用程序连接Greenplum，可以使用PostgreSQL提供的一些通用的API，这些同样也可以应用在Greenplum上。
#### Python
Python连接可以使用psycopg2库，安装后需设置PYTHONPATH。
示例：
```
import psycopg2
sql = 'select * from gp_segment_configuration;'
db_conn = psycopg2.connect(database='postgres', user='dbuser', password='dbpassword', host='10.66.147.89', port='5432')
db_conn.autocommit = True
cursor = db_conn.cursor()
cursor.execute(sql)
rows = cursor.fetchall()
for row in rows:
    print row
db_conn.commit()
db_conn.close()
```
#### JDBC
使用JDBC可以下载PostgreSQL的[驱动包][5]，详细内容请参考[这里][6]，或者使用Pivotal Greenplum Database提供的[工具包][7]。
示例：
```
import java.sql.Connection;  
import java.sql.DriverManager;  
import java.sql.ResultSet;  
import java.sql.SQLException;  
import java.sql.Statement;  
public class gp_conn {  
    public static void main(String[] args) {  
        try {  
            Class.forName("org.postgresql.Driver");  
            Connection db_conn = DriverManager.getConnection("jdbc:postgresql://10.66.147.89:5432/postgres","dbuser","dbpassword");
            Statement s = db_conn.createStatement();  
            ResultSet res = s.executeQuery("select * from gp_segment_configuration;");  
            while (res.next()) {  
                System.out.print(res.getString(1));  
                System.out.print("    |    ");  
                System.out.print(res.getString(2));  
                System.out.print("    |    ");  
                System.out.print(res.getString(3));  
                System.out.print("    |    ");  
                System.out.print(res.getString(4));  
                System.out.print("    |    ");  
                System.out.print(res.getString(5));  
                System.out.print("    |    ");  
                System.out.print(res.getString(6));  
                System.out.print("    |    ");  
                System.out.print(res.getString(7));  
                System.out.print("    |    ");  
                System.out.print(res.getString(8));  
                System.out.print("    |    ");  
                System.out.print(res.getString(9));  
                System.out.print("    |    ");  
                System.out.print(res.getString(10));  
                System.out.print("    |    ");  
                System.out.println(res.getString(11));  
            }  
            res.close();  
            s.close();  
        } catch (ClassNotFoundException e) {  
            e.printStackTrace();  
        } catch (SQLException e) {  
            e.printStackTrace();  
        }  
    }  
}
```
#### 其他
 - libpq
libpq是PostgreSQL用于连接实例的C库，在Greenplum或者PostgreSQL的lib目录下可以找到静态库和动态库，详细文档可查看[这里][8]，示例可看[这里][9]。
 - ODBC
可以使用PostgreSQL的ODBC，[这里][10]可以下载。
### 参考
[Pivotal Greenplum Database官方文档][11]


  [1]: http://gpdb.docs.pivotal.io/4340/client_tool_guides/client/unix/psql.html?spm=5176.doc35428.2.2.9cCiY3
  [2]: https://www.postgresql.org/docs/8.3/static/app-psql.html?spm=5176.doc35428.2.3.F5JyYJ
  [3]: http://gpdb.docs.pivotal.io/4340/admin_guide/access_db/topics/g-pgadmin-iii-for-greenplum-database.html
  [4]: https://www.pgadmin.org/download/
  [5]: https://jdbc.postgresql.org/?spm=5176.doc35428.2.6.zAnsaG
  [6]: https://jdbc.postgresql.org/documentation/94/index.html?spm=5176.doc35428.2.8.zAnsaG
  [7]: http://gpdb.docs.pivotal.io/4380/client_tool_guides/drivers/unix/unix_connect.html?spm=5176.doc35428.2.7.zAnsaG
  [8]: https://www.postgresql.org/docs/9.4/static/libpq.html?spm=5176.doc35428.2.12.ELOvoy
  [9]: https://odbc.postgresql.org/?spm=5176.doc35428.2.9.uf06uB
  [10]: https://odbc.postgresql.org/?spm=5176.doc35428.2.9.cF7Uot
  [11]: http://gpdb.docs.pivotal.io/4380/common/welcome.html?spm=5176.doc35428.2.13.E4QoBb