## 1. 简介
一条规则引擎由 _**规则**_ 和 _**行为**_ 两部分组成。
**规则**表达了对哪些 Topic、以及 Topic 内容中的哪些字段感兴趣，规则使用 SQL 语句来定义的。
**行为**表达了对感兴趣的内容要执行哪些动作，比如存入数据库、转发给其它 Server 等。

## 2. 约束
发往规则引擎的 Topic 消息只能是 Json 格式的，否则规则引擎会直接丢弃不处理。

## 3. 规则
规则使用 SQL 语法来定义，格式如下：
<pre>**SELECT** [字段] **FROM** [Topic] **WHERE**[条件]
</pre>控制台上相应地也提供了输入框来分别填写[字段]、[Topic]、[条件]这三个字段。如下图所示：
![image](https://mc.qcloudimg.com/static/img/b53af0b5bbd1cf2c3b5a941a1d418d62/gui1.png)

上面 SQL 语句表达的意思，就是监听[Topic]的所有消息，对于满足[条件]的消息，就从消息中提取出相应的[字段]。

来看一条完整规则的示例："**SELECT** temperature **FROM** "house_monitor/thermometer/get" **WHERE** temperature > 40 "，相应的字段在控制台上对应如下填写：
![image](https://mc.qcloudimg.com/static/img/b5fcdd9309c1d08d2596a072782f7958/gui2.png)

这条示例表达的含义就是监听 Topic "house_monitor/thermometer/get" 的所有消息，如果消息中包含了字段 temperature，并且 temperature 的值大于 40，那么就提取出 temperature 字段，以供后面的行为使用。

下面来分别介绍下[Topic]、[条件]、[字段]的定义。

### 3.1 [Topic]的定义
最简单的[Topic]定义方式就是直接写出一个 Topic， 比如 house_monitor/thermometer，就代表想要监听 house_monitor/thermometer 这一个 Topic。

如果想要监听多个 Topic，可以使用"#"和"+"通配符来定义多个 Topic。

关于 Topic 通配符的定义可以查看"参考"章节关于通配符的详细解释。

### 3.2 [条件]的定义
[条件]表达式用于过滤 Topic 中的消息。只有当消息满足[条件]表达式规则的条件时，才会被提取并进行后续的处理。举个例子："**SELECT** temperature, house **FROM** house_monitor/thermometer/get **WHERE**  temperature > 40", 这条规则语句中的[条件]表达式就是"temperature > 40", 意味着只有 temperature 字段大于 40 的 Topic 消息才会被选取，否则就会被规则引擎过滤掉从而不被处理。

关于条件表达式更多的定义可以查看"参考"章节关于条件表达式的详细解释。

### 3.3 [字段]的定义
字段是从 Json 格式的消息内容中提取出来的，比如消息内容为
```
{
	"house" : "tencent",
	"temperature" : 40,
	"device_status" : {
		"switch" : "on"
	}
}
```
那么消息中就有三个字段 house、tmperature、device_status.switch 可以提取，字段的名字就是 Json 中的 Key。下面的例子提取消息中的 temperature 和 house 字段，只有当 house 字段值为"tencent"，且温度高于 40 度时才会提取：
<pre>**SELECT** temperature, house **FROM** house_monitor/thermometer/get **WHERE** house="tencent" AND temperature > 40
</pre>字段的选取可以使用 Json 表达式来引用复杂字段，比如上面例子中要选取门的开关字段，可以这么写：device_status.switch

还可以给字段取一个简短易懂的别名，以替代复杂的字段名字，方便后面转发时引用。比如将门的开关字段取一个别名，可以这么写：device_status.switch as ds，这样后续就可以使用 ds 来代表温度计的状态，而不需要写一串"device_status.switch"。比如：
<pre>**SELECT** device_status.switch as ds  **FROM** house_monitor/thermometer/get **WHERE** house="tencent" AND temperature > 40
</pre>
## 4. 行为 Action
当从 Topic 提取到了感兴趣的字段后，就要考虑对其进行一些操作，比如转发或者存储等。目前支持的操作有：
1. 转发给另一个 Topic
2. 转发给第三方定义的服务
3. 即将支持保存到腾讯云的数据库

### 4.1 转发到另一个 Topic
通过将感兴趣的消息字段转发到另一个 Topic，可以实现不同设备间的 M2M 通信。Topic 的填写支持两种方式：
1. 最简单的方式是直接填写一个 Topic 的名字，比如 house_monitor/thermometer。这样就会把满足规则的消息转发到这个 Topic。
2. 另一种是支持带变量的 Topic 填写方式。比如 ${procduct_name}/device, 其中用"${}"包括起来的 house 就代表一个变量名，这个变量名是 SELECT 语句中选取出来的字段名。

举个例子来说明带变量的转发 Topic 是如何生效的，假如定义了一个这样的规则：
<pre>**SELECT** temperature as t, house **FROM** house_monitor/thermometer/get **WHERE** house="tencent" AND temperature > 40
</pre>这条规则从消息中提取了名字为 t 和 house 的两个字段，假定 house 字段的内容为"tencent"，此时如果定义了转发给 house_monitor/app/{house} 这个 Topic，那么规则引擎就会把这个 Topic 中的 ${house} 变量替换为"tencent", 从而把 t 和 house 两个字段的内容发送给 house_monitor/app/tencent 这个 Topic。

下图展示了转发的整个过程：
![image](https://mc.qcloudimg.com/static/img/2fd61f602479ab39f47e7d6eb4f93558/gui3.png)

下面展示是如何在控制台建立一个转发 Topic 的过程：

**第一步：**
点击【添加行为】
![image](https://mc.qcloudimg.com/static/img/523c71ecbc7db67aee13206882706091/gui4.png)

**第二步：**
从【选择行为】下拉框中选择"republish"，以转发给其它 Topic，并在 Topic 一栏中填写相应的 Topic。填写完成后点击创建即可。
操作过程如下图所示：
![image](https://mc.qcloudimg.com/static/img/81b8cc466391585ae5e28bcc9fce7ee8/gui5.png)

### 4.2 转发给第三方的服务
将通过规则提取出来的消息字段转发给第三方的服务，用户可以自定义如何处理这些数据，这种方式是提供给用户灵活性最高的一种消息处理方式。下图是转给第三方服务的整个过程，规则的配置与上面转发给其它 Topic 一致。
![image](https://mc.qcloudimg.com/static/img/d610003fe080abfb6b0dcc6f579c3084/gui6.png)

第三方服务必须以 https 的方式提供服务。如果要配置转发第三方服务，需要提供有支持 https 的网站 url 和端口。

下面展示是如何在控制台建立一个转发第三方服务的过程：

与添加转发 Topic 类似，不同的是在"选择行为"下拉框中选择"forward"选项,并在 API 一栏中填写第三方服务的 URL 和端口。操作过程如下图所示：

![image](https://mc.qcloudimg.com/static/img/889bfe9e6076730e00ff1ff28886e25c/gui7.png)

## 5. 参考

### 5.1 Topic通配符的详细定义
如果想要监听多个 Topic，可以使用"#"和"+"通配符来定义多个 Topic。"#"代表 0 个或多个任意 Topic 段，只能放在 Topic 的最后；"+"代表 1 个任意 Topic 段，可以放在 Topic 的中间。

比如 house_monitor/+/get，可以监听 house_monitor/thermometer/get、house_monitor/door/get 等 Topic。但是不可以监听到 house_monitor/door/switch/get 这个 Topic，因为"+"只能代表 1 个 Topic 段。

比如 house_monitor/#, 可以监听 house_monitor/thermometer、house_monitor/door/switch/get 等 Topic。但是 house/#/get 是非法的，因为"#"只能放在 Topic 的最后。

### 5.2 条件的详细定义
[条件]表达式用于过滤 Topic 中的消息。只有当消息满足[条件]表达式规则的条件时，才会被提取并进行后续的处理。下表是支持的表达式。

|操作符 | 描述 | 举例|
|---|---|---|
|= | 相等 | color = 'red'|
|<>	| 不等于			| color <> ‘red’|
|AND	| 逻辑与			| color = ‘red’ AND siren = ‘on’|
|OR	| 逻辑或			| color = ‘red’ OR siren = ‘on’|
|( )	| 括号代表一个整体	| color = ‘red’ AND (siren = ‘on’ OR isTest)|
|+	| 算术加法			| 4 + 5|
|-	| 算术减			| 5 - 4|
|/	| 除				| 20 / 4|
|*	| 乘				| 5 * 4|
|%	| 取余数			| 20 % 6|
|<	| 小于				| 5 < 6|
|<=	| 小于或等于		| 5 <= 6|
|>	| 大于				| 6 > 5|
|>=	| 大于或等于		| 6 >= 5|
|CASE … WHEN … THEN … ELSE …END	|Case 表达式				| CASE col WHEN 1 THEN ‘Y’ WHEN 0 THEN ‘N’ ELSE ‘’ END as flag|
|IN								| 仅支持枚举，不支持子查询	| 比如 where a in(1,2,3); 不支持以下形式： where a in(select xxx)|
