假设一个智能家居的场景（非实际产品，仅用于阐述物联云功能），我们要实现如下功能：
![come_home](https://mc.qcloudimg.com/static/img/71322deb86ac93b9cb5c63456d132827/1-1.png)

## 1. 解决方案

基于腾讯物联云，我们可以通过 SDK 创建两类智能设备（Door、AirConditioner），基于设备间的消息和规则引擎实现设备之间的联动，如下所示：
![rule_engine_for_smart_home](https://mc.qcloudimg.com/static/img/c0262f0e90da3116994f602c9f31ab8a/1-2.png)
> **注意:**
> airConditioner1 不可以通过直接订阅 door1 的 update 消息来完成消息通信，原因参见 [功能组件 - 权限管理](/document/product/634/11915)。

## 2. 操作步骤

### 2.1 创建门产品和设备

1) 进入 [控制台](https://console.cloud.tencent.com/iot/products), 创建产品（Door）。
![创建门产品](https://mc.qcloudimg.com/static/img/c960b3c5eab6d09fe5084ae97b0f62c7/1-3.png)

2) 在【设备列表】下创建设备（door1）。
> **注意:**
> 创建设备会返回设备密码，此密码用于设备通信，并且不会在物联云后台存储，请妥善保管。

![创建设备返回](https://mc.qcloudimg.com/static/img/abaf6775e640ff222edd7447d3484ec7/1-4.png)
点击【管理】可查询设备详情。
![查询设备](https://mc.qcloudimg.com/static/img/09c05997608471e68c7d81e6b1ead4bb/1-5.png)
查询设备详情页面，设备证书、设备私钥用于 MQTT 的 TLS 非对称加密；对称秘钥用于对称加密通信（两种通信方式差别见 [功能组件 - 设备接入](/document/product/634/11915)。
> **注意:**
> 以上资源的创建可通过 restAPI 由后台创建，具体请参见 [API 概览](https://cloud.tencent.com/document/product/634/12056)。

### 2.2 下载SDK 和根证书

SDK 下载请点击：[SDK下载](https://cloud.tencent.com/document/product/634/11928)
根证书下载请点击：[下载](https://mc.qcloudimg.com/static/archive/53b593776d4ad4ab7b18e1025a86d004/root-ca.zip)
> **注意:**
> 根证书所有设备共享同一份。

### 2.3 配置程序

编辑 SDK 程序 samples/door 下的 iot_config.h，使用“步骤2.1 创建门产品和设备”中获得的设备信息，填写以下配置项（下表物理含义后的编号，与“步骤2.1 创建门产品和设备”截图中的序号一一对应）。

设备连接物联云后台，通过配置的端口决定 TLS 非对称加密连接或者对称加密连接。

| 配置项 | 物理含义 | 
| ---- | ------ | 
| QCLOUD_IOT_MQTT_CLIENT_ID |设备 ID，全局唯一，可从设备详情页面获取<font color=red >（5）</font> |
| QCLOUD_IOT_MQTT_PASSWORD |设备密码, 设备创建之时生成提供，服务端不保存<font color=red >（1）</font> |
| QCLOUD_IOT_MY_PRODUCT_NAME |设备的产品名字，设备详情获取 |
| QCLOUD_IOT_MY_DEVICE_NAME |设备名字，设备详情页面获取<font color=red >（2）</font>|
| QCLOUD_IOT_CA_FILENAME |根证书名字，在 SDK 下载页面获取，仅非对称加密方式使用|
| QCLOUD_IOT_CERT_FILENAME |设备证书名字，在设备详情页面下载获取，仅非对称加密方式使用<font color=red >（3）</font>|
| QCLOUD_IOT_KEY_FILENAME |设备私钥文件名字，在设备详情页面下载获取，仅非对称加密方式使用<font color=red >（4）</font>|
| QCLOUD_IOT_PSK |设备对称秘钥，在设备详情页面下载获取，仅对称加密方式使用<font color=red >（6）</font>|
| QCLOUD_IOT_IS_ASYMC_ENCRYPTION |客户端是否使用非对称加密方式，1：使用非对称加密 0：使用对称加密|

### 2.4 实现 SDK 程序

samples/door/door.c 是门设备相关逻辑代码，有以下逻辑：
1) 完成对 MQTT 通信协议的参数初始化，`_setup_connect_init_params`函数内部需要填写设备相关信息，具体宏定义请参见上表：

```
MQTTInitParams initParams = DEFAULT_MQTTINIT_PARAMS;
_setup_connect_init_params(&initParams);
```
2) 完成对 MQTT connect 请求的参数初始化和执行连接：
```
void *client = IOT_MQTT_Construct(&initParams);
```
作为样例，这里根据用户执行程序时指定的的 action（come_home或者leave_home）和 targetDeviceName（需要中转到的设备名） 参数值，对消息的内容组装和发布。用户可自行组织消息内容和 topic，执行自己的发布消息逻辑。
```
_publish_msg(action, targetDeviceName);
```

### 2.5 编译与执行程序

1) 在 demo 程序 samples/door 执行 make，编译得到 door 可执行程序；
2) 执行 ./door come_home airConditioner1（第一个输入参数是行为：come_home 或者 leave_home; 第二个参数是消息的目标对象，我们这里假设为 airConditioner1），注意如果用 LTS 非对称加密方式，请保证根证书、设备证书和设备私钥文件在 ../../certs 上层目录下。
以下完成门这个设备的连接和发布功能。
![执行结果](https://mc.qcloudimg.com/static/img/d1bb2a2df8c82ed11395c80092cf46b2/1-6.png)

### 2.6 创建空调产品和设备

1) 创建产品（AirConditioner）：
![创建门产品](https://mc.qcloudimg.com/static/img/7a7bad485660ba86707cce3b2a05d526/1-7.png)

2) 在【设备列表】下创建设备(airConditioner1)：
> **注意:**
> 创建设备会返回设备密码，此密码用于设备通信，并且不会在物联云后台存储，请妥善保管。

![创建设备](https://mc.qcloudimg.com/static/img/c11d2cd5de5fb68a3eeda06da36cdecb/1-8.png)
点击【管理】可查询设备详情。
![查询设备](https://mc.qcloudimg.com/static/img/08bb065cfdf334537e31089a9960e4f9/1-9.png)

> **注意:**
> 以上资源的创建可通过 restAPI 由后台创建，具体请参见 [API 概览](https://cloud.tencent.com/document/product/634/12056)。

### 2.7 配置程序

编辑 SDK 程序 samples/airconditioner 下的 iot_config.h，实现与“步骤2.3 配置程序” 基本一致，不再赘述。

### 2.8 实现 SDK 程序

samples/airconditioner/airconditioner.c 的代码主要有以下逻辑：
步骤 1)和步骤 2)：MQTT 协议初始化和 MQTT connect 连接逻辑实现与“步骤2.4 实现 SDK 程序”一致，不再赘述。

作为样例，`_register_subscribe_topics` 实现对 AirConditioner/airConditioner1/get 订阅，并且注册对应的回调处理函数。收到该 topic 消息后回调处理，判断消息内容是 “come_home” 或者 “leave_home” 而分别让 airConditioner 开启或者关闭。用户可在函数内实现对自定义 topic 消息的订阅，并且注册自定义的回调处理。

```
rc = _register_subscribe_topics();
```
在下面循环处理里面，`IOT_Shadow_Yield` 这个函数实现了对订阅 topic 的监听，当收到对应 topic 消息时候则执行其相应的回调函数。一般而言，不用更改处理逻辑。`_simulate_room_temperature` 简单模拟了下室内温度的变化和 airConditioner 的能耗。用户也可以实现其他自定义逻辑。

```
rc = IOT_Shadow_Yield(client, 200);

if (rc == QCLOUD_ERR_MQTT_ATTEMPTING_RECONNECT) {
    sleep(1);
    continue;
}

_simulate_room_temperature(&s_reportTemperature);
```

### 2.9 编译与执行程序

在 demo 程序 samples/airconditioner 下执行 make，编译得到 airconditioner 可执行程序；
执行 ./airconditioner，注意如果用 TLS 非对称加密方式，请保证根证书、设备证书和设备私钥文件在 ../../certs 上层目录下。
![执行结果](https://mc.qcloudimg.com/static/img/08b6cc449f64c9ce05dbfa9f1a98fac5/1-10.png)
以上完成 airConditioner1 这个设备的连接和订阅功能。程序内循环监听订阅的 topic 并且输出室温和能耗相关系数。

### 2.10 创建规则引擎

![创建规则引擎](https://mc.qcloudimg.com/static/img/54f36a15d9e7c2b85485c0d429da0d2d/1-11.png)
具体步骤详见 [规则引擎详情](/document/product/634/11917)。

### 2.11 实现设备互通

1) 以上步骤已建立 door1 与 airConditioner1 之间的通信渠道，重新执行 ./airconditioner；然后执行 ./door come_home airConditioner1，看输出日志。
2) 从日志可见，airConditioner1 已经获取到来自 door1 的消息，并且将状态转为"open"，室温（往缺省配置温度调整）与能耗也有相关动态变化。
![M2M通信](https://mc.qcloudimg.com/static/img/1349784e3c37cd22514a9119a6cec2d0/1-12.png)
