## 1. 概述 


### 1.1 推送原理

如想要接收APNs离线消息通知，需要在腾讯云管理平台提交Push证书，在客户端每次登录时，获取并通过API接口上报Token。详细推送原理可参阅：[Apple Push Notification Service](https://developer.apple.com/library/ios/documentation/NetworkingInternet/Conceptual/RemoteNotificationsPG/Chapters/ApplePushService.html)。

APNs推送功能只用于通知用户，如果APP在前台，以 onNewMessage 回调获取新消息为准，didReceiveRemoteNotification 获取到的消息由于不可控，可以忽略。

### 1.2 证书申请流程

APNs 证书申请流程可参考文档：[Apple推送证书申请](/doc/product/269/Apple推送证书申请)。

### 1.3 上传证书到控制台

APNs 证书申请完成以后，需要把生成的p12证书上传到控制台，上传后会生成证书id，需要setToken调用时设置。

另外上传时有几个注意点：

1. 上传证书名最好使用全英文（尤其不能使用括号等特殊字符）
2. 上传证书生效时间为10分钟左右
3. 上传证书需要设置密码，无密码收不到推送
4. 注意生产环境的选择，需要跟证书是否正式的发布证书对应，否则无法收到推送


## 2. 推送格式 

<img src="//mccdn.qcloud.com/static/img/719853e769ad57dfaad2077e5815dd68/image.png" width=480 />

### 2.1 通用推送规则

对于单聊消息，APNs推送规则为：

```
昵称:内容
```

其中昵称是发送方用户昵称，如果未设置昵称，则只显示内容。

对于群聊消息，APNs 推送规则为：

```
名称(群名):内容
```

其中名称为群名片或者发送者昵称，优先级为 群名片 > 群名。

### 2.2 不同类型消息推送规则

APNs 推送内容部分为消息体中各个Elem内容组合：

- 文本Elem：直接显示内容
- 语音Elem：显示 [语音]
- 文件Elem：显示 [文件]
- 图片Elem：显示 [图片]
- 自定义Elem：显示desc字段内容

例如：
一条消息中包含 文本Elem和图片Elem，文本内容为Test，最终显示的内容为： Test[图片]
另外一条消息中内容为空，则不进行下发，例如如果消息中只有自定义Elem，并且desc为空，则不进行下发；

这里不用关心是否托管账号还是独立账号，只要设置了昵称或者群名推送消息就会带上。 


## 3. 事件上报 

### 3.1 Token 上报

在APP完成初始化时，可通过系统函数 registerForRemoteNotifications（ios 8.0及以上） 或 registerForRemoteNotificationTypes（ios 8.0 以下） 告知系统需要APNs离线推送，随后会在 didRegisterForRemoteNotificationsWithDeviceToken 回调中得到系统的Token，进行上报。另外需要注意，应当在每次登录时都进行上报，API接口调用可在登陆前或登录后设置。
 
**上报函数原型：**

```
/**
 *  SetToken 参数
 */
@interface TIMTokenParam : NSObject
/**
 *  获取的客户端Token信息
 */
@property(nonatomic,retain) NSData* token;
/**
 *  业务ID，传递证书时分配，如果只有一个证书，可以填0
 */
@property(nonatomic,assign) uint32_t busiId;
@end

// setToken 原型
@interface TIMManager : NSObject
-(int) setToken: (TIMTokenParam *)token;
@end
```
**参数说明：**

参数 | 说明
---|---
token  | 为系统获取到的二进制Token 
busiId  |  网站分配的证书编号，多证书时用于区分不同证书 

**示例：**
 
在app获取Token的回调中上报Token，接口无需在登陆后进行调用，ImSDK会缓存到登录后上报： 

```
- (void)application:(UIApplication *)app didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken {
    NSString *token = [NSString stringWithFormat:@"%@", deviceToken];
    TIMTokenParam * param = [[TIMTokenParam alloc] init];
    
    [param setToken:deviceToken];
    
    [[TIMManager sharedInstance] setToken:param];
}
```

### 3.2 后台&锁屏切换上报 

IM云后台进行APNs离线推送是从系统锁屏或者通过Home键把APP切换到后台开始，需要APP在锁屏事件和切后台事件发生时进行上报，另外为了APNs下发未读计数的准确性，需要切后台同时上报当前消息的未读计数，注意：这里上报未读计数仅是修改服务器未读，客户端桌面未读需要用户调用系统API进行重置：
 



