## 1. 登录

用户登录腾讯后台服务器后才能正常收发消息，登录需要用户提供accountType、identifier、userSig等信息，具体含义可参阅帐号文档。

>注意：如果此用户在其他终端被踢，登录将会失败，返回错误码（ERR_IMSDK_KICKED_BY_OTHERS：6208）。开发者必须进行登录错误码ERR_IMSDK_KICKED_BY_OTHERS的判断。关于被踢的详细描述，参见2.6 用户状态变更。

如果用户保存用户票据，可能会存在过期的情况，如果用户票据过期，login将会返回 70001 错误码，开发者可根据错误码进行票据更换。

登录为异步过程，通过回调函数返回是否成功，成功后方能进行后续操作。登录成功或者失败后使用闭包succ和fail进行回调。

**注意：只要登录成功以后，用户没有主动登出或者被踢，网络变更会自动重连，无需开发者关心。不过特别需要注意被踢操作，需要注册[用户状态变更回调](/doc/product/269/9148#5.-.E7.94.A8.E6.88.B7.E7.8A.B6.E6.80.81.E5.8F.98.E6.9B.B45)，否则被踢时得不到通知。**

**原型：**

```
/**
 *  登陆信息
 */

@interface TIMLoginParam : NSObject

/**
 * 用户名
 */
@property(nonatomic,retain) NSString* identifier;

/**
 *  鉴权Token
 */
@property(nonatomic,retain) NSString* userSig;

/**
 *  App用户使用OAuth授权体系分配的Appid
 */
@property(nonatomic,retain) NSString* appidAt3rd;


@end
```

在自有帐号情况下：appidAt3rd字段与sdkAppId相同，其他字段identifier、userSig填写相应内容。

```
/**
 *  登陆
 *
 *  @param param 登陆参数
 *  @param succ  成功回调
 *  @param fail  失败回调
 *
 *  @return 0 请求成功
 */
- (int)login:(TIMLoginParam*)param succ:(TIMLoginSucc)succ fail:(TIMFail)fail;
@end
```

**参数说明：**

参数|说明
---|---
param | 登录参数，详细信息参见 TIMLoginParam 结构说明
succ | 登录成功回调
fail | 登录失败回调

**示例：**

```
TIMLoginParam * login_param = [[TIMLoginParam alloc ]init];
 
// identifier为用户名，userSig 为用户登录凭证
// appidAt3rd 在私有帐号情况下，填写与sdkAppId 一样
login_param.identifier = @"iOS_001";
login_param.userSig = @"usersig";
login_param.appidAt3rd = @"123456";
 
[[TIMManager sharedInstance] login: login_param succ:^(){
    NSLog(@"Login Succ");
} fail:^(int code, NSString * err) {
    NSLog(@"Login Failed: %d->%@", code, err);
}];
```

## 2. 登出

如用户主动注销或需要进行用户的切换，则需要调用注销操作：

**原型：**

```
@interface TIMManager : NSObject

/**
 *  登出
 *
 *  @param succ 成功回调，登出成功
 *  @param fail 失败回调，返回错误吗和错误信息
 *
 *  @return 0 发送登出包成功，等待回调
 */
- (int)logout:(TIMLoginSucc)succ fail:(TIMFail)fail; 

@end
```

**示例：**
```
[[TIMManager sharedInstance] logout:^() {
    NSLog(@"logout succ");
} fail:^(int code, NSString * err) {
    NSLog(@"logout fail: code=%d err=%@", code, err);
}];
```

>注意：在需要切换帐号时，需要logout回调成功或者失败后才能再次login，否则login可能会失败。

## 3. 无网络情况下查看消息

如用当前网络异常，或者想在不调用login的时候查看用户消息，可调用initStorage方法初始化存储，完成后可获取会话列表和消息：

**原型：**


```
@interface TIMManager (MsgExt)
 
/**
 *  初始化存储，仅查看历史消息时使用，如果要收发消息等操作，如login成功，不需要调用此函数
 *
 *  @param param 登陆参数（userSig 不用填写）
 *  @param succ  成功回调，收到回调时，可以获取会话列表和消息
 *  @param fail  失败回调
 *
 *  @return 0 请求成功
 */
- (int)initStorage:(TIMLoginParam*)param succ:(TIMLoginSucc)succ fail:(TIMFail)fail;
 
@end
```

**参数说明：**

param	与登录参数相同，userSig可不填
succ	成功回调，成功后可获取会话列表，以及进一步登录
fail	失败回调

**示例：**

```
TIMLoginParam * login_param = [[TIMLoginParam alloc ]init];
 
// identifier为用户名
// appidAt3rd 在私有帐号情况下，填写与sdkAppId 一样
login_param.identifier = @"iOS_001";
login_param.appidAt3rd = @"123456";
 
[[TIMManager sharedInstance] initStorage: login_param succ:^(){
    NSLog(@"Init Succ");
} fail:^(int code, NSString * err) {
    NSLog(@"Init Failed: %d->%@", code, err);
}];
```

示例中初始化存储，成功后可获取会话列表。

## 4. 获取当前登陆用户

通过TIMManager成员方法getLoginUser可以获取当前用户名，也可以通过这个方法判断是否已经登陆。

**原型：**

```
@interface TIMManager : NSObject
 
/**
 *  获取当前登陆的用户
 *
 *  @return 如果登陆返回用户的identifier，如果未登录返回nil
 */
- (NSString*)getLoginUser;
 
@end
```

>说明：
返回值为当前登陆的用户名，需要注意的是，如果是自有账号登陆，用户名与登陆所传入的identifier相同，如果是第三方账号，如微信登陆，QQ登陆等，登陆后会有内部转换过的identifer，后续搜索好友，入群等，都需要使用转换后的identifier操作。

## 5. ImSDK同步离线消息

ImSDK 启动后会同步离线消息和最近联系人，最近联系人可通过接口禁用： [禁用最近联系人](/doc/product/269/9150#4.2-.E6.9C.80.E8.BF.91.E8.81.94.E7.B3.BB.E4.BA.BA.E6.BC.AB.E6.B8.B832) 。如果不需要离线消息，可以在发消息时使用：[发送在线消息](/doc/product/269/9150#1.10-.E5.9C.A8.E7.BA.BF.E6.B6.88.E6.81.AF11)。

默认登陆后会异步获取离线消息以及同步资料数据（如果有开启，可参见关系链资料章节），同步完成后会通过onRefresh回调通知更新界面，用户得到这个消息时，可以刷新界面，比如会话列表的未读等等：

```
@interface TIMUserConfig : NSObject

/**
 *  会话刷新监听器（未读计数、已读同步）（加载消息扩展包有效）
 */
@property(nonatomic,retain) id<TIMRefreshListener> refreshListener;

@end
```

