## 1 简介

云通信拥有丰富的高并发、高可靠的运营经验。如果APP开发者希望接入云通信，但正在使用自主研发或第三方即时通信服务，就需要考虑迁移问题。云通信根据不同的场景分别提出了迁移方案。

## 2 术语约定

后续文档中，我们约定：
1. 老系统：APP原本使用的即时通信服务；
1. 新系统：腾讯云的云通信服务；
1. APP 1.0：基于老系统来实现即时通信功能的APP；
1. APP 2.0：基于新系统来实现即时通信功能的APP；
1. 停服：是指停止即时通信服务，其他不依赖即时通信的服务不受影响；
1. 消息路由（消息回调）服务：第三方通信服务商在收到消息后，向APP后台转发一份消息，类似于云通信的[发单聊消息之后回调](/doc/product/269/发单聊消息之后回调)。

迁移过程，本质上就是把即时通信服务后台从老系统切换到新系统，并把APP 1.0升级到APP2.0的过程。

## 3 内容提要

云通信为您提供如下两种备选迁移解决方案：
1. 强制升级策略：
    需要短暂停服来实施迁移；
    迁移完成之后，APP 1.0将无法使用；
2. 新老兼容策略：
    需要短暂停服来实施迁移；
    迁移完成之后，新老APP可以共存，消息互通；
    在APP 1.0彻底停用之前，APP后台需要在新老系统之间保持实时双向同步。

不同方案的迁移效果不同，实施难度也相差很大，需要综合考虑APP现有的即时通信实现场景来确定合理的迁移方案。
下面罗列出几种可能的迁移场景，供APP参考。

### 3.1 场景1

老系统为其他即时通信服务提供商。
帐号体系、用户资料、关系链完全托管在老系统，APP后台不保存用户资料、关系链。
老系统不提供消息路由（消息回调）服务。

这一场景下，基本上无法实施新老系统双向同步，唯一的迁移策略是强制升级策略。

### 3.2 场景2

老系统为其他即时通信服务提供商。
帐号体系、用户资料、关系链完全托管在老系统，APP后台不保存用户资料、关系链。
老系统能够提供消息路由（消息回调）服务，但无法提供更多的回调服务。

由于帐号体系完全托管在老系统，所以在老系统中注册的用户无法实时同步到新系统，故而只能使用强制升级策略。

### 3.3 场景3

老系统为其他即时通信服务提供商。
帐号体系、用户资料、关系链均由APP自己管理，只是会实时同步到老系统中。
老系统能够提供消息路由（消息回调）服务，但无法提供更多的回调服务。

此时账户体系、用户资料、关系链均可以实现新老系统实时同步。单聊服务可以使用新老兼容策略，但群组系统依然只能使用强制升级策略进行迁移。

### 3.4 场景4

老系统为APP自研即时通信服务，一切服务均可以自主控制。

此时APP有条件实施双向数据同步。APP可以使用任意一种迁移策略。

<table style="width:100%;" >
		<tbody>
			<tr>
				<td align="center" rowspan="3" style="width:7%;background-color:#CCCCCC;">
					场景
				</td>
				<td align="center" rowspan="3" style="width:12%;background-color:#CCCCCC;">
					<p>
						<span style="line-height:1.5;">老系统</span> 
					</p>
					<p>
						<span style="line-height:1.5;">类型</span> 
					</p>
				</td>
				<td align="center" rowspan="3" style="width:15%;background-color:#CCCCCC;">
					账号体系、用户资料、关系链是否托管在老系统
				</td>
				<td align="center" colspan="2" style="width:20%;background-color:#CCCCCC;">
					<p>
						老系统支持的路由类型
					</p>
				</td>
				<td align="center" colspan="3" style="width:36%;background-color:#CCCCCC;">
					可行策略
				</td>
				<td align="center" rowspan="3" style="background-color:#CCCCCC;">
					实施方法
				</td>
			</tr>
			<tr>
				<td align="center" rowspan="2" style="width:11%;background-color:#CCCCCC;">
					消息路由
				</td>
				<td align="center" rowspan="2" style="width:11%;background-color:#CCCCCC;">
					复杂回调
				</td>
				<td align="center" rowspan="2" style="width:11%;background-color:#CCCCCC;">
					强制升级
				</td>
				<td align="center" colspan="2" style="width:22%;background-color:#CCCCCC;">
					新老兼容
				</td>
			</tr>
			<tr>
				<td align="center" style="width:11%;background-color:#CCCCCC;">
					单聊服务
				</td>
				<td align="center" style="width:11%;background-color:#CCCCCC;">
					群聊服务
				</td>
			</tr>
			<tr>
				<td>
					场景1<br>
				</td>
				<td>
					第三方IM
				</td>
				<td>
					是
				</td>
				<td>
					否
				</td>
				<td>
					否
				</td>
				<td>
					支持
				</td>
				<td>
					不支持
				</td>
				<td>
					不支持
				</td>
				<td>
					<a href="/doc/product/269/迁移场景1的实施方法">强制升级</a> 
				</td>
			</tr>
			<tr>
				<td>
					场景2<br>
				</td>
				<td>
					第三方IM
				</td>
				<td>
					是
				</td>
				<td>
					是
				</td>
				<td>
					否
				</td>
				<td>
					支持
				</td>
				<td>
					不支持
				</td>
				<td>
					不支持
				</td>
				<td>
					<a href="/doc/product/269/迁移场景2的实施方法">强制升级</a> 
				</td>
			</tr>
			<tr>
				<td>
					场景3<br>
				</td>
				<td>
					第三方IM
				</td>
				<td>
					否
				</td>
				<td>
					是
				</td>
				<td>
					否
				</td>
				<td>
					支持
				</td>
				<td>
					支持
				</td>
				<td>
					不支持
				</td>
				<td>
					<a href="/doc/product/269/迁移场景3的实施方法（强制升级）">强制升级</a>或<a href="/doc/product/269/迁移场景3的实施方法（新老兼容）">新老兼容</a> 
				</td>
			</tr>
			<tr>
				<td>
					场景4<br>
				</td>
				<td>
					自主研发IM
				</td>
				<td>
					否
				</td>
				<td>
					是
				</td>
				<td>
					是
				</td>
				<td>
					支持
				</td>
				<td>
					支持
				</td>
				<td>
					支持
				</td>
				<td>
					<a href="/doc/product/269/迁移场景4的实施方法（强制升级）">强制升级</a>或<a href="/doc/product/269/迁移场景4的实施方法（新老兼容）">新老兼容</a> 
				</td>
			</tr>
		</tbody>
	</table>
	
如果上述四种场景无法涵盖APP现有的即时通信服务，您可以联系商务经理一起协商合理的迁移方案。