## 1 消息内容MsgBody说明
MsgBody中所填写字段是消息内容。腾讯即时通信支持一条消息中包括多种消息元素类别。如一条消息中既包括文本消息元素，还包括表情消息元素。因此MsgBody定义为Array格式，可按照需求加入多类消息元素。消息元素名称为TIMMsgElement，消息元素TIMMsgElement组成MsgBody例子见下文章节消息内容MsgBody实例。

消息元素TIMMsgElement的格式统一为
```
{
    "MsgType": "",
    "MsgContent": {}
}
```

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| MsgType | String | 消息元素类别；目前支持的消息对象包括：TIMTextElem(文本消息)，TIMFaceElem(表情消息)，TIMLocationElem(位置消息)，TIMCustomElem(自定义消息)。 |
|MsgContent|Object|消息元素的内容，不同的MsgType有不同的MsgContent格式，具体参见下文。|
目前支持消息类别MsgType见下表

| MsgType的值 | 类型 |
|---------|---------|---------|
| TIMTextElem | 文本消息。|
|TIMLocationElem|地理位置消息。|
|TIMFaceElem|表情消息。|
|TIMCustomElem|自定义消息，当接收方为IOS系统且应用处在后台时，此消息类型可携带除文本以外的字段到APNS。注意，一条组合消息中只能包含一个TIMCustomElem自定义消息元素。|
|TIMSoundElem|语音消息。（服务端集成Rest API不支持发送该类消息）|
|TIMImageElem|图像消息。（服务端集成Rest API不支持发送该类消息）|
|TIMFileElem|文件消息。（服务端集成Rest API不支持发送该类消息）|
注意，通过服务端集成的Rest API接口，只能发送 TIMTextElem，TIMLocationElem，TIMLocationElem，TIMCustomElem类型的消息，其它类型的消息（TIMSoundElem，TIMImageElem，TIMFileElem）不能通过Rest API接口发送。

## 2 消息元素TIMMsgElement

### 2.1 文本消息元素

```
{
    "MsgType": "TIMTextElem",
    "MsgContent": {
        "Text": "hello world"
    }
}
```

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| Text | String | 消息内容。当接收方为iphone后台在线时，做iOS离线Push时文本展示。 |
    
当接收方为iOS系统且应用处在后台时，json请求包体中的Text字段作为离线推送文本。

### 2.2 地理位置消息元素

```
{
    "MsgType": "TIMLocationElem", 
    "MsgContent": {
        "Desc": "someinfo", 
        "Latitude": 29.340656774469956, 
        "Longitude": 116.77497920478824
    }
}
```

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| Desc | String | 地理位置描述信息。 |
|Latitude|Number|纬度|
|Longitude|Number|经度|

当接收方为iOS系统且应用处在后台时，中文版离线推送文本为“[位置]”，英文版推送文本为“[Location]”。

### 2.3 表情消息元素

```
{
    "MsgType": "TIMFaceElem", 
    "MsgContent": {
        "Index": 1, 
        "Data": "content"
    }
}
```
| 字段 | 类型 | 说明 |
|---------|---------|---------|
| Index | Number | 表情索引，用户自定义。 |
|Data|String|额外数据|
当接收方为iOS系统且应用处在后台时，中文版离线推送文本为“[表情]”，英文版为“[Face]”。

### 2.4 自定义消息元素

```
{
    "MsgType": "TIMCustomElem", 
    "MsgContent": {
        "Data": "message", 
        "Desc": "notification", 
        "Ext": "url", 
        "Sound": "dingdong.aiff"
    }
}
```
| 字段 | 类型 | 说明 |
|---------|---------|---------|
| Data | String | 自定义消息数据。 不作为APNS的payload中字段下发，故从payload中无法获取Data字段。|
|Desc|String|自定义消息描述信息；当接收方为iPhone后台在线时，做iOS离线Push时文本展示。|
|Ext|String|扩展字段；当接收方为iOS系统且应用处在后台时，此字段作为APNS请求包Payloads中的ext键值下发，Ext的协议格式由业务方确定，APNS只做透传。|
|Sound|String|自定义APNS推送铃音。|
当接收方为iOS系统且应用处在后台时，Desc作为推送文本， Ext字段作为APNS请求包Payloads中的ext键值下发， Data字段不作为APNS的Payloads字段下发。注意，一条组合消息中只能包含TIMCustomElem自定义消息元素。
### 2.5 语音消息元素
注意：不能通过服务端集成的Rest API接口发送语音消息，发送语音消息需要通过客户端集成相应的接口。
```
{
    "MsgType": "TIMSoundElem",
    "MsgContent": {
        "UUID": "305c0201",
        "Size": 62351,
        "Second": 1
    }
}
```

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| UUID | String | 语音序列号。后台用于索引语音的键值。 |
| Size | Number | 语音数据大小。 |
| Second | Number | 语音时长，单位:秒。 |

### 2.6 图像消息元素
注意：不能通过服务端集成的Rest API接口发送图像消息，发送图像消息需要通过客户端集成相应的接口。
```
{
    "MsgType": "TIMImageElem",
    "MsgContent": {
        "UUID": "1853095_D61040894AC3DE44CDFFFB3EC7EB720F",
        "ImageFormat": 1,
        "ImageInfoArray": [
            {
                "Type": 1,           //原图
                "Size": 1853095,
                "Width": 2448,
                "Height": 3264,
                "URL": "http://xxx/3200490432214177468_144115198371610486_D61040894AC3DE44CDFFFB3EC7EB720F/0"
            },
            {
                "Type": 2,      //大图
                "Size": 2565240,
                "Width": 0,
                "Height": 0,
                "URL": "http://xxx/3200490432214177468_144115198371610486_D61040894AC3DE44CDFFFB3EC7EB720F/720"
            },
            {
                "Type": 3,   //缩量图
                "Size": 12535,
                "Width": 0,
                "Height": 0,
                "URL": "http://xxx/3200490432214177468_144115198371610486_D61040894AC3DE44CDFFFB3EC7EB720F/198"
            }
        ]
    }
}
```

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| UUID | String | 图片序列号。后台用于索引图片的键值。 |
| ImageFormat | Number | 图片格式。BMP=1,JPG=2,GIF=3,其他=0。 |
| ImageInfoArray | Array | 原图、缩略图或者大图下载信息。 |
| Type | Number | 图片类型： 1-原图，2-大图 3-缩略图。 |
| Size | Number | 图片数据大小。 |
| Width | Number | 图片宽度。 |
| Height | Number | 图片高度。 |
| URL | Number | 图片下载地址。 |

### 2.7 文件消息元素
注意：不能通过服务端集成的Rest API接口发送文件消息，发送文件消息需要通过客户端集成相应的接口。
```
{
    "MsgType": "TIMFileElem",
    "MsgContent": {
        "UUID": "305c02010",
        "FileSize": 1773552,
        "FileName": "file:///private/var/Application/tmp/trim.B75D5F9B-1426-4913-8845-90DD46797FCD.MOV"
    }
}
```

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| UUID | String | 文件序列号。后台用于索引语音的键值。 |
| FileSize | Number | 文件数据大小。 |
| FileName | String | 文件名称。 |


## 3 MsgBody消息内容实例

### 3.1 单一文本元素消息

单条消息中只包括一中文本消息元素，文本内容为hello world。

```
{
    "MsgBody": [
        {
            "MsgType": "TIMTextElem", 
            "MsgContent": {
                "Text": "hello world"
            }
        }
    ]
}
```

### 3.2 组合消息

下述的单条消息中包括两个文本消息元素和一个表情元素，消息元素顺序是文本+表情+文本。
```
{
    "MsgBody": [
        {
            "MsgType": "TIMTextElem", 
            "MsgContent": {
                "Text": "hello"
            }
        }, 
        {
            "MsgType": "TIMFaceElem", 
            "MsgContent": {
                "Index": 1, 
                "Data": "content"
            }
        }, 
        {
            "MsgType": "TIMTextElem", 
            "MsgContent": {
                "Text": "world"
            }
        }
    ]
}
```

注意，一条组合消息中只能带一个TIMCustomElem自定义消息元素， 其它消息元素数量无限制。
## 4 Apple Push Notification Service（APNS）相关说明
### 4.1 客户端推送展示格式说明
#### 4.1.1 未设置账号昵称
如果账号没有设置昵称，APNS推送只展示推送文本内容。单聊消息只展示“推送文本”，群组消息展示“(群名称):推送文本“。
![](//mccdn.qcloud.com/static/img/09cf6994a8f5522f79a43ac46e1086d7/image.png)
#### 4.1.2 已设置账号昵称
如果账号设置昵称，单聊消息展示格式为“昵称：推送文本内容”，群组消息展示格式为昵称(群名称)：推送文本内容。
![](//mccdn.qcloud.com/static/img/c739cd153546cf62dc82d877becda9ae/image.png)

#### 4.1.3 组合消息展示格式
对于组合消息，按顺序叠加各个消息元素中推送文本作为展示文本。下述为已设置账户昵称的单聊消息，推送文本为"helloworld"。注意helloworld中间没有空格，后台按照顺序叠加，各个消息元素推送文本之间不添加任何字符。如需要在各个不同的消息元素间添加空格或其他字符，需调用方自己控制。
```
{
    "MsgBody": [
        {
            "MsgType": "TIMTextElem", 
            "MsgContent": {
                "Text": "hello"  
            }
        },
        {
            "MsgType": "TIMCustomElem",
            "MsgContent": {
                "Data": "message",
                "Desc": "world",
                "Ext": "/:url",               
                "Sound": "dingdong.aiff"
            }
        }
    ] 
}

```
![](//mccdn.qcloud.com/static/img/4cef00f3e38038e32f5e1529a1b8b018/image.png)

各类消息元素推送文本字段汇总。

| MsgType的值 | 类型 |消息元素推送文本|
|---------|---------|---------|---------|
| TIMTextElem | 文本消息。|Text字段。|
|TIMLocationElem|地理位置消息。|中文"[位置]"；英文“[Location]”.|
|TIMFaceElem|表情消息。|中文版离线推送文本为“[表情]”，英文版为“[Face]”|
|TIMCustomElem|自定义消息。|Desc字段。|
### 4.2 昵称和群名称REST API设置接口
设置账号昵称REST API接口：[设置资料](/doc/product/269/设置资料)。

设置群名称REST API接口：[修改群组基础资料](/doc/product/269/修改群组基础资料)。
### 4.3 高级应用
#### 4.3.1 自定义推送声音，APNS下发扩展字段.
利用自定义消息元素TIMCustomElem，Sound填写自定义声音文件名称， Ext填写下发的扩展字段，请求扩展字段可以从APNS推送PayLoad中的ext字段获取。
```
{
    "To_Account": "lumotuwe5", 
    "MsgRandom": 121212, 
    "MsgBody": [
        {
            "MsgType": "TIMCustomElem", 
            "MsgContent": {
                "Data": "other information", 
                "Desc": "hello", 
                "Ext": "www.qq.com", 
                "Sound": "dingdong.aiff"
            }
        }, 
        {
            "MsgType": "TIMTextElem", 
            "MsgContent": {
                "Text": "world"
            }
        }
    ]
}

```

客户端收到APNS推送JSON Payload为

```
{
    "aps": {
        "alert": "Nickname:helloworld",   //各个消息元素推送文本顺序叠加
        "badge": 5,                       
        "sound": "dingdong.aiff"         //对应TIMCustomElem中Sound字段
    }, 
    "ext": "www.qq.com"                //对应TIMCustomElem中Ext字段
}

```

## 5 离线推送 OfflinePushInfo 说明

OfflinePushInfo是专用于离线推送配置的Json对象，允许配置该条消息是否关闭推送、推送文本描述内容、推送透传字符串等等。使用OfflinePushInfo可以方便地设置离线推送信息，无需再通过TIMCustomElem封装实现。注意：如果填写了OfflinePushInfo，那么TIMCustomElem中与离线推送有关的信息配置会被忽略。目前OfflinePushInfo适用于APNs推送，以及安卓厂商推送（小米、华为推送）。

OfflinePushInfo的格式示例如下：

```
{
    // ...
    "MsgBody": [...] // 这里同 MsgBody相关描述 ,
    "OfflinePushInfo": {
        "PushFlag": 0,
        "Desc": "这是离线推送内容",
        "Ext": "这是透传的内容",
        "AndroidInfo": { 
            "Sound": "android.mp3"
        },
        "ApnsInfo": {
            "Sound": "apns.mp3",
            "BadgeMode": 1,
            "Title":"apns title",
            "SubTitle":"apns subtitle",
            "Image":"www.image.com"
        }
    }
}
```

字段说明如下：

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| PushFlag | Integer | 选填 | 0表示推送，1表示不离线推送。 |
| Desc | String | 选填 | 离线推送内容 。|
| Ext | String | 选填 | 离线推送透传内容。 |
| Sound | String | 选填 | 离线推送声音文件路径。 |
| BadgeMode | Integer | 选填 | 这个字段缺省或者为 0 表示需要计数，为 1 表示本条消息不需要计数，即右上角图标数字不增加|
|Title|String|选填|该字段用于标识apns推送的标题|
|SubTitle|String|选填|该字段用于标识apns推送的子标题|
|Image|String|选填|该字段用于标识apns携带的图片地址，当客户端拿到该字段时，可以通过下载图片资源的方式将图片展示在弹窗上|

注意：由于APNs推送限制数据包大小不能超过4K，因此除去其他控制字段，建议Desc和Ext字段之和不要超过3K。

## 6 参考

Apple Push Notification Service(APNS)[苹果推送开发文档](https://developer.apple.com/library/ios/documentation/NetworkingInternet/Conceptual/RemoteNotificationsPG/Chapters/Introduction.html#//apple_ref/doc/uid/TP40008194-CH1-SW1)。

iOS离线消息推送配置：[离线推送（iOS SDK）](/doc/product/269/离线推送（iOS SDK）)。









