## 1. 介绍

本文档实现在托管模式下指导用户快速接入腾讯IM云通信功能，该文档仅介绍如何实现初始化ImSDK，如何实现用户注册、用户登录，如何发送C2C消息，其他功能请参见云通信[产品文档](https://cloud.tencent.com/document/product/269)。

## 2. 托管模式介绍

托管模式是指，由腾讯云后台为开发者提供APP帐号的密码注册、存储和密码验证。帐号验证成功后，派发私钥加密生成的签名到客户端，APP业务服务器可以通过[下载的公钥](/doc/product/269/下载公钥)解密签名进行验证。

详细描述文档请参见[帐号集成文档](https://cloud.tencent.com/document/product/269/1509)。

## 3. 集成ImSDK到工程

从 [官网](https://cloud.tencent.com/product/im.html#sdk) 下载ImSDK开发包，主要包括：ImSDK.framework、IMMessageExt.framework、IMGroupExt.framework、IMFriendshipExt.framework、TLSSDK.framework、QALSDK.framework。各个包的说明如下：

必选SDK：**必须是一个版本成套使用，不同版本不可混用**

* ImSDK.framework 		IM基础功能包
* QALSDK.framework		网络SDK
* TLSSDK.framework		登录SDK

可选SDK：

* IMMessageExt.framework		IM全量消息能力扩展包
  * 包含消息本地存储、会话列表、最近联系人、拉取漫游消息等功能
  * 增加消息的未读计数、已读回执、草稿等功能
* IMGroupExt.framework   IM全量群组能力扩展包
  * 包含全量的群组类型和群组资料
  * 包含全量的群成员能力
  * 包含全量的群组管理能力
* IMFriendshipExt.framework    IM全量关系链资料能力扩展包
  * 包含全量的关系链能力
* IMSDKBugly.framework	  Crash上报功能
 * 如无特殊需要，推荐使用，在控制台页面可以查看Crash率等信息
 * 如果不加入此SDK，需要调用 [TIMManager sharedInstance] disableCrashReport]; 禁用功能

其他SDK：

* QALHttpSDK.framework		网络透传SDK
 * 只有用到网络透传功能时使用

创建一个新工程，填入工程名，这里以IMDemo为例：

![](//avc.qcloud.com/wiki2.0/im/imgs/20150928013356_56054.jpg)
![](//avc.qcloud.com/wiki2.0/im/imgs/20150928013638_56711.jpg)

选中IMDemo的Target，在General面板中的Linked Frameworks and Libraries添加依赖库。

![](//avc.qcloud.com/wiki2.0/im/imgs/20150928013833_31715.jpg)

需要添加的依赖库有：

```
CoreTelephony.framework
SystemConfiguration.framework
libstdc++.6.dylib
libc++.dylib
libz.dylib
libsqlite3.dylib
ImSDK.framework
IMMessageExt.framework
IMGroupExt.framework
IMFriendshipExt.framework
TLSSDK.framework
QALSDK.framework
IMSDKBugly.framework
```

其中 ImSDK.framework、IMMessageExt.framework、IMGroupExt.framework、IMFriendshipExt.framework、TLSSDK.framework、QALSDK.framework 为步骤1.1.1下载的SDK，其余均为系统内置库。另外**需要在Build Setting中Other Linker Flags添加-ObjC**。

在调用代码中引入头文件ImSDK.h、IMMessageExt.h、IMGroupExt.h、IMFriendshipExt.h，根据后续章节的开发指引进行功能的开发。

其他平台请分别参考[Android文档](https://cloud.tencent.com/document/product/269/9227)和[Windows文档](https://cloud.tencent.com/document/product/269/1579)。

## 4. 功能开发

## 4.1 初始化

在使用ImSDK之前需要对SDK进行初始化操作，包括设置sdkappid、accountType、消息回调对象等参数。

**示例：**

```

- (void)initSDK
{
    // 初始化SDK，设置sdkappid和accoutType，由腾讯云控制台分配
    TIMSdkConfig * config = [[TIMSdkConfig alloc] init];
    config.sdkAppId = 1400001533;
    config.accountType = @"792";
    [[TIMManager sharedInstance] initSdk:config];
    
    // 初始化用户参数配置，使用默认配置
    TIMUserConfig * userConfig = [[TIMUserConfig alloc] init];
    [[TIMManager sharedInstance] setUserConfig:userConfig];
    
    // 添加新消息监听器，实现onNewMessage:
    [[TIMManager sharedInstance] addMessageListener:self];
}

/**
 收到新消息时，ImSDK回调此方法

 @param msgs 新消息列表
 */
- (void)onNewMessage:(NSArray*)msgs
{
    // 收到新消息，将第一个消息的文本elem展示在界面
    for (TIMMessage * msg in msgs) {
        TIMTextElem * elem = (TIMTextElem*)[msg getElem:0];
        if ([elem isKindOfClass:[TIMTextElem class]]) {
            _msgRecv.text = elem.text;
            return;
        }
    }
}

```

## 4.2 注册帐号

开发者可以使用TLSSDK的接口在客户端注册新用户。

**示例：**

```

/**
 注册新用户
 */
- (void)registerNewUser
{
    // 注册：使用托管账号模式，注册用户
    int ret = [[TLSHelper getInstance] TLSStrAccountReg:@"test_01" andPassword:@"12345678" andTLSStrAccountRegListener:self];
    if (ret != TLS_ACCOUNT_SUCCESS) {
        NSLog(@"注册失败!");
    }
}

#pragma mark TLS注册回调
-(void)OnStrAccountRegSuccess:(TLSUserInfo *)userInfo{
	NSLog(@"注册成功!");
}
-(void)OnStrAccountRegFail:(TLSErrInfo *)errInfo{
	NSLog(@"注册失败：%@", errInfo.sErrorMsg);
}
-(void)OnStrAccountRegTimeout:(TLSErrInfo *)errInfo
{
	NSLog(@"注册超时");
}

```

## 4.3 获取UserSig

完成用户注册操作后，用户需要通过TLSSDK获取UserSig，传入到ImSDK中进行登录操作。

**示例：**

```

/**
 登录用户test_01
 */
- (void)login
{
    // 1.登录：使用托管账号密码，获取usersig
    int ret = [[TLSHelper getInstance] TLSPwdLogin:@"test_01" andPassword:@"12345678" andTLSPwdLoginListener:self];
    if (ret != TLS_ACCOUNT_SUCCESS) {
        NSLog(@"登录失败!");
    }
}


#pragma mark TLS登录回调
- (void)OnPwdLoginSuccess:(TLSUserInfo *)userInfo{
    // 2.登录：获取usersig，生成ImSDK登录参数
    NSString *userSig = [[TLSHelper getInstance] getTLSUserSig:userInfo.identifier];
    TIMLoginParam * loginParam = [[TIMLoginParam alloc] init];
    loginParam.identifier = _userName.text;
    loginParam.appidAt3rd = @"1400001533";
    loginParam.userSig = userSig;
    
    // 3.登录：登录ImSDK，成功后才可以进行收发消息等操作
    [[TIMManager sharedInstance] login:loginParam succ:^{
        NSLog(@"登录成功！");
    } fail:^(int code, NSString *msg) {
        NSLog(@"登录失败：%@", msg);
    }];
}

- (void)OnPwdLoginFail:(TLSErrInfo *)errInfo{
    NSLog(:@"登录失败：%@", errInfo.sErrorMsg);
}

- (void)OnPwdLoginTimeout:(TLSErrInfo *)errInfo{
	NSLog(@"登录超时");
}

- (void)OnPwdLoginReaskImgcodeSuccess:(NSData *)picData{
}

- (void)OnPwdLoginNeedImgcode:(NSData *)picData andErrInfo:(TLSErrInfo *)errInfo{
}


```

登录常见错误码 | 原因
---|---
6012 | 登录超时，请检查网络
6200 | 没有网络
6208 | 其他终端登录帐号被踢，需重新登录
70001 | sig过期，请尝试重新生成。如果是刚生成，就过期，请检查有效期填写的是否过小，或者填的0

## 4.4 发送消息

完成登录操作后，即可以发送消息。

**示例：**

```

/**
 登录成功后实现发C2C消息功能
 */
-(void)sendMsg
{
    /*获取c2c_conversation*/
    TIMConversation * c2c_conversation = [[TIMManager sharedInstance] getConversation:TIM_C2C receiver:@"Tyrekezhao_1"];
    
    /*生成elment*/
    TIMTextElem * text_elem = [[TIMTextElem alloc] init];
    
    [text_elem setText:@"this is a text message"];
    
    /*初始化消息对象*/
    TIMMessage * msg = [[TIMMessage alloc] init];
    
    /*将element添加至消息体中*/
    [msg addElem:text_elem];
    
    /*发消息*/
    [c2c_conversation sendMessage:msg succ:^(){
        NSLog(@"SendMsg Succ");
    }fail:^(int code, NSString * err) {
        NSLog(@"SendMsg Failed:%d->%@", code, err);
    }];
}

```

![](http://wikiuv-1253488539.cosgz.myqcloud.com/uv.png)