## 1. 介绍

本文档实现在独立模式下指导用户快速接入腾讯IM云通信功能，该文档仅介绍如何实现初始化ImSDK，如何实现用户登录，如何发送C2C消息，其他功能请参见云通信[产品文档](https://cloud.tencent.com/document/product/269)。

## 2. 独立模式介绍

独立模式是指，用户注册和身份验证由开发者负责，开发者和腾讯之间通过签名验证建立信任关系。开发者在申请接入时，直接下载公私钥用于开发，而后用私钥加密指定数据生成签名交由腾讯服务器验证合法性。

详细描述文档请参见[帐号集成文档](https://cloud.tencent.com/document/product/269/1508)。

## 3. 集成ImSDK到工程

从 [官网](https://cloud.tencent.com/product/im.html#sdk) 下载ImSDK开发包，主要包括：ImSDK.framework、IMMessageExt.framework、IMGroupExt.framework、IMFriendshipExt.framework、TLSSDK.framework、QALSDK.framework。各个包的说明如下：

必选SDK：**必须是一个版本成套使用，不同版本不可混用**

* ImSDK.framework 		IM基础功能包
* QALSDK.framework		网络SDK
* TLSSDK.framework		登录SDK

可选SDK：

* IMMessageExt.framework		IM全量消息能力扩展包
  * 包含消息本地存储、会话列表、最近联系人、拉取漫游消息等功能
  * 增加消息的未读计数、已读回执、草稿等功能
* IMGroupExt.framework   IM全量群组能力扩展包
  * 包含全量的群组类型和群组资料
  * 包含全量的群成员能力
  * 包含全量的群组管理能力
* IMFriendshipExt.framework    IM全量关系链资料能力扩展包
  * 包含全量的关系链能力
* IMSDKBugly.framework	  Crash上报功能
 * 如无特殊需要，推荐使用，在控制台页面可以查看Crash率等信息
 * 如果不加入此SDK，需要调用 [TIMManager sharedInstance] disableCrashReport]; 禁用功能

其他SDK：

* QALHttpSDK.framework		网络透传SDK
 * 只有用到网络透传功能时使用

创建一个新工程，填入工程名，这里以IMDemo为例：

![](//avc.qcloud.com/wiki2.0/im/imgs/20150928013356_56054.jpg)
![](//avc.qcloud.com/wiki2.0/im/imgs/20150928013638_56711.jpg)

选中IMDemo的Target，在General面板中的Linked Frameworks and Libraries添加依赖库。

![](//avc.qcloud.com/wiki2.0/im/imgs/20150928013833_31715.jpg)

需要添加的依赖库有：

```
CoreTelephony.framework
SystemConfiguration.framework
libstdc++.6.dylib
libc++.dylib
libz.dylib
libsqlite3.dylib
ImSDK.framework
IMMessageExt.framework
IMGroupExt.framework
IMFriendshipExt.framework
TLSSDK.framework
QALSDK.framework
IMSDKBugly.framework
```

其中 ImSDK.framework、IMMessageExt.framework、IMGroupExt.framework、IMFriendshipExt.framework、TLSSDK.framework、QALSDK.framework 为步骤1.1.1下载的SDK，其余均为系统内置库。另外**需要在Build Setting中Other Linker Flags添加-ObjC**。

在调用代码中引入头文件ImSDK.h、IMMessageExt.h、IMGroupExt.h、IMFriendshipExt.h，根据后续章节的开发指引进行功能的开发。

其他平台请分别参考[Android文档](https://cloud.tencent.com/document/product/269/9227)和[Windows文档](https://cloud.tencent.com/document/product/269/1579)。

## 4. 功能开发

## 4.1 初始化

在使用ImSDK之前需要对SDK进行初始化操作，包括设置sdkappid、accountType、消息回调对象等参数。

**示例：**

```

- (void)initSDK
{
    // 初始化SDK，设置sdkappid和accoutType，由腾讯云控制台分配
    TIMSdkConfig * config = [[TIMSdkConfig alloc] init];
    config.sdkAppId = 1400001533;
    config.accountType = @"792";
    [[TIMManager sharedInstance] initSdk:config];
    
    // 初始化用户参数配置，使用默认配置
    TIMUserConfig * userConfig = [[TIMUserConfig alloc] init];
    [[TIMManager sharedInstance] setUserConfig:userConfig];
    
    // 添加新消息监听器，实现onNewMessage:
    [[TIMManager sharedInstance] addMessageListener:self];
}

/**
 收到新消息时，ImSDK回调此方法

 @param msgs 新消息列表
 */
- (void)onNewMessage:(NSArray*)msgs
{
    // 收到新消息，将第一个消息的文本elem展示在界面
    for (TIMMessage * msg in msgs) {
        TIMTextElem * elem = (TIMTextElem*)[msg getElem:0];
        if ([elem isKindOfClass:[TIMTextElem class]]) {
            _msgRecv.text = elem.text;
            return;
        }
    }
}

```

## 4.2 获取UserSig

开发者可以使用TLS后台API生成UserSig，传递给客户端填入ImSDK进行登录操作。

**linux下生成sig和校验sig**

首先不带参数执行 tls_licence_tools，即执行下面的命令：

```
$ ./tls_licence_tools
```


输出：
 ```
current version: 201511190000
Usage:
    get sig: ./tls_licence_tools gen pri_key_file sig_file sdkappid identifier
    get sig e.g.:./tls_licence_tools gen ec_key.pem sig 1400001052 xiaojun
    verify sig:./tls_licence_tools verify pub_key_file sig_file sdkappid identifier
    verify sig e.g.: ./tls_licence_tools verify public.pem sig 1400001052 xiaojun
```

下面是演示截图：

![](//avc.qcloud.com/wiki2.0/im/imgs/20151126140600_45285.png)

输出实际上是参数模板和示例。

执行类似于下面的命令可以生成 sig：

```
./tls_licence_tools gen ec_key.pem sig 1400001052 xiaojun
```

对应的参数解释是：


```
./tls_licence_tools gen 私钥文件路径 sig将要存放的路径 sdkappid 用户id
```


执行类似于下面的命令可以校验 sig：

```
./tls_licence_tools verify public.pem sig 1400001052 xiaojun
```

对应参数的解释是：

```
./tls_licence_tools verify 公钥文件路径 sig的存放路径 sdkappid 用户id
```

下面是生成sig演示截图：

![](//avc.qcloud.com/wiki2.0/im/imgs/20151126140852_93229.png)

上面是生成sig，下面是校验sig：

![](//avc.qcloud.com/wiki2.0/im/imgs/20151126140903_32964.png)

下面解释下参数模板中参数的意义：

```
gen和verify分别表示生成sig和校验sig的命令
pri_key_file：私钥文件的路径
pub_key_file：公钥文件的路径
sig_file：sig 文件的路径，如果是生成 sig，那么会将 sig 写入这个文件，如果是校验 sig，那么会从这个文件读取 sig 的内容
sdkappid：创建应用时页面上分配的 sdkappid
identifier：用户标识，即用户id
```

>注意：生成的sig有效期为180天，开发者需要在sig过期前，重新生成sig。

其他语言的API工具请参考[TLS后台API](https://cloud.tencent.com/document/product/269/1510#1-.E6.A6.82.E8.BF.B0)

## 4.3 登录&发消息

登录过程需要使用上一步中的UserSig才能实现。登录成功后即可以进行发送消息操作。

**示例：**

```

/**
 登录ImSDK并发送一条C2C消息
 */
- (void)login
{
    /*获取SIG*/
    
    /*登录操作*/
    TIMLoginParam * login_param = [[TIMLoginParam alloc ]init];
    
    // identifier为用户名，userSig 为用户登录凭证
    // appidAt3rd 在私有帐号情况下，填写与sdkAppId 一样
    login_param.identifier  = @"tom4";           //用户自定义
    //独立模式计算获取，托管模式需要网络交互获取到
    login_param.userSig     = @"";               //TLS后台API生成后返回
    login_param.appidAt3rd  = @"1400001533";     //与sdkAppId一致
    
    /*登录操作，登陆成功后执行succ. 不需要关注其他SDK的初始化（例如QAL、TLS、IMBugly）初始化*/
    [[TIMManager sharedInstance] login: login_param succ:^() {
        NSLog(@"Login Succ");
        
        /*登录成功后实现发C2C消息功能*/
        
        /*获取c2c_conversation*/
        TIMConversation * c2c_conversation = [[TIMManager sharedInstance] getConversation:TIM_C2C receiver:@"Tyrekezhao_1"];
        
        /*生成elment*/
        TIMTextElem * text_elem = [[TIMTextElem alloc] init];
        
        [text_elem setText:@"this is a text message"];
        
        /*初始化消息对象*/
        TIMMessage * msg = [[TIMMessage alloc] init];
        
        /*将element添加至消息体中*/
        [msg addElem:text_elem];
        
        /*发消息*/
        [c2c_conversation sendMessage:msg succ:^(){
            NSLog(@"SendMsg Succ");
        }fail:^(int code, NSString * err) {
            NSLog(@"SendMsg Failed:%d->%@", code, err);
        }];
    } fail:^(int code, NSString * err) {
        NSLog(@"Login Failed: %d->%@", code, err);
        /*常见错误码及原因*/
    }];
}

```

登录常见错误码 | 原因
---|---
6012 | 登录超时，请检查网络
6200 | 没有网络
6208 | 其他终端登录帐号被踢，需重新登录
70001 | sig过期，请尝试重新生成。如果是刚生成，就过期，请检查有效期填写的是否过小，或者填的0


![](http://wikiuv-1253488539.cosgz.myqcloud.com/uv.png)