## 1 功能说明  

1.支持批量导入单向好友；
2.往同一个用户导入好友时建议采用批量导入的方式，避免并发写导致的写冲突。
## 2 接口调用说明 

### 2.1 请求URL 
```
https://console.tim.qq.com/v4/sns/friend_import?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
```
### 2.2 请求参数 

URL中各参数的含义以及填写方式参见<a href="https://cloud.tencent.com/document/product/269/1519">REST API简介</a>。 

### 2.3 最高调用频率 

100次/秒。如需提升调用频率，请根据<a href="https://cloud.tencent.com/document/product/269/3916#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4">REST API调用频率调整</a>提交工单申请处理。

### 2.4 HTTP请求方式 

POST 

### 2.5 HTTP请求包体格式 

JSON 

### 2.6 请求包示例

#### 2.6.1 基础形式

```
{
    "From_Account":"id",
    "AddFriendItem":
    [
        {
            "To_Account":"id1",
            "AddSource":"AddSource_Type_XXXXXXXX"
        }
    ]
}
```

#### 2.6.2 完整形式

```
{
    "From_Account":"id",
    "AddFriendItem":
    [
        {
            "To_Account":"id1",
            "Remark":"remark1",
            "RemarkTime":1420000001,
            "GroupName":["朋友"],
            "AddSource":"AddSource_Type_XXXXXXXX",
            "AddWording":"I'm Test1",
            "AddTime":1420000001,
            "CustomItem":
            [
                {
                    "Tag":"Tag_SNS_1300000000_XXXX",
                    "Value":"Test"
                },
                {
                    "Tag":"Tag_SNS_1300000000_YYYY",
                    "Value":0
                }
            ]
        }
    ]
}
```

#### 2.6.3 批量加好友

```
{
    "From_Account":"id",
    "AddFriendItem":
    [
        {
            "To_Account":"id1",
            "AddSource":"AddSource_Type_XXXXXXXX"
        },
        {
            "To_Account":"id2",
            "Remark":"remark2",
            "RemarkTime":1420000001,
            "GroupName":["朋友"],
            "AddSource":"AddSource_Type_XXXXXXXX",
            "AddWording":"I'm Test2",
            "AddTime":1420000001
        },
        {
            "To_Account":"id3",
            "Remark":"remark3",
            "RemarkTime":1420000001,
            "GroupName":["同事","朋友"],
            "AddSource":"AddSource_Type_XXXXXXXX",
            "AddWording":"I'm Test3",
            "AddTime":1420000001,
            "CustomItem":
            [
                {
                    "Tag":"Tag_SNS_1300000000_XXXX",
                    "Value":"Test"
                },
                {
                    "Tag":"Tag_SNS_1300000000_YYYY",
                    "Value":0
                }
            ]
        }
    ]
}
```

### 2.7 请求包字段说明 

<table style="display:table;width:100%">
	<tbody>
		<tr style="background:#C2D3FC;border:1px solid blue;">
			<td style="width:15%;">字段</td>
			<td style="width:10%;">类型</td>
			<td style="width:10%;">属性</td>
			<td style="width:65%;">说明</td>
		</tr>
		<tr>
			<td>From_Account</td>
			<td>String</td>
			<td>必填</td>
			<td>需要为该Identifier添加好友。</td>
		</tr>
		<tr>
			<td>AddFriendItem</td>
			<td>Array</td>
			<td>必填</td>
			<td>好友结构体对象。</td>
		</tr>
		<tr>
			<td>To_Account</td>
			<td>String</td>
			<td>必填</td>
			<td>好友的Identifier。</td>
		</tr>
		<tr>
			<td>Remark</td>
			<td>String</td>
			<td>选填</td>
			<td>From_Account对To_Account的好友备注，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。</td>
		</tr>
		<tr>
			<td>RemarkTime</td>
			<td>Integer</td>
			<td>选填</td>
			<td>From_Account对To_Account的好友备注时间。</td>
		</tr>
		<tr>
			<td>GroupName</td>
			<td>Array</td>
			<td>选填</td>
			<td>From_Account对To_Account的分组信息，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。</td>
		</tr>
		<tr>
			<td>AddSource</td>
			<td>String</td>
			<td>必填</td>
			<td>
				加好友来源字段，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。
			</td>
		</tr>
		<tr>
			<td>AddWording</td>
			<td>String</td>
			<td>选填</td>
			<td>From_Account和To_Account形成好友关系时的附言信息，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。</td>
		</tr>
		<tr>
			<td>AddTime</td>
			<td>Integer</td>
			<td>选填</td>
			<td>From_Account和To_Account形成好友关系的时间。</td>
		</tr>
		<tr>
			<td>CustomItem</td>
			<td>Array</td>
			<td>选填</td>
			<td>From_Account对To_Account的自定义表示对象信息数组，每一个对象都包含了Tag和Value。</td>
		</tr>
		<tr>
			<td>Tag</td>
			<td>String </td>
			<td>选填</td>
			<td>From_Account对To_Account的自定义标签，使用前需要联系云通讯团队申请一个Tag。</td>
		</tr>
		<tr>
			<td>Value</td>
			<td>String/Integer </td>
			<td>选填</td>
			<td>From_Account对To_Account的自定义内容，可以是字符串，也可以是一个整数或者是一段Buffer。</td>
		</tr>
	</tbody>
</table>


### 2.8 应答包体示例

#### 2.8.1 基础形式、完备形式

```
{
	"ResultItem":
	[
		{
			"To_Account":"id1",
			"ResultCode":0,
			"ResultInfo":""
		}
	],
	"Fail_Account":[],
	"Invalid_Account":[],
	"ActionStatus":"OK",
	"ErrorCode":0,
	"ErrorInfo":"",
	"ErrorDisplay":""
}
```

#### 2.8.2 批量加好友

```
{
	"ResultItem":
	[
		{
			"To_Account":"id1",
			"ResultCode":0,
			"ResultInfo":""
		},
		{
			"To_Account":"id2",
			"ResultCode":0,
			"ResultInfo":""
		},
		{
			"To_Account":"id3",
			"ResultCode":0,
			"ResultInfo":""
		}
	],
	"Fail_Account":[],
	"Invalid_Account":[],
	"ActionStatus":"OK",
	"ErrorCode":0,
	"ErrorInfo":"",
	"ErrorDisplay":""
}
```

### 2.9 应答包字段说明 

<table style="display:table;width:100%">
	<tbody>
		<tr style="background:#C2D3FC;border:1px solid blue;">
			<td style="width:15%;">字段</td>
			<td style="width:10%;">类型</td>
			<td style="width:75%;">说明</td>
		</tr>
		<tr>
			<td>ResultItem</td>
			<td>Array </td>
			<td>批量加好友的结果对象数组。</td>
		</tr>
		<tr>
			<td>To_Account</td>
			<td>String </td>
			<td>请求添加的好友的Identifier。</td>
		</tr>
		<tr>
			<td>ResultCode</td>
			<td>Integer </td>
			<td>批量加好友中单个好友的处理结果，0表示业务成功，非0表示业务失败。</td>
		</tr>
		<tr>
			<td>Fail_Account</td>
			<td>Array </td>
			<td>返回处理失败的用户列表。</td>
		</tr>
		<tr>
			<td>Invalid_Account</td>
			<td>Array </td>
			<td>返回请求包中的非法用户列表。</td>
		</tr>
		<tr>
			<td>ActionStatus</td>
			<td>String </td>
			<td>请求处理的结果，“OK”表示处理成功，“FAIL”表示失败。</td>
		</tr>
		<tr>
			<td>ErrorCode</td>
			<td>Integer </td>
			<td>错误码。</td>
		</tr>
		<tr>
			<td>ErrorInfo</td>
			<td>String </td>
			<td>详细错误信息。</td>
		</tr>
		<tr>
			<td>ErrorDisplay</td>
			<td>String </td>
			<td>详细的客户端展示信息。</td>
		</tr>
	</tbody>
</table>

### 2.10 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见<a href="https://cloud.tencent.com/document/product/269/1671#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81">REST API公共错误码</a>。 
本API私有错误码如下： 

<table style="display:table;width:100%">
	<tbody>
		<tr style="background:#C2D3FC;border:1px solid blue;">
			<td style="width:5%;">错误码</td>
			<td style="width:95%;">详细错误信息</td>
		</tr>
		<tr>
			<td>30001</td>
			<td>
				关系链系统解包失败：<br />
				如果是REST API请求，请参照REST API文档确认请求包的合法性和完整行；<br />
				如果不是REST API请求，请联系技术客服。
			</td>
		</tr>
		<tr>
			<td>30002</td>
			<td>SDKAppId非法，请检查SDKAppId及帐号的合法性或联系技术客服。</td>
		</tr>
		<tr>
			<td>30003</td>
			<td>帐号非法，请检查帐号的合法性或联系技术客服。</td>
		</tr>
		<tr>
			<td>30004</td>
			<td>来自REST API的请求，但是不具备管理员权限，请联系技术客服。</td>
		</tr>
		<tr>
			<td>30005</td>
			<td>关系链字段中有敏感词，请检查关系链字段或联系技术客服。</td>
		</tr>
		<tr>
			<td>30801</td>
			<td>
				请求包参数错误，请检查请求包的合法性，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。</td>
		</tr>
		<tr>
			<td>30802</td>
			<td>好友导入获取SDKAppId失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30803</td>
			<td>好友导入读好友数错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30804</td>
			<td>好友导入获取组信息和序列号错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30805</td>
			<td>好友导入获取组信息和序列号元数据错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30806</td>
			<td>好友导入封装标配信息行数据错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30807</td>
			<td>好友导入封装标配信息元数据错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30808</td>
			<td>好友导入更新标配信息错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30809</td>
			<td>好友导入封装自定义信息行数据错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30810</td>
			<td>好友导入封装自定义信息元数据错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30811</td>
			<td>好友导入更新自定义信息错误，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30812</td>
			<td>好友导入好友个数已达上限，调用方可以捕捉该错误给用户一个合理的提示。</td>
		</tr>
		<tr>
			<td>30813</td>
			<td>好友导入好友分组个数已达上限，调用方可以捕捉该错误给用户一个合理的提示。</td>
		</tr>
		<tr>
			<td>30814</td>
			<td>向同一个用户并发导入好友导致写冲突，建议改成批量导入方式，避免并发写同一个用户的数据。</td>
		</tr>
	</tbody>
</table>

## 3 接口调试工具 

### 3.1 Web调试工具 

通过<a href="https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/sns/friend_import">REST API调试工具</a>调试本接口。 

### 3.2 Server调试工具 

可以通过<a href="https://cloud.tencent.com/document/product/269/1538">PHP Server SDK</a>中的调试工具进行简单的REST API调试，命令如下： 
```
# 建立好友关系
./TimRestApiGear.php sns friend_import (account_id) (receiver)
```

更多调试工具参见<a href="https://avc.cloud.tencent.com/im/APITester/APITester.html">REST API调试工具</a>。

## 4 API集成 

### 4.1 PHP集成 

在云通信<a href="https://cloud.tencent.com/document/product/269/1538">PHP Server SDK</a>中，可以通过TimRestInterface的如下成员函数快速集成该API： 
```
// 建立好友关系
abstract function sns_friend_import($accout_id, $receiver);
```

## 5 可能触发的回调 

无

## 6 参考 

REST API：<a href="https://cloud.tencent.com/document/product/269/1643">添加好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/12525">更新好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1644">删除好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1645">删除所有好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1646">校验好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1647">拉取好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/8609">拉取指定好友</a>
