## 1 功能说明  

1.支持批量更新同一用户的多个好友的关系链数据；
2.更新一个用户多个好友时，建议采用批量方式，避免并发写导致的写冲突。

## 2 接口调用说明 

### 2.1 请求URL 
```
https://console.tim.qq.com/v4/sns/friend_update?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
```
### 2.2 请求参数 

URL中各参数的含义以及填写方式参见<a href="https://cloud.tencent.com/document/product/269/1519">REST API简介</a>。 

### 2.3 最高调用频率 

100 次/秒。如需提升调用频率，请根据<a href="https://cloud.tencent.com/document/product/269/3916#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4">REST API调用频率调整</a>提交工单申请处理。

### 2.4 HTTP请求方式 

POST 

### 2.5 HTTP请求包体格式 

JSON 

### 2.6 请求包示例

#### 2.6.1 基础形式

```
{
    "From_Account":"id",
    "UpdateItem":
    [
        {
            "To_Account":"id1",
            "SnsItem":
            [
                {
                    "Tag":"Tag_SNS_IM_Remark",
                    "Value":"remark1"
                }
            ]
        }
    ]
}

```

#### 2.6.2 完整形式

```
{
    "From_Account":"id",
    "UpdateItem":
    [
        {
            "To_Account":"id1",
            "SnsItem":
            [
                {
                    "Tag":"Tag_SNS_IM_Remark",
                    "Value":"remark1"
                },
                {
                    "Tag":"Tag_SNS_IM_Group",
                    "Value":"group1"
                },
                {
                    "Tag":"Tag_SNS_Custom_Test",
                    "Value":"test"
                }
            ]
        }
    ]
}
```

#### 2.6.3 批量加好友

```
{
    "From_Account":"id",
    "UpdateItem":
    [
        {
            "To_Account":"id1",
            "SnsItem":
            [
                {
                    "Tag":"Tag_SNS_IM_Remark",
                    "Value":"remark1"
                }
            ]
        },
        {
            "To_Account":"id2",
            "SnsItem":
            [
                {
                    "Tag":"Tag_SNS_IM_Remark",
                    "Value":"remark2"
                },
                {
                    "Tag":"Tag_SNS_IM_Group",
                    "Value":"group2"
                }
            ]
        },
        {
            "To_Account":"id3",
            "SnsItem":
            [
                {
                    "Tag":"Tag_SNS_IM_Remark",
                    "Value":"remark3"
                },
                {
                    "Tag":"Tag_SNS_IM_Group",
                    "Value":"group3"
                },
                {
                    "Tag":"Tag_SNS_Custom_Test",
                    "Value":"test"
                }
            ]
        }
    ]
}
```

### 2.7 请求包字段说明 

<table style="display:table;width:100%">
	<tbody>
		<tr style="background:#C2D3FC;border:1px solid blue;">
			<td style="width:15%;">字段</td>
			<td style="width:10%;">类型</td>
			<td style="width:10%;">属性</td>
			<td style="width:65%;">说明</td>
		</tr>
		<tr>
			<td>From_Account</td>
			<td>String</td>
			<td>必填</td>
			<td>需要更新该 Identifier 的关系链数据。</td>
		</tr>
		<tr>
			<td>UpdateItem</td>
			<td>Array</td>
			<td>必填</td>
			<td>需要更新的好友对象数组。</td>
		</tr>
		<tr>
			<td>To_Account</td>
			<td>String</td>
			<td>必填</td>
			<td>好友的 Identifier。</td>
		</tr>
		<tr>
			<td>SnsItem</td>
			<td>Array</td>
			<td>必填</td>
			<td>需要更新的关系链数据对象数组</a>。</td>
		</tr>
		<tr>
			<td>Tag</td>
			<td>String</td>
			<td>必填</td>
			<td>需要更新的关系链字段的字段名，目前只支持好友备注、好友分组、关系链自定义字段的更新操作，关系链字段的详细信息可参见<a href="https://cloud.tencent.com/document/product/269/1501#3-.E5.A5.BD.E5.8F.8B.E8.A1.A8">好友表</a>。</td>
		</tr>
		<tr>
			<td>Value</td>
			<td>Array/String/Integer</td>
			<td>必填</td>
			<td>需要更新的关系链字段的值，关系链字段的值类型信息可参见<a href="https://cloud.tencent.com/document/product/269/1501#3-.E5.A5.BD.E5.8F.8B.E8.A1.A8">好友表</a>。</td>
		</tr>
	</tbody>
</table>


### 2.8 应答包体示例

#### 2.8.1 基础形式、完备形式

```
{
	"ResultItem":
	[
		{
			"To_Account":"id1",
			"ResultCode":0,
			"ResultInfo":""
		}
	],
	"Fail_Account":[],
	"Invalid_Account":[],
	"ActionStatus":"OK",
	"ErrorCode":0,
	"ErrorInfo":"",
	"ErrorDisplay":""
}
```

#### 2.8.2 批量加好友

```
{
	"ResultItem":
	[
		{
			"To_Account":"id1",
			"ResultCode":0,
			"ResultInfo":""
		},
		{
			"To_Account":"id2",
			"ResultCode":0,
			"ResultInfo":""
		},
		{
			"To_Account":"id3",
			"ResultCode":0,
			"ResultInfo":""
		}
	],
	"Fail_Account":[],
	"Invalid_Account":[],
	"ActionStatus":"OK",
	"ErrorCode":0,
	"ErrorInfo":"",
	"ErrorDisplay":""
}
```

### 2.9 应答包字段说明 

<table style="display:table;width:100%">
	<tbody>
		<tr style="background:#C2D3FC;border:1px solid blue;">
			<td style="width:15%;">字段</td>
			<td style="width:10%;">类型</td>
			<td style="width:75%;">说明</td>
		</tr>
		<tr>
			<td>ResultItem</td>
			<td>Array </td>
			<td>批量更新好友的结果对象数组。</td>
		</tr>
		<tr>
			<td>To_Account</td>
			<td>String </td>
			<td>请求更新的好友的Identifier。</td>
		</tr>
		<tr>
			<td>ResultCode</td>
			<td>Integer </td>
			<td>批量更新好友的单个好友的处理结果，0 表示业务成功，非 0 表示业务失败。</td>
		</tr>
		<tr>
			<td>Fail_Account</td>
			<td>Array </td>
			<td>返回处理失败的好友账号列表。</td>
		</tr>
		<tr>
			<td>Invalid_Account</td>
			<td>Array </td>
			<td>返回请求包中的非法账号列表。</td>
		</tr>
		<tr>
			<td>ActionStatus</td>
			<td>String </td>
			<td>请求处理的结果，“OK” 表示处理成功，“FAIL” 表示失败。</td>
		</tr>
		<tr>
			<td>ErrorCode</td>
			<td>Integer </td>
			<td>错误码。</td>
		</tr>
		<tr>
			<td>ErrorInfo</td>
			<td>String </td>
			<td>详细错误信息。</td>
		</tr>
		<tr>
			<td>ErrorDisplay</td>
			<td>String </td>
			<td>详细的客户端展示信息。</td>
		</tr>
	</tbody>
</table>

### 2.10 错误码说明 

除非发生网络错误（例如 502 错误），该接口的 HTTP 返回码均为 200。真正的错误码、错误信息是通过应答包体中的 ErrorCode、ErrorInfo 来表示的。 
公共错误码（60000 到 79999）参见<a href="https://cloud.tencent.com/document/product/269/1671#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81">REST API公共错误码</a>。 
 本 API 私有错误码如下： 

<table style="display:table;width:100%">
	<tbody>
		<tr style="background:#C2D3FC;border:1px solid blue;">
			<td style="width:5%;">错误码</td>
			<td style="width:95%;">详细错误信息</td>
		</tr>
		<tr>
			<td>30001</td>
			<td>
				关系链系统解包失败：<br />
				如果是 REST API 请求，请参照 REST API 文档确认请求包的合法性和完整行；<br />
				如果不是 REST API 请求，请联系技术客服。
			</td>
		</tr>
		<tr>
			<td>30002</td>
			<td>SDKAppId 非法，请检查 SDKAppId 及帐号的合法性或联系技术客服。</td>
		</tr>
		<tr>
			<td>30003</td>
			<td>帐号非法，请检查帐号的合法性或联系技术客服。</td>
		</tr>
		<tr>
			<td>30004</td>
			<td>来自 REST API 的请求，但是不具备管理员权限，请联系技术客服。</td>
		</tr>
		<tr>
			<td>30005</td>
			<td>关系链字段中有敏感词，请检查关系链字段的值的合法性或联系技术客服。</td>
		</tr>
		<tr>
			<td>30701</td>
			<td>
				好友数据更新参数错误，请检查备注内容的长度是否超过 96 字节，分组名称的长度是否超过 30 字节，多个分组名称出现是否为空，Tag 名称是否非法，目前的 Tag 名称只支持：“Tag_SNS_IM_Remark”和“Tag_SNS_IM_Group”。<br />
			</td>
		</tr>
		<tr>
			<td>30702</td>
			<td>好友数据更新获取好友失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30703</td>
			<td>好友数据更新获取好友元数据失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30704</td>
			<td>好友数据更新获取好友行数据失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30705</td>
			<td>好友数据更新标配信息行数据失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30706</td>
			<td>好友数据更新标配信息元数据失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30707</td>
			<td>好友数据更新标配信息失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30708</td>
			<td>好友数据更新自定义信息行数据失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30709</td>
			<td>好友数据更新自定义信息元失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30710</td>
			<td>好友数据更新自定义信息失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30711</td>
			<td>好友数据更新执行任务失败，请再次尝试或联系技术客服。</td>
		</tr>
		<tr>
			<td>30712</td>
			<td>好友数据更新的好友不存在，在自己的好友表中没有找到需要更新的好友，调用方可以捕捉该错误给用户一个合理的提示。</td>
		</tr>
		<tr>
			<td>30713</td>
			<td>
				好友数据更新分组个数已达系统上限，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>，调用方可以捕捉该错误给用户一个合理的提示。<br />
			</td>
		</tr>
	</tbody>
</table>

## 3 接口调试工具 

通过<a href="https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/sns/friend_update">REST API调试工具</a>调试本接口。 

## 4 API集成 

无

## 5 可能触发的回调 

无

## 6 参考

REST API：<a href="https://cloud.tencent.com/document/product/269/1643">添加好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/8301">导入好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1644">删除好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1645">删除所有好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1646">校验好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/1647">拉取好友</a>
REST API：<a href="https://cloud.tencent.com/document/product/269/8609">拉取指定好友</a>

