## 1. 功能说明

1. 该API接口v4/openim/importmsg作用是导入历史单聊消息到腾讯云；
2. 平滑过渡期间，将原有即时通信实时单聊消息导入到腾讯云；
3. 该接口不会触发回调。

## 2. 接口调用说明

### 2.1 请求URL
```
https://console.tim.qq.com/v4/openim/importmsg?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
```
### 2.2 请求参数

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。

### 2.3最高调用频率

100次/秒。如需提升调用频率，请联系商务经理提需求工单。

### 2.4 HTTP请求方式

POST

### 2.5 HTTP请求包体格式

JSON

### 2.6 请求包示例

#### 2.6.1 平滑过渡期间，实时消息导入

```
{
    "SyncFromOldSystem": 1,               //平滑过渡期间，实时消息导入，消息计入未读
    "From_Account": "lumotuwe1",          //消息发送方账号
    "To_Account": "lumotuwe2",       //接收方账号
    "MsgRandom": 1287657,                 //消息随机数
    "MsgTimeStamp": 5454457,              //消息时间，unix时间戳
    "MsgBody": [                          //消息内容，本条消息包括两类消息元素，一个文本和一个表情
        { 
            "MsgType": "TIMTextElem",     //文本消息元素
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```

#### 2.6.2 历史消息导入

```
{
    "SyncFromOldSystem": 2,                //历史消息导入，消息不计入未读
    "From_Account": "lumotuwe1",           //消息发送方账号
    "To_Account": "lumotuwe2",             //接收方账号
    "MsgRandom": 1287657,                  //消息随机数
    "MsgTimeStamp": 5454457,               //消息时间，unix时间戳
    "MsgBody": [                           //消息内容，本条消息包括两种消息元素，一个文本和一个表情
        {
            "MsgType": "TIMTextElem",      //文本消息元素
            "MsgContent": { 
                "Text": "hi, beauty"       //消息内容
            }
        }
    ]
}

```

### 2.8 请求包字段说明



| 字段 | 类型|属性| 说明 |
|---------|---------|----|---------|
| SyncFromOldSystem | Integer |必填|1，实时消息导入，消息加入未读计数；2，历史消息导入，消息不计入未读。  |
| From_Account | String |必填| 消息发送方账号。（用于指定发送消息方）  |
| To_Account | String |必填| 消息接收方账号。  |
| MsgRandom | Integer |必填| 消息随机数,由随机函数产生。（用作消息去重）  |
| MsgTimeStamp | Integer |选填| 消息时间戳，unix时间戳。  |
| MsgBody | Object |必填| 消息内容，具体格式请参考[消息格式描述](/doc/product/269/消息格式描述)。（注意，一条消息可包括多种消息元素，MsgBody为Array类型）  |
| MsgType | String|必填| TIM消息对象类型，目前支持的消息对象包括： TIMTextElem(文本消息),TIMFaceElem(表情消息)， TIMLocationElem(位置消息)，TIMCustomElem(自定义消息)。  |
| MsgContent | Object |必填| 对于每种MsgType用不同的MsgContent格式，具体可参考[消息格式描述](/doc/product/269/消息格式描述)。   |

### 2.9 应答包体示例

```
{
   "ActionStatus" : "OK",
   "ErrorInfo" : "",
   "ErrorCode" : 0
}

```
### 2.10 应答包字段说明

| 字段|类型 |说明 |
|---------|---------|---------|
| ActionStatus| String | 请求处理的结果，OK表示处理成功，FAIL表示失败。  |
| ErrorCode| Integer | 错误码。  |
| ErrorInfo| String | 错误信息。  |

### 2.11 错误码说明 

除非发生网络错误(例如502错误)，该接口的HTTP返回码均为200．真正的错误码，错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[公共错误码](/doc/product/269/错误码)。
本API私有错误码如下： 

| 错误码 |含义说明 | 
|---------|---------|
| 90001 |Json格式解析失败,请检查请求包是否符合JSON规范。| 
| 90002 |Json格式请求包中MsgBody不符合消息格式描述，或者MsgBody不是Array类型，请参考[消息格式描述](/doc/product/269/消息格式描述)。|
| 90003 |Json格式请求包中To_Account不符合消息格式描述，请检查To_Account类型是否为String。| 
| 90004 |Json格式请求包体中MsgSeq不是Number类型或者其值范围不在0~4294967295。| 
| 90005 |Json格式请求包体中MsgRandom不是Number类型或者其值范围不在0~4294967295。| 
| 90006 |Json格式请求包体中MsgTimeStamp不是Number类型或者其值范围不在0~4294967295。| 
| 90007 |Json格式请求包体中MsgBody类型不是Array类型，请将其修改为Array类型。| 
| 90008 |Json格式请求包体中From_Account解析失败，请检查From_Account是否是String类型。| 
| 90009 |非管理员账户，无权代发消息，请用管理员账号使用该Rest API接口。| 
| 90010 |Json格式请求包不符合消息格式描述，请参考[消息格式描述](/doc/product/269/消息格式描述)的定义。| 
| 90011 |批量发消息目标账户超过500，请减少To_Account中目标账号数量。| 
| 90012 |To_Account没有注册或不存在，请确认To_Account是否导入腾讯云或者是否拼写错误。| 
|90028| To_Account不是Array类型。|
|90029|To_Account账号数量为0，请添加目标账户。|
|90030|SyncFromOldSystem不是Number类型或者其值范围不在0~4294967295|
|90031|SyncFromOtherMachine不是Number类型或者其值范围不在0~4294967295|
| 91000 |服务内部错误，请重试。| 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.qcloud.com/im/APITester/APITester.html#v4/openim/importmsg)调试本接口。 

### 3.2 Server调试工具 
无。
更多调试工具参见[REST API调试工具](/doc/product/269/REST API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。  

## 4 API集成 

### 4.1 PHP集成 
无。

## 5 参考 

导入群消息（[v4/group_open_http_svc/import_group_msg](/doc/product/269/导入群消息)）。 
