## 1 功能说明 

1. 该接口支持一次性针对最多500个用户进行单发消息； 
2. 与单发消息相比，该接口更适用于营销类消息、系统通知tips等时效性较强的消息； 
3. 管理员指定某一账户向目标账户批量发消息，接收方看到发送者不是管理员，而是管理员指定的账号；
4. 该接口不触发回调请求。
5. 注意，当使用服务端集成REST API发送批量消息时，存在是否将消息同步至发送方（管理员账户或者由管理员指定的某账户）问题，同步方式包括在线终端和漫游，REST API提供SyncOtherMachine参数用于说明是否进行同步，详细使用方式参见2.6节。

## 2 接口调用说明 

### 2.1 请求URL 
```
https://console.tim.qq.com/v4/openim/batchsendmsg?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
```
### 2.2 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.3 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。

### 2.4 HTTP请求方式 

POST 

### 2.5 HTTP请求包体格式 

JSON 

### 2.6 请求包示例 
#### 2.6.1 管理员向目标账户批量发消息
注意，若不希望将消息同步至From_Account，则SyncOtherMachine填写2。若希望将消息同步至From_Account，则SyncOtherMachine填写1
```
{
    "SyncOtherMachine": 2,//消息不同步至发送方
    "To_Account": [                    //目标账户列表
        "bonnie",   
        "rong"
    ], 
    "MsgRandom": 19901224,             //消息随机数
    "MsgBody": [                       //消息
        {
            "MsgType": "TIMTextElem",  //消息类型，TIMTextElem为文本消息
            "MsgContent": {
                "Text": "hi, beauty"   //消息文本
            }
        }
    ]
}
```

#### 2.6.2 管理员指定某一账号向目标账号批量发消息，同时设置离线推送信息
From_Accout为管理员指定的发送方，接收方看到发送者不是管理员，而是From_Account。下述Json请求表达的是dave向账号bonnie和账号rong发送一条消息。 bonnie和rong收到消息，看到消息发送方是dave。
注意，若不希望将消息同步至From_Account，则SyncOtherMachine填写2。若希望将消息同步至From_Account，则SyncOtherMachine填写1
```
{
    "SyncOtherMachine": 1, //消息同步至发送方
    "From_Account": "dave",
    "To_Account": [
        "bonnie",
        "rong"
    ],
    "MsgRandom": 19901224,
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ],
    "OfflinePushInfo": {
        "PushFlag": 0,
        "Desc": "离线推送内容",
        "Ext": "这是透传的内容",
        "AndroidInfo": { 
            "Sound": "android.mp3"
        },
        "ApnsInfo": {
            "Sound": "apns.mp3",
            "BadgeMode": 1,      // 这个字段缺省或者为 0 表示需要计数，为 1 表示本条消息不需要计数，即右上角图标数字不增加
            "Title":"apns title",//apns title
            "SubTitle":"apns subtitle",//apns subtitle
            "Image":"www.image.com"//image url
        }
    }
}

```

### 2.7 请求包字段说明 

| 字段 | 类型 |属性 |说明 |
|---------|---------|---------|---------|---------|
| SyncOtherMachine | Integer | 选填 | 1：把消息同步到From_Account在线终端和漫游上；2：消息不同步至From_Account；若不填写默认情况下会将消息存From_Account漫游|
| From_Account | String |选填 |管理员指定消息发送方账号。  |
| To_Account | String |必填| 消息接收方用户identifier。  |
| MsgRandom | Integer |必填| 消息随机数,由随机函数产生个随机数即可。  |
| MsgBody | Object |必填| TIM消息，请参考[消息格式描述](/doc/product/269/消息格式描述)。  |
| MsgType | String | 必填|TIM消息对象类型，目前支持的消息对象包括：TIMTextElem(文本消息), TIMFaceElem(表情消息)，TIMLocationElem(位置消息)，TIMCustomElem(自定义消息)。 |
| MsgContent | Object |必填| MsgContent为TIM消息对象，具体可参考[消息格式描述](/doc/product/269/消息格式描述)。 |
| OfflinePushInfo | Object | 选填| 离线推送信息配置，具体可参考[消息格式描述](/doc/product/269/消息格式描述)。 |


### 2.8 应答包体示例 

```
{
    "ActionStatus": "FAIL", 
    "ErrorInfo": "", 
    "ErrorList": [                    //发送消息失败列表
        {
            "To_Account": "rong",     //目标账户
            "ErrorCode":  20003       //错误码
        }
    ]
}
```

### 2.9 应答包字段说明 

| 字段 | 类型  |说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。  |
| ErrorList | Array | 发消息失败列表；在此列表中的目标账户，消息发送失败；消息全部发送成功，ErrorList为空。因此判断回包中是否包含ErrorList来判断，消息是否全都判断成功。   |
| To_Account | String | 发送消息失败的账号。  |
| ErrorCode | Number | 发送失败的错误码。  |

## 3 错误码说明 

除非发生网络错误(例如502错误),该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[公共错误码](/doc/product/269/错误码)。 
本API私有错误码如下： 

| 错误码 |含义说明 | 
|---------|---------|
| 90001 |Json格式解析失败,请检查请求包是否符合JSON规范。| 
| 90002 |Json格式请求包中MsgBody不符合消息格式描述，或者MsgBody不是Array类型，请参考[消息格式描述](/doc/product/269/消息格式描述)。|
| 90003 |Json格式请求包中To_Account不符合消息格式描述，请检查To_Account类型是否为String。| 
| 90004 |Json格式请求包体中MsgSeq不是Number类型或者其值范围不在0~4294967295。| 
| 90005 |Json格式请求包体中MsgRandom不是Number类型或者其值范围不在0~4294967295。| 
| 90006 |Json格式请求包体中MsgTimeStamp不是Number类型或者其值范围不在0~4294967295。| 
| 90007 |Json格式请求包体中MsgBody类型不是Array类型，请将其修改为Array类型。| 
| 90008 |Json格式请求包体中From_Account解析失败，请检查From_Account是否是String类型。| 
| 90009 |非管理员账户，无权代发消息，请用管理员账号使用该Rest API接口。| 
| 90010 |Json格式请求包不符合消息格式描述，请参考[消息格式描述](/doc/product/269/消息格式描述)的定义。| 
| 90011 |批量发消息目标账户超过500，请减少To_Account中目标账号数量。| 
| 90012 |To_Account没有注册或不存在，请确认To_Account是否导入腾讯云或者是否拼写错误。| 
|90028| To_Account不是Array类型。|
|90029|To_Account账号数量为0，请添加目标账户。|
|90030|SyncFromOldSystem不是Number类型或者其值范围不在0~4294967295|
|90031|SyncFromOtherMachine不是Number类型或者其值范围不在0~4294967295|
| 91000 |服务内部错误，请重试。| 

## 4 接口调试工具 

### 4.1 Web调试工具 

通过[REST API在线调试工具](https://avc.qcloud.com/im/APITester/APITester.html#v4/openim/batchsendmsg)调试本接口。 

### 4.2 Server调试工具 

可以通过PHP Server SDK中的调试工具进行简单的REST API调试，命令如下： 
```
# 批量单发文本消息
./TimRestApiGear.php openim batchsendmsg (account_id1,account_id2,...) (text_content)

# 批量单发图片消息
./TimRestApiGear.php openim batchsendmsg_pic (account_id1,account_id2,...) (pic_path)
```
更多调试工具参见[REST API调试工具](/doc/product/269/REST API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。 

## 5 API集成 

### 5.1 PHP集成 

在云通信[PHP Server SDK](/doc/product/269/PHP Server SDK)中，可以通过TimRestInterface的如下成员函数快速集成该API： 
```
// 批量单发文本消息
abstract function openim_batch_sendmsg($account_list, $text_content);

// 批量单发图片消息
abstract function openim_batch_sendmsg_pic($account_list, $pic_path);

// 批量单发消息（高级接口）
abstract function openim_batch_sendmsg2($account_list, $msg_content);;
```

## 6 参考 

单发单聊消息（[v4/openim/sendmsg](/doc/product/269/单发单聊消息)）。

群组内发普通消息（[v4/group_open_http_svc/send_group_msg](/doc/product/269/在群组中发送普通消息)）。

在群组中发送系统通知（[v4/group_open_http_svc/send_group_system_notification](/doc/product/269/在群组中发送系统通知)）。

[消息格式描述](/doc/product/269/消息格式描述)。 
