## 1 功能说明 

APP管理员可以通过该接口获取APP中某天某小时的所有单发或群组消息记录的下载地址。 

## 2 注意事项 

1. 消息记录以日志文件形式存在并GZip压缩，通过该接口获取到下载地址后，请自行下载并处理；
1. 消息记录文件每小时产生一次，例如0点(00:00~00:59)的数据在01:00后开始处理，一般1小时内处理完毕（消息较多则处理时间较长）；
1. 文件有效期3天，无论是否下载过，都会在3天后删除；
1. 获取到的下载地址存在有效期，请在过期前进行下载，若地址失效，请通过该接口重新获取；
1. 语音、文件和段视频消息，只能通过客户端接口拿到大数据资源。

## 3 接口调用说明 

### 3.1 请求URL 
```
https://console.tim.qq.com/v4/open_msg_svc/get_history?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json 
```
### 3.2 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 3.3 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 3.4 HTTP请求方式 

POST 

### 3.5 HTTP请求包体格式 

JSON 

### 3.6 请求包示例

```
{
    "ChatType": "C2C",
    "MsgTime": "2015120121"
}
```

### 3.7 请求包字段说明 

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| ChatType | String | 必填 |消息类型，C2C:单发消息 Group:群组消息。 |
| MsgTime | String | 必填 |需要下载的时间段，2015120121表示获取2015年12月1日21:00~21:59的消息的下载地址。  |

### 3.8 应答包体示例

```
{
	"File": [
		{
			"URL": "https://download.tim.qq.com/msg_history/2/9b8f8f063b73f61698ce11e58207e89ade40.gz",
			"ExpireTime": "2015-12-02 16:45:23",
			"FileSize": 65207,
			"FileMD5": "cceece008bb7f469a47cf8c4b7acb84e",
			"GzipSize": 1815,
			"GzipMD5": "c3a0269dde393fd7a8bb18bfdeaeee2e"
		}
	],
	"ActionStatus": "OK",
	"ErrorInfo": "",
	"ErrorCode": 0
}
```

### 3.9 应答包字段说明 

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，“OK”表示处理成功，“FAIL”表示失败。 |
| ErrorCode | Integer | 错误码。  |
| ErrorInfo | String  | 错误信息。 |
| File | Array  | 消息记录文件下载信息。 |
| URL | String | 消息记录文件下载地址。 |
| ExpireTime | String | 下载地址过期时间，请在过期前进行下载，若地址失效，请通过该接口重新获取。|
| FileSize | Integer | GZip压缩前的文件大小（单位Byte）。 |
| FileMD5 | String | GZip压缩前的文件MD5。|
| GzipSize | Integer |GZip压缩后的文件大小（单位Byte）。|
| GzipMD5 | String  |GZip压缩后的文件MD5。 |

### 3.10 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码)。 
本API私有错误码如下： 

| 错误码 | 含义说明| 
|---------|---------|
| 1001 | 请求非法。请检查“请求URL”是否正确。  | 
| 1002 | 参数非法。请检查是否管理员账号，必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 1003 | 系统错误。  | 
| 1004 | 文件尚未生成，或者请求时段内没有消息。| 
| 1005 | 文件已过期。 | 

### 3.11消息记录文件格式

```
//单发消息
{"SdkAppId":1104620500,"ChatType":"C2C","MsgTime":"2015120121","MsgList":[
{"From_Account":"peakerdong","To_Account":"qiyueliuhuo2018","MsgTimestamp":1448974806,"MsgSeq":3452069198,"MsgRandom":45838,"MsgBody":[{"MsgType":"TIMTextElem","MsgContent":{"Text":"四等分"}}]},
{"From_Account":"group_root","To_Account":"group_test4","MsgTimestamp":1448974808,"MsgSeq":462709847,"MsgRandom":19196437,"MsgBody":[{"MsgType":"TIMTextElem","MsgContent":{"Text":"hi, beauty"}}]} 
]}

//群组消息
{"SdkAppId":1104620500,"ChatType":"Group","MsgTime":"2015120121","MsgList":[
{"From_Account":"Test_1","GroupId":"@TGS#1FDFVPAE2","MsgTimestamp":1448975384,"MsgSeq":1,"MsgBody":[{"MsgType":"TIMTextElem","MsgContent":{"Text":"Private activate"}}]},
{"From_Account":"Test_1","GroupId":"@TGS#1FDFVPAE2","MsgTimestamp":1448975384,"MsgSeq":1,"MsgBody":[{"MsgType":"TIMTextElem","MsgContent":{"Text":"Private activate"}}]} 
]}
```
文件第一行记录了该文件的基本信息，接下来的每一行记录一条消息，直到最后一行“]}”结束，每条消息格式可参考[TIMMsgElement对象](/doc/product/269/消息格式描述)的定义； 
若文件较小，可直接使用JSON库解析整个文件，MsgList是该时段的消息数组。例如 ：
```
# Python示例代码
import gzip, json
with gzip.open('1104620500_Group_2015120121.gz', 'rb') as fp:
    info = json.load(fp)
for msg in info['MsgList']:
    pass #do sth with msg
```
若文件较大，建议逐行解析。例如 ：
```
# Python示例代码
import gzip, json
with gzip.open('1104620500_Group_2015120121.gz', 'rb') as fp:
    cnt = -1
    for line in fp:
        line = line.strip().rstrip(b',')
        if line == b']}': break
        if cnt < 0:
            info = json.loads(line + b']}')
        else:
            msg = json.loads(line)
            #do sth with msg
        cnt += 1
```

## 4 接口调试工具 

### 4.1 Web调试工具 

通过[REST API在线调试工具](https://avc.qcloud.com/im/APITester/APITester.html#v4/open_msg_svc/get_history)调试本接口。

## 5 可能触发的回调 

无 

## 6 参考 

无  

