## 1 功能说明

1. 可以全员推送，也可以按条件进行推送；
1. 管理员向账号推送消息，接收方看到消息发送者是管理员；
1. 管理员指定某一账户向其他账户推送消息，接收方看到发送者不是管理员，而是管理员指定的账号。

## 2 接口调用说明

### 2.1 请求URL 
```
https://console.tim.qq.com/v4/openim/push?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
```
### 2.2 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.3 最高调用频率 

目前处于公测阶段，暂不设频率限制。

### 2.4 HTTP请求方式 

POST 

### 2.5 HTTP请求包体格式 

JSON 

### 2.6 请求包示例

#### 2.6.1 依照简单条件推送

管理员进行全员推送（发送方帐号为请求URL中的identifier参数，即管理员本身）：

```
{
    "MsgRandom": 2016020204,
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```

管理员指定某一帐号进行全员推送（例子中发送方帐号为xiaoming） ：

```
{
    "MsgRandom": 2016020204,
    "From_Account": "xiaoming",
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```

管理员给在深圳或者性别为男的用户推送消息：

```
{
    "MsgRandom": 2016020204,
    "Condition": {
        "TagsOr": {
            "0": "男",
            "1": "深圳"
        }
    },
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```

管理员给在深圳的男用户推送消息：

```
{
    "MsgRandom": 2016020204,
    "Condition": {
        "TagsAnd": {
            "0": "男",
            "1": "深圳"
        }
    },
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```

管理员给全员推送消息，并且消息离线保存1天(例子中MsgLifeTime为86400秒，即1天)：

```
{
    "MsgRandom": 2016020204,
    "MsgLifeTime": 86400,
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```


#### 2.6.2 更复杂的推送示例（ALL IN ONE）

管理员指定某一帐号(xiaoming)给性别为男的或者在深圳的VIP推送消息，并且消息可以离线保存1天

```
{
    "MsgRandom": 2016020204,
    "From_Account": "xiaoming",
    "MsgLifeTime": 86400,
    "Condition": {
        "TagsOr": {
            "0": "男",
            "1": "深圳"
        },
        "TagsAnd": {
            "2": "VIP"
        }
    },
    "MsgBody": [
        {
            "MsgType": "TIMTextElem",
            "MsgContent": {
                "Text": "hi, beauty"
            }
        }
    ]
}
```

### 2.7 请求包字段说明 
| 字段 | 类型|属性| 说明 |
|---------|---------|---------|
| Condition | Object |选填|Condition包含TagsOr和TagsAnd两种属性条件类型。这两种可以类型可以并存。这时候表示同时满足TagsOr和TagsAnd的用户。如果没有Condition,则推送给全部用户。  |
| MsgRandom | Integer |必填| 消息随机数,由随机函数产生。用于推送任务去重。即同一天内的不同推送请求，MsgRandom不能重复，否则视为相同的推送任务（调用推送API返回失败的时候可以用相同的MsgRandom进行重试）|
| MsgBody | Object |必填 | 消息内容，具体格式请参考[MsgBody消息内容说明](/doc/product/269/消息格式描述#1-.E6.B6.88.E6.81.AF.E5.86.85.E5.AE.B9msgbody.E8.AF.B4.E6.98.8E)。（一条消息可包括多种消息元素，所以MsgBody为Array类型）  |
| MsgType | String |必填| TIM消息对象类型，目前支持的消息对象包括： TIMTextElem(文本消息),TIMFaceElem(表情消息)， TIMLocationElem(位置消息)，TIMCustomElem(自定义消息)。  |
| MsgContent | Object |必填 | 对于每种MsgType用不同的MsgContent格式，具体可参考TIMMsgElement对象的定义。   |
| MsgLifeTime | Integer |选填 | 消息离线存储时间，单位秒，最多7 天。默认为0, 表示不离线存储。  |
| From_Account | String |选填 | 消息推送方账号。  |
| TagsOr | Object  |选填| 标签条件的并集。每个标签条件是一个键值对。标签的键（key）是"0"~"9"（含"0"和"9"）的任意值，具体代表的含义由用户自定义。标签的值(value)也是字符串，长度限定在50字节以内。示例："0"代表城市，"1"表示性别。那么{"TagsOr": {"0": "深圳","1": "男"}} 表示推送给在深圳或性别为男的用户。可以与TagsAnd并存，并存的时候表示推送给既满足TagsOr又满足TagsAnd的用户（即两者的交集）。  |
| TagsAnd | Object |选填 | 标签条件的交集。每个标签条件也是一个键值对。键值对的要求与TagsOr相同。  |

### 2.8 应答包体示例

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0,
    "TaskId": "123456789_201621292_2016020204"
}
```

### 2.9 应答包字段说明 


| 字段|类型 |说明 |
|---------|---------|---------|
| ActionStatus| String | 请求处理的结果，OK表示处理成功，FAIL表示失败。  |
| ErrorCode| Integer | 错误码。  |
| ErrorInfo| String | 错误信息。  |
| TaskId| String | 推送任务ID。可用于推送任务状态查询。  |

### 2.10 错误码说明 

除非发生网络错误(例如502错误)，该接口的HTTP返回码均为200．真正的错误码，错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 |含义说明 | 
|---------|---------|
| 90001 |Json格式解析失败,请检查请求包是否符合JSON规范。| 
| 90002 |Json格式请求包中MsgBody不符合消息格式描述，或者MsgBody不是Array类型，请参考[MsgBody消息内容说明](/doc/product/269/消息格式描述#1-.E6.B6.88.E6.81.AF.E5.86.85.E5.AE.B9msgbody.E8.AF.B4.E6.98.8E)。|
| 90004 |Json格式请求包体中MsgSeq不是Number类型或者其值范围不在0~4294967296。| 
| 90005 |Json格式请求包体中MsgRandom不是Number类型或者其值范围不在0~4294967296。| 
| 90007 |Json格式请求包体中MsgBody类型不是Array类型，请将其修改为Array类型。| 
| 90009 |非管理员账户，无权代发消息，请用管理员账号使用该Rest API接口。| 
| 90010 |Json格式请求包不符合消息格式描述，请参考[TIMMsgElement对象](/doc/product/269/消息格式描述#2-.E6.B6.88.E6.81.AF.E5.85.83.E7.B4.A0timmsgelement)的定义。| 
| 90013 |标签长度超过限制（不能超过50字节）。| 
| 90014 |获取推送状态指定任务数过多。| 
| 90020 |标签长度超过限制（不能超过50字节）。| 
| 90020 |Tag 非法（必须是均为字符串的键值对，键的取值“0”~“9”）。| 
| 90024 |推送频率超过限制。| 
|90025|推送任务已存在（同一天内的不同推送请求MsgRandom必须不同，否则视为重复的推送任务）。|
|90026|消息离线存储时间错误（最多不能超过7天）。|
|90027|推送条件非法，请检查Condition字段。|
| 91000 |服务内部错误，请重试。| 
| 20002 |签名验证失败。| 

## 3. 接口调试工具 

### Web调试工具 

通过[REST API在线调试](https://avc.qcloud.com/im/APITester/APITester.html#v4/openim/push)工具调试本接口。 

## 4. 可能触发的回调 

无。 

## 5. 参考 

无。 