## 1 功能说明 
1. APP管理员可以通过该接口创建群组。
 
## 2 接口调用说明 

### 2.1 适用的群组类型

云通信中内置了私有群、公开群、聊天室、互动直播聊天室、在线成员广播大群五种群组类型，详情请见[群组形态介绍](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，其中：

1. 私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群全部支持使用本REST AP创建新的群组；
2. 特别的，创建互动直播聊天室和在线成员广播大群时不能拉人入群，如果创建时指定了拉入的群成员会返回10007错误。用户加入互动直播聊天室和在线成员广播大群的唯一方式是用户申请加群。

### 2.2 请求URL 
```
https://console.tim.qq.com/v4/group_open_http_svc/create_group?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
```
### 2.3 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.4 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 2.5 HTTP请求方式 

POST 

### 2.6 HTTP请求包体格式 

JSON 

### 2.7 请求包示例

#### 2.7.1 基础形式

创建群，Owner_Account字段是选填的，如果不填则群没有群主。 
```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom/AVChatRoom/BChatRoom（必填）
    "Name": "TestGroup" // 群名称（必填）
}
```

#### 2.7.2 仅包含群基础信息

创建群，并指定群简介、群公告等群基础信息。 
```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom/AVChatRoom/BChatRoom（必填）
    "Name": "TestGroup", // 群名称（必填）
    "Introduction": "This is group Introduction", // 群简介（选填）
    "Notification": "This is group Notification", // 群公告（选填）
    "FaceUrl": "http://this.is.face.url", // 群头像URL（选填）
    "MaxMemberCount": 500, // 最大群成员数量（选填）
    "ApplyJoinOption": "FreeAccess"  // 申请加群处理方式（选填）
}
```

#### 2.7.3 仅包含群成员信息

创建群，并指定初始化群成员列表，群成员列表在请求包说明表中有描述。 
```
{
    "Name": "TestGroup", // 群名称（必填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom(不支持AVChatRoom和BChatRoom)（必填）
    "MemberList": [  // 初始群成员列表，最多500个（选填）
         {
            "Member_Account": "bob", // 成员（必填）
            "Role": "Admin" // 赋予该成员的身份，目前备选项只有Admin（选填）
         }, 
         {
            "Member_Account": "peter"
         }
     ]
}
```

#### 2.7.4 自定义群组ID

为了使得群组ID更加简单，腾讯云支持APP在通过REST API创建群组时自定义群组ID。
```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom/AVChatRoom/BChatRoom（必填）
    "GroupId": "MyFirstGroup", //用户自定义群组ID（选填）
    "Name": "TestGroup"   // 群名称（必填）
}
```

#### 2.7.5 仅包含群维度自定义信息

创建群，并指定群维度的自定义字段。AppDefineData默认是没有的，需要开通，详见请求包字段说明表。 
```
{
    "Name": "TestGroup", // 群名称（必填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom/AVChatRoom/BChatRoom（必填）
    "AppDefinedData": [  // 群组维度的自定义字段（选填）
        {
            "Key": "GroupTestData1", // APP自定义的字段Key
            "Value": "xxxxx" // 自定义字段的值
        },
        {
            "Key": " GroupTestData2",
            "Value": "abc\u0000\u0001" // 自定义字段支持二进制数据
        }
    ]
}
```

#### 2.7.6 仅包含群成员维度自定义信息

创建群，并指定群成员维度的自定义字段。AppMemberDefinedData默认是没有的，需要开通后才能使用，详见请求包字段说明表。 
```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom(不支持AVChatRoom和BChatRoom)（必填）
    "Name": "TestGroup", // 群名称（必填）
    "MemberList": [
       {
          "Member_Account":"bob",
          "AppMemberDefinedData":[   //群成员维度自定义字段（选填）
               {
                   "Key": "MemberDefined1",  //群成员维度自定义的Key
                   "Value": "MemberData1"    //群成员维度自定义字段值
               },
               {
                   "Key": "MemberDefined2",
                   "Value": "MemberData2"
               }
           ]
       },
       {
          "Member_Account":"peter",
          "AppMemberDefinedData":[
               {
                   "Key": "MemberDefined1",
                   "Value": "MemberData1"
               },
               {
                   "Key": "MemberDefined2",
                   "Value": "MemberData2"
               }
           ]
       }
    ]
}
```

#### 2.7.7 ALL IN ONE

```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom(不支持AVChatRoom和BChatRoom)（必填）
    "GroupId":"MyFirstGroup", //用户自定义群组ID（选填）
    "Name": "TestGroup",   // 群名称（必填）
    "Introduction": "This is group Introduction", // 群简介（选填）
    "Notification": "This is group Notification", // 群公告（选填）
    "FaceUrl": "http://this.is.face.url", // 群头像URL（选填） 
    "MaxMemberCount": 500, // 最大群成员数量（选填）
    "ApplyJoinOption": "FreeAccess", // 申请加群处理方式（选填）
    "AppDefinedData": [  // 群组维度的自定义字段（选填）
        {
            "Key": "GroupTestData1",  // APP自定义的字段Key
            "Value": "xxxxx"  // 自定义字段的值
        },
        {
            "Key": "GroupTestData2",
            "Value": "abc\u0000\u0001"  // 自定义字段支持二进制数据
        }
    ],
    "MemberList": [  // 初始群成员列表，最多500个（选填）
        {
            "Member_Account": "bob",   // 成员（必填）
            "Role": "Admin",   // 赋予该成员的身份，目前备选项只有Admin（选填）
            "AppMemberDefinedData":[   //群成员维度自定义字段（选填）
               {
                   "Key":"MemberDefined1",  //群成员维度自定义的Key
                   "Value":"MemberData1"    //群成员维度自定义字段值
               },
               {
                   "Key":"MemberDefined2",
                   "Value":"MemberData2"
               }
           ]
        }, 
        {
            "Member_Account": "peter",
            "AppMemberDefinedData":[
               {
                   "Key":"MemberDefined1",
                   "Value":"MemberData1"
               },
               {
                   "Key":"MemberDefined2",
                   "Value":"MemberData2"
               }
           ]
        }
    ]
}
```

### 2.8 请求包字段说明 

| 字段 | 类型 | 属性 |说明|
|---------|---------|---------|---------|
| Owner_Account | String | 选填 |群主id，自动添加到群成员中。如果不填，群没有群主。 |
| Type | String | 必填 |[群组形态](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，包括Public（公开群），Private（私密群），ChatRoom（聊天室），AVChatRoom（互动直播聊天室），BChatRoom（在线成员广播大群）。  |
| GroupId | String | 选填 |为了使得群组ID更加简单，便于记忆传播，腾讯云支持APP在通过REST API创建群组时自定义群组ID。详情参见：[自定义群组ID](/doc/product/269/群组系统#5-.E8.87.AA.E5.AE.9A.E4.B9.89.E7.BE.A4.E7.BB.84id)。  |
| Name | String | 必填 |群名称，最长30字节。 |
| Introduction | String | 选填 |群简介，最长240字节。 |
| Notification | String | 选填 |群公告，最长300字节。 |
| FaceUrl | String | 选填 |群头像URL，最长100字节。 |
| MaxMemberCount | Integer | 选填 |最大群成员数量，缺省时的默认值：私有群是200，公开群是2000，聊天室是10000，互动直播聊天室和在线成员广播大群无限制。 |
| ApplyJoinOption | String | 选填 |申请加群处理方式。包含FreeAccess（自由加入），NeedPermission（需要验证），DisableApply（禁止加群），不填默认为NeedPermission（需要验证）。 |
| AppDefinedData | Array | 选填 |群组维度的自定义字段，默认情况是没有的，需要开通，详情参见：[自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)。 |
| MemberList | Array | 选填 |初始群成员列表，最多500个。成员信息字段详情参见：[群成员资料](/doc/product/269/群组系统#4.2-.E7.BE.A4.E6.88.90.E5.91.98.E8.B5.84.E6.96.99)。 |
| AppMemberDefinedData | Array | 选填 |群成员维度的自定义字段，默认情况是没有的，需要开通，详情参见：[自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)。 |

### 2.9 应答包体示例

#### 2.9.1 基础形式、仅包含群基础信息、仅包含群成员信息和仅包含自定义信息

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0, 
    "GroupId": "@TGS#2J4SZEAEL" 
}
```

#### 2.9.2 自定义群组ID和ALL IN ONE

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0, 
    "GroupId": "MyFirstGroup" 
}
```

### 2.10 应答包字段说明 

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。 |
| ErrorCode | Integer | 错误码。  |
| ErrorInfo | String | 错误信息。  |
| GroupId | String | 创建成功之后的群ID，由IM云后台分配。 |

### 2.11 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 | 含义说明 |
|---------|---------|
| 10002 | 系统错误，请再次尝试或联系技术客服。 | 
| 10003| 请求命令非法，请再次尝试或联系技术客服。 | 
| 10004| 参数非法。请根据应答包中的ErrorInfo字段，检查必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 10005 | 请求包体中携带的用户数量过多（超过了 500 个成员），请减少一次请求的用户数量。 | 
| 10007 | 操作权限不足。请确认操作者是否是APP管理员。 | 
| 10016 | 该请求触发了到APP后台的“[创建群组之前回调](/doc/product/269/创建群组之前回调)”，云通讯后台根据回调结果拒绝创建该群组。 | 
| 10021 | 群组ID已被使用，请选择其他的群组ID。  | 
| 80001 | 文本安全打击。请检查群名称、群公告和群简介等是否有敏感词汇。 | 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/group_open_http_svc/create_group)调试本接口。 

### 3.2 Server调试工具 

可以通过[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK)中的调试工具进行简单的REST API调试，命令如下： 
```
# 创建群组(最大成员数量默认为500)
./TimRestApiGear.php group_open_http_svc create_group (group_type) (group_name) (owner_id)
```
更多调试工具参见[REST API调试工具](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。 

## 4 API集成 

### 4.1 PHP集成 

在云通信[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK#3-timrestapigear.php.E4.BD.BF.E7.94.A8.E8.AF.B4.E6.98.8E)中，可以通过TimRestInterface的如下成员函数快速集成该API： 
```
// 创建群
abstract function group_create_group($group_type, $group_name, $owner_id);

// 创建群(高级接口)
abstract function group_create_group2($group_type, $group_name, $owner_id, 
    $info_set, $mem_list);
```

## 5 可能触发的回调 

[创建群组之前回调](/doc/product/269/创建群组之前回调)； 
[创建群组之后回调](/doc/product/269/创建群组之后回调)。 

## 6 参考 

REST API：解散群组（[v4/group_open_http_svc/destroy_group](/doc/product/269/解散群组)）。 
