## 1 功能说明 
1. APP管理员可以通过该接口在群组中发送普通消息。 
 
## 2 接口调用说明  

### 2.1 适用的群组类型

云通信中内置了私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群五种群组类型，详情请见[群组形态介绍](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，其中：

私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群全部支持使用本REST API发送普通消息。

### 2.2 请求URL 
```
https://console.tim.qq.com/v4/group_open_http_svc/send_group_msg?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json
``` 
### 2.3 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.4 最高调用频率

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 2.5 HTTP请求方式 

POST 

### 2.6 HTTP请求包体格式 

JSON 

### 2.7 请求包示例

#### 2.7.1 基础形式

发送普通群消息，消息的发送者为APP管理员。 
```
{
    "GroupId": "@TGS#2C5SZEAEF",
    "Random": 8912345, // 随机数字，五分钟数字相同认为是重复消息
    "MsgBody": [  // 消息体，由一个element数组组成，详见字段说明
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        },
        {
            "MsgType": "TIMFaceElem", // 表情
            "MsgContent": {
                "Index": 6,
                "Data": "abc\u0000\u0001"
            }
        }
    ],
    "OfflinePushInfo": {
        "PushFlag": 0,  // 正常推送，
        "Desc": "离线推送内容",
        "Ext": "这是透传的内容",
        "AndroidInfo": { 
            "Sound": "android.mp3"
        },
        "ApnsInfo": {
            "Sound": "apns.mp3",
            "BadgeMode": 1,      // 这个字段缺省或者为 0 表示需要计数，为 1 表示本条消息不需要计数，即右上角图标数字不增加
            "Title":"apns title",//apns title
            "SubTitle":"apns subtitle",//apns subtitle
            "Image":"www.image.com"//image url
        }
    }
}
```

#### 2.7.2 指定消息发送者

可以指定某一位群成员作为消息发送者，在From_Account中设置；
其他用户收到群消息后，显示的消息来自APP管理员指定的那一位群成员。
```
{
    "GroupId": "@TGS#2C5SZEAEF",
    "From_Account": "leckie", //指定消息发送者（选填）
    "Random": 8912345, // 随机数字，五分钟数字相同认为是重复消息
    "MsgBody": [  // 消息体，由一个element数组组成，详见字段说明
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        },
        {
            "MsgType": "TIMFaceElem", // 表情
            "MsgContent": {
                "Index": 6,
                "Data": "abc\u0000\u0001"
            }
        }
    ]
}
```

#### 2.7.3 指定消息优先级

可以指定消息的优先级，默认优先级Normal；
可以指定4种优先级，从高到低依次为High，Normal，Low，Lowest，区分大小写。
```
{
    "GroupId": "@TGS#2C5SZEAEF",
    "Random": 8912345, // 随机数字，五分钟数字相同认为是重复消息
    "MsgPriority": "High", // 消息优先级
    "MsgBody": [  // 消息体，由一个element数组组成，详见字段说明
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        },
        {
            "MsgType": "TIMFaceElem", // 表情
            "MsgContent": {
                "Index": 6,
                "Data": "abc\u0000\u0001"
            }
        }
    ]
}
```

#### 2.7.4 指定消息不回调
在回调开关打开的情况下，用户通过ForbidCallbackControl控制单条消息是否发起回调，默认情况发起回调。
```
{
    "GroupId": "@TGS#2C5SZEAEF",
    "Random": 8912345, // 随机数字，五分钟数字相同认为是重复消息
    "ForbidCallbackControl":[
		    "ForbidBeforeSendMsgCallback",
		    "ForbidAfterSendMsgCallback"], //禁止回调控制选项
    "MsgBody": [  // 消息体，由一个element数组组成，详见字段说明
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        },
        {
            "MsgType": "TIMFaceElem", // 表情
            "MsgContent": {
                "Index": 6,
                "Data": "abc\u0000\u0001"
            }
        }
    ]
}
```

#### 2.7.5 指定消息不存离线及漫游
如果消息体中指定OnlineOnlyFlag，只要值大于0，则消息表示只在线下发，不存离线和漫游（AVChatRoom和BChatRoom不允许使用）。
```
    {
        "GroupId": "@TGS#2C5SZEAEF",
        "Random": 8912345, // 随机数字，五分钟数字相同认为是重复消息
        "OnlineOnlyFlag": 1,   // 表示只在线下发(只有在线群成员才能收到)，不存离线及漫游
        "MsgBody": [  // 消息体，由一个element数组组成，详见字段说明
            {
                "MsgType": "TIMTextElem", // 文本
                "MsgContent": {
                    "Text": "red packet"
                }
            },
            {
                "MsgType": "TIMFaceElem", // 表情
                "MsgContent": {
                    "Index": 6,
                    "Data": "abc\u0000\u0001"
                }
            }
        ]
    }
```

### 2.8 请求包字段说明 

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| GroupId | String | 必填 |向哪个群组发送消息。   |
| Random | Integer | 必填 |32位随机数。如果5分钟内两条消息的随机值相同，后一条消息将被当做重复消息而丢弃。 |
| MsgPriority | String | 选填 |消息的优先级。 |
| MsgBody | Array | 必填 |消息体，具体参见[消息格式描述](/doc/product/269/消息格式描述)。 |
| From_Account | String | 选填 |消息来源帐号，选填。如果不填写该字段，则默认消息的发送者为调用该接口时使用的[APP管理员](/doc/product/269/账号登录集成说明#3.4-app.E7.AE.A1.E7.90.86.E5.91.98)帐号。除此之外，APP亦可通过该字段“伪造”消息的发送者，从而实现一些特殊的功能需求。需要注意的是，如果指定该字段，必须要确保字段中的帐号是存在的。 |
| OfflinePushInfo | Object | 选填| 离线推送信息配置，具体可参考[消息格式描述](/doc/product/269/消息格式描述)。 |
|ForbidCallbackControl|Array|选填|消息回调禁止开关，只对单条消息有效，ForbidBeforeSendMsgCallback表示禁止发消息前回调，ForbidAfterSendMsgCallback表示禁止发消息后回调。|

### 2.9 应答包体示例

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0,
    "MsgTime": 1497249503,
    "MsgSeq": 1
}
```

### 2.10 应答包字段说明

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。 |
| ErrorCode | Integer | 错误码。 |
| ErrorInfo | String | 错误信息。  |
| MsgTime | Integer | 消息发送的时间戳，对应后台server时间。 |
| MsgSeq | Integer | 消息序列号，唯一标示一条消息。 |

### 2.11 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 | 含义说明| 
|---------|---------|
| 10002 | 系统错误，请再次尝试或联系技术客服。  | 
| 10004 | 参数非法。请根据应答包中的ErrorInfo字段，检查必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 10007 | 操作权限不足。请确认操作者是否是APP管理员。 | 
| 10010 | 群组不存在，或者曾经存在过，但是目前已经被解散。 | 
| 10015 | 群组ID非法，请检查群组ID是否填写正确。  | 
| 10016 | 该请求触发了到APP后台的“[群内发言之前回调](/doc/product/269/群内发言之前回调)”，云通讯后台根据回调结果拒绝下发该消息。  | 
| 10017 | 因被禁言而不能发送消息，请检查发送者是否被设置禁言。  | 
| 10023| 请求命令非法，请再次尝试或联系技术客服。 | 
| 80001 | 文本安全打击。请检查消息文本中是否有敏感词汇。| 
| 80002 | 消息内容过长，目前最大支持8000字节的消息，请调整消息长度。| 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/group_open_http_svc/send_group_msg)调试本接口。 

### 3.2 Server调试工具 

可以通过[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK)中的调试工具进行简单的REST API调试，命令如下： 
```
# 群组中发送普通消息
./TimRestApiGear.php group_open_http_svc send_group_msg (account_id) (group_id) \
    (text_content)

# 群组中发送图片
./TimRestApiGear.php group_open_http_svc send_group_msg_pic (account_id) (group_id) \
    (pic_path)
```
更多调试工具参见[REST API调试工具](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。

## 4 API集成 

### 4.1 PHP集成 

在云通信[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK#3-timrestapigear.php.E4.BD.BF.E7.94.A8.E8.AF.B4.E6.98.8E)中，可以通过TimRestInterface的如下成员函数快速集成该API： 
```
// 在某一群组里发普通消息
abstract function group_send_group_msg($account_id, $group_id, $text_content);

// 在某一群组里发送图片
abstract function group_send_group_msg_pic($account_id, $group_id, $pic_path);

// 在某一群组里发普通消息(高级接口)
abstract function openim_send_msg2($account_id, $receiver, $msg_content);
```

## 5 可能触发的回调 

[群内发言之前回调](/doc/product/269/群内发言之前回调)。   

## 6 参考 

REST API：在群组中发送系统通知（[v4/group_open_http_svc/send_group_system_notification](/doc/product/269/在群组中发送系统通知)）； 
REST API：单发单聊消息（[v4/openim/sendmsg](/doc/product/269/单发单聊消息)）； 
REST API：批量发单聊消息（[v4/openim/batchsendmsg](/doc/product/269/批量发单聊消息)）； 
[消息格式描述](/doc/product/269/消息格式描述)； 
[群组内普通消息与系统通知之间的区别](/doc/product/269/群组内普通消息与系统消息的区别)。 


