## 1 功能说明 
1. APP管理员可以通过该接口导入群组，不会触发回调、不会下发通知。
2. 当APP需要从其他即时通信系统迁移到云通信时，使用该协议导入存量群组数据。
 
## 2 接口调用说明 

### 2.1 适用的群组类型

云通信中内置了私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群五种群组类型，详情请见[群组形态介绍](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，其中：
1. 私有群、公开群和聊天室支持使用本REST API导入群基础资料；
2. 互动直播聊天室和在线成员广播大群不支持导入群基础资料，对这两种类型的群组进行操作时会返回10007错误。如果需要达到导入群组基础资料的效果，可以通过[创建群组](/doc/product/269/创建群组)和[修改群组基础资料](/doc/product/269/修改群组基础资料)的方式实现。

### 2.2 请求URL 
```
https://console.tim.qq.com/v4/group_open_http_svc/import_group?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json 
```
### 2.3 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.4 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 2.5 HTTP请求方式 

POST 

### 2.6 HTTP请求包体格式 

JSON 

### 2.7 请求包示例

#### 2.7.1 基础形式

导入群，可以用CreateTime指定群组的创建时间。  
```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom（必填）
    "Name": "TestGroup",   // 群名称（必填）
    "CreateTime": 1448357837 //群组的创建时间（选填，不填会以请求时刻为准）
}
```

#### 2.7.2 指定其他选填字段

指定简介、公告等选填字段，和创建群组相同。 
```
{
    "Owner_Account": "leckie", // 群主的UserId（选填）
    "Type": "Public", // 群组类型：Private/Public/ChatRoom（必填）
    "GroupId":"MyFirstGroup", //用户自定义群组外显id（选填）
    "Name": "TestGroup",   // 群名称（必填）
    "Introduction": "This is group Introduction",   // 群简介（选填）
    "Notification": "This is group Notification",    // 群公告（选填）
    "FaceUrl": "http://this.is.face.url",   
    "MaxMemberCount": 500,// 最大群成员数量（选填）
    "ApplyJoinOption": "FreeAccess", // 申请加群处理方式（选填）
    "CreateTime": 1448357837, //群组的创建时间（选填，不填会以请求时刻为准）
    "AppDefinedData": [  // 群组维度的自定义字段（选填）
        {
            "Key": "GroupTestData1",  // APP自定义的字段Key
            "Value": "xxxxx"  // 自定义字段的值
        },
        {
            "Key": " GroupTestData2",
            "Value": "abc\u0000\u0001"  // 自定义字段支持二进制数据
        }
    ]
}
```

### 2.8 请求包字段说明 

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| Owner_Account | String | 选填 |群主id，自动添加到群成员中。如果不填，群没有群主。  |
| Type | String | 必填 |[群组形态](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，包括Public（公开群），Private（私密群）， ChatRoom（聊天室）。 |
| GroupId | String | 选填 |为了使得群组ID更加简单，便于记忆传播，腾讯云支持APP在通过REST API创建群组时自定义群组ID。详情参见：[自定义群组ID](/doc/product/269/群组系统#5-.E8.87.AA.E5.AE.9A.E4.B9.89.E7.BE.A4.E7.BB.84id)。  |
| Name | String | 必填 |群名称，最长30字节。 |
| Introduction | String | 选填 |群简介，最长240字节。  |
| Notification | String | 选填 |群公告，最长300字节。 |
| FaceUrl | String | 选填 |群头像URL，最长100字节。 |
| MaxMemberCount | Integer | 选填 |最大群成员数量，最大为10000，不填默认为2000个。  |
| ApplyJoinOption | String | 选填 |申请加群处理方式。包含FreeAccess（自由加入），NeedPermission（需要验证），DisableApply（禁止加群），不填默认为NeedPermission（需要验证）。 |
| AppDefinedData | Array | 选填 |群组维度的自定义字段，默认情况是没有的，需要开通，详情参见：[自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)。 |
| CreateTime | Integer | 选填 |群组的创建时间。 |

### 2.9 应答包体示例
#### 2.9.1 基础形式

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0, 
    "GroupId": "@TGS#2J4SZEAEL" 
}
```

#### 2.9.2 指定其他选填字段

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0, 
    "GroupId": "MyFirstGroup" 
}
```

### 2.10 应答包字段说明 

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。 |
| ErrorCode | Integer | 错误码。 |
| ErrorInfo | String | 错误信息。  |
| GroupId | String | 创建成功之后的群ID，由IM云后台分配或者用户指定。  |

### 2.11 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 | 含义说明| 
|---------|---------|
| 10002 | 系统错误，请再次尝试或联系技术客服。  | 
| 10003 | 请求命令非法，请再次尝试或联系技术客服。 | 
| 10004 | 参数非法。请根据应答包中的ErrorInfo字段，检查必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 10007 | 操作权限不足。请确认操作者是否是APP管理员。 | 
| 10021 | 群组ID已被使用，请选择其他的群组ID。  | 
| 80001 | 文本安全打击。请检查群名称、群公告和群简介等是否有敏感词汇。  | 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/group_open_http_svc/import_group_info)调试本接口。 

### 3.2 Server调试工具 

无。
更多调试工具参见[REST API调试工具](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。

## 4 API集成 

### 4.1 PHP集成 

无。

## 5 可能触发的回调 

无。

## 6 参考 

REST API：设置成员未读计数（[v4/group_open_http_svc/set_unread_msg_num](https://cloud.tencent.com/doc/product/269/%E8%AE%BE%E7%BD%AE%E6%88%90%E5%91%98%E6%9C%AA%E8%AF%BB%E6%B6%88%E6%81%AF%E8%AE%A1%E6%95%B0)）。 
REST API：导入群成员（[v4/group_open_http_svc/import_group_member](/doc/product/269/导入群成员)）。 
REST API：解散群组（[v4/group_open_http_svc/destroy_group](/doc/product/269/解散群组)）。 
