## 1 功能说明 
1. 该API接口的作用是导入群组的消息，不会触发回调、不会下发通知。
2. 当APP需要从其他即时通信系统迁移到云通信时，使用该协议导入存量群消息数据。
 
## 2 接口调用说明 

### 2.1 适用的群组类型

云通信中内置了私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群五种群组类型，详情请见[群组形态介绍](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，其中：
1. 私有群、公开群和聊天室支持使用本REST API导入群消息；
2. 互动直播聊天室和在线成员广播大群不支持导入群消息，对这两种类型的群组进行操作时会返回10007错误。因为这两种类型群组所适用的场景一般不需要历史消息，所以没有提供这一功能。

### 2.2 请求URL 
```
https://console.tim.qq.com/v4/group_open_http_svc/import_group_msg?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json 
```
### 2.3 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.4 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 2.5 HTTP请求方式 

POST 

### 2.6 HTTP请求包体格式 

JSON 

### 2.7 请求包示例

批量导入群消息，一次最多导入20条； 
使用本接口导入消息后所有成员的未读计数都会变成0，如果要保留未读计数，请在导入所有消息后再[导入群成员](/doc/product/269/导入群成员)或者[设置成员未读计数](https://cloud.tencent.com/doc/product/269/%E8%AE%BE%E7%BD%AE%E6%88%90%E5%91%98%E6%9C%AA%E8%AF%BB%E6%B6%88%E6%81%AF%E8%AE%A1%E6%95%B0)； 
导入的消息必须按时间戳的顺序导入，且时间戳必须大于建群时间且小于当前时间，否则会失败。 
```
{
    "GroupId": "@TGS#2C5SZEAEF",
    "MsgList": [
        {
            "From_Account": "leckie", //指定消息发送者
            "SendTime":1448357837,
            "Random": 8912345, // 消息随机数（可选）
            "MsgBody": [  // 消息体，由一个element数组组成，详见TIMMessage消息对象
                {
                    "MsgType": "TIMTextElem", // 文本
                    "MsgContent": {
                        "Text": "red packet"
                    }
                },
                {
                    "MsgType": "TIMFaceElem", // 表情
                    "MsgContent": {
                        "Index": 6,
                        "Data": "abc\u0000\u0001"
                    }
                }
            ]
        },
        {
            "From_Account": "peter", //指定消息发送者
            "SendTime":1448357837,
            "MsgBody": [  // 消息体，由一个element数组组成，详见TIMMessage消息对象
                {
                    "MsgType": "TIMTextElem", // 文本
                    "MsgContent": {
                        "Text": "red packet"
                    }
                }
            ]
        }

    ]
}
```

### 2.8 请求包字段说明 

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| GroupId | String | 必填 |要导入消息的群ID。   |
| MsgList | String | 必填 |导入的消息列表。  |
| From_Account | String | 必填 |指定消息发送者。  |
| SendTime | Integer | 必填 |指定消息发送者。  |
| Random | Integer | 选填 |32位随机数。如果5分钟内两条消息的随机值相同，后一条消息将被当做重复消息而丢弃。  |
| MsgBody | Object | 必填 |TIM消息，请参考[TIMMsgElement对象的定义](/doc/product/269/消息格式描述#2-.E6.B6.88.E6.81.AF.E5.85.83.E7.B4.A0timmsgelement)。   |
| MsgType | String | 必填 |TIM消息对象类型，目前支持的消息对象包括： TIMTextElem(文本消息)，TIMFaceElem(表情消息)，TIMLocationElem(位置消息)，TIMCustomElem(自定义消息)。|
| MsgContent | Object | 必填 |MsgContent为TIM消息对象， 具体可参考[TIMMsgElement对象的定义](/doc/product/269/消息格式描述#2-.E6.B6.88.E6.81.AF.E5.85.83.E7.B4.A0timmsgelement)。 |

### 2.9 应答包体示例

```
{
    "ActionStatus": "OK", 
    "ErrorCode": 0, 
    "ImportMsgResult": [
        {
            "Result": 0, 
            "MsgSeq": 1, 
            "MsgTime": 1449454106
        }, 
        {
            "Result": 0, 
            "MsgSeq": 2, 
            "MsgTime": 1449454116
        }, 
        {
            "Result": 0, 
            "MsgSeq": 3, 
            "MsgTime": 1449454106
        }, 
        {
            "Result": 0, 
            "MsgSeq": 4, 
            "MsgTime": 1449454116
        }
    ]
}
```

### 2.10 应答包字段说明 

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。 |
| ErrorCode | Integer | 错误码。 |
| ImportMsgResult | Array | 具体的消息导入结果。 |
| Result | Integer | 单条消息导入结果。  |
| MsgSeq | Integer | 给消息分配的seq。  |
| MsgTime | Integer | 消息的时间戳。   |

### 2.11 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 | 含义说明| 
|---------|---------|
| 10002 | 系统错误，请再次尝试或联系技术客服。  | 
| 10004 | 参数非法。请根据应答包中的ErrorInfo字段，检查必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 10007 | 操作权限不足。请确认操作者是否是APP管理员。 | 
| 10010 | 群组不存在，或者曾经存在过，但是目前已经被解散。 | 
| 10015 | 操群组ID非法，请检查群组ID是否填写正确。  | 
| 10020 | 消息内容过长，目前最大支持8000字节的消息，请调整消息长度。  | 
| 80001 | 文本安全打击。请检查群名称、群公告和群简介等是否有敏感词汇。  | 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/group_open_http_svc/import_group_msg)调试本接口。 

### 3.2 Server调试工具 

无。
更多调试工具参见[REST API调试工具](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。

## 4 API集成 

### 4.1 PHP集成 

无。

## 5 可能触发的回调 

无。

## 6 参考 

REST API：设置成员未读消息计数（[v4/group_open_http_svc/set_unread_msg_num](/doc/product/269/设置成员未读消息计数)）。 
