## 1 功能说明 
1. APP管理员可以通过该接口获取某一用户加入的群组。 
 
## 2 接口调用说明 

### 2.1 适用的群组类型

云通信中内置了私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群五种群组类型，详情请见[群组形态介绍](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，其中：
1. 私有群、公开群和聊天室支持使用本REST API获取用户加入的群组；
2. 互动直播聊天室和在线成员广播大群因为内部实现的差异，获取用户加入的群组时不会获取到这两种类型的群组。

### 2.2 请求URL 
```
https://console.tim.qq.com/v4/group_open_http_svc/get_joined_group_list?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json 
```
### 2.3 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.4 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 2.5 HTTP请求方式 

POST 

### 2.6 HTTP请求包体格式 

JSON 

### 2.7 请求包示例

#### 2.7.1 基础形式 

用来获取用户加入的群组，群组信息只包含所在群组的用户ID。 
```
{
    "Member_Account": "leckie"
}
```

#### 2.7.2 分页拉取 

可以使用Limit和Offset两个值用于控制分页拉取； 
Limit限制回包中GroupIdList数组中群组的个数，不得超过5000； 
Offset控制从整个群组列表中的第多少个开始读取（默认从0开始）。对于分页请求（页码数字从1开始），每一页的Offset值应当为：（页码数– 1）×每页展示的群组数量；
例如：假设需要分页拉取，每页展示20个，则第一页的请求参数应当为：`{“Limit”: 20, “Offset”: 0}`，第二页的请求参数应当为`{“Limit”: 20, “Offset”: 20}`，依此类推；
Limit或者Offset的取值不会对应答包体中的TotalCount造成影响。 
```
{
    "Member_Account": "leckie", 
    "Limit": 10,  // 拉取多少个，不填标识拉取全部
    "Offset": 0  // 从第多少个开始拉取
}
```

#### 2.7.3 指定群组形态 

可以指定所拉取的群组所属的群组形态，如Public，Private和ChatRoom（如果指定AVChatRoom，获得的成员可能不完整）。
```
{
    "Member_Account": "leckie",
    "GroupType": "Public"  // 拉取哪种群组形态，不填为拉取所有
}
```

#### 2.7.4 拉取指定信息 

可以指定拉取的基础信息字段，在GroupBaseInfoFilter中设置； 
可以指定拉取的群成员自身在群内的信息，在SelfInfoFilter中设置。 
```
{
    "Member_Account": "leckie",
    "ResponseFilter": {
        "GroupBaseInfoFilter": [  // 需要哪些基础信息字段
            "Type",
            "Name",
            "Introduction",
            "Notification",
            "FaceUrl",
            "CreateTime",
            "Owner_Account",
            "LastInfoTime",
            "LastMsgTime",
            "NextMsgSeq",
            "MemberNum",
            "MaxMemberNum",
            "ApplyJoinOption",
            "ShutUpAllMember"
        ],
        "SelfInfoFilter": [  // 需要自身在群内的信息
            "Role",   // 群内身份
            "JoinTime",  // 入群时间
            "MsgFlag",   // 消息屏蔽类型
            "UnreadMsgNum"  // 未读消息数量（IM云后台计算得出）
        ]
    }
}
```

#### 2.7.5 ALL IN ONE

```
{
    "Member_Account": "leckie", 
    "Limit": 10,  // 拉取多少个，不填标识拉取全部
    "Offset": 0,  // 从第多少个开始拉取
    "GroupType": "Public",  // 拉取哪种群组形态，不填为拉取所有
    "ResponseFilter": {
        "GroupBaseInfoFilter": [  // 需要哪些基础信息字段，含义参见“基本字段介绍”
            "Type",
            "Name",
            "Introduction",
            "Notification",
            "FaceUrl",
            "CreateTime",
            "Owner_Account",
            "LastInfoTime",
            "LastMsgTime",
            "NextMsgSeq",
            "MemberNum",
            "MaxMemberNum",
            "ApplyJoinOption",
            "ShutUpAllMember"
        ],
        "SelfInfoFilter": [  // 自身在群内的信息
            "Role",   // 群内身份
            "JoinTime",  // 入群时间
            "MsgFlag",   // 消息屏蔽类型
            "UnreadMsgNum"  // 未读消息数量（IM云后台计算得出）
        ]
    }
}
```

### 2.8 请求包字段说明 

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| Member_Account | String | 必填 |需要查询的用户账号。   |
| Limit | Integer | 选填 |单次拉取的群组数量，如果不填代表所有群组，分页方式与[获取APP中的所有群组](/doc/product/269/获取APP中的所有群组)相同。 |
| Offset | Integer | 选填 |从第多少个群组开始拉取，分页方式与[获取APP中的所有群组](/doc/product/269/获取APP中的所有群组)相同。|
| GroupType | String | 选填 |拉取哪种[群组形态](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，例如Private，Public，ChatRoom或AVChatRoom，不填为拉取所有。  |
| ResponseFilter | Object | 选填 |分别包含GroupBaseInfoFilter和SelfInfoFilter两个过滤器； GroupBaseInfoFilter表示需要拉取哪些基础信息字段，具体参见[群基础资料](/doc/product/269/群组系统#4.1-.E7.BE.A4.E5.9F.BA.E7.A1.80.E8.B5.84.E6.96.99)；SelfInfoFilter表示需要拉取用户在每个群组中的哪些个人资料，具体请参见[群成员资料](/doc/product/269/群组系统#4.2-.E7.BE.A4.E6.88.90.E5.91.98.E8.B5.84.E6.96.99)。 |

### 2.9 应答包体示例

#### 2.9.1 基础形式和分页拉取

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0, 
    "TotalCount": 2, // 不论Limit和Offset如何设置，该值总是满足条件的群组总数
    "GroupIdList": [
        {
            "GroupId": "@TGS#2J4SZEAEL"
        }, 
        {
            "GroupId": "@TGS#2C5SZEAEF"
        }
    ]
}
```

#### 2.9.2 指定群组形态

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0, 
    "TotalCount": 1,
    "GroupIdList": [
        {
            "GroupId": "@TGS#2J4SZEAEL"
        }
    ]
}
```

#### 2.9.3 拉取指定信息

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0,
    "TotalCount": 2,
    "GroupIdList": [
        {
            "GroupId": "@TGS#2J4SZEAEL",
            "Type": "Public",
            "LastMsgTime": 1425976500,
            "MemberCount": 48,
            "ShutUpAllMember": "On",
            "SelfInfo": {
                "Role": "Owner",
                "MsgFlag": "AcceptAndNotify",
                "UnreadMsgNum": 1
            }
        },
        {
            "GroupId": "@TGS#2C5SZEAEF",
            "Type": "ChatRoom",
            "LastMsgTime": 1425976567,
            "MemberCount": 120,
            "ShutUpAllMember": "Off",
            "SelfInfo": {
                "Role": "Member",
                "MsgFlag": "AcceptAndNotify",
                "UnreadMsgNum": 0
            }
        }
    ]
}
```

#### 2.9.4 ALL IN ONE

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0,
    "TotalCount": 1, // 不论Limit和Offset如何设置，该值总是满足条件的群组总数
    "GroupIdList": [
        {
            "GroupId": "@TGS#2J4SZEAEL",
            "Type": "Public",
            "LastMsgTime": 1425976500,
            "MemberCount": 48,
            "SelfInfo": {
                "Role": "Owner",
                "MsgFlag": "AcceptAndNotify",
                "UnreadMsgNum": 1
            }
        }
    ]
}
```

### 2.10 应答包字段说明

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。 |
| ErrorCode | Integer | 错误码。 |
| ErrorInfo | String | 错误信息。  |
| TotalCount | Integer | 用户所加入的群组个数。   |
| GroupIdList | Array | 拉取到的群组信息，会根据高级接口中过滤器设置的过滤字段对结果进行结果进行过滤。  |

### 2.11 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 | 含义说明| 
|---------|---------|
| 10002 | 系统错误，请再次尝试或联系技术客服。  | 
| 10003 | 请求命令非法，请再次尝试或联系技术客服。 | 
| 10004 | 参数非法。请根据应答包中的ErrorInfo字段，检查必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 10018 | 应答包长度超限。因为请求的内容过多，导致应答包超过了最大包长（1MB），请尝试减少单次请求的数据量。  | 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/group_open_http_svc/get_joined_group_list)调试本接口。 

### 3.2 Server调试工具 

可以通过[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK)中的调试工具进行简单的REST API调试，命令如下： 
```
# 获取用户所加入的所有群组
./TimRestApiGear.php group_open_http_svc get_joined_group_list (account_id)
```
更多调试工具参见[REST API调试工具](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。

## 4 API集成 

### 4.1 PHP集成 

在云通信[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK)中，可以通过TimRestInterface的如下成员函数快速集成该API： 
```
// 获取某一用户加入的群组
abstract function group_get_joined_group_list($account_id);

// 获取某一用户加入的群组(高级接口)
abstract function group_get_joined_group_list2($account_id, $group_type, 
    $base_info_filter, $self_info_filter);
```

## 5 可能触发的回调 

无。  

## 6 参考 

无。

