## 1 功能说明 
1. APP管理员可以根据群组ID获取群组的详细信息。
 
## 2 接口调用说明 

### 2.1 适用的群组类型

云通信中内置了私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群五种群组类型，详情请见[群组形态介绍](/doc/product/269/群组系统#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D)，其中：

私有群、公开群、聊天室、互动直播聊天室和在线成员广播大群全部支持使用本REST API获取群组详细资料。

### 2.2 请求URL 
```
https://console.tim.qq.com/v4/group_open_http_svc/get_group_info?usersig=xxx&identifier=admin&sdkappid=88888888&random=99999999&contenttype=json 
```
### 2.3 请求参数 

URL中各参数的含义以及填写方式参见[REST API简介](/doc/product/269/REST API简介)。 

### 2.4 最高调用频率 

100次/秒。如需提升调用频率，请根据[工单模板](/doc/product/269/云通信配置变更需求工单#2.15-rest-api.E8.B0.83.E7.94.A8.E9.A2.91.E7.8E.87.E8.B0.83.E6.95.B4)提交工单申请处理。 

### 2.5 HTTP请求方式 

POST 

### 2.6 HTTP请求包体格式 

JSON 

### 2.7 请求包示例

#### 2.7.1 基础形式

用来获取群组的详细信息（所有群基础信息、群成员信息和自定义信息），请求中只包含群ID的列表，一次请求最多支持50个群组。 
```
{
    "GroupIdList": [  // 群组列表（必填）
        "@TGS#1NVTZEAE4", 
        "@TGS#1CXTZEAET"
    ]
}
```

#### 2.7.2 拉取指定的信息

可以指定拉取的基础信息字段，在GroupBaseInfoFilter中设置； 
可以指定拉取的成员信息字段，在MemberInfoFilter中设置； 
可以指定拉取的群组维度的自定字段，在AppDefinedDataFilter_Group中设置（该字段默认没有，需要额外开通，请求包字段表中有说明）； 
可以指定拉取的群成员维度的自定字段，在AppDefinedDataFilter_GroupMember（该字段默认没有，需要额外开通，请求包字段表中有说明）； 
如果设置了过滤器，没有在过滤器中指明的字段将不被拉取。 
```
{
    "GroupIdList": [   // 群组列表，必填
        "@TGS#1NVTZEAE4",
        "@TGS#1CXTZEAET"
    ],
    "ResponseFilter": {  //返回
        "GroupBaseInfoFilter": [  // 如果基础信息字段，请在此数组中添加
            "Type",
            "Name",
            "Introduction",
            "Notification"
        ],
        "MemberInfoFilter": [ // 如果需要成员信息，请添加此数组
            "Account", // 成员ID
            "Role"
        ],
        "AppDefinedDataFilter_Group": [  // 群组维度的自定义字段过滤，该默认情况是没有的
            "GroupTestData1",
            "GroupTestData2"
        ],
        "AppDefinedDataFilter_GroupMember": [ //群成员维度自定义字段过滤，该默认情况是没有的
            "MemberDefined2",
            "MemberDefined1"
        ]
    }
}
```

### 2.8 请求包字段说明 

| 字段 | 类型 | 属性 | 说明 |
|---------|---------|---------|---------|
| GroupIdList | String | 必填 |需要拉取的群组列表。  |
| ResponseFilter | Object | 选填 |包含三个过滤器：GroupBaseInfoFilter，MemberInfoFilter，AppDefinedDataFilter_Group，分别是基础信息字段过滤器，成员信息字段过滤器，群组维度的自定义字段过滤器。 |
| GroupBaseInfoFilter | Array | 选填 |基础信息字段过滤器，指定需要获取的基础信息字段，基础信息字段详情参见：[群基础资料](/doc/product/269/群组系统#4.1-.E7.BE.A4.E5.9F.BA.E7.A1.80.E8.B5.84.E6.96.99)。 |
| MemberInfoFilter | Array | 选填 |成员信息字段过滤器，指定需要获取的成员信息字段，成员信息字段详情参见：[群成员资料](/doc/product/269/群组系统#4.2-.E7.BE.A4.E6.88.90.E5.91.98.E8.B5.84.E6.96.99)。 |
| AppDefinedDataFilter_Group | Array | 选填 |该字段用来群组维度的自定义字段过滤器，指定需要获取的[群组维度的自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)。 |
| AppDefinedDataFilter_GroupMember | Array | 选填 |该字段用来群成员维度的自定义字段过滤器，指定需要获取的[群成员维度的自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)。 |

### 2.9 应答包体示例

#### 2.9.1 基础形式

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "",  //这里的ErrorInfo无意义，需要判断每个群组的ErrorInfo
    "ErrorCode": 0,  // 这里的ErrorCode无意义，需要判断每个群组的ErrorCode
    "GroupInfo": [  // 返回结果为群组信息数组，为简单起见这里仅列出一个群
        {
            "GroupId": "@TGS#2J4SZEAEL", 
            "ErrorCode": 0,   // 针对该群组的返回结果
            "ErrorInfo": "" ,   // 针对该群组的返回结果
            "Type": "Public",  // 群组类型
            "Name": "MyFirstGroup",   // 群组名称
            "Introduction": "TestGroup",   // 群组简介
            "Notification": "TestGroup",   // 群组通知
            "FaceUrl": "http://this.is.face.url",  // 群组头像
            "Owner_Account": "leckie",   // 群主ID
            "CreateTime": 1426976500,  // 群组创建时间（UTC时间）
            "LastInfoTime": 1426976500,  // 最后群资料变更时间（UTC时间）
            "LastMsgTime": 1426976600,  // 群内最后一条消息的时间（UTC时间）
            "NextMsgSeq": 1234,  // 
            "MemberNum": 2,  // 当前群成员数量
            "MaxMemberNum": 50,  // 最大群成员数量
            "ApplyJoinOption": "FreeAccess", // 申请加群处理方式
            "ShutUpAllMember": "On",    //群全员禁言状态
            "AppDefinedData": [  // 群组维度的自定义字段
                {
                    "Key": "GroupTestData1",  // 自定义字段的key
                    "Value": "xxxx"  // 自定义字段的值
                },
                {
                    "Key": "GroupTestData2",
                    "Value": "abc\u0000\u0001"  // 自定义字段支持二进制数据
                }
            ],
            "MemberList": [  // 群成员列表
                {
                    "Member_Account": "leckie",  // 成员ID
                    "Role": "Owner",  // 群内角色
                    "JoinTime": 1425976500,  // 入群时间（UTC时间）
                    "MsgSeq": 1233, 
                    "MsgFlag": "AcceptAndNotify",  // 消息屏蔽选项
                    "LastSendMsgTime": 1425976500,  // 最后发言时间（UTC时间）
                    "ShutUpUntil": 1431069882, // 禁言截至时间（UTC时间）
                    "AppMemberDefinedData": [ //群成员自定义字段
                        {
                             "Key": "MemberDefined1",
                             "Value": "ModifyDefined1"
                        },
                        {
                             "Key": "MemberDefined2",
                             "Value": "ModifyDefined2"
                        }
                    ]
                }, 
                {
                    "Member_Account": "peter", 
                    "Role": "Member", 
                    "JoinTime": 1425976500,  // 入群时间
                    "MsgSeq": 1233, 
                    "MsgFlag": "AcceptAndNotify", 
                    "LastSendMsgTime": 1425976500,  // 最后一次发消息的时间
                    "ShutUpUntil": 0,  // 0表示未被禁言，否则为禁言的截止时间
                    "AppMemberDefinedData":[ //群成员自定义字段
                        {
                            "Key": "MemberDefined1",
                            "Value": "ModifyDefined1"
                        },
                        {
                            "Key":"MemberDefined2",
                            "Value":"ModifyDefined2"
                        }
                     ]
                }
            ]
        }
    ]
}
```

#### 2.9.2 拉取指定的信息

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "",  //这里的ErrorInfo无意义，需要判断每个群组的ErrorInfo
    "ErrorCode": 0,  // 这里的ErrorCode无意义，需要判断每个群组的ErrorCode
    "GroupInfo": [  // 返回结果为群组信息数组，为简单起见这里仅列出一个群
        {
            "GroupId": "@TGS#2J4SZEAEL", 
            "ErrorCode": 0,   // 针对该群组的返回结果
            "ErrorInfo":"" ,   // 针对该群组的返回结果
            "Type": "Public",  // 群组类型
            "Name": "MyFirstGroup",   // 群组名称
            "Introduction": "TestGroup",   // 群组简介
            "Notification": "TestGroup",   // 群组通知
            "AppDefinedData": [  // 群组维度的自定义字段
                {
                    "Key": "GroupTestData1",  // 自定义字段的key
                    "Value": "xxxx"  // 自定义字段的值
                },
                {
                    "Key": "GroupTestData2",
                    "Value": "abc\u0000\u0001"  // 自定义字段支持二进制数据
                }
            ],
            "MemberList": [  // 群成员列表
                {
                    "Member_Account": "leckie",  // 成员ID
                    "Role": "Owner",  // 群内角色
                    "AppMemberDefinedData":[ //群成员自定义字段
                        {
                            "Key":"MemberDefined1",
                            "Value":"ModifyDefined1"
                        },
                        {
                            "Key":"MemberDefined2",
                            "Value":"ModifyDefined2"
                        }
                     ]
                }, 
                {
                    "Member_Account": "peter", 
                    "Role": "Member",
                    "AppMemberDefinedData":[ //群成员自定义字段
                        {
                            "Key":"MemberDefined1",
                            "Value":"ModifyDefined1"
                        },
                        {
                            "Key":"MemberDefined2",
                            "Value":"ModifyDefined2"
                        }
                     ] 
                }
            ]
        }
    ]
}
```

### 2.10 应答包字段说明 

| 字段 | 类型 | 说明 |
|---------|---------|---------|
| ActionStatus | String | 请求处理的结果，OK表示处理成功，FAIL表示失败。 |
| ErrorCode | Integer | 错误码。 |
| ErrorInfo | String | 错误信息。  |
| GroupInfo | Array | 返回结果为群组信息数组，内容包括[群基础资料](/doc/product/269/群组系统#4.1-.E7.BE.A4.E5.9F.BA.E7.A1.80.E8.B5.84.E6.96.99)字段、[群成员资料](/doc/product/269/群组系统#4.2-.E7.BE.A4.E6.88.90.E5.91.98.E8.B5.84.E6.96.99)字段、[群组维度自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)和[群成员维度自定义字段](/doc/product/269/群组系统#6-.E8.87.AA.E5.AE.9A.E4.B9.89.E5.AD.97.E6.AE.B5)。 |

### 2.11 错误码说明 

除非发生网络错误（例如502错误），该接口的HTTP返回码均为200。真正的错误码、错误信息是通过应答包体中的ErrorCode、ErrorInfo来表示的。 
公共错误码（60000到79999）参见[REST API公共错误码](/doc/product/269/错误码#rest-api.E5.85.AC.E5.85.B1.E9.94.99.E8.AF.AF.E7.A0.81)。 
本API私有错误码如下： 

| 错误码 | 含义说明| 
|---------|---------|
| 10002 | 系统错误，请再次尝试或联系技术客服。  | 
| 10003 | 请求命令非法，请再次尝试或联系技术客服。 | 
| 10004 | 参数非法。请根据应答包中的ErrorInfo字段，检查必填字段是否填充，或者字段的填充是否满足协议要求。 | 
| 10007 | 操作权限不足。请确认操作者是否是APP管理员。 | 
| 10010 | 群组不存在，或者曾经存在过，但是目前已经被解散。 | 
| 10015 | 群组ID非法，请检查群组ID是否填写正确。  | 
| 10018 | 应答包长度超限。因为请求的内容过多，导致应答包超过了最大包长（1MB），请尝试减少单次请求的数据量。  | 

## 3 接口调试工具 

### 3.1 Web调试工具 

通过[REST API在线调试工具](https://avc.cloud.tencent.com/im/APITester/APITester.html#v4/group_open_http_svc/get_group_info)调试本接口。 

### 3.2 Server调试工具 

可以通过[PHP Server SDK](/doc/product/269/PHP%20Server%20SDK)中的调试工具进行简单的REST API调试，命令如下： 
```
# 获取群组详细信息
./TimRestApiGear.php group_open_http_svc get_group_info (group_id)
```
更多调试工具参见[REST API调试工具](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)。

## 4 API集成 

### 4.1 PHP集成 

在云通信[PHP Server SDK](/doc/product/269/REST%20API简介#5-rest-api.E8.B0.83.E8.AF.95.E5.B7.A5.E5.85.B7)中，可以通过TimRestInterface的如下成员函数快速集成该API： 
```
// 获取群组详细信息
abstract function group_get_group_info($group_id);

// 获取群组详细信息(高级接口)
abstract function group_get_group_info2($group_list, $base_info_filter, $member_info_filter,
    $app_define_filter);
```

## 5 可能触发的回调 

无。 

## 6 参考 

REST API：获取群成员详细资料（[v4/group_open_http_svc/get_group_member_info](/doc/product/269/获取群组成员详细资料)）； 
REST API：修改群组基础资料（[v4/group_open_http_svc/modify_group_base_info](/doc/product/269/修改群组基础资料)）； 
REST API：修改群成员资料（[v4/group_open_http_svc/modify_group_member_info](/doc/product/269/修改群成员资料)）。 
