## 1 功能说明 

APP后台可以通过该回调实时监控黑名单的删除情况，包括：
1. APP后台可以修改相应的好友表； 
2. APP后台可以修改相应的黑名单列表； 
3. APP后台可以修改相应的推荐列表。 

## 2 注意事项 

1. 要启用回调，必须配置回调URL，并打开本条回调协议对应的开关，配置方法详见<a href="https://cloud.tencent.com/document/product/269/1522#6-.E5.9B.9E.E8.B0.83.E9.85.8D.E7.BD.AE">回调配置</a>；
2. 回调的方向是：云通信后台向APP后台发起HTTP POST请求；
3. APP后台在收到回调请求之后，务必校验请求URL中的参数SdkAppid是否是自己的SdkAppid；
4. 其他安全相关事宜请参考<a href="https://cloud.tencent.com/document/product/269/1522#4-.E5.AE.89.E5.85.A8.E8.80.83.E8.99.91">安全考虑</a>。
 
## 3 可能触发该回调的场景 

1. APP用户通过客户端发起把某个用户从黑名单列表中删除的请求；
2. APP用户通过REST API删除黑名单。 
 
## 4  回调发生时机 

用户发起删除黑名单请求，后台删除黑名单成功后。 

## 5 接口说明 

### 5.1 请求URL 

假定APP配置的回调URL为 `https://www.example.com`，本回调请求的URL如下：
`https://www.example.com/SdkAppid=$SdkAppid&CallbackCommand=$CallbackCommand&contenttype=json`

### 5.2 请求参数 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">参数</td>
				<td style="background-color:#CCCCCC;">含义</td>
			</tr>
			<tr>
				<td>SdkAppid</td>
				<td>APP在云通讯申请的Appid。</td>
			</tr>
			<tr>
				<td>CallbackCommand</td>
				<td>固定为：Sns.CallbackBlackListDelete。</td>
			</tr>
			<tr>
				<td>contenttype</td>
				<td>固定为：json。</td>
			</tr>
		</tbody>
	</table>

### 5.3 HTTP请求方式 

POST 

### 5.4 HTTP请求包体格式 

JSON 

### 5.5 回调请求包示例 

```
{
    "CallbackCommand": "Sns.CallbackBlackListDelete",
    "PairList": [
        {
            "From_Account": "id", 
            "To_Account": "id1",
            "TimeStamp": 1432000000
        },
        {
            "From_Account": "id",
            "To_Account": "id2",
            "TimeStamp": 1432000000
        },
        {
            "From_Account": "id",
            "To_Account": "id3",
            "TimeStamp": 1432000000
        }
    ]
}
```

### 5.6 回调请求包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">字段</td>
				<td style="width:5%;background-color:#CCCCCC;">类型</td>
				<td style="background-color:#CCCCCC;">说明</td>
			</tr>
			<tr>
				<td>CallbackCommand</td>
				<td>String</td>
				<td>回调命令。</td>
			</tr>
			<tr>
				<td>PairList</td>
				<td>Array</td>
				<td>成功删除的黑名单关系链对。 </td>
			</tr>
			<tr>
				<td>From_Account</td>
				<td>String</td>
				<td>From_Account的黑名单列表中删除了To_Account。 </td>
			</tr>
			<tr>
				<td>To_Account</td>
				<td>String</td>
				<td>To_Account从From_Account的黑名单列表中删除了。 </td>
			</tr>
			<tr>
				<td>TimeStamp</td>
				<td>Integer</td>
				<td>删除黑名单关系时的时间戳。 </td>
			</tr>
		</tbody>
	</table>
	
### 5.7 回调应答包示例

```
{
    "ActionStatus": "OK", 
    "ErrorCode": 0,
    "ErrorInfo": ""
}
```

### 5.8 应答包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">字段</td>
				<td style="width:5%;background-color:#CCCCCC;">类型</td>
				<td style="width:10%;background-color:#CCCCCC;">属性</td>
				<td style="background-color:#CCCCCC;">说明</td>
			</tr>
			<tr>
				<td>ActionStatus</td>
				<td>String</td>
				<td>必填</td>
				<td>请求处理的结果，OK表示处理成功，FAIL表示失败。</td>
			</tr>
			<tr>
				<td>ErrorCode</td>
				<td>Integer</td>
				<td>必填</td>
				<td>错误码，0表示APP后台处理成功，1表示APP后台处理失败。</td>
			</tr>
			<tr>
				<td>ErrorInfo</td>
				<td>String</td>
				<td>必填</td>
				<td>错误信息。</td>
			</tr>
		</tbody>
	</table>

## 6 参考 

1、<a href="https://cloud.tencent.com/document/product/269/1522">第三方回调简介</a>；
2、<a href="https://cloud.tencent.com/document/product/269/3718">添加黑名单</a>。


