## 1 功能说明 

APP后台可以通过该回调实时分析用户的加好友行为，并对本次加好友行为作出相应的处理，例如：APP后台可以打击恶意加好友行为，禁止恶意用户添加好友。 

## 2 注意事项 

1. 要启用回调，必须配置回调URL，并打开本条回调协议对应的开关，配置方法详见<a href="https://cloud.tencent.com/document/product/269/1522#6-.E5.9B.9E.E8.B0.83.E9.85.8D.E7.BD.AE">回调配置</a>；
2. 回调的方向是：云通信后台向APP后台发起HTTP POST请求；
3. APP后台在收到回调请求之后，务必校验请求URL中的参数SdkAppid是否是自己的SdkAppid；
4. 如果当前请求是管理员发起的加好友请求，云通信后台不会往APP后台发送添加好友之前的回调请求；
5. 其他安全相关事宜请参考<a href="https://cloud.tencent.com/document/product/269/1522#4-.E5.AE.89.E5.85.A8.E8.80.83.E8.99.91">安全考虑</a>。
 
## 3 可能触发该回调的场景 

APP用户通过客户端发起添加其他用户为好友的请求。


## 4  回调发生时机 

用户通过客户端发起加好友请求，云通信后台收到加好友请求后，先往APP后台发送加好友之前的回调请求，如果app后台允许该用户发起加好友请求，则继续后面的加好友处理逻辑。 

## 5 接口说明 

### 5.1 请求URL 

假定APP配置的回调URL为`https://www.example.com`，本回调请求的URL如下：
`https://www.example.com/SdkAppid=$SdkAppid&CallbackCommand=$CallbackCommand&contenttype=json`

### 5.2 请求参数 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;"> 参数 </td>
				<td style="background-color:#CCCCCC;"> 含义 </td>
			</tr>
			<tr>
				<td> SdkAppid </td>
				<td> APP在云通讯申请的Appid。</td>
			</tr>
			<tr>
				<td> CallbackCommand </td>
				<td> 回调命令字，本回调中该字段固定为：Sns.CallbackPrevFriendAdd 。</td>
			</tr>
			<tr>
				<td> contenttype </td>
				<td> 回调的内容类型，本回调中该字段固定为：json。</td>
			</tr>
		</tbody>
	</table>

### 5.3 HTTP请求方式 

POST 

### 5.4 HTTP请求包体格式 

JSON 

### 5.5 回调请求包示例 

```
{
    "CallbackCommand":"Sns.CallbackPrevFriendAdd",
    "Requester_Account":"id",
    "From_Account":"id",
    "AddType":"Add_Type_Both",
    "FriendItem":[
        {
            "To_Account":"id1",
            "Remark":"remark1",
            "GroupName":"同学",
            "AddSource":"AddSource_Type_XXXXXXXX",
            "AddWording":"I'm remark1"
        },
        {
            "To_Account":"id2",
            "Remark":"remark2",
            "GroupName":"同事",
            "AddSource":"AddSource_Type_XXXXXXXX",
            "AddWording":"I'm remark2"
        },
        {
            "To_Account":"id3",
            "Remark":"remark3",
            "GroupName":"家人",
            "AddSource":"AddSource_Type_XXXXXXXX",
            "AddWording":"I'm remark3"
        }
    ],
    "ForceAddFlags":0
}
```

### 5.6 回调请求包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;"> 字段 </td>
				<td style="width:5%;background-color:#CCCCCC;"> 类型 </td>
				<td style="background-color:#CCCCCC;"> 说明 </td>
			</tr>
			<tr>
				<td> CallbackCommand </td>
				<td> String </td>
				<td> 回调命令字，本回调中该字段固定为：Sns.CallbackPrevFriendAdd。</td>
			</tr>
			<tr>
				<td> Requester_Account </td>
				<td> String </td>
				<td> 发起加好友请求的用户的Identifier。</td>
			</tr>
			<tr>
				<td> From_Account </td>
				<td> String </td>
				<td> 请求加好友的用户的Identifier，对应加好友请求里面的From_Account。</td>
			</tr>
			<tr>
				<td> AddType </td>
				<td> String </td>
				<td>
				    加好友方式（默认双向加好友方式）：<br />
				    "Add_Type_Single"表示单向加好友；<br />
				    "Add_Type_Both"表示双向加好友。<br />
				</td>
			</tr>
			<tr>
				<td> FriendItem </td>
				<td> Array </td>
				<td> 加好友请求的对象数组。</td>
			</tr>
			<tr>
				<td> To_Account </td>
				<td> String </td>
				<td> From_Account请求添加为好友的账号。</td>
			</tr>
			<tr>
				<td> Remark </td>
				<td> String </td>
				<td>
					From_Account为To_Account设置的备注信息，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。
				</td>
			</tr>
			<tr>
				<td> GroupName </td>
				<td> String </td>
				<td>
					From_Account为To_Account设置的分组信息，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。
				</td>
			</tr>
			<tr>
				<td> AddSource </td>
				<td> String </td>
				<td>
					加好友来源，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。
				</td>
			</tr>
			<tr>
				<td> AddWording </td>
				<td> String </td>
				<td>
					加好友附言，详情可参见<a href="https://cloud.tencent.com/document/product/269/1501#3.1-.E6.A0.87.E9.85.8D.E5.A5.BD.E5.8F.8B.E5.AD.97.E6.AE.B5">标配好友字段</a>。
				</td>
			</tr>
			<tr>
				<td> ForceAddFlags </td>
				<td> Integer </td>
				<td> 
					管理员强制加好友标记： <br />
					1 - 表示强制加好友； <br />
					0 - 表示常规加好友方式。 <br />
				</td>
			</tr>
		</tbody>
	</table>
	
### 5.7 回调应答包示例

```
{
    "ActionStatus": "OK",
    "ErrorCode": 0,
    "ErrorInfo": "",
    "ResultItem": [
        {
            "To_Account": "id1",
            "ResultCode": 0,
            "ResultInfo": ""
        },
        {
            "To_Account": "id2",
            "ResultCode": 0,
            "ResultInfo": ""
        },
        {
            "To_Account": "id3",
            "ResultCode": 38000,
            "ResultInfo": "操作过于频繁，请稍后再添加"
        }
    ]
}
```

### 5.8 应答包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:15%;background-color:#CCCCCC;"> 字段 </td>
				<td style="width:10%;background-color:#CCCCCC;"> 类型 </td>
				<td style="width:10%;background-color:#CCCCCC;"> 属性 </td>
				<td style="background-color:#CCCCCC;"> 说明 </td>
			</tr>
			<tr>
				<td> ActionStatus </td>
				<td> String </td>
				<td> 必填 </td>
				<td> 请求处理的结果，OK表示处理成功，FAIL表示失败。</td>
			</tr>
			<tr>
				<td> ErrorCode </td>
				<td> Integer </td>
				<td> 必填 </td>
				<td> 
					APP后台处理结果：<br />
					0表示APP后台处理成功，后台将根据ResultCode来判断是否继续处理加好友逻辑；<br />
					非0表示APP后台处理失败，云通信后台将不判断ResultCode，正常处理加好友逻辑。<br />
				</td>
			</tr>
			<tr>
				<td> ErrorInfo </td>
				<td> String </td>
				<td> 必填 </td>
				<td> APP后台处理失败时返回给云通信后台的错误信息。</td>
			</tr>
			<tr>
				<td> ResultItem </td>
				<td> Array </td>
				<td> 必填 </td>
				<td> APP后台处理结果的对象数组。</td>
			</tr>
			<tr>
				<td> To_Account </td>
				<td> String </td>
				<td> 必填 </td>
				<td> From_Account请求添加为好友的账号。</td>
			</tr>
			<tr>
				<td> ResultCode </td>
				<td> Integer </td>
				<td> 必填 </td>
				<td>
					错误码信息：<br />
					1、0表示允许添加，非0值表示不允许发起添加好友请求；<br />
					2、非0类型的错误码的合理取值范围是：【38000,39000】。<br />
				</td>
			</tr>
			<tr>
				<td> ResultInfo </td>
				<td> String </td>
				<td> 必填 </td>
				<td> 不允许发起添加好友请求的原因。</td>
			</tr>
		</tbody>
	</table>

## 6 参考 

1、<a href="https://cloud.tencent.com/document/product/269/1522">第三方回调简介</a>；
2、<a href="https://cloud.tencent.com/document/product/269/1643">添加好友</a>。
