
## 1 功能说明 

APP后台可以通过该回调实时监控用户的c2c消息，包括：
1. 对c2c消息进行实时记录（例如记录日志，或者同步到其他系统）；
2. 拦截用户的c2c发言请求；
3. 修改用户发言内容（例如敏感词过滤，或者增加一些APP自定义信息）。
 
## 2 注意事项 

1. 要启用回调，必须配置回调URL，并打开本条回调协议对应的开关，配置方法详见[第三方回调配置](/doc/product/269/第三方回调简介#6-.E5.9B.9E.E8.B0.83.E9.85.8D.E7.BD.AE)；
2. 回调的方向是：云通讯后台向APP后台发起HTTP POST请求；
3. APP后台在收到回调请求之后，务必校验请求URL中的参数SdkAppid是否是自己的SdkAppid；
4. 若同时开启发单聊消息之前和之后两种回调，且发单聊消息之前回调返回禁止发言，则发单聊消息之后回调将不会被触发；
5. 若同时开启发单聊消息之前和之后两种回调，且发单聊消息之前回调修改了消息体，则发单聊消息之后回调将使用修改过的消息进行回调；
6. 其他安全相关事宜请参考[第三方回调：安全考虑](/doc/product/269/第三方回调简介#4-.E5.AE.89.E5.85.A8.E8.80.83.E8.99.91)。
 
## 3 可能触发该回调的场景 

1. APP用户通过客户端发送c2c消息；
2. APP管理员通过REST API发送c2c消息。
 
## 4 回调发生时机 

云通信后台收到用户发送的c2c消息之后、将该消息下发给目标用户之前。 

## 5 接口说明 

### 5.1 请求URL 

```
https://www.example.com/SdkAppid=$SdkAppid&CallbackCommand=$CallbackCommand&contenttype=json&ClientIP=$ClientIP&OptPlatform=$OptPlatform
```
此处假定APP配置的回调URL为`https://www.example.com` 。

### 5.2 请求参数 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					参数<br />
				</td>
				<td style="background-color:#CCCCCC;">
					含义<br />
				</td>
			</tr>
			<tr>
				<td>
					SdkAppid<br />
				</td>
				<td>
					APP在云通讯申请的Appid。
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					固定为：C2C.CallbackBeforeSendMsg。<br />
				</td>
			</tr>
			<tr>
				<td>
					contenttype<br />
				</td>
				<td>
					固定为：json。<br />
				</td>
			</tr>
			<tr>
				<td>
					ClientIP<br />
				</td>
				<td>
					客户端IP地址。<br />
				</td>
			</tr>
			<tr>
				<td>
					OptPlatform<br />
				</td>
				<td>
					客户端平台。取值参见<a href="/doc/product/269/第三方回调简介#3-.E5.9B.9E.E8.B0.83.E5.8D.8F.E8.AE.AE">回调协议</a>中OptPlatform的参数含义。<br />
				</td>
			</tr>
		</tbody>
	</table>
	
### 5.3 HTTP请求方式 

POST 

### 5.4 HTTP请求包体格式 

JSON 

### 5.5 回调请求包体示例
注意，回调请求包体位于HTTP POST请求的Body中 

```
{
    "CallbackCommand": "C2C.CallbackBeforeSendMsg",  // 回调命令
    "From_Account": "jared",  // 发送者
    "To_Account": "Jonh",  // 接收者
    "MsgBody": [  // 消息体，参见TIMMessage消息对象
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        }
    ]
}
```

### 5.6 回调请求包体字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					String
				</td>
				<td>
					回调命令。<br />
				</td>
			</tr>
			<tr>
				<td>
					From_Account
				</td>
				<td>
					String
				</td>
				<td>
					消息发送者ID。
				</td>
			</tr>
			<tr>
				<td>
					To_Account
				</td>
				<td>
					String
				</td>
				<td>
					消息接收者ID。
				</td>
			</tr>
			<tr>
				<td>
					MsgBody<br />
				</td>
				<td>
					Array
				</td>
				<td>
					消息体，具体参见<a href="/doc/product/269/消息格式描述">消息格式描述</a>。注意，当前仅支持文本、表情、文件、位置和自定义消息体回调。
				</td>
			</tr>
		</tbody>
	</table>
	
### 5.7 回调应答包示例（允许发言）
 
允许用户发言，同时也不修改即将下发的消息的内容。

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0 // 0为允许发言
}
```

### 5.8 回调应答包示例（禁止发言）
 
不允许用户发言，该消息将不会下发，同时给调用方返回错误码：20006。

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 1 // 1为拒绝发言
}
```

### 5.9 回调应答包示例（修改消息内容）
 
如下的应答示例为：对用户发送的c2c消息进行了修改（增加了自定义消息）。云通信后台将会下发经过修改之后的消息。 
APP后台可以基于这一特性在用户发送的消息中增加一些特殊内容，比如用户等级、头衔等信息。 

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0, // 必须为0，只有这样，修改之后的消息才能正常下发
    "MsgBody": [ // APP修改之后的消息，如果没有，则默认使用用户发送的消息
        {
            "MsgType": "TIMTextElem",// 文本
            "MsgContent": {
                "Text": "red packet"
            }
        },
        {
            "MsgType": "TIMCustomElem",// 自定义消息
            "MsgContent": {
                "Desc": " CustomElement.MemberLevel ",// 描述
                "Data": " LV1"// 数据
            }
        }
    ]
}
```

### 5.10 回调应答包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					属性
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					ActionStatus<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					请求处理的结果，OK表示处理成功，FAIL表示失败。
				</td>
			</tr>
			<tr>
				<td>
					ErrorCode<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					必填
				</td>
				<td>
					错误码，0为允许发言；1为拒绝发言。若业务希望拒绝发言的同时，将错误码ErrorCode和ErrorInfo传递至客户端，请将错误码ErrorCode设置在[120001, 130000]区间内。
				</td>
			</tr>
			<tr>
				<td>
					ErrorInfo<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					错误信息。
				</td>
			</tr>
			<tr>
				<td>
					MsgBody<br />
				</td>
				<td>
					Array<br />
				</td>
				<td>
					选填
				</td>
				<td>
					经过APP修改之后的消息体，云通讯后台将把修改后的消息发送给好友，具体格式参见<a href="/doc/product/269/消息格式描述">消息格式描述</a>。
				</td>
			</tr>
		</tbody>
	</table>
	
## 6 参考 

[第三方回调简介](/doc/product/269/第三方回调简介)；
REST API： [单发单聊消息](/doc/product/269/单发单聊消息)，[批量发单聊消息](/doc/product/269/批量发单聊消息)；
[发单聊消息之后回调](/doc/product/269/发单聊消息之后回调)。
