## 1 第三方回调简介 

为方便第三方APP精细化控制APP的功能形态，腾讯云为第三方提供了完全免费且强大的回调能力。所谓回调，即腾讯云会在某一事件发生之前或者之后，向APP的后台服务器发送请求，APP后台可以据此进行必要的数据同步，或者干预事件的后续处理流程。

例如，APP可以开启群发消息回调，腾讯云后台会在下发该消息之前回调第三方服务器，并根据回调结果决定该消息是否应当下发。APP不仅可以基于该回调来实现消息同步，而且可以进行发消息安全打击。其业务流程如下图所示：
 ![](//mccdn.qcloud.com/static/img/3708a8d1c1397cfb112c78ef9125fb24/image.png)

## 2 回调分类 

从功能角度来看，回调可以分为如下四大类：
1. 单发消息回调；
1. 群组相关回调；
1. 用户资料相关回调；
1. 关系链相关回调；
1. 状态变更回调。

从腾讯云对回调结果的处理角度来看，回调可以分为两大类：
1. 事件发生之前回调：回调的主要目的在于让第三方APP后台可以干预该事件的处理逻辑，腾讯云会根据回调返回码确定后续处理流程（例如发送群消息之前回调）；
1. 事件发生之后通知：回调的主要目的在于让第三方APP实现必要的数据同步，腾讯云忽略回调返回码（例如群组成员退群之后通知）。
 
## 3 回调协议 

第三方回调基于HTTP/HTTPS协议，APP服务器需要向腾讯云提供回调URL，腾讯云使用POST请求的方式来向APP服务器发起回调请求。 
腾讯云在发起回调时，会在APP提供的URL之后增加如下几个参数： 


| 参数名称 | 参数含义 |
|---------|---------|
|  功能说明  | APP在云通信中分配到的ID。 | 
|  CallbackCommand  | 回调命令字。 | 
|  contenttype  | 固定为json。 | 
|  ClientIP  | 客户端IP地址。 | 
|  OptPlatform  | 客户端平台。对应不同的平台类型，可能的取值有：<br />	RESTAPI（使用REST API发送请求）、Web（使用Web SDK发送请求）、<br/>Android、iOS、Windows、Mac、Unkown（使用未知类型的设备发送请求）。 | 

具体的回调内容则会包含在HTTP请求包体中，参见回调示例。 

### 3.1 回调示例 

回调请求示例： 

```
POST /?SdkAppid=888888&CallbackCommand=Group.CallbackAfterNewMemberJoin&contenttype=json&ClientIP=$ClientIP&OptPlatform=$OptPlatform HTTP/1.1
Host: www.example.com
Content-Length: 337

{
    "CallbackCommand": "Group.CallbackAfterNewMemberJoin",
    "GroupId" : "@TGS#2J4SZEAEL",
    "Type": "Public",
    "JoinType": "Apply",
    "Operator_Account": "leckie",
    "NewMemberList": [
        {
            "Member_Account": "jared"
        },
        {
            "Member_Account": "tommy"
        }
    ]
}
```
回调应答示例： 

```
HTTP/1.1 200 OK
Server: nginx/1.7.10
Date: Fri, 09 Oct 2015 02:59:55 GMT
Content-Length: 75
 
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0
}
```

## 4 安全考虑 

腾讯云支持三种回调类型： 
1. HTTP回调；
1. HTTPS回调，APP服务器的webserver配置的是CA机构签发的证书或者是腾讯云免费签发的证书；
1. HTTPS双向认证回调，APP服务器的webserver配置的是CA机构签发的证书或者是腾讯云免费签发的证书，且启用双向认证能力。
 
三种方案的安全性逐步递增： 
1. HTTP回调存在两个缺陷：一是明文传输的数据容易被窃听，二是第三方APP无法判断回调请求是否真正来自于腾讯云；
1. 对于HTTPS回调，如果不启用双向认证，可以解决数据的加密问题，但依然无法确保回调的请求来源是腾讯云；
1. 只有HTTPS与双向认证结合，才能确保第三方回调的安全性。

因此我们强烈建议APP使用第三种方式实现回调，且腾讯云签发证书完全免费。
 
## 5 回调超时时间 

腾讯云回调APP后台服务器的超时时间为2秒，且没有重试。如果回调超时，后续处理逻辑与没有配置回调时相同（例如，假设“发送群消息之前回调”超时，消息会正常下发）。

为确保回调成功率，第三方APP应当尽可能加快回调处理速度，例如先发送回调应答，然后再处理具体业务逻辑。 

## 6 回调配置 

目前云通信控制台支持自助配置回调，包括配置回调URL以及启用哪些回调。配置方法参见[第三方回调接入指引](/doc/product/269/第三方回调接入指引)。 

**注意：** 

在控制台中自助配置的回调仅支持HTTP/HTTPS回调。如果您需要启用安全级别最强的HTTPS双向认证，需要： 
1. 在控制台中配置回调URL（必须为HTTPS域名）、回调开关；
1. 给腾讯云提需求工单，由云通信后台给APP签发双向认证所需的证书，所需要的资料包括： 
	1. sdkappid； 
	1. APP名称； 
	1. 回调URL（必须与控制台中自助配置的回调URL一致）； 
1. 拿到证书之后，依照如下两篇指引配置HTTPS双向认证： 
	1. [Apache配置HTTPS双向认证指南](/doc/product/269/Apache双向认证配置指南)； 
	1. [Nginx配置HTTPS双向认证指南](/doc/product/269/Nginx双向认证配置指南)。 
