## 1 功能说明 

APP后台可以通过该回调实时监控群成员加入的消息，包括： 
1. 通知APP后台有成员入群，APP可以据此进行必要的数据同步。 

## 2 注意事项 

1. 要启用回调，必须配置回调URL，并打开本条回调协议对应的开关，配置方法详见[第三方回调配置](/doc/product/269/第三方回调简介#6-.E5.9B.9E.E8.B0.83.E9.85.8D.E7.BD.AE)；
2. 回调的方向是：云通讯后台向APP后台发起HTTP POST请求；
3. APP后台在收到回调请求之后，务必校验请求URL中的参数SdkAppid是否是自己的SdkAppid；
4. 其他安全相关事宜请参考[第三方回调：安全考虑](/doc/product/269/第三方回调简介#4-.E5.AE.89.E5.85.A8.E8.80.83.E8.99.91)。
 
## 3 可能触发该回调的场景 

1. APP用户通过客户端主动申请加群并得到通过。
2. APP用户通过客户端拉其他人入群成功。
3. APP管理员通过REST API添加用户到群组。
 
## 4 回调发生时机 

用户主动申请加群并得到通过，或者被其他用户邀请入群之后，APP管理员通过REST API添加群成员。 

## 5 接口说明 

### 5.1 请求URL 
```
https://www.example.com/SdkAppid=$SdkAppid&CallbackCommand=$CallbackCommand&contenttype=json&ClientIP=$ClientIP&OptPlatform=$OptPlatform
```
此处假定APP配置的回调URL为`https://www.example.com`。 

### 5.2 请求参数 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					参数<br />
				</td>
				<td style="background-color:#CCCCCC;">
					含义<br />
				</td>
			</tr>
			<tr>
				<td>
					SdkAppid<br />
				</td>
				<td>
					APP在云通讯申请的Appid。
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					固定为：Group.CallbackAfterNewMemberJoin  。<br />
				</td>
			</tr>
			<tr>
				<td>
					contenttype<br />
				</td>
				<td>
					固定为：json。<br />
				</td>
			</tr>
			<tr>
				<td>
					ClientIP<br />
				</td>
				<td>
					客户端IP地址。<br />
				</td>
			</tr>
			<tr>
				<td>
					OptPlatform<br />
				</td>
				<td>
				  客户端平台。取值参见<a href="/doc/product/269/第三方回调简介#3-.E5.9B.9E.E8.B0.83.E5.8D.8F.E8.AE.AE">回调协议</a>中OptPlatform的参数含义。
				</td>
			</tr>
		</tbody>
	</table>

### 5.3 HTTP请求方式 

POST 

### 5.4 HTTP请求包体格式 

JSON 

### 5.5 回调请求包示例 

```
{
    "CallbackCommand": "Group.CallbackAfterNewMemberJoin", // 回调命令
    "GroupId" : "@TGS#2J4SZEAEL",
    "Type": "Public", // 群组类型
    "JoinType": "Apply", // 入群方式：Apply（申请入群）；Invited（邀请入群）。
    "Operator_Account": "leckie", // 操作者成员
    "NewMemberList": [ // 新入群成员列表
        {
            "Member_Account": "jared"
        },
        {
            "Member_Account": "tommy"
        }
    ]
}
```

### 5.6 回调请求包字段说明

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					String
				</td>
				<td>
					回调命令。<br />
				</td>
			</tr>
			<tr>
				<td>
					GroupId<br />
				</td>
				<td>
					String
				</td>
				<td>
					要将其他用户拉入的群组ID。
				</td>
			</tr>
			<tr>
				<td>
					Type<br />
				</td>
				<td>
					String
				</td>
				<td>
					请求创建的<a href="/doc/product/269/%E7%BE%A4%E7%BB%84%E7%B3%BB%E7%BB%9F#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D">群组类型</a>，例如Private，Public和ChatRoom。
				</td>
			</tr>
			<tr>
				<td>
					JoinType<br />
				</td>
				<td>
					String
				</td>
				<td>
					入群方式：Apply（申请入群）；Invited（邀请入群）。<br />
				</td>
			</tr>
			<tr>
				<td>
					Operator_Account<br />
				</td>
				<td>
					String
				</td>
				<td>
					请求的操作者ID。
				</td>
			</tr>
			<tr>
				<td>
					NewMemberList<br />
				</td>
				<td>
					Array
				</td>
				<td>
					新入群成员ID集合。
				</td>
			</tr>
		</tbody>
	</table>

### 5.7 回调应答包示例
 
APP后台同步数据后，返回应答包。 

```
{
    "ActionStatus": "OK", 
    "ErrorInfo": "", 
    "ErrorCode": 0  // 忽略应答结果
}
```

### 5.8 应答包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					属性
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					ActionStatus<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					请求处理的结果，OK表示处理成功，FAIL表示失败。
				</td>
			</tr>
			<tr>
				<td>
					ErrorCode<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					必填
				</td>
				<td>
					错误码，0表示允许忽略应答结果。 
				</td>
			</tr>
			<tr>
				<td>
					ErrorInfo<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					错误信息。
				</td>
			</tr>
		</tbody>
	</table>
	
## 6 参考 

[第三方回调简介](/doc/product/269/第三方回调简介)；
 REST API：[增加群组成员](/doc/product/269/增加群组成员)。


