## 1 功能说明 

APP后台可以通过该回调实时监控用户的群发消息，包括：
1. 对群消息进行实时记录（例如记录日志，或者同步到其他系统）； 
2. 拦截用户在群内发言的请求；
3. 修改用户发言内容（例如敏感词过滤，或者增加一些APP自定义信息）。 

## 2 注意事项 

1. 要启用回调，必须配置回调URL，并打开本条回调协议对应的开关，配置方法详见[第三方回调配置](/doc/product/269/第三方回调简介#6-.E5.9B.9E.E8.B0.83.E9.85.8D.E7.BD.AE)；
2. 回调的方向是：云通讯后台向APP后台发起HTTP POST请求；
3. APP后台在收到回调请求之后，务必校验请求URL中的参数SdkAppid是否是自己的SdkAppid；
4. 其他安全相关事宜请参考[第三方回调：安全考虑](/doc/product/269/第三方回调简介#4-.E5.AE.89.E5.85.A8.E8.80.83.E8.99.91)。
 
## 3 可能触发该回调的场景 

1. APP用户通过客户端发送群消息；
2. APP管理员通过REST API发送群组消息。 
 
## 4 回调发生时机 

云通信后台收到用户发送的群发消息之后、将该消息下发给群成员之前。 

## 5 接口说明 

### 5.1 请求URL 
```
https://www.example.com/SdkAppid=$SdkAppid&CallbackCommand=$CallbackCommand&contenttype=json&ClientIP=$ClientIP&OptPlatform=$OptPlatform
```
此处假定APP配置的回调URL为`https://www.example.com`。

### 5.2 请求参数 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					参数<br />
				</td>
				<td style="background-color:#CCCCCC;">
					含义<br />
				</td>
			</tr>
			<tr>
				<td>
					SdkAppid<br />
				</td>
				<td>
					APP在云通讯申请的Appid。
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					固定为：Group.CallbackBeforeSendMsg。<br />
				</td>
			</tr>
			<tr>
				<td>
					contenttype<br />
				</td>
				<td>
					固定为：json。<br />
				</td>
			</tr>
			<tr>
				<td>
					ClientIP<br />
				</td>
				<td>
					客户端IP地址。<br />
				</td>
			</tr>
			<tr>
				<td>
					OptPlatform<br />
				</td>
				<td>
				  客户端平台。取值参见<a href="/doc/product/269/第三方回调简介#3-.E5.9B.9E.E8.B0.83.E5.8D.8F.E8.AE.AE">回调协议</a>中OptPlatform的参数含义。
				</td>
			</tr>
		</tbody>
	</table>

### 5.3 HTTP请求方式 

POST 

### 5.4 HTTP请求包体格式 

JSON 

### 5.5 回调请求包示例 

```
{
    "CallbackCommand": "Group.CallbackBeforeSendMsg",  // 回调命令
    "GroupId": "@TGS#2J4SZEAEL",  // 群组ID
    "Type": "Public",  // 群组类型
    "From_Account": "jared",  // 发送者
    "Operator_Account":"admin", //请求的发起者
    "Random": 123456,  // 随机数
    "MsgBody": [  // 消息体，参见TIMMessage消息对象
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        }
    ]
}
```

### 5.6 回调请求包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					String
				</td>
				<td>
					回调命令。<br />
				</td>
			</tr>
			<tr>
				<td>
					GroupId<br />
				</td>
				<td>
					String
				</td>
				<td>
					产生群消息的群组ID。
				</td>
			</tr>
			<tr>
				<td>
					Type<br />
				</td>
				<td>
					String
				</td>
				<td>
					产生群消息的<a href="/doc/product/269/%E7%BE%A4%E7%BB%84%E7%B3%BB%E7%BB%9F#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D">群组类型</a>，例如Private，Public和ChatRoom。
				</td>
			</tr>
			<tr>
				<td>
					From_Account<br />
				</td>
				<td>
					String
				</td>
				<td>
					消息发送者ID。
				</td>
			</tr>
			<tr>
				<td>
					Operator_Account<br />
				</td>
				<td>
					String
				</td>
				<td>
					请求发起者ID，可以用来识别是否为管理员请求的。
				</td>
			</tr>
			<tr>
				<td>
					Random<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					发消息请求中的32位随机数。
				</td>
			</tr>
			<tr>
				<td>
					MsgBody<br />
				</td>
				<td>
					Array
				</td>
				<td>
				消息体，具体参见<a href="/doc/product/269/消息格式描述">消息格式描述</a>。
				</td>
			</tr>
		</tbody>
	</table>

### 5.7 回调应答包示例

#### 5.7.1 允许发言
 
允许用户发言，同时也不修改即将下发的消息的内容。 

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0  // 0为允许发言
}
```

#### 5.7.2 禁止发言

不允许用户发言，该消息将不会下发，同时给调用方返回错误码：10016。
```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 1  // 1为拒绝发言
}
```

#### 5.7.3 静默丢弃

不允许用户发言，该消息将不会下发，但会给调用方返回成功，使调用方以为消息已经发出。
```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 2  // 2为静默丢弃
}
```
#### 5.7.4 修改消息内容
 
如下的应答示例为：对用户发送的群消息进行了修改（增加了自定义消息）。云通信后台将会下发经过修改之后的消息。 
APP后台可以基于这一特性在用户发送的消息中增加一些特殊内容，比如用户等级、头衔等信息。 

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0, // 必须为0，只有这样，修改之后的消息才能正常下发
    "MsgBody": [ // APP修改之后的消息，如果没有，则默认使用用户发送的消息
        {
            "MsgType": "TIMTextElem",// 文本
            "MsgContent": {
                "Text": "red packet"
            }
        },
        {
            "MsgType": "TIMCustomElem",// 自定义消息
            "MsgContent": {
                "Desc": "CustomElement.MemberLevel",// 描述
                "Data": "LV1"// 数据
            }
        }
    ]
}
```

### 5.8 应答包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					属性
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					ActionStatus<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					请求处理的结果，OK表示处理成功，FAIL表示失败。
				</td>
			</tr>
			<tr>
				<td>
					ErrorCode<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					必填
				</td>
				<td>
				错误码，0为允许发言；1为拒绝发言；2为静默丢弃。 
				</td>
			</tr>
			<tr>
				<td>
					ErrorInfo<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					错误信息。
				</td>
			</tr>
			<tr>
				<td>
					MsgBody<br />
				</td>
				<td>
					Array
				</td>
				<td>
					选填
				</td>
				<td>
					经过APP修改之后的消息体，云通讯后台将把修改后的消息发送到群组中，具体格式参见<a href="/doc/product/269/消息格式描述">消息格式描述</a>。
				</td>
			</tr>
		</tbody>
	</table>
	
## 6 参考 

[第三方回调简介](/doc/product/269/第三方回调简介)；
REST API：[在群组中发送普通消息](/doc/product/269/在群组中发送普通消息)。
 


