## 1 功能说明 

APP后台可以通过该回调实时监控用户的群发消息，包括：
1.  通知APP后台有群组消息发送成功，APP可以据此进行必要的数据同步。

## 2 注意事项 

1. 要启用回调，必须配置回调URL，并打开本条回调协议对应的开关，配置方法详见[第三方回调配置](/doc/product/269/第三方回调简介#6-.E5.9B.9E.E8.B0.83.E9.85.8D.E7.BD.AE)；
2. 回调的方向是：云通讯后台向APP后台发起HTTP POST请求；
3. APP后台在收到回调请求之后，务必校验请求URL中的参数SdkAppid是否是自己的SdkAppid；
4. 其他安全相关事宜请参考[第三方回调：安全考虑](/doc/product/269/第三方回调简介#4-.E5.AE.89.E5.85.A8.E8.80.83.E8.99.91)。
 
## 3 可能触发该回调的场景 

1. APP用户通过客户端发送群消息；
2. APP管理员通过REST API发送群组消息。 
 
## 4 回调发生时机 

群组消息发送成功之后。 

## 5 接口说明 

### 5.1 请求URL 
```
https://www.example.com/SdkAppid=$SdkAppid&CallbackCommand=$CallbackCommand&contenttype=json&ClientIP=$ClientIP&OptPlatform=$OptPlatfor
```
此处假定APP配置的回调URL为`https://www.example.com`。

### 5.2 请求参数 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					参数<br />
				</td>
				<td style="background-color:#CCCCCC;">
					含义<br />
				</td>
			</tr>
			<tr>
				<td>
					SdkAppid<br />
				</td>
				<td>
					APP在云通讯申请的Appid。
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					固定为：Group.CallbackAfterSendMsg。<br />
				</td>
			</tr>
			<tr>
				<td>
					contenttype<br />
				</td>
				<td>
					固定为：json。<br />
				</td>
			</tr>
			<tr>
				<td>
					ClientIP<br />
				</td>
				<td>
					客户端IP地址。<br />
				</td>
			</tr>
			<tr>
				<td>
					OptPlatform<br />
				</td>
				<td>
				  客户端平台。取值参见<a href="/doc/product/269/第三方回调简介#3-.E5.9B.9E.E8.B0.83.E5.8D.8F.E8.AE.AE">回调协议</a>中OptPlatform的参数含义。
				</td>
			</tr>
		</tbody>
	</table>

### 5.3 HTTP请求方式 

POST 

### 5.4 HTTP请求包体格式 

JSON 

### 5.5 回调请求包示例 

```
{
    "CallbackCommand": "Group.CallbackAfterSendMsg",  // 回调命令
    "GroupId": "@TGS#2J4SZEAEL",  // 群组ID
    "Type": "Public",  // 群组类型
    "From_Account": "jared",  // 发送者
	"MsgSeq": 123, //消息的序列号
	"MsgTime": 1490686222,  //消息的时间
    "MsgBody": [  // 消息体，参见TIMMessage消息对象
        {
            "MsgType": "TIMTextElem", // 文本
            "MsgContent": {
                "Text": "red packet"
            }
        }
    ]
}
```

### 5.6 回调请求包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					CallbackCommand<br />
				</td>
				<td>
					String
				</td>
				<td>
					回调命令。<br />
				</td>
			</tr>
			<tr>
				<td>
					GroupId<br />
				</td>
				<td>
					String
				</td>
				<td>
					产生群消息的群组ID。
				</td>
			</tr>
			<tr>
				<td>
					Type<br />
				</td>
				<td>
					String
				</td>
				<td>
					产生群消息的<a href="/doc/product/269/%E7%BE%A4%E7%BB%84%E7%B3%BB%E7%BB%9F#2-.E7.BE.A4.E7.BB.84.E5.BD.A2.E6.80.81.E4.BB.8B.E7.BB.8D">群组类型</a>，例如Private，Public和ChatRoom。
				</td>
			</tr>
			<tr>
				<td>
					From_Account<br />
				</td>
				<td>
					String
				</td>
				<td>
					消息发送者ID。
				</td>
			</tr>
			<tr>
				<td>
					MsgTime<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					消息发送的时间戳，对应后台Server时间。
				</td>
			</tr>
			<tr>
				<td>
					MsgSeq<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					消息序列号，唯一标示一条消息。
				</td>
			</tr>
			<tr>
				<td>
					MsgBody<br />
				</td>
				<td>
					Array
				</td>
				<td>
				消息体，具体参见<a href="/doc/product/269/消息格式描述">消息格式描述</a>。
				</td>
			</tr>
		</tbody>
	</table>
	

### 5.7 回调应答包示例
 
APP后台同步数据后，发送回调应答包。

```
{
    "ActionStatus": "OK",
    "ErrorInfo": "",
    "ErrorCode": 0 // 忽略回调结果
}
```

### 5.8 应答包字段说明 

<table style="width:100%;" >
		<tbody>
			<tr>
				<td style="width:25%;background-color:#CCCCCC;">
					字段
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					类型
				</td>
				<td style="width:5%;background-color:#CCCCCC;">
					属性
				</td>
				<td style="background-color:#CCCCCC;">
					说明
				</td>
			</tr>
			<tr>
				<td>
					ActionStatus<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					请求处理的结果，OK表示处理成功，FAIL表示失败。
				</td>
			</tr>
			<tr>
				<td>
					ErrorCode<br />
				</td>
				<td>
					Integer
				</td>
				<td>
					必填
				</td>
				<td>
				错误码，此处填0表示忽略应答结果。 
				</td>
			</tr>
			<tr>
				<td>
					ErrorInfo<br />
				</td>
				<td>
					String
				</td>
				<td>
					必填
				</td>
				<td>
					错误信息。
				</td>
			</tr>
		</tbody>
	</table>
	
## 6 参考 

[第三方回调简介](/doc/product/269/第三方回调简介)；
REST API：[在群组中发送普通消息](/doc/product/269/在群组中发送普通消息)。
 


