[微信小程序](http://mp.weixin.qq.com/wiki?t=resource/res_main&id=mp1474632113_xQVCl&token=&lang=zh_CN) 提供了一套在微信上运行小程序的解决方案，有比较完整的框架、组件以及 API，开发者在这个平台上有很大的创作空间。

微信对 WebSocket 特性的支持可以让开发者实现一些实时同步或者协作的小程序。本示例利用 WebSocket 协议，开发了一个简单的剪刀石头布游戏，为想要在小程序中使用 WebSocket 的开发者提供参考。通过示例用户可以快速了解 WebSocket 长连接的使用方法和应用场景。

游戏的规则非常简单：连接到服务器后自动匹配在线玩家（没有则分配一个机器人），然后两人进行剪刀石头布的对抗游戏。当对方进行拳头选择的时候，头像会旋转，这个过程使用 WebSocket 会变得简单快速。

以下是游戏运行截图：

![剪刀石头布小游戏截图](https://mc.qcloudimg.com/static/img/1d4772272b20760b8063356069328be9/1.gif)


## 整体架构

小程序的架构中包含两条网络同步：对于常规请求，会走 HTTPS 通路；对于 WebSocket 请求，会先走 HTTPS 后再切换协议到 WebSocket 的 TCP 连接，从而实现全双工通信。

![整体架构](https://mc.qcloudimg.com/static/img/6cfe55ed5c1aa3650efd2e4913ee33cf/2.jpg)

## 1. 准备域名和证书

在微信小程序中，所有的网络请求受到严格限制，不满足条件的域名和协议无法请求，具体包括：

1. 只允许和在 MP 中配置好的域名进行通信，如果还没有域名，需要 [注册域名](https://cloud.tencent.com/product/dm.html?utm_source=jiaocheng&utm_medium=domain2&utm_ca)。
2. 网络请求必须走 HTTPS 协议，所以需要为注册的域名 [申请证书](https://console.cloud.ten1cent.com/ssl?utm_source=jiaocheng&utm_medium=ssl2&utm_campaign=qcloud)。

域名注册好之后，登录 [微信公众平台](https://mp.weixin.qq.com/) 配置通信域名。

![配置通信域名](https://mc.qcloudimg.com/static/img/8be69d06928a2b9888c60e6b2cf20ac3/3.jpg)

## 2. 云主机和镜像部署

剪刀石头布的服务器运行代码和配置已经打包成腾讯云 CVM 镜像，推荐直接 [购买使用](https://buy.cloud.tencent.com/cvm?marketImgId=371&utm_source=jiaocheng&utm_medium=cvm2&utm_campaign=qcloud)。

> 腾讯云用户可以 [领取礼包](https://cloud.tencent.com/act/event/yingyonghao.html#section-voucher)，体验腾讯云小程序解决方案。

![选择服务市场镜像](https://mc.qcloudimg.com/static/img/99abf95520936341c20f2b7e8bbf2c7a/4.jpg)

镜像部署完成之后，云主机上即运行有 WebSocket 服务的基本环境、代码和配置。

> 镜像已包含所有小程序的服务器环境与代码，其它小程序无需重复部署

## 3. 配置 HTTPS

镜像中已经部署了 nginx，需要在 `/etc/nginx/conf.d` 下修改配置中的域名、证书、私钥。

![证书 Nginx 配置](https://mc.qcloudimg.com/static/img/afdf12da547a4c29588184778955448d/5.jpg)

配置完成后，即可启动 nginx。

```
nginx
```

## 4. 域名解析

完成上述步骤后，添加域名记录解析到腾讯云服务器上，即可以使用域名进行 HTTPS 服务。

在腾讯云注册的域名，可以直接使用 [云解析控制台](https://console.cloud.tencent.com/cns/domains?utm_source=jiaocheng&utm_medium=cns&utm_campaign=qcloud) 添加主机记录，选择上面购买的 CVM 按下图所示进行配置：

![添加域名解析](https://mc.qcloudimg.com/static/img/27c84b21a0600f2d1c4c3ec1efb0f927/6.jpg)

解析生效后，在浏览器使用域名即可进行 HTTPS 访问。

![HTTPS 访问效果图](https://mc.qcloudimg.com/static/img/c6127cb39de915ac3692762ee8fb45c0/7.jpg)

## 5. 启动 WebSocket 服务

在镜像的 nginx 配置中（`/etc/nginx/conf.d`），已经把 `/applet/websocket` 的请求转发到 `http://127.0.0.1:9595` 处理。用户需要把 Node 实现的 WebSocket 服务在这个端口里运行起来。

进入镜像中源码位置：
```
cd /data/release/qcloud-applet-websocket
```

使用 pm2 启动服务：

```
pm2 start process.json
```

![启动效果](https://mc.qcloudimg.com/static/img/1426a72c0b9777c3fb4eb4664c51ffa6/8.jpg)

## 6. 启动微信小程序

在微信开发者工具中修改小程序源码中的 `config.js` 配置，把通讯域名修改成上面申请的域名。完成后点击调试即可连接到 WebSocket 服务进行游戏。

![修改通信域名](https://mc.qcloudimg.com/static/img/ba5267a54490c35ef28650a9ddb02983/9.jpg)

配置完成后，运行小程序就可以看到成功搭建的提示：

![成功搭建微信小程序](https://mc.qcloudimg.com/static/img/c013d7fdafe335762ac01e412f95cd2a/10.jpg)


如需了解剪刀石头布小程序的消息类型、服务器逻辑设计等更多实现细节，请参阅 [WebSocket 长连接应用场景](https://cloud.tencent.com/document/product/448/6405)。
