## WeCOS 是什么

WeCOS 是一个本地命令行工具（也提供 npm 包），主要用于帮助开发者解决小程序包超过大小限制的问题。WeCOS 不仅支持自动将小程序项目的图片资源上传到配置好的腾讯云对象存储服务(COS)上存储，同时，还可以自动替换项目代码中本地资源引用地址为线上URL，并移除项目目录中的图片资源。为小程序项目包瘦身，一键解决项目包超过1MB的烦恼。


## 开始使用
我们有一个开发好的小程序开发目录`app`，目录大小为10M。目录下有大量图片且代码中有对图片资源的引用。为了能够上传并正常运行项目代码，下面来示范如何使用腾讯云 WeCOS 来解决项目包过大的问题。项目目录如图。

![](//mc.qcloudimg.com/static/img/f2bebc7017b00ca6591adc3a0c36446c/image.png)


## 根据 WeCOS 使用指引，只需三步

### 1.前期准备

注册腾讯云账号，开通 COS 并创建 Bucket。

下载 WeCOS：
- [从 github 访问 >>](https://github.com/tencentyun/wecos)
- [ 点击下载 >>](https://mc.qcloudimg.com/static/archive/131829048f153be9c589a8704552e7f7/wecos-master.zip)

在本机上安装 `Node.js` 的环境。


### 2.安装 WeCOS 并修改配置文件

在命令行中使用 `node.js` 自带的 npm 工具，输入`npm install wecos -g`，等待完成安装。`-g` 表示全局安装，这样才能全局调用 WeCOS 命令，安装如图。

![](//mc.qcloudimg.com/static/img/737d7f3db63fff3c12aa50efd4b0a12c/image.png)

根据指引，在与开发目录` app` 同目录下创建一个 `wecos.config.json` 配置文件，在配置里填写基本的配置信息。

![](//mc.qcloudimg.com/static/img/27936145d4b83b55988e0aeffd391300/image.png)
 
`wecos.config.json` 里填写了最基本的配置项。
其中，
- `appDir` 指定了小程序开发目录。
- `appid` 为腾讯云账号的appid。
- `bucketname` 是为存储图片创建的 bucket 的名称，这里是名为 `weixintest` 的 bucket。
- `folder` 可以指定到 bucket 下的某个目录，本文指定到 /wxtest 目录下。
- `region` 是指定上传到 COS 的指定地区，这里指定为 `tj` ，即天津。目前COS 支持天津、上海、广州。
- `secret_key`、`secret_id`是账户密钥，用户可以自行到腾讯云 COS 控制台上获取。

以上信息指定了开发目录以及图片要上传到的 COS 的地址，完成这些配置，基本上已经完工。

![](//mc.qcloudimg.com/static/img/16d2809c1c11bf5c9a9b7c8338b8dc5f/image.png)




###  3.运行程序

最后，在命令行中执行 `wecos` 命令。


![](//mc.qcloudimg.com/static/img/131b2ac9b87de97b2ee81824fef868d2/image.png)

可以看到，命令行显示项目中的三个图片上传成功。翻看项目目录，发现图片已经被删除，代码中的图片引用也被换成了线上的地址，项目包一下子小了。同时，WeCOS 很贴心的在开发项目外生成了个 `wecos_backup` 目录，来保存原来的图片作为备份。除此之外，WeCOS 默认启用监听模式，这是为了让开发过程中无感知，当我们不再进行项目开发，停止运行 WeCOS 即可。
 
![](//mc.qcloudimg.com/static/img/cc5632b2a7d54985545311bc54fc6b0b/image.png)

被处理后的整个项目目录只剩下不到5KB，用微信小程序开发者工具预览小程序发现除了图片部分的更改，其他部分跟处理之前没有什么差别。此时，可以重新上传我们的小程序代码，代码很顺利的上传成功了。

![](//mc.qcloudimg.com/static/img/0c44aea7150eac564a0c98798818e877/image.png)


## WeCOS 高级配置

除了基础配置之外，WeCOS 还提供一些个性化的高级配置（说是高级配置，使用起来其实也是十分简便）。

### 设置图片后缀

有些时候，我们需要限制上传图片的格式，例如只允许 jpg 格式，可以通过WeCOS提供的图片后缀配置项来定义
WeCOS默认支持 jpg,png,gif 三种格式，假如还需要添加其他格式，例如 webp，可以在该配置项中添加
"uploadFileSuffix": [".jpg",".png",".gif",".webp"]


### 设置图片黑名单

开发过程中，某些特定的图片我们不希望被上传，可以通过 WeCOS 的黑名单配置来解决这个问题，配置后上传程序会自动忽略掉这些图片
黑名单配置支持目录或具体到文件名的写法
  "uploadFileBlackList": ["./images/logo.png","./logo/"]


### 自定义域名

如果希望 COS 文件链接使用自定义的域名，可以配置 `targetHost` 代替默认域名，可以省略：http://：
  "targetHost": "`http://example.com`"
如果代码中的图片链接想换一个域名，可以配置 replaceHost targetHost 来实现。
  "replaceHost": "`http://wx-12345678.myqcloud.com`",
  "targetHost": "`https://example.com`"

### 开启图片压缩

图片上传到 COS 之后虽然大大减轻了程序包的大小，但如果图片自身体积过大，访问速度也会影响到用户体验
WeCOS还额外提供了基于腾讯云万象优图的图片压缩功能。首先，需要在万象优图控制台创建 COS 的同名 bucket。然后，开启该选项，资源将被压缩后上传（注：如果图片已经小到一定程度，压缩后大小可能不会变化）
 "compress": true


### 设置实时监听

WeCOS默认实时监听项目目录变化，自动处理图片资源，在开发过程中，如果觉得实时监听不方便，或者只需要一次性处理就停止，可以修改该配置，程序将只会执行一次后退出
  "watch": false


