![](https://mc.qcloudimg.com/static/img/06d3b1a6be4d9798286256ce2ecebbed/poly.png)

整个策略的语法结构如上图所示。

	
策略(policy)由版本(version)和语句(statement)构成，还可以包含委托人(principal)信息，委托人仅限于策略管理API中策略语法相关的参数中使用。语句(statement)是由若干个子语句构成。每条子语句包括操作(action)、资源(resource)、生效条件(condition)以及效力(effect)这四个元素，其中condition是非必填项。
	
### 1.JSON格式
	
策略语法是以 JSON 格式为基础。创建或更新的策略不满足JSON格式时，无法提交成功，用户必须要确保 JSON 格式正确。JSON格式标准在 RFC 7159 中定义。您也可以使用在线 JSON 验证程序检查策略格式。
    
### 2.语法约定
    
语法描述中有如下约定：
    
1) 以下字符是包含在策略语法中的json字符：

 { } [ ] " , :
    
2) 以下字符是用于描述策略语法中的特殊字符，不包含在策略中： 

 = < > ( ) |
   
3) 当一个元素允许多个值时，使用逗号分隔符和省略号进行表示。例如：

  ```        
 [<resource_string>, < resource_string>, ...]
     
 <principal_map> = { <principal_map_entry>, > <principal_map_entry>, ... }
   ```      
	 
允许多个值时，也可以只包含一个值。当元素只有一个值时，尾部的逗号必须去掉，且中括号"[]"标记可选。例如：

 ```    
 "resource": [<resource_string>]
     
 "resource": <resource_string>
     
```


4) 元素后的问号 (?) 表示该元素是非必填项。例如：
 

 ```   
 <condition_block?>
```
     
5) 元素是枚举值的情况下，枚举值之间用竖线"|" 表示，并用"()"括号定义枚举值的范围。例如：

 ```      
("allow" | "deny")
```
 
6) 字符串元素用双引号包括起来。例如：
 
      
```
<version_block> = "version" : "2.0"
```



### 3.语法描述

```

policy  = {
     <version_block>
     <principal_block?>,
     <statement_block>
}

<version_block> = "version" : "2.0"

<statement_block> = "statement" : [ <statement>, <statement>, ... ]

<statement> = {     
    <effect_block>,
    <action_block>,
    <resource_block>,
    <condition_block?>
}

<effect_block> = "effect" : ("allow" | "deny")  

<principal_block> = "principal": ("*" | <principal_map>)

<principal_map> = { <principal_map_entry>, <principal_map_entry>, ... }

<principal_map_entry> = "qcs":   
    [<principal_id_string>, <principal_id_string>, ...]

<action_block> = "action": 
    ("*" | [<action_string>, <action_string>, ...])

<resource_block> = "resource": 
    ("*" | [<resource_string>, <resource_string>, ...])

<condition_block> = "condition" : { <condition_map> }
<condition_map> { 
  <condition_type_string> : { <condition_key_string> : <condition_value_list> },
  <condition_type_string> : { <condition_key_string> : <condition_value_list> }, ...
}  
<condition_value_list> = [<condition_value>, <condition_value>, ...]
<condition_value> = ("string" | "number")
```
语法说明：

1) 一个策略(policy)可以包含多条语句(statement)。
     
策略的最大长度是4096个字符(不包含空格)，具体信息请参阅限制。

各个块(block)的显示顺序无限制。例如，在策略中，version_block 可以跟在 effect_block 后面等。

2) 当前支持的语法版本为2.0。

3) principal_block元素在控制台中不允许写入，仅支持在策略管理API中和策略语法相关的参数中使用principal。

4) 操作(action)和资源(resource)都支持列表，其中action还支持各产品定义的操作集(permid)。
    
5) 生效条件可以是单个条件，或者包括多个子条件块的逻辑组合。每个生效条件包括条件操作符(condition_type)、条件键(condition_key)，条件值(condition_value）构成。
    
6) 每条语句(statement)的效力(effect)为deny或allow。当策略中包含的语句中既包含有allow又包含有deny时，我们遵循deny优先原则。

### 4.字符串说明

    
语法描述的元素字符串的一些说明。
    
action_string:
    
由描述作用域、服务类型和操作名称组成。   


```
//所有产品所有操作
"action":"*"
"action":"name/*:*"
//cos产品所有操作
"action":"name/cos:*"
//cos产品的名为GetBucketPolicy的操作
"action":"name/cos:GetBucketPolicy"
//cos产品部分匹配Bucket的操作
"action":"name/cos:*Bucket*"
//操作集ID为280649的操作列表
"action":"permid/280649"
//cos产品，名为GetBucketPolicy\PutBucketPolicy\DeleteBucketPolicy的操作列表
"action":["name/cos:GetBucketPolicy","name/cos:PutBucketPolicy","name/cos: DeleteBucketPolicy"]
```

 permid为各产品定义的操作集合ID。具体信息请参阅各产品的帮助文档。
    
resource_string:
    
资源通过六段式描述。"qcs: project :serviceType:region:account:resource"。示例如下所示:

```
//cos产品的object资源，上海地域，资源拥有者的uid是1238423，资源名是bucket1/object2，资源前缀是prefix
qcs::cos:sh:uid/1238423:prefix/bucket1/object2
//cmq产品的队列，上海地域，资源拥有者的uin是6887234，资源名是6887234/queueName1,资源前缀是queueName
qcs::cmqqueue:sh:uin/6887234:queueName/6887234/queueName1
```
 condition_type_string:
    
条件操作符，描述测试条件的类型。例如string_equal、string_not_equal、date_ equal、date_not_equal、ip_equal、ip_not_equal、numeric_equal、numeric_not_equal等。示例如下所示:

```
"condition":{
         "string_equal":{"qcs:tag":["dev1","dev3"],
                      "mfa":"1"]},
         "ip_equal":{"qcs:ip":"10.131.12.12/24"}
}
```
condition_key_string:
    
条件键，描述将对其值采用条件操作符进行操作，以便确定条件是否满足。CAM 定义了一组在所有产品中都可以使用的条件键，包括 qcs:current_time、qcs:ip 、qcs:uin和qcs:owner_uin等。具体细节请参阅生效条件。
    
principal_id_string:
    
对于cam产品而言，用户也是它的资源。因此委托人(principal)也是用六段式描述。示例如下，具体细节请参阅资源描述方式。

```
"principal":   {"qcs":["qcs::cam::uin/1238423:uin/3232",
             "qcs::cam::uin/1238423:groupid/13"]}
```
