### 1.概念和使用场景
    
在很多场景下，我们需要对创建的策略进一步约束生效的条件(condition)。
    
场景1：CAM用户调用云API时，需要限制用户访问来源，则要求在现有的策略基础上加上IP条件。
    
场景2：当CAM用户在调用VPC对等连接API时，除了需要判断CAM用户是否拥有对等连接API和对等连接资源的访问权限外，还需要确认CAM用户是否拥有对等连接关联的VPC的访问权限。
    
### 2.语法结构	

![](https://mc.qcloudimg.com/static/img/4c47f9d1a72dfcdd76a7c3837711ae07/600.png)

生效条件的语法结构如上图所示。
    
一个条件块可以由若干个子条件块(sub block)构成，每个子条件块(sub block)对应一个条件操作符和若干个多个条件键，每个条件键对应了若干个条件值。    
    
### 3.评估逻辑
    
条件生效的评估逻辑如下所述。
    
1) 条件键会对应到多个条件值，只要上下文信息中的对应键值在关联的条件操作符作用下满足其中任意一个条件值，则条件生效。
    
2) 对于一个子条件块中存在多个条件键的情况下，只有每个条件键对应的条件都生效时，该子条件块才生效。
    
3) 对于包含多个子条件块的情况，只有每个子条件块都生效时，整个条件才生效。
    
4) 对于包含if_exist的条件键，如果上下文信息中不包含对应的键值，该条件依然生效。
    
### 4.使用示例
    
1) 该示例描述了允许给指定队列发送消息，限制条件是用户必须在10.217.182.* 或者111.21.33.*的网段调用云API。


```
{
  "version": "2.0",
  "statement": {
    "effect": "allow",
    "action": "name/cmqqueue:Sendmessages",
    "resource": "qcs::cmq:sh::queueName/123877/test",
    "condition": {"ip_equal": {"qcs:ip": ["10.217.182.3/24", "111.21.33.72/24"]}}
  }
}
```

2) 该示例描述了允许VPC绑定指定的NAT网关，限制条件是VPC的地域是上海，且VPCID值为324238。

```
{
  "version": "2.0",
  "statement": {
    "effect": "allow",
    "action": "name/vpc:AcceptVpcPeeringConnection",
    "resource": "qcs::vpc:sh::pcx/2341",
    "condition": {"string_equal_if_exist": {"vpc:region": "sh"}}
  }
}
```

### 5.条件操作符列表
    
下面列出了目前支持的条件操作符列表以及通用的条件键和示例等信息。每个产品自定义的条件键，请参阅对应的产品文档。


| 条件操作符 | 含义 | 条件名|举例 |
|---------|---------|---------|---------|
| string_equal | 字符串等于 | qcs:tag |{"string_equal":{"qcs:tag/tag_name1":"tag_value1"}} |
|string_not_equal|字符串不等于|qcs:tag|{"string_not_equal":{"qcs:tag/tag_name1":"tag_value1"}}|
|date_not_equal|时间不等于|qcs:current_time|{"date_not_equal":{"qcs:current_time":"2016-06-01T00:01:00Z"}}|
|date_greater_than|时间大于|qcs:current_time|{" date_greater_than ":{"qcs:current_time":"2016-06-01T00:01:00Z"}}|
|date_greater_than_equal|时间大于等于|qcs:current_time|{" date_greater_than_equal ":{"qcs:current_time":"2016-06-01T00:01:00Z"}}|
|date_less_than|时间小于|qcs:current_time|{" date_less_than ":{"qcs:current_time":"2016-06-01T 00:01:00Z"}}|
|date_less_than_equal|时间小于等于|qcs:current_time|{" date_less_than ":{"qcs:current_time":"2016-06-01T 00:01:00Z"}}|
|date_less_than_equal|时间小于等于|qcs:current_time|{"date_less_than_equal ":{"qcs:current_time":"2016-06-01T00:01:00Z"}}|
|ip_equal|ip等于|qcs:ip|{"ip_equal":{"qcs:ip ":"10.121.2.10/24"}}|
|ip_not_equal|ip不等于|qcs:ip|{"ip_not_equal":{"qcs:ip ":["10.121.2.10/24", "10.121.2.20/24"]}}|
|numeric_not_equal|数值不等于|qcs:mfa|{" numeric_not_equal":{"mfa":1}}|
|numeric_greater_than|数值大于||{"numeric_greater_than ":{"cvm_system_disk_size":10}}|
|numeric_greater_than_equal|数值大于等于||{"numeric_greater_than_equal ":{"cvm_system_disk_size":10}}|
|numeric_less_than|数值小于||{"numeric_less_than ":{"cvm_system_disk_size":10}}|
| numeric_less_than_equal | 数值小于等于 |  |{"numeric_less_than_equal ":{"cvm_system_disk_size":10}}|
|numeric_equal|数值等于|qcs:mfa|{" numeric_equal":{"mfa":1}}|
| numeric_greater_than | 数值大于 |  |{"numeric_greater_than ":{"some_key":11}} |

说明：

1) 日期格式按照ISO8601标准表示，并需要使用UTC时间。

2) IP格式要符合CIDR规范。

3) 条件键加上后缀_if_exist，表示上下文信息中即便不包含对应的键值依然生效。

4) 部分业务不支持条件，或仅支持部分条件。具体信息参考业务文档说明。



