互动直播SDK1.3起，提供了视频录制的功能，用户可通过相应的API使用该功能。录制的文件将存储在腾讯云提供的点播服务上，用户可通过点播的管理控制台、API进行管理、转码、分发等操作。

使用录制功能前，请先开通腾讯云点播服务，否则将无法使用。

录制功能开发指南如下：

## 1 时序图
![](//qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/hudongzhibolz-1.png)

## 2 开始录制

### 2.1 Android平台

原型：

```
public void requestMultiVideoRecorderStart(TIMAvManager.RoomInfo roomInfo,
                                           TIMAvManager.RecordParam param,
                                           TIMCallBack cb)
```

发起开始录制请求

Parameters:

```
roomInfo - 录制房间相关信息，详见TIMAvManager.RoomInfo
param - 录制参数，详见TIMAvManager.RecordParam
cb - 回调
```

示例：

```
TIMAvManager.getInstance().requestMultiVideoRecorderStart(roomInfo, param,  new TIMCallBack(){

    @Override
    public void onError(int code, String desc) {
        // TODO Auto-generated method stub
        Log.e(tag, "Recorder start failed: " + code + " desc " + desc);
    }

    @Override
    public void onSuccess() {
        // TODO Auto-generated method stub
        Log.d(tag, "Recorder start succ");
    }

});
```

>注意：录制同一个用户同一时刻只能发起一路录制请求。


### 2.2 iOS平台

原型：
 
```
 */**
  * 发送开始录制请求

  * @param roomInfo 房间信息
  * @paramrecordInfo 录制请求参数
  * @param succ 成功回调
  * @param fail 失败回调,返回错误码
  *
  *@return 0 发包成功
  */
- (int)requestMultiVideoRecorderStart:(OMAVRoomInfo *)roomInfo 
recordInfo:(AVRecordInfo *)recordInfo 
okBlock:(OMMultiSucc)succ 
errBlock:(OMMultiFail)fail;

  @end
```

参数说明:


```
roomInfo 音视频房间信息
recordInfo 录制参数
succ 成功回调
fail 失败回调，会返回错误码和错误信息，详见错误码表
OMAVRoomInfo {
  Uint32 relationId;    群组ID
  Uint32 roomId;      房间ID
}
AVRecordInfo {
  NSString *fileName;    录制生成的文件名
  NSArray *tags;		视频标签（NSString）列表
  UInt32 classId;		视频分类ID
  AVSDKType avSdkType;		SDK业务类型
  BOOL isTransCode;		是否转码
  BOOL isScreenShot;		是否截图
  BOOL isWaterMark;		是否打水印
}
```

返回值：

0 表示发送数据成功

示例：

```
[[IMSdkInt sharedInstance] 
requestMultiVideoRecorderStart:(OMAVRoomInfo *)roomInfo 
recordInfo:(AVRecordInfo *)recordInfo 
okBlock:^{
NSLog(@"start recordersucc");
}
errBlock:^(int code, NSString *err) {
NSLog(@"start recorder failed:code=%d err=%@", code, err);
}];
```

>注意：录制同一个用户同一时刻只能发起一路录制请求。


### 2.3 Windows平台

原型：

```
void RequestMultiVideoRecorderStart(const TIMRoomInfo& room_info, const 
TIMRecordParam& para, TIMCallBack* cb);     

```

发起开始推流请求

参数:

```
room_info - 房间信息
para- 录制参数
cb- 在onSuccess参数中返回分享用的url列表

struct TIMRoomInfo
{
	TIMRoomInfo():relation_id(0), room_id(0) {}
	int relation_id; // 讨论组ID
	int room_id;	 // 房间ID
};
relation_id - 讨论组ID
room_id- 房间ID

struct TIMStreamParam
{
		TIMRecordParam()
		:class_id(0)
		, is_transcode(false)
		, is_screenshot(false)
		, is_watermark(false)
		, sdk_type(SDKType_Normal)
		, record_data_type(0){}
	std::string filename;				//录制后的文件名
	int class_id;				 		//视频分类ID
	bool is_transcode;					//是否转码
	bool is_screenshot;				 	//是否截图
	bool is_watermark;					//是否打水印
	std::list<std::string> tags;	 	//视频标签列表
	E_TIMSDKType	sdk_type;
	uint32_t		record_data_type; //录制的数据类型：0.摄像头视频 1.辅流
};
```

示例：


```
//创建回调
class DemoReqMutilStreamStartCB :public TIMValueCallBack < TIMStreamRsp& >
{
	void OnSuccess(TIMStreamRsp& value) override
	{
		delete this;
	}
	void OnError(int code, const std::string &desc) override
	{
		delete this;
	}
};
//开始推流
void DemoRequestMutli()
{
	AVPre();				 //prepare
	TIMRoomInfo room_info;
	room_info.relation_id = 15000; //开房间时所用的relation id
	room_info.room_id = 0; //开房间时返回的room id
	TIMStreamParam stream_para;
	stream_para.encode = HLS;
	TIMIntManager::get().RequestMultiVideoStreamerStart(room_info, stream_para, new DemoReqMutilStreamStartCB);
	SLEEP(5);
}
```

>注意：推流同一个用户同一时刻只能发起一路推流，同一时刻重复发起如果已经有一路推流在直播了会返回推流频道已存在错误。

### 2.4 Web平台
原型：
                              
```
StartRecordVideo(videotype, filename, classid,transcode,snapshot, watermark)   
```

开始录制视频
参数:

```
videotype 视频源类型，0：摄像头，1：辅流（暂时不支持）
filename：文件名，不需要后缀名
classid：业务自定义ID，整数
transcode：是否转码，1：转码，0：不转码（暂没有作用）
snapshot：是否截图，1：截图，0：不截图（暂没有作用）
watermark：是否打水印，1：打水印，0：不打水印（暂没有作用）
```

示例：

```
//开始录制视频
function startRecordVideo(type){
    if (currentStatus < StatusType.enter_room) {
        alert('开始录制视频失败：未进入房间');
        return;
    }
    if(curRecordVideoType!=null){
        alert('正在录制视频，不能重复录制');
        return;
    }
    //type=0,表示把摄像头当作视频源，type=1，表示辅流，即把PC显示器上的图像作为视频源(web暂不支持辅流的录制)
    curRecordVideoType=type;
    var fileName;//保存的视频文件名称，不需要后缀名
    var curTimestamp=new Date().getTime();
    if(type==0){
        fileName='web_video_camera_'+curTimestamp;
    }else{
        fileName='web_video_desktop_'+curTimestamp;
    }
    var classId=Math.ceil(Math.random()*1000000);//业务自己定义的id,整型
    var isTransCode=0;//是否转码，暂时没有作用
    var isSnapShot=0;//是否截图，暂时没有作用
    var isWaterMark=0;//是否打水印，暂时没有作用
    log.info('start StartRecordVideo,curRecordVideoType='+curRecordVideoType+',filename='+fileName+',classId='+classId);
    qavSdk.StartRecordVideo(type,fileName,classId,isTransCode,isSnapShot,isWaterMark);
    log.info('after StartRecordVideo');
}

```

## 3 结束录制

### 3.1 Android平台

原型：
  
```
public void requestMultiVideoRecorderStop(TIMAvManager.RoomInfo roomInfo,
TIMValueCallBack<java.util.List<java.lang.String>> cb)
```

发起结束录制请求

Parameters:
  
```
roomInfo - 录制房间相关信息，详见TIMAvManager.RoomInfo
cb - 回调，onSuccess的参数中返回文件名ID
```

示例：

```
TIMAvManager.getInstance().requestMultiVideoRecorderStop(roomInfo, new TIMValueCallBack<List<String>>(){

    @Override
    public void onError(int code, String desc) {
        Log.e(tag, "Recorder stop failed: " + code + " desc " + desc);
    }

    @Override
    public void onSuccess(List<String> fileIds) {
        Log.d(tag, "Recorder stop succ");
        for(String fileId : fileIds){
            Log.d(tag, "fileId: " + fileId);
        }
    }

});
```

### 3.2 iOS平台

原型：


```
/**
* 发送停止录制请求
*
* @param roomInfo 房间信息
* @param succ 成功回调，返回文件ID
* @param fail 失败回调,返回错误码
*
* @return 0 发包成功
*/
- (int)requestMultiVideoRecorderStop:(OMAVRoomInfo *)roomInfo 
okBlock:(OMMultiVideoRecorderStopSucc)succ 
errBlock:(OMMultiFail)fail;
@end
```

参数说明:


```
roomInfo 音视频房间信息
succ 成功回调，返回文件ID
fail 失败回调，会返回错误码和错误信息，详见错误码表
```

返回值：

0 表示发送数据成功

示例：


```
[[IMSdkInt sharedInstance] 
requestMultiVideoRecorderStop:(OMAVRoomInfo *)roomInfo 
okBlock:^(NSArray *fileIDs){
NSLog(@"stop recordersucc");
   for (NSString *fileId in fileIDs) {
    NSLog(@"fileID = %@", fileId);
   }
} 
errBlock:^(int code, NSString *err) {
NSLog(@"stop recorder failed:code=%d err=%@", code, err);
}];
```

### 3.3 Windows平台

原型：

```
void RequestMultiVideoRecorderStop(const TIMRoomInfo& room_info, const TIMRecordParam& para,
TIMValueCallBack<std::list<std::string>&> *cb);   
```

发起结束推流请求

参数:

```
room_info			房间信息
para				录制信息
cb			回调返回 录制文件的file_id
```

示例：


```
//创建回调
class DemoReqMutilStreamStopCB : public TIMValueCallBack<std::list<std::string>&>
{
	void OnSuccess(std::list<std::string>& value) override
	{
		delete this;
	}
	void OnError(int code, const std::string &desc) override
	{
		delete this;
	}
};
//结束推流
void DemoRequestMutli()
{
	AVPre();				 //prepare
	TIMRoomInfo room_info;
	room_info.relation_id = 15000; //开房间时所用的relation id
	room_info.room_id = 0; //开房间时返回的room id
	TIMStreamParam stream_para;
	stream_para.encode = HLS;
	std::list<uint64_t> channel_ids;
	channel_ids.push_back(1000); //此处填写实际channel_id
	TIMIntManager::get().RequestMultiVideoStreamerStop(room_info, stream_para, channel_ids, new DemoReqMutilStreamStopCB);
	SLEEP(5);
}
```
### 3.4 Web平台
原型：

```
StopRecordVideo(videotype)
```
停止录制视频
参数：

```
videotype 视频源类型，0：摄像头，1：辅流（暂不支持）
```
示例：

```
		//停止录制视频
function stopRecordVideo(){
    if (currentStatus < StatusType.enter_room) {
        alert('停止录制视频失败：未进入房间');
        return;
    }
    if (curRecordVideoType==null) {
        alert('请先开始录制视频');
        return;
    }
    log.info('before StopRecordVideo,curRecordVideoType='+curRecordVideoType);
    qavSdk.StopRecordVideo(curRecordVideoType);
    log.info('after StopRecordVideo');
}
```

## 4 视频管理

通过音视频通信SDK录制的视频将存储在点播服务中

（1）用户访问点播的管理控制台 http://console.cloud.tencent.com/video 可以对录制的文件进行相应的管理操作
（2）用户也可以通过点播提供的API进行管理操作，API的使用手册如下：
https://cloud.tencent.com/doc/api/257/API%E6%A6%82%E8%A7%88
（3）DescribeVodPlayInfo能根据文件名（开始录制Api中，录制参数所填文件名）获取到录制
文件下载地址,详见 https://cloud.tencent.com/doc/api/257/%E8%8E%B7%E5%8F%96%E8%A7%86%E9%A2%91%E6%92%AD%E6%94%BE%E4%BF%A1%E6%81%AF%E5%88%97%E8%A1%A8
（4）根据录制结束返回的FileId查询视频地址并设置回调的接口DescribeRecordPlayInfo(一般由客户的第三方后台来调用), 详见：
http://cloud.tencent.com/doc/api/257/获取录播视频播放信息-互动直播用户专用


## 5 价格与计费说明

录制功能本身是不收费的，但由于使用的是点播服务的能力，在云点播中会产生存储、流量的费用，具体的计费规则如下：
https://cloud.tencent.com/doc/product/268/5129#2..E5.BD.95.E5.88.B6.E7.9B.B8.E5.85.B3.E8.AE.A1.E8.B4.B9

需要说明的是，如果你已开通点播服务，并选定套餐或后付费中的一种计费模式，将沿用你已选定的计费模式，如果你未开通点播服务，将默认选择后付费按流量的计费模式。

## 6 注意事项

（1）录制每隔90分钟或录制结束时不足90分钟会生成一个MP4录制文件，超过90分钟则会生成多个文件
（2）APP运行过程中crash或异常退出，1分钟没收到数据会自动关闭录制，后端会录制用户异常退出前音视频
（3）现版本不支持多路上行视频合并和混音处理

## 7 错误码

1：用户没有录制权限 
2：用户点播余额不足 
30000000-30000099： 解析客户端录制请求包错误 
30000200-30000299： 请求录制服务器错误
30000300-30000399： 解析录制服务器回包错误
30000400-30000499： 请求流控服务器错误 