## 1 相关背景

在某些场景下，业务可能希望把用户进入退出音视频房间的动作或其他状态变化通知给房间里的其他人，或触发业务后台的某些逻辑处理。但考虑到通知信令的路径长度、大型互动房间人员进出的频繁程度以及业务侧HTTPS服务的接入性能等因素，腾讯互动直播后台暂时没有提供与业务后台之间关于状态变化的直接回调。为了帮助有需要的业务实现这类通知功能，本文列举了几种可能的实现方案供业务技术负责人参考。

## 2 【方案一】基于业务自建通道的通知方案

如果业务侧有自己的外网接入服务，可以实现App与自身业务后台的信令交互，则可以遵循下图的流程实现通知机制。这里我们考虑的场景是，通知需要经过业务后台处理一些业务逻辑，然后再扩散给房间里的其他人，下面的场景也遵从此假设。如果不需要扩散，就简单去掉方案中的扩散步骤即可。

![基于业务自建通道的通知方案](//mccdn.qcloud.com/img56cdd27e26d02.png)

本方案的优点是：  

+ 整体方案简洁直观，充分利用业务现有的基础设施

本方案的问题是：

+ 整个流程依赖业务自己的信令/消息**`接入服务`**的质量，而通常中小规模的业务在接入点数量、分布覆盖的广度、并发容量、安全性（通道加密）和稳定性等方面都或多或少存在隐患
+ 某些业务的后台与客户端之间的连接机制实现得比较简陋，难以承载实时的信令交互逻辑

对于自行维护信令接入服务有困难的业务，我们更推荐下面这种方案

## 3 【方案二】基于OpenSSO通道/QAL的业务通知方案

本方案与上一个推荐方案仅有一点不同，即引入了腾讯云OpenSSO作为接入层。腾讯云OpenSSO提供了与QQ相同级别的接入覆盖能力，在海量并发处理、安全性、可靠性和稳定性方面都经过了海量用户的考验，可以完美解决[上一方案](#2-基于业务自建通道的通知方案)中存在的接入隐患。此外，业务还可以使用这条高质量的通道传输其他信令，从而降低维护成本，提升业务的整体信令传输质量。值得一提的是，IMSDK（1.7+版本）也会复用这条通道来传输IM消息信令，所以这条通道的质量是绝对有保障的

![基于OpenSSO通道的业务通知方案](//mccdn.qcloud.com/img56cdd2d9be4d0.png)

## 4 【方案三】基于ImSdk接口的回调方案

由于腾讯云互动直播(互动直播ILVB)的AVSDK依赖于腾讯云通信的IMSDK，所以使用腾讯云互动直播服务的App天然拥有了IM通信能力，因此可以基于ImSdk提供的[第三方回调](http://avc.qcloud.com/wiki2.0/im/第三方回调/第三方回调简介/第三方回调简介.html)机制来实现音视频进出房间的通知。

![通过ImSdk回调接口的回调方案](//mccdn.qcloud.com/img56cdd457088cf.png)

本方案的优点：

+ IMSDK直接提供消息接口，使用方便
+ 全程使用IM消息的通道，信令传输质量有保障

注意：目前IM消息的机制是，要么所有消息都回调，要么都不回调。所以，如果业务已经以不回调方式使用了IM服务，那么该方案需要将回调机制变更为全部回调

## 5 美女主播类业务直播结束提示的建议方案

市面上常见的美女主播类应用，通常只有一个主播上行音视频数据，其他用户观看并通过IM消息实现互动。当主播退出房间之后，通常需要提示所有观看用户直播已结束，即使该房间并未物理上销毁（只要房间里还有用户存在，音视频后台就不会销毁该房间）

这里我们建议采用上文提到的[【方案三】](#4-【方案三】基于ImSdk接口的回调方案)来实现此功能。首先，我们假设业务的App和业务后台之间存在心跳机制，以保障业务后台能及时感知App的状态变化。其次，我们假设业务使用了腾讯云IM服务，可以通过App或业务后台群发IM消息（当然，业务使用第三方消息服务或自建通道发送IM消息也是可以的）。具体地：
- 如果主播的客户端App**`正常退出`**音视频房间，那么App可以在AVSDK退房操作之后，主动发出一条IM消息通知所有收看用户，收看用户的App收到此消息后可以弹出直播已结束的提示
- 如果主播的客户端App**`非正常退出`**（Crash、断网超时等），则业务后台与App之间心跳必然超时，从而感知到主播客户端App被动退出了房间。此时，业务后台可以主动向该房间内所有观看用户群发IM通知消息，收看用户的App收到此消息后可以弹出直播已结束的提示

需要说明一下为什么直播结束的提示逻辑要采用**IM消息通知**而不是AVSDK自带的事件回调**`OnEndpointsUpdateInfo(EVENT_ID_ENDPOINT_EXIT)`**。主要是因为腾讯云互动直播解决方案支持万人同时在线的超大房间，大房间里用户进出动作频繁且不可控，如果全部进出动作都以AVSDK回调形式通知客户端，对客户端性能会产生严重影响。所以，目前AVSDK后台只会在房间人数***`小于50人`***的时候下发人员进出的通知，而当房间人数大于50人的时候，则不再下发用户进出房间的通知，即客户端不再有**`OnEndpointsUpdateInfo(EVENT_ID_ENDPOINT_EXIT/ENTER)`**回调。鉴于美女主播房间人数通常都会超过50人，不建议此类业务使用AVSDK回调来实现直播结束提示功能。