互动直播SDK1.4起，提供了旁路直播的功能，结合腾讯云直播服务可实现HLS、RTMP的直播下发。使用旁路直播功能前，请先开通腾讯云直播服务，否则将无法使用。

旁路直播开发指南如下：

## 1 时序图
![](//qzonestyle.gtimg.cn/qzone/vas/opensns/res/img/hudongzhibolz-2.png)

## 2 开始旁路直播

### 2.1 Android平台

原型：

```
public void requestMultiVideoStreamerStart(TIMAvManager.RoomInfo roomInfo,
                                           TIMAvManager.StreamParam streamParam,
                                           TIMValueCallBack<TIMAvManager.StreamRes> cb)

```

发起开始旁路直播请求

Parameters:


```
roomInfo – 旁路直播房间相关信息，详见TIMAvManager.RoomInfo
streamParam – 旁路直播相关参数，详见TIMAvManager.StreamParam
cb - 回调，在onSuccess中返回频道ID及播放地址，详见详见TIMAvManager.StreamRes
```

示例：

```
TIMAvManager.getInstance().requestMultiVideoStreamerStart(roomInfo,
                    streamParam, new TIMValueCallBack<TIMAvManager.StreamRes>() {
	@Override
	public void onError(int code, String desc) {
    	Log.d(tag, "create channel failed. code " + code + ", descr " + desc);
	}

	@Override
	public void onSuccess(TIMAvManager.StreamRes streamRes) {
　　//这里的streamRes.getChnlId()直接打印的时候会是一个负数，所以如果需要打印查看的时候需要转换一下。结束推流的时候直接使用即可，不需要转换的。
　　Long num = streamRes.getChnlId();
　　BigInteger unsignedNum = BigInteger.valueOf(num); 
	if(num < 0) unsignedNum = unsignedNum.add(BigInteger.ZERO.flipBit(64));
    	Log.d(tag, "create channel succ. channelid: " + unsignedNum
               	+ ", addr size " + streamRes.getUrls().size());
    	}
	});

```

>注意：旁路直播同一个用户同一时刻只能发起一路直播，同一时刻重复发起如果已经有一路直播了会返回直播频道已存在错误。

### 2.2 iOS平台

原型：

```
/**
*  发送创建直播频道，开始旁路直播的请求
*
* @param roomInfo 房间信息
* @param streamInfo 直播频道信息
* @param succ 成功回调
* @param fail 失败回调,返回错误码
*
*  @return 0 发包成功
*/
- (int)requestMultiVideoStreamerStart:(OMAVRoomInfo *)roomInfo 
                      streamInfo:(AVStreamInfo *)streamInfo 
                         okBlock:(OMMultiVideoStreamerStartSucc)succ 
                         errBlock:(OMMultiFail)fail;

@end
```

参数说明:


```
roomInfo 音视频房间信息
streamInfo 旁路直播参数
succ 成功回调，返回频道ID和URL（NSString）列表
fail 失败回调，会返回错误码和错误信息，详见错误码表
OMAVRoomInfo {
   Uint32 relationId;    群组ID
   Uint32 roomId;      房间ID
}
LVBChannelInfo {
   NSString *channelName;      直播频道的名称
   NSString *channelDescribe;    直播频道的描述
   NSString *playerPassword;     为接收方播放器设置的密码
}
AVStreamInfo {
   AVEncodeType encodeType;    编码格式
   AVSDKType avSdkType;         SDK业务类型
   LVBChannelInfo *channelInfo;   频道信息
}
AVStreamerResp {
   Uint64 channelID;    频道ID
   NSArray *urls;        URL列表
}
```

返回值：

0 表示发送数据成功

示例：


```
[[IMSdkInt sharedInstance] 
 requestMultiVideoStreamerStart:(OMAVRoomInfo *)roomInfo 
                      streamInfo:(AVStreamInfo *)streamInfo 
                         okBlock:(AVStreamerResp *rsp) {
   NSLog(@"create LVBChannel succ:channelID=%@", rsp.channelID);
   for (NSString *url in rsp.urls) {
     NSLog(@"LVBChannel url=%@", url);
   } 
 }
                         errBlock:^(int code, NSString *err) {
     NSLog(@"create LVBChannel failed:code=%d err=%@", code, err);
}];
```

### 2.3 Windows平台

原型：


```
void RequestMultiVideoStreamerStart(const TIMRoomInfo& room_info, 
const TIMStreamParam& para, TIMValueCallBack<TIMStreamRsp&> *cb); 
```

发起开始旁路直播请求

参数:


```
room_info - 房间信息
para- 旁路直播参数
cb- 在onSuccess参数中返回分享用的url列表

struct TIMRoomInfo
{
	TIMRoomInfo():relation_id(0), room_id(0) {}
	int relation_id; // 讨论组ID
	int room_id;	 // 房间ID
};
relation_id - 讨论组ID
struct TIMStreamParam
{
	TIMStreamParam()
		:encode(HLS), sdk_type(SDKType_Normal), push_data_type(0){}
	E_TIMStreamEncode encode;
	E_TIMSDKType sdk_type;
	std::string channel_name;
	std::string channel_desc;
	std::string channel_password;
	uint32_t	push_data_type; //推流的数据类型 0:摄像头 1：辅流 
};
};
```

示例：


```
//创建回调
class DemoReqMutilStreamStartCB :public TIMValueCallBack < TIMStreamRsp& >
{
	void OnSuccess(TIMStreamRsp& value) override
	{
		delete this;
	}
	void OnError(int code, const std::string &desc) override
	{
		delete this;
	}
};
//开始推流
void DemoRequestMutli()
{
	AVPre();				 //prepare
	TIMRoomInfo room_info;
	room_info.relation_id = 15000; //开房间时所用的relation id
	room_info.room_id = 0; //开房间时返回的room id
	TIMStreamParam stream_para;
	stream_para.encode = HLS;
	TIMIntManager::get().RequestMultiVideoStreamerStart(room_info, stream_para, new DemoReqMutilStreamStartCB);
	SLEEP(5);
}
```

>注意：旁路直播同一个用户同一时刻只能发起一路直播，同一时刻重复发起如果已经有一路直播了会返回直播频道已存在错误。

## 3 结束旁路直播

### 3.1 Android平台

原型：

```
public void requestMultiVideoStreamerStop(TIMAvManager.RoomInfo roomInfo,
                                          java.util.List<java.lang.Long> channelIDs,
                                          TIMCallBack cb)
```

发起结束旁路直播请求

Parameters:

```
roomInfo – 旁路直播房间相关信息，详见TIMAvManager.RoomInfo
channelIDs - 需要关闭的频道的ID集
cb - 回调
```

示例：


```
TIMAvManager.getInstance().requestMultiVideoStreamerStop(roomInfo,
        ids, new TIMCallBack() {
    @Override
    public void onError(int code, String desc) {
        Log.d(tag, "stop channel failed. code " + code + ", descr " + desc);
    }

    @Override
    public void onSuccess() {
        Log.d(tag, "stop channel succ");
    }
});
```


### 3.2 iOS平台

原型：


```
/**
*  发送关闭直播频道，停止旁路直播的请求
*
* @param roomInfo 房间信息
* @param channelIDs 频道ID（NSString）列表
* @param succ 成功回调
* @param fail 失败回调,返回错误码
*
*  @return 0 发包成功
*/
- (int) requestMultiVideoStreamerStop:(OMAVRoomInfo *)roomInfo 
                          channelIDs:(NSArray *)channelIDs 
                             okBlock:(OMMultiSucc)succ 
                             errBlock:(OMMultiFail)fail;
@end
```

参数说明:


```
roomInfo 音视频房间信息
channelIDs 频道ID（NSString）列表
succ 成功回调
fail 失败回调，会返回错误码和错误信息，详见错误码表
```

返回值：

0 表示发送数据成功

示例：


```
[[IMSdkInt sharedInstance] 
  requestMultiVideoStreamerStop:(OMAVRoomInfo *)roomInfo 
                      channelIDs:(NSArray *)channelIDs
                         okBlock:^{
    NSLog(@"stop LVBChannel succ");
} 
                     errBlock:^(int code, NSString *err) {
    NSLog(@"stop LVBChannel failed:code=%d err=%@", code, err);
}];
```

### 3.3 Windows平台

原型： 

```
 void RequestMultiVideoStreamerStop(const TIMRoomInfo& room_info, const 
TIMStreamParam& para, const std::list<uint64_t>& channel_ids, TIMCallBack *cb); 
```

发起结束旁路直播请求

参数:

```
room_info			房间信息
para				旁路直播参数
channel_ids		RequestMultiVideoStreamerStart 返回的channel_id
param cb			回调返回
```

示例：


```
//创建回调
class DemoReqMutilStreamStopCB : public TIMCallBack
{
	void OnSuccess() override
	{
		delete this;
	}
	void OnError(int code, const std::string &desc) override
	{
		delete this;
	}
};
//结束推流
void DemoRequestMutli()
{
	AVPre();				 //prepare
	TIMRoomInfo room_info;
	room_info.relation_id = 15000; //开房间时所用的relation id
	room_info.room_id = 0; //开房间时返回的room id
	TIMStreamParam stream_para;
	stream_para.encode = HLS;
	std::list<uint64_t> channel_ids;
	channel_ids.push_back(1000); //此处填写实际channel_id
	TIMIntManager::get().RequestMultiVideoStreamerStop(room_info, stream_para, channel_ids, new DemoReqMutilStreamStopCB);
	SLEEP(5);
}
```

## 4 直播管理

通过互动直播SDK发起旁路直播，直播下发是通过腾讯云直播服务实现的

（1）用户可以访问直播服务的管理控制台http://console.cloud.tencent.com/live进行相应的管理操作
（2）用户也可以通过直播服务提供的API进行管理操作，API的使用手册如下：
https://cloud.tencent.com/doc/api/258/4703

## 5 价格与计费说明
旁路直播会产生费用，具体的计费规则与腾讯云直播服务一致，详细说明如下：
https://cloud.tencent.com/doc/product/268/5129#1..E6.97.81.E8.B7.AF.E7.9B.B4.E6.92.AD.E8.AE.A1.E8.B4.B9

需要说明的是，如果你已开通直播服务，并选定套餐或后付费中的一种计费模式，将沿用你已选定的计费模式，如果你未开通直播服务，将默认选择后付费按流量的计费模式。

## 6 注意事项

(1) 双人音视频房间不支持录制功能
(2) 现版本不支持多路上行视频合并和混音处理

## 7 错误码

40000000-40000099： 解析客户端推流请求包错误
40000200-40000299： 请求推流服务器错误
40000300-40000399： 解析推流服务器回包错误
40000400-40000499： 请求推流服务器错误