# 后台接口的规格说明（HTTPs）

客户端请求的数据为HTTPs Req+JSON格式的Content Body，服务端返回给客户端的数据为HTTPs Rsp+JSON格式的Content Body。

## 双向认证
为系统安全性考虑，第三方后台请求要求双向认证。双向认证证书申请请参考腾讯云官网相关文档：[产品文档-云通信-第三方回调回调-双向认证配置指南-Nginx双向认证配置指南](http://cloud.tencent.com/doc/product/269/Nginx双向认证配置指南)


## HTTPs 请求的格式
HTTP请求的格式为：`POST URL HTTP/1.1\r\n`

## 后台服务URL格式

URL的格式为：`/ver/servicename/command?parameter/`，其中`ver`为版本号，目前为`v3`。servicenanme为`openim`。command根据请求的不同而设置。

例如，音频后台请求为：`v3/openim/videorelay`

### 域名:

测试环境为：<https://test.tim.qq.com/>
正式环境为：<https://openapi.tim.qq.com/>

### Comand：

| Command | 说明 |
|---------|---------|
| videorelay | 视频聊天服务 |

### Parameter

Parameter的格式为：`usersig=xxxx& identifier=xxxx&sdkappid=xxxx&random=xxxxx&apn=x/`

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| sdkappid | unsigned int | 使用open APP sdk时分配的appid | 在应用列表-应用配置-应用信息找到 |
| usersig | String | open app sdk的token | 在应用列表-应用配置-帐号集成体系-下载用户凭证找到。 |
| identifier | String | 管理员帐号 | 在应用列表-应用配置-帐号集成体系-帐号管理员由开发者创建 |
| random | unsigned int | 标识当前请求的整数随机数参数 | 32位整数随机数 |
| apn | unsigned int | 网络类型，0未知、1  wifi、2 2G、3 3G、4 4G | 后台操作填0 |

### 示例
完整的url如下：<
https://openapi.tim.qq.com/v3/openim/videorelay?usersig=xxxx&apn=1&identifier=xxxx&sdkappid=xxxx&random=xxxx&contenttype=json>

# 后台接口的内容定义（json）

## 包体结构

【请求格式】

	{
		"reqhead":object of GVCommOprHead
		"reqbody":由GVCommOprHead中子命令决定
	}

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| reqhead | GVCommOprHead | 音视频服务通用包头 |   |
| reqbody | 由GVCommOprHead中子命令决定 |   |   |    |

【响应格式】

		{
		"reqhead":object of GVCommOprHead
		"rspbody":由GVCommOprHead中子命令决定
		}

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| reqhead | GVCommOprHead | 音视频服务通用包头 |   |
| rspbody | 由GVCommOprHead中子命令决定 |   |    |   |

## GVCommOprHead通用包头定义

	{
	 "uint32_sub_cmd":xxx,
	 "uint32_seq":xxx,
	 "uint32_auth_key":xxxx,
	 "uint32_sdk_appid":xxx,
	 "str_av_token":"xxx",
	 "str_openid:"xxxx",
	 "rpt_to_Account":["xxxx"],
	 "bytes_cookie_buff":"xxxx",
	 "uint32_result:"xxxx",
	 "str_error_msg:"xxxx"
	}

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| uint32_sub_cmd | unsigned int/必填 | 子命令：1：踢出房间成员5:请求录制和停止录制6：请求推流和停止推流 |   |
| uint32_seq | unsigned int/必填 | 请求序号 | 需要第三方原样带回 |
| uint32_auth_key | unsigned int/必填 | 群组号码 | 第三方定义的群组 |
| uint32_sdk_appid | unsigned int/必填 | 开放sdk appid |   |
| str_av_token | String/可选 | 第三方调用QQ音视频服务鉴权标识（无需填写）  |   |
| str_openid | String/可选 | 发起操作的openid后台操作时无需填写 |   |
| rpt_to_Account | String/可选 | 被操作的openid列表， **最多10个** ，具体含义参见业务包体 | **对于0x5、0x6请求只支持一个** |
| uint32_result | int/可选 | 非业务结果（0：成功，非0：失败）-1：表示解包错误-2：包体错误-3：内部服务失败-4：包头校验失败-5 ：av_token校验不通过 | 响应消息才用到 |
| str_error_msg | String/可选 | 错误消息 | 响应消息才用到 |
| bytes_cookie_buff | String | 业务cook，响应时原样带回 |   |

【代码示例】

	"reqhead":
	{
		"uint32_sub_cmd":6,
		"uint32_seq":xxx,
		"uint32_auth_key":xxx,
		"uint32_sdk_appid":xxx,
		"rpt_to_Account":["xxx"],
		"bytes_cookie_buff":"xxxx"
	},

## 接口功能内容定义

### 0x6 sdk旁路直播请求

- 子命令：0x6
- 请求："reqbody":object of req_0x6

		req_0x6
		{
			"uint32_oper":xxx,
			"uint32_live_code":xxx,
			"uint32_sdk_type":xxx,
			"str_channel_name":"xxx",
			"str_channel_describe":"xxx",
			"str_player_pwd":"xxx",
			"uint32_push_data_type":xxx,
			"uint32_tape_flag":xxx,
			"uint32_watermark_flag":xxx,
			"uint32_watermark_id":xxx,
			"rpt_rate_type":[xxx]
		}
注：旁路推流操作的对象为rpt_to_Account，必须填写，只支持一个

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| uint32_oper | unsigned int | 操作类型：1 启动推流；2 关闭推流； | 启动推流：必填 停止推流：必填  |
| uint32_live_code | unsigned int | 直播流输出编码： 1  hls推流；5  rtmp推流；6  hls+rtmp推流；  | 启动推流：必填 停止推流：不填  |
| uint32_sdk_type | unsigned int | SDK类型：1 普通SDK ；2 物联摄像头； | 启动推流：必填 停止推流：必填 |
| str_channel_name | string | 通道名称 | 启动推流：可选 停止推流：不填 |
| str_channel_describe | string | 通道描述 | 启动推流：可选 停止推流：不填 |
| str_player_pwd | string | 指定通过密码才允许观看，需使用腾讯云提供的播放器才支持，否则设置无效 | 启动推流：可选 停止推流：不填 |
| uint32_push_data_type | unsigned int | 推流的数据类型0 推流摄像头；1 推流屏幕分享数据； | 启动推流：必填 停止推流：必填  |
| uint32_tape_flag | unsigned int | 是否需要在推流过程中录制：0 不需要录制；1 需要录制；  | 启动推流：必填 停止推流：不填  |
| uint32_watermark_flag	| unsigned int | 是否添加水印：0 不添加水印; 1 添加水印;	|启动推流：可选 停止推流：不填 (如果需要携带水印，请在直播控制台上传相关水印图片,如果不携带此参数，默认为不添加水印)|
| uint32_watermark_id | unsigned int |水印ID：0为默认水印或者对应的水印ID号|启动推流：可选 停止推流：不填 (如果设置启用水印而当前参数不携带，使用用户上传的默认水印)|
| rpt_rate_type | unsigned int | 支持多码率：0  原始码率 10 标清码率（550K）20 高清码率（900K）|启动推流：可选 停止推流：不填（不携带此参数默认返回原始码率url。数组结构，可以同时返回多组url）





	"reqbody":
	{
			"req_0x6":
			{
				"uint32_oper":xxx,
				"uint32_live_code":xxx,
				"uint32_sdk_type":xxx,
				"uint32_push_data_type":xxx
			}
	}

- 响应："rspbody":object of rsp_0x6

		rsp_0x6定义：
		{
		 "uint32_result":xxx,       // 操作结果, 0成功, 非0失败
		 "str_errorinfo":"xxx",
		 "msg_live_url":"[xxx]"
		}

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| uint32_result | unsigned int | 操作结果0：成功，非0：失败 | 详细错误码见附录 |
| str_errorinfo | string | 错误信息 | 错误字符串信息 |
| uint64_channel_id | unsigned  long long | 启动推流的时候返回 |   |
| msg_live_url | [LiveUrl] | 直播URL | 参考LiveUrl的定义 |
| uint32_tape_task_id | unsigned int | 录制对应的tape_task_id | 只有启动推流的时候设置uint32_tape_flag为1才返回 |

#### LiveUrl

	{
	"uint32_type":"xxx",
	"string_play_url":"xxx"
	"RateType ":xxx
	}

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| uint32_type | unsigned int | 直播流输出编码1  hls推流；5  rtmp推流；6  hls+rtmp推流； |   |
| string_play_url | String | 直播流输出编码对应URL |   | 
| RateType | unsigned int | 此url对应的码率类型： 0  原始码率 10 标清码率（550K） 20 高清码率（900K）| 不包含此参数表示是原始码率  | 

***注意：启动旁路直播需要用户进入音视频房间之后操作才能成功***

#### json包体请求实例说明：

以启动旁路直播的json包举例说明，需要把里面的参数值替换成自己的

{

        "reqhead":{
                "uint32_sub_cmd":6,
                "uint32_seq":xxx,
                "uint32_auth_key":xxx,
                "uint32_sdk_appid":xxx,
                "rpt_to_Account":["xxx"],
                "bytes_cookie_buff":"xxx"
        },

        "reqbody":{
                "req_0x6":{
                        "uint32_oper":xxx,
                        "uint32_live_code":xxx,
                        "uint32_sdk_type":xxx,
                        "str_channel_name":"xxx",
                        "str_channel_describe":"xxx",
                        "uint32_push_data_type":xxx,
                        "uint32_tape_flag":xxx
                }
        }
}


### 0x5 sdk录制请求

- 子命令：0x5
- 请求："reqbody":object of req_0x5

		req_0x5
		{
			"uint32_oper":xxx,
			"string_file_name":"xxx",
			"string_tags":["xxx"],
			"uint32_classid":xxx,
			"uint32_IsTransCode":xxx,
			"uint32_IsScreenShot":xxx,
			"uint32_IsWaterMark":xxx,
			"uint32_sdk_type":xxx,
			"uint32_record_data_type":xxx
		}

***注意：录制操作的对象为rpt_to_Account，必须填写，只支持一个***

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| uint32_oper | unsigned int | 操作类型：1 启动录制；2 关闭录制； | 启动录制：必填 停止录制：必填  |
| string_file_name | string | 录制的文件名称 | 启动录制：必填 停止录制：不填 |
| string_tags | [string] | 视频标签列表,string数组 | 启动录制：可选 停止录制：不填 |
| uint32_classid | unsigned int | 视频分类ID | 启动录制：可选 停止录制：不填 |
| uint32_IsTransCode | unsigned int | 是否转码 | 启动录制：可选 停止录制：不填 |
| uint32_IsScreenShot | unsigned int | 是否截图 | 启动录制：可选 停止录制：不填 |
| uint32_IsWaterMark | unsigned int | 是否打水印 | 启动录制：可选 停止录制：不填 |
| uint32_sdk_type | unsigned int | SDK类型：1 普通SDK； 2 物联摄像头； | 启动录制：必填 停止录制：必填  |
| uint32_record_data_type | unsigned int | 录制的数据类型：0 录制摄像头； 1 录制屏幕分享数据； | 启动录制：必填 停止录制：必填  |

	"reqbody":
	{
		"req_0x5":
		{
			"uint32_oper":xxx,
			"string_file_name":xxx,
			"uint32_sdk_type":xxx,
			"uint32_record_data_type":xxx,
		}
	}

- 响应："rspbody":object of rsp_0x5

		rsp_0x5定义：
		{
		 "uint32_result":xxx,       // 操作结果, 0成功, 非0失败
		 "str_errorinfo":"xxx",
		 "str_fileID":["xxx"]
		}

| 参数名称 | 类型 | 说明 | 备注 |
| --- | --- | --- | --- |
| uint32_result | unsigned int | 操作结果0：成功;非0：失败; | 详细错误码见附录 |
| str_errorinfo | string | 错误信息 | 错误字符串信息 |
| str_fileID | [String] | 视频文件ID列表,string数组。 | 只有在录制结束的时候返回 |

***注意：启动录制需要用户进入音视频房间之后操作才能成功***

# 错误码说明

## 0x6推流错误码说明

| 错误码 | 错误说明 | 处理建议 |
| --- | --- | --- |
| 40000000 | SDK请求解析失败 | 【推流请求字段填写是否完整】 |
| 40000001 | SDK请求解析失败-没有推流请求包体 | 【推流请求字段填写是否完整】 |
| 40000002 | SDK请求解析失败-没有推流请求操作字段 | 【推流请求字段填写是否完整】 |
| 40000003 | SDK请求解析失败-缺少推流请求的输出编码（HLS/RTMP等） | 【推流请求字段填写是否完整】 |
| 40000004 | SDK请求解析失败-视频源类型错误（摄像头/桌面等） | 【推流请求字段填写是否完整】 |
| 40000005 | SDK请求解析失败-请求操作错误（请求推流、停止推流） | 【推流请求字段填写是否完整】 |
| 40000201 | 请求服务器内部数据打包错误 | 【反馈腾讯客服】 |
| 40000202 | 请求服务器内部数据打包错误 | 【反馈腾讯客服】 |
| 40000203 | 请求服务器内部数据打包错误 | 【反馈腾讯客服】 |
| 40000207 | 请求推流服务器通讯错误-拉取推流服务器地址失败 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 40000208 | 请求推流服务器通讯错误-请求推流服务器超时 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 40000301 | 解析推流服务器回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 40000302 | 解析推流服务器回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 40000303 | 解析推流服务器回包错误-没有返回IP | 【反馈腾讯客服】 |
| 40000304 | 解析推流服务器回包错误-没有返回端口 | 【反馈腾讯客服】 |
| 40000305 | 解析推流服务器回包错误-没有返回结果 | 【反馈腾讯客服】 |
| 40000306 | 解析推流服务器回包错误-返回url长度溢出 | 【反馈腾讯客服】 |
| 40000401 | 查询房间获取grocery服务IP错误 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 40000402 | 查询房间拉取grocery数据错误 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 40000403 | 查询房间拉取grocery不存在（请求推流的房间不存在） | 【检查是否成功开房，推流的用户ID，groupid是否填写正确】 |
| 40000404 | 查询房间流控服务器超时 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 40000405 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 40000406 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 40000407 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 40000408 | 查询房间回包错误-没有返回结果 | 【反馈腾讯客服】 |
| 40000409 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 40000410 | 请求推流的房间不存在 | 【检查是否成功开房，推流的用户ID，groupid是否填写正确】 |
| 40000411 | 发起推流用户不在房间内 | 【检查是否成功开房，推流的用户ID，groupid是否填写正确】 |
| 40000412 | 停止推流重复发送，用户已经停止推流 | 【如果是推流停止操作说明已经停止，重复停止操作，无需处理】 |
| 40000413 | 停止推流重复发送，用户已经停止推流 | 【如果是推流停止操作说明已经停止，无需处理】 |
| 40000414 | 查询房间-服务器内部操作类型错误 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 40000415 | 启动推流重复发送，用户正在推流 | 【如果是推流启动操作说明已经是在推流状态，无需处理】 |
| 1001 | 权限错误 | 【一般是sdkappid填写错误导致】 |
| 20101 | 通道数超过上限 | 【推流通道数存在上限，在推流控制台检查并删除无用的通道】 |
| 20406 | 用户欠费 | 【检查是否已欠费】 |

## 0x5录制错误码说明

| 错误码 | 错误说明 | 处理建议 |
| --- | --- | --- |
| 30000000 | SDK请求解析失败 | 【录制请求字段填写是否完整】 |
| 30000001 | SDK请求解析失败-没有录制请求包体 | 【录制请求字段填写是否完整】 |
| 30000002 | SDK请求解析失败-没有录制文件名字段 | 【录制请求字段填写是否完整】 |
| 30000003 | SDK请求解析失败-没有录制请求操作字段 | 【录制请求字段填写是否完整】 |
| 30000004 | SDK请求解析失败-视频源类型错误（摄像头/桌面等） | 【录制请求字段填写是否完整】 |
| 30000201 | 请求服务器内部数据打包错误 | 【反馈腾讯客服】 |
| 30000202 | 请求服务器内部数据打包错误 | 【反馈腾讯客服】 |
| 30000203 | 请求服务器内部数据打包错误 | 【反馈腾讯客服】 |
| 30000207 | 请求录制服务器通讯错误-拉取录制服务器地址失败 | 【反馈腾讯客服】 |
| 30000208 | 请求录制服务器通讯错误-请求录制服务器超时 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 30000301 | 解析录制服务器回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 30000302 | 解析录制服务器回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 30000303 | 解析录制服务器回包错误-没有返回IP | 【反馈腾讯客服】 |
| 30000304 | 解析录制服务器回包错误-没有返回端口 | 【反馈腾讯客服】 |
| 30000305 | 解析录制服务器回包错误-没有返回结果 | 【反馈腾讯客服】 |
| 30000401 | 查询房间获取grocery服务IP错误 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 30000402 | 查询房间拉取grocery数据错误 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 30000403 | 查询房间拉取grocery不存在（房间不存在） | 【检查是否成功开房，录制的用户ID，groupid是否填写正确】 |
| 30000404 | 查询房间流控服务器超时 | 【可能是网络问题，重试处理，重试失败反馈腾讯客服】 |
| 30000405 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 30000406 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 30000407 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 30000408 | 查询房间回包错误-没有返回结果 | 【反馈腾讯客服】 |
| 30000409 | 查询房间回包错误-数据包解析失败 | 【反馈腾讯客服】 |
| 30000410 | 录制的房间不存在 | 【检查是否成功开房，录制的用户ID，groupid是否填写正确】 |
| 30000411 | 录制的房间不存在，或发起录制的用户不存在 | 【检查是否成功开房，录制的用户ID，groupid是否填写正确】 |
| 30000412 | 停止录制重复发送，用户已经停止录制 | 【如果是录制停止操作说明已经停止，检查是否多次发送停止操作，无需处理】 |
| 30000413 | 停止录制重复发送，用户已经停止录制 | 【如果是录制停止操作说明已经停止，检查是否多次发送停止操作，无需处理】 |
| 30000414 | 查询房间-服务器内部操作类型错误 | 【反馈腾讯客服】 |
| 30000415 | 启动录制重复发送，用户正在录制；或者发起录制的用户不存在 | 【检查是否成功开房，录制的用户ID，groupid是否填写正确】 |



