权限秘钥为可选操作，可用于互动直播进房间时设置音视频权限的协议加密。

## 1 音视频权限密钥

长度：16字符
如：1234567890abcdef

## 2 密文内容

<table class="t">
<tbody><tr>
<th> <b>字段描述</b>
</th><th> <b>类型/长度</b>
</th><th> <b>值定义/备注</b>
</th></tr>
<tr>
<td> cVer
</td><td> unsigned char/1
</td><td> 版本号，填0
</td></tr>
<tr>
<td> wAccountLen
</td><td> unsigned short /2
</td><td> 第三方自己的帐号长度
</td></tr>
<tr>
<td> buffAccount
</td><td> wAccountLen
</td><td> 第三方自己的帐号字符
</td></tr>
<tr>
<td> dwSdkAppid
</td><td> unsigned int/4
</td><td> sdkappid
</td></tr>
<tr>
<td> dwAuthId
</td><td> unsigned int/4
</td><td> 群组号码
</td></tr>
<tr>
<td> dwExpTime
</td><td> unsigned int/4
</td><td> 过期时间 （当前时间 + 有效期（单位：秒，建议300秒））
</td></tr>
<tr>
<td> dwPrivilegeMap
</td><td> unsigned int/4
</td><td> 权限位
</td></tr>
<tr>
<td> dwAccountType
</td><td> unsigned int/4
</td><td> 第三方帐号类型
</td></tr></tbody></table>

## 3 加密方式

1、加密算法：Tea加密

2、加密库及例子：附件[《tea.zip》](http://qzonestyle.gtimg.cn/qzone/vas/opensns/res/doc/tea.zip)

3、加密方法：

（1）密文中的数字转换成网络字节序（大端字节序）；
（2）把密文拼接成一段字符串；
（3）用tea加密对字符串加密，symmetry_encrypt函数输出的字符串即为权限加密串；

## 4 互动直播SDK使用
SDK进房间之后，如果需要修改到指定权限，调用AVMultiRoom接口的以下方法：

```
  /*
  @brief 更改自己在房间内的权限。

  @details 通话中动态修改自己的音视频上下行权限，用于第三方实现权限控制和管理。

  @param [in] auth_buffer 权鉴加密串。

  @return 返回操作结果。
  */
  virtual int32 ChangeAuthority(const std::string& auth_buffer) = 0;
```

其中 auth_buffer就是已生成好的权限加密串, SDK会通过AVMultiRoom::Delegate异步返回修改结果。

```
/// 多人房间委托类，App需要实现其成员函数来响应房间成员变化。
  struct Delegate : public AVRoom::Delegate {

    /**
    @brief AVRoomMulti::ChangeAuthority()的回调函数。

    @details 此函数用来异步返回AVRoomMulti::ChangeAuthority()的执行结果。

    @param ret_code 错误码：
     \n AV_OK 执行成功；
     \n AV_ERR_FAILED 执行失败。
    */

    virtual void OnChangeAuthority(int32 ret_code) = 0;
  };
```

