# 直播接口

iLiveSDK中的音视频通讯能力被抽象为房间这个概念。在同一个房间内的成员可以看到房间内其他成员的音视频，每个房间同时最多可以有四路视频。iLiveSDK(IE)提供了房间管理，音视频设备管理等功能，方便用户建立互动视频。具体的直播业务流程如下：

![业务流程](http://mc.qcloudimg.com/static/img/e6632b362fbc90745505823b1dc295bd/image.png)

## 创建对象
创建iliveSDK对象供后续使用。

```
//iLiveSDK是cab组件的id
var sdk = new ILiveSDK(sdkappid, accounttype, "iLiveSDK");
```

## 初始化
使用其他各项功能前必须将iLiveSDK初始化。

```
sdk.init(function () {
    alert("init succ");
}, function (errMsg) {
    alert("错误码:" + errMsg.code + " 错误信息:" + errMsg.desc);
});
```

## 登录
用户在登录后才能使用消息通讯，互动视频等功能。登录需要填写用户id和签名。其中签名是由[腾讯登录服务](https://cloud.tencent.com/document/product/269/1507)提供的。

```
sdk.login(id, sig, function () {
    alert("login succ");
}, function (errMsg) {
    alert("错误码:" + errMsg.code + " 错误信息:" + errMsg.desc);
});
```

## 音视频权限管理

**业务层需重点关注房间成员的音视频权限**。 只有主播或者需要上麦的观众才能拥有音视频上行的权限。在进入或者创建房间时需要填写正确的权限（详见下文进入房间）。另外成员允许在房间内改变自己的权限。   
您可以在腾讯云[控制台配置](https://github.com/zhaoyang21cn/suixinbo_doc/blob/master/SPEARConfig.md)自身业务需要的角色及其权限，腾讯云服务器会根据房间成员不同的权限分配不同的[接入机](https://cloud.tencent.com/document/product/268/7651)。错误配置权限可能导致不必要的带宽支出和观众异常上行数据等问题。



## 进入/创建房间
创建房间可以设置角色权限，房间号，房间号不能重复。

```js
sdk.createRoom(roomid, "LiveMaster", function () {
    alert("create room succ");
}, function (errMsg) {
    alert("错误码:" + errMsg.code + " 错误信息:" + errMsg.desc);
});
```
加入房间可以填写角色权限，房间号。

```js
sdk.joinRoom(roomid, "Guest", function () {
    alert("join room succ");
}, function (errMsg) {
    alert("错误码:" + errMsg.code + " 错误信息:" + errMsg.desc);
});
```

## 设备管理

### 打开摄像头
在房间中拥有上行权限的成员打开摄像头，其他房间成员就可以获取视频画面数据。没有权限的成员的上行数据会被服务器丢弃。在打开摄像头前可以先调用接口获取当前的摄像头列表。

```js
var szRet = sdk.getCameraList();
if (szRet.code != 0) {
    alert("获取摄像头列表出错; 错误码:" + szRet.code);
    return;
}
var nRet = sdk.openCamera(szRet.cameras[0].id);
if (nRet != 0) {
    alert("打开摄像头失败; 错误码:" + nRet);
}
```
### 关闭摄像头
需要停止视频时，需要关闭摄像头。

```js
var nRet = sdk.closeCamera();
```
### 打开麦克风

```js
var nRet = sdk.openMic();
```
### 关闭麦克风

```js
var nRet = sdk.closeMic();
```
## 视频渲染
收到每个用户的视频数据后，需要使用渲染控件来渲染收到的视频

```js
render.setIdentifer( userid ); //渲染控件设置了用户id后,收到此用户的视频数据，将会自动渲染
```
用户的视频数据停止后，需要对渲染控件进行释放

```js
render.freeRender();
```

##  美颜
设置美颜程度 0~10

```JS
sdk.setBeauty(beauty);
```

设置美白程度 0~10

```JS
sdk.setWhite(white);
```

 销毁美颜滤镜资源；如果开启了美颜功能，在 相机关闭 时，调用即可

```JS
sdk.destroyFilter();
```

说明：
 1. sdk默认关闭美颜
 2. 美颜 和 美白程度都设置为0，sdk自动关闭美颜功能；其中一项不为0，sdk打开美颜功能
 3. sdk.destroyFilter 接口建议在关闭相机后调用





## 退出房间
退出房间并回收资源

```js
sdk.quitRoom(function () {
    alert("quit room succ");
}, function (errMsg) {
    alert("错误码:" + errMsg.code + " 错误信息:" + errMsg.desc);
});
```




## 登出
登录的逆操作

```
sdk.logout(function () {
    alert("logout succ");
}, function (errMsg) {
    alert("错误码:" + errMsg.code + " 错误信息:" + errMsg.desc);
});
```

## 在线状态
用户登录后是有在线状态的，每个账号同时只能在一个终端登录。在其他终端登录时将会把当前终端的登录踢下线，当前终端会收到被踢下线通知。   
sdk允许设置踢下线通知的监听，业务层收到通知后可以在上层处理登录态的变化。
```
sdk.setForceOfflineListener(function() {
    alert("您已被踢下线，请重新登录");
});
```
