#  互动消息和上麦

### 准备
无论是发送消息还是上麦，都需要在创建或进入房间前设置事件和消息监听。示例：
```
//添加im消息监听
//用addMessageListener添加的监听对象，在对象销毁时，必须要调用removeMessageListener,否则会添加多个消息监听，导致收到多个消息的情况
[[[ILiveSDK getInstance] getTIMManager] addMessageListener:self];
```

### 1 发送消息

|接口名|接口描述|
|---|---|
|sendC2CMessage:message:succ:fail:|发送C2C消息|
|sendOnlineC2CMessage: succ: failed:|发送C2C在线消息|
|sendGroupMessage: succ: failed:|发送Group消息|
|sendOnlineGroupMessage: succ: failed:|发送Group在线消息|

**普通消息和在线消息的区别：**

1、发送普通消息，接收方一定能接收到(如果接收方不在线，则下次登录时会再次接收到)

2、发送在线消息，接收方在线，则能收到消息，如果不在线，则收到消息，且以后登录也无法收到消息

以上接口的调用发发类似，下面是发送“群在线消息”的示例代码：

```
//1、发送消息
TIMTextElem *elem = [[TIMTextElem alloc] init];
elem.text = @"msg text";

TIMMessage *msg = [[TIMMessage alloc] init];
[msg addElem:elem];

__weak typeof(self) ws = self;
[[ILiveRoomManager getInstance] sendOnlineGroupMessage:msg succ:^{
    NSLog(@"send msg  succ");
} failed:^(NSString *module, int errId, NSString *errMsg) {
    NSLog(@"send msg fail.M=%@,errId=%d,errMsg=%@",module,errId,errMsg);
}];
```

```
// 2. 消息接收（所有的IM消息都在onNewMessage:中回调）
- (void)onNewMessage:(NSArray *)msgs
{
    //如果没有addMessageListener添加监听对象，则不会收到onNewMessage回调
    NSLog(@"收到消息，在这里解析消息，详细解析步骤，可参考demo程序");
}
```

### 2 上麦
#### 2.1 主播邀请上麦流程图：
![](http://mc.qcloudimg.com/static/img/ccbafe376da2e175ff41bd681856581e/image.png)
------
#### 2.2 观众请求上麦流程图:
![](http://mc.qcloudimg.com/static/img/4d21a6ce428740fa16ebc58a0675b3e7/image.png)
------
#### 2.3 接口

** 注：控制信令全部是通过发送自定义消息实现 **

##### 2.3.1 邀请上麦

```
//消息组装
NSString *dataStr = @"";
NSError *error;
//自定定义消息的data是键-值对，在demo中以kMsgCmdKey作为命令字的key，kMsgDataKey作为其他参数的key
//命令字是用户自己定义的，只需要用的app中统一即可
NSDictionary *sendDic = [NSDictionary dictionaryWithObjectsAndKeys:@(AVIMCMD_Multi_Host_Invite), kMsgCmdKey, dataStr, kMsgDataKey,nil];
NSData *sendData = [NSJSONSerialization dataWithJSONObject:sendDic options:NSJSONWritingPrettyPrinted error:&error];
if(error != nil){
    NSLog(@"serialization msg fail");
    return;
}
TIMCustomElem *imCustomElem = [[TIMCustomElem alloc] init];
[imCustomElem setData:sendData];
TIMMessage *imMessage = [[TIMMessage alloc] init];
[imMessage addElem:imCustomElem];
__weak typeof(self) ws = self;

[[ILiveRoomManager getInstance] sendOnlineC2CMessage:recvId message:imMessage succ:^{
    NSLog(@"发送连麦消息邀请成功");
} failed:^(NSString *module, int errId, NSString *errMsg) {
    NSLog(@"发送连麦邀请失败,M=%@,code=%d,Msg=%@",module,errId,errMsg);
}];
```
##### 2.3.2 上麦接口

```
- (void)onNewMessage:(NSArray *)msgs
{
    //收到消息，解析，判断是否为邀请上麦消息，如果是做上麦操作，解析方法详见demo
    ...
    //上麦步骤：修改角色->打开相机->打开Mic
    __weak typeof(self) ws = self;
    ILiveRoomManager *manager = [ILiveRoomManager getInstance];
    //kSxbRole_InteractHD是demo的角色名，开发者需要改成自己的appid在控制台配置的角色名
    [manager changeRole:kSxbRole_InteractHD succ:^ {
        NSLog(@"上麦:改变角色成功");
        [manager enableCamera:CameraPosFront enable:YES succ:^{
            NSLog(@"上麦:打开摄像头成功");
            [manager enableMic:YES succ:^{
                NSLog(@"上麦:打开麦克风成功");
                NSLog(@"上麦:上麦成功");
            } failed:^(NSString *module, int errId, NSString *errMsg) {
                NSLog(@"上麦:打开麦克风失败,M=%@,code=%d,Msg=%@",module,errId,errMsg);
            }];
         } failed:^(NSString *module, int errId, NSString *errMsg) {
             NSLog(@"上麦:打开摄像头失败,M=%@,code=%d,Msg=%@",module,errId,errMsg);
         }];
    } failed:^(NSString *module, int errId, NSString *errMsg) {
       NSLog(@"上麦:切换角色失败,M=%@,code=%d,Msg=%@",module,errId,errMsg);
    }];
}
```
##### 2.3.3 设置上麦者渲染画面的区域接口

|接口名|接口描述|
|---|---|
|addRenderAt:forIdentifier:srcType:|添加渲染界面的区域，以及设置渲染视图对应的key(通常使用渲染视图对应用户的id)|

|参数类型|参数名|说明|
|---|---|---|
|CGRect|rect|视图渲染区域|
|NSString|forIdentifier|视图对应的key，用作业务逻辑，通常使用画面对应的用户id|
|avVideoSrcType|srcType|视频源类型|

```
- (BOOL)onEndpointsUpdateInfo:(QAVUpdateEvent)event updateList:(NSArray *)endpoints
{
    TILLiveManager *manager = [TILLiveManager getInstance];
    switch (event) 
    {
        case ILVLIVE_AVEVENT_CAMERA_ON:
        {
           for (NSString *user in users) 
            {
                //user:事件对应的用户id
                ILiveFrameDispatcher *frameDispatcher = [[ILiveRoomManager getInstance] getFrameDispatcher];
                ILiveRenderViewForMac *view = [frameDispatcher addRenderAt:NSMakeRect(0, 0, 640, 480) forIdentifier:user    srcType:QAVVIDEO_SRC_TYPE_CAMERA];
                [self.window.contentView addSubview:view];
            }	
        }
        break;
    }
    return YES;
}
```
若上述步骤均无误，则可以实现主播邀请观众连麦，观众成功上麦，直播间中出现多路画面(主播和互动观众的)。
