
## 互动消息

iLiveSDK(Windows)提供了消息通讯的功能。基于消息通讯可以实现房间内成员的群消息，两个用户之间的C2C消息（不用加好友）。当前SDK只支持发文本消息和自定义消息。

### 发送C2C消息

C2C消息指的是两个用户之间的点对点聊天消息。邀请房间成员上麦，点赞等消息可以在业务层通过C2C自定义消息实现。具体的实现可以参考demo。

|接口名|接口描述|
|---|---|
|sendC2CMessage|发送C2C消息|

|参数类型|参数名|说明|
|---|---|---|
|const char *|dstUser|接收方id|
|const Message	&|message|IM消息内容|
|iLiveSuccCallback|suc|发送消息成功回调|
|iLiveErrCallback|err|发送消息失败回调|
|void*|data|用户自定义数据的指针，在成功和失败的回调函数中原封不动地返回|

* 示例

```c++
void OnSendC2CMsgSuc( void* data )
{
  //发送C2C消息成功
}
void OnSendC2CMsgErr( int code, const char *desc, void* data )
{
  //发送C2C消息失败
}
Message message;
MessageTextElem *elem = new MessageTextElem("hello");
message.elems.push_back(elem);
GetILive()->sendC2CMessage(  message, OnSendC2CMsgSuc, OnSendC2CMsgErr, NULL );
```

### 发送群消息
当前仅支持给当前所在房间发群消息，房间内其他成员都会收到该消息。

|接口名|接口描述|
|---|---|
|sendGroupMessage|发送群消息|

|参数类型|参数名|说明|
|---|---|---|
|const Message &|message|消息内容|
|iLiveSuccCallback|suc|发送消息成功回调|
|iLiveErrCallback|err|发送消息失败回调|
|void*|data|用户自定义数据的指针，在成功和失败的回调函数中原封不动地返回|

* 示例

```c++
void OnSendGroupMsgSuc( void* data )
{
  //发送群消息成功
}
void OnSendGroupMsgErr( int code, const char *desc, void* data )
{
  //发送群消息失败
}
Message message;
MessageTextElem *elem = new MessageTextElem("hello");
message.elems.push_back(elem);
GetILive()->sendGroupMessage(  message, OnSendGroupMsgSuc, OnSendGroupMsgErr, NULL );
```
## 接收消息

设置消息监听回调后，SDK每次收到消息都会通知上层。

```c++
void OnMessage(const Message& message)
{
	std::string szSender = message.sender.c_str();	
	for (size_t i = 0; i < message.elems.size(); ++i)
	{
		MessageElem *pElem = message.elems[i];
		switch( pElem->type )
		{
		case TEXT:
			{				
				MessageTextElem *elem = static_cast<MessageTextElem*>(pElem);
				std::cout << elem->content.c_str() << std::endl;
				break;
			}
		case CUSTOM:
			{
				MessageCustomElem *elem = static_cast<MessageCustomElem*>(pElem);
				std::string szDate = elem->data.c_str();
				break;
			}
		default:
			break;
		}
	}
}
GetILive()->setMessageCallBack(OnMessage, NULL);
```

## 连麦互动

### 主播邀请上麦流程:
![邀请上麦](https://mc.qcloudimg.com/static/img/fba65e3aea7b724de6a378589ce5ea55/image.png)<br/>

### 主播断开连麦观众流程:
![断开连麦](https://mc.qcloudimg.com/static/img/c0f507d28e9fb94d21aa6d441ba49623/image.png)<br/>

### 接口
iLiveSDK未对上/下麦进行封装，用户可以参考随心播的sendC2CCustomCmd()和sendGroupCustomCmd()函数，发送自定义消息作为邀请上麦和接受邀请的信令;观众上麦和下麦，需要切换用户角色和修改用户权限;

- 切换角色

|接口名|接口描述|
|---|---|
|changeRole|更改角色|

|参数类型|参数名|说明|
|---|---|---|
|const char *|szControlRole|角色字符串(由用户App的控制台配置)|
|iLiveSuccCallback|suc|成功的回调函数|
|iLiveErrCallback|err|失败的回调函数|
|void* |data | 用户自定义数据的指针，在成功和失败的回调函数中原封不动地返回|

示例:
```c++
void OnChangeRoleSuc( void* data )
{
	//切换角色成功
}
void OnChangeRoleErr( int code, const char *desc, void* data )
{
	//切换角色失败
}
GetILive()->changeRole(Role, OnChangeRoleSuc, OnChangeRoleErr, NULL);
```

