#  互动消息和上麦

### 准备
无论是发送消息还是上麦，都需要在创建或进入房间前设置事件和消息监听。示例：
```
TILLiveManager *manager = [TILLiveManager getInstance];
[manager setAVListener:self]; //设置音视频事件监听
[manager setIMListener:self]; //设置消息监听
```

### 1 发送文本消息

|接口名|接口描述|
|---|---|
|sendTextMessage: succ: failed:|发送文本消息|

|参数类型|参数名|说明|
|---|---|---|
|ILVLiveTextMessage|msg|文本消息类型|
|TCIVoidBlock|succ|发送消息成功回调|
|TCIErrorBlock|failed|发送消息失败回调|

*示例:
```
// 1. 发送文本消息
TILLiveManager *manager = [TILLiveManager getInstance];
ILVLiveTextMessage *msg = [[ILVLiveTextMessage alloc] init];

msg.type = ILVLIVE_IMTYPE_GROUP;    //群消息（也可发C2C消息）
msg.text = @"这里是消息的内容";        //消息内容
msg.sendId = @"这里是消息的发送方id";
msg.sendId = @"这里是消息的接收方id";

[manager sendTextMessage:msg succ:^{
    NSLog(@"发送成功");
} failed:^(NSString *moudle, int errId, NSString *errMsg) {
    NSLog(@"发送失败");
}];
```

```
// 2. 文本消息接收（在文本消息回调中接受文本消息）
- (void)onTextMessage:(ILVLiveTextMessage *)msg
{
    NSLog(@"收到消息：%@", msg.text);
}
```
### 2 上麦
#### 2.1 主播邀请上麦流程图：
![](http://mc.qcloudimg.com/static/img/ccbafe376da2e175ff41bd681856581e/image.png)
------
#### 2.2 观众请求上麦流程图:
![](http://mc.qcloudimg.com/static/img/4d21a6ce428740fa16ebc58a0675b3e7/image.png)
------
#### 2.3 接口
##### 2.3.1 发送自定义消息接口

|接口名|接口描述|
|---|---|
|sendCustomMessage: succ: failed:|发送自定义消息|

|参数类型|参数名|说明|
|---|---|---|
|ILVLiveCustomMessage|msg|自定义消息体|
|TCIVoidBlock|succ|发送自定义消息成功回调|
|TCIErrorBlock|failed|发送自定义消息失败回调|

*示例：
```
TILLiveManager *manager = [TILLiveManager getInstance];
ILVLiveCustomMessage *msg = [[ILVLiveCustomMessage alloc] init];
msg.cmd = ILVLIVE_IMCMD_INVITE;     //邀请信令
msg.type = ILVLIVE_IMTYPE_C2C;      //C2C消息类型
msg.recvId = @"这里是消息的接收方id";

[manager sendCustomMessage:msg succ:^{
    NSLog(@"邀请成功");
} failed:^(NSString *moudle, int errId, NSString *errMsg) {
    NSLog(@"邀请失败"); 
}];
```
##### 2.3.2 上麦接口

|接口名|接口描述|
|---|---|
|upToVideoMember: role: succ: failed:|观众上麦，包括打开摄像头、麦克风，切换角色，切换权限等操作|

|参数类型|参数名|说明|
|---|---|---|
|uint64_t|auth|通话能力权限位,在 QAVCommon.h 文件中可以查看所有权限位定义|
|NSString|role|角色字符串 （由业务方App的控制台生成）|
|TCIVoidBlock|succ|上麦成功回调|
|TCIErrorBlock|failed|上麦失败回调|

*示例：
```
//观众在消息回调中可以收到主播发送自定义消息
- (void)onCustomMessage:(ILVLiveCustomMessage *)msg
{
    TILLiveManager *manager = [TILLiveManager getInstance];
    switch (msg.cmd) 
    {
        case ILVLIVE_IMCMD_INVITE:
        {
            //收到邀请调用上麦接口
            [manager upToVideoMember:ILVLIVEAUTH_INTERACT role:@"腾讯云后台配置的角色" succ:^{
                NSLog(@"上麦成功"); 
            } failed:^(NSString *moudle, int errId, NSString *errMsg) {
                NSLog(@"上麦失败"); 
            }];
        }
        break;
    }
}
```
##### 2.3.3 设置上麦着渲染画面的区域接口

|接口名|接口描述|
|---|---|
|addAVRenderView: forKey:|添加渲染界面的区域，以及设置渲染视图对应的key(一般使用渲染视图对应用户的id)|

|参数类型|参数名|说明|
|---|---|---|
|CGRect|frame|视图渲染区域|
|NSString|key|视图对应的key，用作业务逻辑，一般使用画面对应的用户id|

*示例：
```
- (void)onUserUpdateInfo:(ILVLiveAVEvent)event users:(NSArray *)users
{
    TILLiveManager *manager = [TILLiveManager getInstance];
    switch (event) 
    {
        case ILVLIVE_AVEVENT_CAMERA_ON:
        {
            for (NSString *user in users) 
            {
                //因为主播的渲染位置创建或进入房间的时候已经指定，这里不需要再指定。
                //当然也可根据自己的逻辑再此处指定主播的渲染位置。
                if(![user isEqualToString:self.host])
                { 
                    [manager addAVRenderView:CGRectMake(20, 20, 120, 160) forKey:user];
                }
            }	
        }
        break;
    }
}
```
若上述步骤均无误，则可以实现主播邀请观众连麦，观众成功上麦，直播间中出现多路画面(主播和互动观众的)。
