# ILVB Flowchart with ILiveSDK

![](http://mc.qcloudimg.com/static/img/06d2fb5027be53492249d4b81bd2f5a5/image.png)


# 1 Initialize ILiveSDK
Initialize ILiveSDK when the application starts.

| API | Description |
|---|---|
| InitSdk:  accountType: | Initialize ILiveSDK internal class (AppId is indicated). IMSDK initialization is included internally |

| Parameter Type | Parameter Name | Description |
|---|---|---|
| int | appId | appid of business side |
| int | accountType | accountType of business side |

*Example:
```
[[ILiveSDK getInstance] initSdk:[ShowAppId intValue] accountType:[ShowAccountType intValue]];
```

# 2 Account login

## 2.1 Hosting mode
Hosted mode: user account system is hosted to Tencent Cloud. [More Details](https://cloud.tencent.com/doc/product/269/1509)

| API | Description |
|---|---|
| tlsLogin:  pwd:  succ:  failed: | Log in to Tencent Cloud backend in hosted mode |

| Parameter Type | Parameter Name | Description |
|---|---|---|
| NSString | uid | Account registered by user in hosted mode |
| NSString | pwd | Password registered by user in hosted mode |
| TCIVoidBlock | succ | "Logged in successfully" callback |
| TCIErrorBlock | failed | "Login failed" callback |

*Example:
```
[[ILiveLoginManager getInstance] tlsLogin:@"Account ID " pwd:@" Login password" succ:^{
    NSLog(@"Logged in successfully");
} failed:^(NSString *moudle, int errId, NSString *errMsg) {
    NSLog(@"Login failed");
}];
```

## 2.2 Standalone mode
Standalone mode: The user account system is maintained by the user's own server. In standalone mode, Signature needs to be generated at business backend. The client cannot log in to the Tencent Cloud backend until it obtains the Signature. [More Details](https://cloud.tencent.com/doc/product/269/1508)

| API | Description |
|---|---|
|iLiveLogin:  sig:  succ:  failed: | Log in to Tencent Cloud backend in standalone mode |

| Parameter Type | Parameter Name | Description |
|---|---|---|
| NSString | uid | Account registered by user in standalone mode |
| NSString | sig | The signature obtained by the user at the business backend |
| TCIVoidBlock | succ | "Logged in successfully" callback |
| TCIErrorBlock | failed | "Login failed" callback |

*Example:
```
[[ILiveLoginManager getInstance] iLiveLogin:@"Account ID " sig:@" Signature string" succ:^{
    NSLog(@"Logged in successfully");
} failed:^(NSString *moudle, int errId, NSString *errMsg) {
    NSLog(@"Login failed");
}];
```

# 3 Create a room (join a room)

## 3.1 VJ creates a room

| API | Description |
|---|---|
|createRoom:  option:  succ:  failed: | VJ creates a live room, with local view being automatically rendered, and starts broadcasting |

| Parameter Type | Parameter Name | Description |
|---|---|---|
| int | roomId | The room number generated by the business backend. Its uniqueness should be ensured |
| ILiveRoomOption | option | Options configured when VJ creates a room. You can use API defaultHostLiveOption to obtain the default configurations of VJ. |
| TCIVoidBlock | succ | "Room created successfully" callback |
| TCIErrorBlock | failed | "Failed to create room" callback |

*Example:
```
ILiveRoomOption *option = [ILiveRoomOption defaultHostLiveOption]; //Default VJ configuration
TILLiveManager *manager = [TILLiveManager getInstance];
[manager setAVRootView:self.view]; //Set the view for rendering
[manager addAVRenderView:self.view.bounds forKey:self.host]; //Add rendering position

[manager createRoom:self.roomId option:option succ:^{
    NSLog(@"Room created successfully");
} failed:^(NSString *moudle, int errId, NSString *errMsg) {
    NSLog(@"Failed to create room");
}];
```

## 3.2 Viewer joins the room

| API | Description |
|---|---|
|joinRoom:  option:  succ:  failed: | Viewer joins the room, with remote view being pulled and rendered automatically, and starts watching the broadcasting |

| Parameter Type | Parameter Name | Description |
|---|---|---|
| int | roomId | Room number. generated by the business backend. Its uniqueness should be ensured |
| ILiveRoomOption | option | Options configured when viewer joins a room. You can use API defaultGuestLiveOption to obtain the default configurations of viewer |
| TCIVoidBlock | succ | "Joined the room successfully" callback |
| TCIErrorBlock | failed | "Failed to join the room" callback |

*Example:
```
ILiveRoomOption *option = [ILiveRoomOption defaultGuestLiveOption]; //Default viewer configuration
TILLiveManager *manager = [TILLiveManager getInstance];
[manager setAVRootView:self.view]; //Set the view for rendering
[manager addAVRenderView:self.view.bounds forKey:self.host]; //Add rendering position

[manager joinRoom:self.roomId option:option succ:^{
    NSLog(@"Joined the room successfully");
} failed:^(NSString *moudle, int errId, NSString *errMsg) {
    NSLog(@"Failed to join the room");
}];
```

If the above steps are correctly performed, the VJ starts broadcasting and viewers watches the broadcasting. 

