### 直播码模式下旁路直播和录制支持项

旁路直播开启方式  | 旁路直播录制方式  | 多录制格式|  录制回调 | 开发便利程度 | 可靠性| 资源消耗
:-----: | :-----: | :-----: |:-----: |:-----: | :-----:| :-----:
自动|自动 |FLV/HLS/MP4|✔️|※※※※|※※※※|※
手动|自动 |FLV/HLS/MP4|✔️|※※※|※※※|※※
自动|手动 |MP4|❌|※※|※※|※※※
手动|手动 |MP4|❌|※|※|※※※※


### 1. 录制方法

##### 我们推荐采用自动录制方案。开发者可以通过控制推流的时机来实现对录制的控制。

1.1  方法一： 全局自动录制

* 在开通直播码的时候选择`直播录制`，则所有的旁路直播都会被录制下来。

1.2 方法二： 旁路直播的时候指定录制格式

* 参考`直播码模式下旁路直播开发指南中的旁路直播参数`

1.3 手动录制

如果有特殊的业务需求，仍然可以手工控制录制开始和结束的时间。但此种方式容易出错，需要开发者投入较大精力。具体方法参考附录。

### 2. 录制处理录制事件通知

回调事件的参数格式和应答方案请参考直播码模式下旁路直播开发指南附录。

##### 录制通知的event_type为**100**，代表新的录制文件生成。同时消息体会额外包含如下信息：

| 字段名称  | 类型        | 含义        |
|------------  |-------------|-------------|
| file_id   | string      | 点播用id，在点播平台可以唯一定位一个点播视频文件  |
|file_format|string|录制文件格式|
| video_url  | string      | 点播视频的下载地址  | 
| file_size  | string       | 文件大小  |
| start_time  | int      | 开始时间（unix时间戳，由于I帧干扰，暂时不能精确到秒级）  |
| end_time  | int       | 结束时间（unix时间戳，由于I帧干扰，暂时不能精确到秒级）  |
| stream_param  | string       | 录制的参数，包括房间号，sdkappid等，其中cliRecoId是客户端推流时传入的recordId字段，可以过滤特定的录制文件 |

示例：一个id为9192487266581821586的新的flv录制分片已经生成，播放地址为：`http://200025724.vod.myqcloud.com/200025724_ac92b781a22c4a3e937c9e61c2624af7.f0.flv`。

```json
{
    "appid": XXXXX,
    "channel_id": "2519_2500647",
    "duration": 272,
    "end_time": 1496220894,
    "event_type": 100,
    "file_format": "flv",
    "file_id": "9031868222958931071",
    "file_size": 30045521,
    "record_file_id": "9031868222958931071",
    "sign": "XXXXX",
    "start_time": 1496220622,
    "stream_id": "2519_2500647",
    "stream_param": "txSecret=e48f758df8f3c736ebecf6183640330c2&txTime=5a20f5ca&from=interactive&client_business_type=0&sdkappid=1400027849&sdkapptype=1&groupid=801235&userid=eWpw&ts=59f968c5&cliRecoId=213", 
    "t": 1496221502,
    "video_id": "200011683_481565e0befe4e44903839aebe370ef6",
    "video_url": "http://1252033264.vod2.myqcloud.com/d7a4cabbvodgzp1252033264/0257ade99031868222958931071/f0.flv"
}

```

### 3. 查询录制文件方式的变化

* 在服务器回调事件中可以录制的视频文件的下载地址。
* 如果需要模糊查询，可以使用视频名前缀的方式进行查询。视频名前缀前缀拼接规则为:直播码_录制ID<br/>
假设直播码为：`8888_81265058829fd2e50c8ec2ac78d55127`，则录制文件前缀是：`8888_81265058829fd2e50c8ec2ac78d55127`。
* 查询录制文件的[API文档](https://cloud.tencent.com/document/product/266/7825)

====================================================================

### 附录

#### 如果有特殊的业务需求，仍然可以手工控制录制开始和结束的时间。但此种方式容易出错，需要开发者投入较大精力。

### 1. 手工录制的注意事项

* 手工录制只有MP4格式，无录制回调事件，90分钟生成一个文件。
* 在进入音视频房间开启摄像头之后或者启动屏幕分享之后启动录制，在客户端退出房间之前停止录制。
* 考虑到外网接入，网络可能存在丢包，延迟等情况，启动录制需要有重试的机制，但是重试间隔建议是3s以上
* 注意携带的房间ID，主播ID等参数保证对应关系。

### 2. Android SDK录制接口

##### 2.1 设置录制参数

```java
ILiveRecordOption option = new ILiveRecordOption();
option.fileName(filename);
option.classId(Integer.parseInt(classId));
```

* 录制参数：ILiveRecordOption

字段名|字段类型|默认值|说明
:--:|:--:|:--:|:--:
fileName|String|必填| 录制生成的文件名
classId|int|必填（当前版本请填0）|视频分类ID
transCode|boolean|（暂不支持，默认为NO）|是否转码
screenShot|boolean|（暂不支持，默认为NO）|是否截图
waterMark|boolean|（暂不支持，默认为NO）|是否打水印
sdkType|TIMAvManager.SDKType|必填（当前版本请选Normal）|SDK对应的业务类型
recordType|AVRecordType|AV_RECORD_TYPE_VIDEO|录制类型


##### 2.2 开始录制

```java
ILiveRoomManager.getInstance().startRecordVideo(option, new ILiveCallBack() {
    @Override
    public void onSuccess(Object data) {
        //开始录制成功
    }

    @Override
    public void onError(String module, int errCode, String errMsg) {
        //开始录制失败
    }
});
```

##### 2.3 结束录制

```java
ILiveRoomManager.getInstance().stopRecordVideo(new ILiveCallBack<List<String>>() {
    @Override
    public void onSuccess(List<String> data) {
        //停止录制成功
        for (String url : data){
            //文件id
        }
    }

    @Override
    public void onError(String module, int errCode, String errMsg) {
        //停止录制失败
    }
});
```

### 3. ios SDK录制接口

##### 3.1 设置录制参数

```c++
ILiveRecordOption *option = [[ILiveRecordOption alloc] init];
option.fileName = @"新随心播录制文件";
option.classId = [tag intValue];
option.avSdkType = sdkType;
option.recordType = recordType;
```

* 录制参数：ILiveRecordOption

字段名|字段类型|默认值|说明
:--:|:--:|:--:|:--:
fileName|NSString|必填| 录制生成的文件名
tags|NSArray|必填|视频标签列表
classId|UInt32|必填(当前版本请填0)|视频分类ID
isTransCode|BOOL|（暂不支持，默认为NO）|是否转码
isScreenShot|BOOL|（暂不支持，默认为NO）|是否截图
isWaterMark|BOOL|（暂不支持，默认为NO）|是否打水印
sdkType|AVSDKType|必填（当前版本请选AVSDK_TYPE_NORMAL）|SDK对应的业务类型
recordType|AVRecordType|AV_RECORD_TYPE_VIDEO|录制类型

##### 3.2 开始录制

```c++
[[ILiveRoomManager getInstance] startRecordVideo:option succ:^{
    NSLog(@"已开始录制");
} failed:^(NSString *module, int errId, NSString *errMsg) {
    NSLog(@"开始录制失败");
}];
```

##### 3.3  结束录制

```c++
[[ILiveRoomManager getInstance] stopRecordVideo:^(id selfPtr) {
    NSArray *fileIds = (NSArray *)selfPtr;
    NSLog(@"已停止录制");
} failed:^(NSString *module, int errId, NSString *errMsg) {
    NSLog(@"停止录制失败");
}];
```

### 4. PC SDK录制接口

##### 4.1 设置录制参数

```c++
RecordOption recordOpt;
recordOpt.recordDataType = recordType;
recordOpt.fileName = fileName;
classId = classId;
```

* 录制参数：RecordOption

字段名|字段类型|默认值|说明
:--:|:--:|:--:|:--:
recordDataType|E_RecordDataType|E_RecordCamera|录制类型
fileName|String|必填|录制生成的文件名
classId|int|(暂不支持,默认为0)|视频分类ID

##### 4.2 开始录制

```c++
void onStartRecordVideoSuc(void* data)
{
    //已经开始录制
}

void onStartRecordVideoErr(int code, const char *desc, void* data)
{
    //开始录制失败
}

GetILive()->startRecord(recordOpt, OnStartRecordVideoSuc, OnStartRecordVideoErr, NULL);
```

##### 4.3  结束录制

```c++
void OnStopRecordSuc(Vector<String>& value, void* data)
{
    //已经停止录制
}

void OnStopRecordErr(int code, const char *desc, void* data)
{
    //停止录制失败
}

GetILive()->stopRecord( OnStopRecordSuc, OnStopRecordErr, NULL);
```
