### 直播码模式下旁路直播和录制支持项

旁路直播开启方式  | 旁路直播录制方式  | 多录制格式|  录制回调 | 开发便利程度 | 可靠性| 资源消耗
:-----: | :-----: | :-----: |:-----: |:-----: | :-----:| :-----:
自动|自动 |FLV/HLS/MP4|✔️|※※※※|※※※※|※
手动|自动 |FLV/HLS/MP4|✔️|※※※|※※※|※※
自动|手动 |MP4|❌|※※|※※|※※※
手动|手动 |MP4|❌|※|※|※※※※

### 1. 自动旁路直播

#### 1.1 开通方式

在互动直播控制台的`旁路直播配置`中开启。

#### 1.2 自动旁路直播启动的时机：

* 用户开启摄像头或者屏幕分享成功后，会触发启动旁路直播的逻辑。这个启动过程一般会在3s内完成。
* 如果启动失败，后台会间隔5s做重试启动操作。可以通过回调URL获得旁路直播开启成功的通知。
* 用户退出房间后会停止旁路直播。

### 2. 手动旁路直播

##### 2.1 手工旁路直播的注意事项

* 在进入音视频房间开启摄像头之后或者启动屏幕分享之后启动旁路直播，在客户端退出房间之前停止旁路直播。
* 考虑到外网接入，网络可能存在丢包，延迟等情况，启动旁路直播需要有重试的机制，但是重试间隔建议是3s以上
* 注意携带的房间ID，主播ID等参数保证对应关系。
* 可以在旁路直播的参数中选择是否开启录制。

##### 2.2 开始旁路直播SDK接口

Android

```java
ILivePushOption option = new ILivePushOption()
    .encode(ILivePushOption.Encode.HLS)         // 旁路直播协议类型
    .recordFileType(ILivePushOption.RecordFileType.RECORD_HLS_FLV_MP4)      // 录制文件格式
    .channelName("频道1")                                   // 频道名称 直播码模式下无意义
    .channelDesc("我的频道")                               // 频道描述 直播码模式下无意义
    .recordId(123456);                              //手动推流自动录制时，如果需要后台识别特定的录制文件，用户可以通过这个字段做区分。(使用这个字段时，控制台的“自动旁路直播”开关必须关闭)
ILiveRoomManager.getInstance().startPushStream(option, new ILiveCallBack<ILivePushRes>() {
    @Override
    public void onSuccess(ILivePushRes data) {
        iPushId = data.getChnlId();
        Log.d("PUSH_DBG", "startPush->success id: "+data.getChnlId());
        if (null != data.getUrls()){
            // 打印推流类型及地址
            for (ILivePushUrl url : data.getUrls()){
                Log.d("PUSH_DBG", "type:"+url.getEncode()+", "+url.getRateType()+":"+url.getUrl());
            }
        }
    }

    @Override
    public void onError(String module, int errCode, String errMsg) {
        Log.d("PUSH_DBG", "startPush->failed:"+module+"|"+errCode+"|"+errMsg);
    }
});
```
ios

```c++
ILivePushOption *option = [[ILivePushOption alloc] init];
ILiveChannelInfo *info = [[ILiveChannelInfo alloc] init];
info.channelName = @"测试频道"; //直播码模式下无意义
info.channelDesc = @"测试频道描述"; //直播码模式下无意义
option.channelInfo = info;
option.encodeType = AV_ENCODE_HLS;
option.recrodFileType = AV_RECORD_FILE_TYPE_HLS;
option.recordId = 123456;//手动推流自动录制时，如果需要后台识别特定的录制文件，用户可以通过这个字段做区分。(使用这个字段时，控制台的“自动旁路直播”开关必须关闭)

[[ILiveRoomManager getInstance] startPushStream:option succ:^(id selfPtr) {
    AVStreamerResp *resp = (AVStreamerResp *)selfPtr;
    NSLog(@"推流成功 %@", [resp urls]);
    NSLog(@"推流获取到的频道ID：%llu", resp.channelID)
} failed:^(NSString *module, int errId, NSString *errMsg) {
    NSLog(@"推流失败");
}];
```

pc

```c++
void OnStartPushStreamSuc( PushStreamRsp &value, void *data )
{
    //开始推流成功
    m_channelId = value.channelId;	//频道ID，停止推流时需要使用此ID;直播码模式下，此值始终未0;
    m_pushUrls = value.urls.;		//推流地址
}

void OnStartPushStreamErr( int code, const char *desc, void* data )
{
    //开始推流失败
}

PushStreamOption pushOpt;
pushOpt.pushDataType = E_PushCamera;        //推送数据类型
pushOpt.encode = RTMP;                      //推流数据编码方式
pushOpt.recordFileType = RecordFile_NONE;   //推流时自动录制的文件类型
pushOpt.recordId = 123456;                  //手动推流自动录制时，如果需要后台识别特定的录制文件，用户可以通过这个字段做区分。(使用这个字段时，控制台的“自动旁路直播”开关必须关闭)
GetILive()->startPushStream( pushOpt, OnStartPushStreamSuc, OnStartPushStreamErr, NULL );
```

##### 2.3 停止旁路直播SDK接口

Android

```java
ILiveRoomManager.getInstance().stopPushStream(iPushId, new ILiveCallBack() {
    @Override
    public void onSuccess(Object data) {
        Log.d("PUSH_DBG", "stopPush->success");
    }

    @Override
    public void onError(String module, int errCode, String errMsg) {
        Log.d("PUSH_DBG", "stopPush->failed:"+module+"|"+errCode+"|"+errMsg);
    }
});
```
ios

```c++
//  pushID为startPushStream中返回的频道ID
NSArray *chids = @[(pushID)];
[[ILiveRoomManager getInstance] stopPushStreams:chids succ:^{
    NSLog(@"停止推流成功");
} failed:^(NSString *module, int errId, NSString *errMsg) {
    NSLog(@"停止推流失败");
}];
```

pc

```c++
void OnStopPushStreamSuc( void* data )
{
    //停止推流成功
}

void OnStopPushStreamErr( int code, const char *desc, void* data )
{
    //停止推流失败
}

GetILive()->stopPushStream(m_channelId, OnStopPushStreamSuc, OnStopPushStreamErr, NULL);
```

### 3. 拼接播放地址方式的变化

#### 3.1 直播码计算规则:<br/>

* 直播码=**`BIZID_MD5(房间号_用户名_数据类型)`**。<br/>
* 字符串传输按utf-8编码。摄像头数据类型是main，屏幕分享的数据类型是aux。而BIZID是一个固定的参数，可以在直播控制台的顶部找到它。<br/>
* 假如BIZID=8888,用户名=14y2l2c，房间号=293710，在进行摄像头分享，则`MD5(293710_14y2l2c_main)=81265058829fd2e50c8ec2ac78d55127`。那么直播码就是`8888_81265058829fd2e50c8ec2ac78d55127`。

#### 3.2 拼接播放地址规则

* 播放地址=<font color='blue'>`传输协议://BIZID.liveplay.myqcloud.com/live/直播码[.格式]`</font>
* 以上面为例，三种格式的播放地址依次就是:<br/>
rtmp:`rtmp://8888.liveplay.myqcloud.com/live/8888_81265058829fd2e50c8ec2ac78d55127`<br/>
flv: `http://8888.liveplay.myqcloud.com/live/8888_81265058829fd2e50c8ec2ac78d55127.flv`<br/>
hls:`http://8888.liveplay.myqcloud.com/live/8888_81265058829fd2e50c8ec2ac78d55127.m3u8`<br/>
* 我们强烈建议**<font color='blue'>业务后台拼接播放地址，再下发给客户端</font>**。这样容易应对播放地址拼接规则的变动。

### 4. 旁路直播事件服务器回调通知

回调事件的参数格式和应答方案请参考附录。

#### 旁路直播会收到两种event_type。**0** 代表旁路直播中断，**1** 代表旁路直播开启，同时消息体会额外包含如下信息：

| 字段名称  | 类型        | 含义        |
|-------------|-------------|--------------|
| appname | string      | 推流路径  |
| app         | string      | 推流域名  |
| appid|integer|用户标识|
|stream_param|string|推流参数中的cliRecoId是透传客户端推流时传入的recordId，可以通过这个字段过滤特定的录制文件

示例：腾讯云通知直播流（1234_15919131751）发生断流（event_type=0）事件。

```json
{
    "app": "1234.livepush.myqcloud.com",
    "appid": 1251659802,
    "appname": "live",
    "channel_id": "1234_15919131751",
    "errorcode": 0,
    "errmsg": "", 
    "event_time": 1484033909,
    "event_type": 0,
    "node": "123.126.122.22",
    "sequence": "2480768755672606517",
    "sign": "fef79a097458ed80b5f5574cbc13e1fd",
    "stream_id": "1234_15919131751",
    "stream_param": "txSecret=e48f758df8f3c736ebecf6183640330c2&txTime=5a20f5ca&from=interactive&client_business_type=0&sdkappid=1400027849&sdkapptype=1&groupid=801235&userid=eWpw&ts=59f968c5&cliRecoId=213", 
    "t": 1473126233
    "user_ip": "123.112.131.123"
}
```

====================================================================

### 附录

### 1. 回调事件的参数格式

#### 消息组织格式

通知信息是以 JSON 格式进行组织的，然后放在 HTTP POST 协议体力。<br/>
注意这里的 POST 格式的 ContentType 是 application/json，而不是 multipart/form-data，所以<font color='red'>不要使用 PHP 或者 Java 里读取表单字段的函数</font>来读取信息。

#### 公共的头信息

如下的字段是每种类型的通知消息都一定会携带的：

| 字段名称 | 类型 | 含义 | 备注 |
|------------|-------------|---------|---------|
| t           | string      | 有效时间  |UNIX时间戳(十进制) |
| sign      | string     | 安全签名  | MD5(KEY+t) |
| event_type | int     | 事件类型   | 目前可能值为： 0、1、100、200  |
| stream_id | string     | 直播码   |  标示事件源于哪一条直播流  |
| channel_id | string     | 直播码  | 同stream_id   |

- **stream_id | channel_id（直播码）**
在直播码模式下，stream_id 和 channel_id 两个字段都是同一个值，有两个不同的名字主要是历史原因所致。

- **t（过期时间）**
来自腾讯云的消息通知的默认过期时间是10分钟，如果一条通知消息中的 t 值所指定的时间已经过期，则可以判定这条通知无效，进而可以防止网络重放攻击。t 的格式为十进制UNIX时间戳，即从1970年1月1日（UTC/GMT的午夜）开始所经过的秒数。

- **sign（安全签名）**
<font color='blue'>sign = MD5(key + t) </font>：腾讯云把API鉴权key 和 t 进行字符串拼接后，通过MD5计算得出sign值，并将其放在通知消息里，您的后台服务器在收到通知消息后可以根据同样的算法确认sign是否正确，进而确认消息是否确实来自腾讯云后台。

- **event_type（通知类型）**
目前腾讯云支持三种消息类型的通知：0 — 断流； 1 — 推流；100 — 新的录制文件已生成；200 — 新的截图文件已生成。

### 2. 回调URL的应答方式

很多客户会担心消息丢了怎么办，比如客户的服务器宕机了一下会儿，消息会不会丢失呢？<br/>
腾讯云后台目前的消息可靠性保证机制是基于**简单重传**实现的，即：<br/>
<font color='blue'>如果一条通知消息没有成功发送到您指定的回调URL，腾讯云会反复重试。</font>

那怎么确认消息是已经送达您的服务器了呢？这里是需要您的协助的：<font color='red'>当您的服务器成功收到一条http事件通知消息时，请回复：</font> 200的状态码，以代表您已经成功收到了消息，从而避免腾讯云反复重复通知。

代表：“嗯，我（客户服务器）已经你的通知了，请（腾讯云）不要再不断地发消息给我”。

如果腾讯云没有收到正确回包，会以1次/分钟，最多10次的重试逻辑继续通知。
