This document describes the access method for OpenSDK game voice C# API SDK, which is suitable for the games developed using Unity3D engine.
### 1. Download SDK
SDK is available in the unitypackage format, and you just need double-click to import it into the Unity project. After importing, the directory structure is as follows:
![Directory Structure](https://mc.qcloudimg.com/static/img/ec0d5e296afdffbb9b376aa74fba8409/image.png)
### 2. Instances of Access Codes:
```
public class MainScene : MonoBehaviour{
	void onClickStartContextBtn()
	{
		IQAVVoiceEngine engine = IQAVVoiceEngine.GetEngine ();
		//You need to Apply for AppID and AccountType on Tencent Cloud.
		//The OpenID is generated by App automatically to ensure each user has a unique OpenID. Currently, this ID must be a number.
		engine.SetAppInfo("AppID","AccountType","OpenID");
		
		engine.Init(delegate(int result, string error_info){
			if(result == QAVContext.AV_OK){
				int roomID = 0;       //The RoomID is assigned by App automatically. Users that join a room with the same RoomID can talk with each other.
				string role = "user"; //The role is preset by App developer on the configuration page of Spear engine in Tencent Cloud.
				engine.JoinRoom(roomID, role);
			}
		});
	}
}
```
### 3. Process for Calling API
#### 3.1 Basic API: The basic API is required for both voice messaging and real-time voice.

**API Description:** Acquire the voice engine handle
**Function Prototype:** `IQAVVoiceEngine GetEngine();`
#### 3.2 Real-time Voice API: It is called for real-time voice feature.
**API Description:** Configure the business information
**Function Prototype:** `int SetAppInfo(string appID, string accountType, string openID);`

| Parameter | Type | Description |
|---------|---------|---------|
| appID | string | The game ID on the business activation page. You can apply for one through Tencent Cloud |
| accountType | string | It is applied for through Tencent Cloud |
| openID | string | The unique ID of player, such as the OpenID obtained from mobile QQ or WeChat |
| Returned Value | int | QAVError.AV_OK is returned for a successful operation |

**API Description:** Initialize QAVVoiceEngine. It must be called after SetAppInfo.
**Function Prototype:** `int Init(InitCompleteHandler initHandler);`

| Parameter | Type | Description |
|---------|---------|---------|
| initHandler | InitCompleteHandler | Callback |
| Returned Value | int | QAVError.AV_OK is returned for a successful operation |

**API Description:** Join the voice room
**Function Prototype:** `int JoinRoom(int roomID, String role);`

| Parameter | Type | Description |
|---------|---------|---------|
| roomID | int | The ID for joining a room is assigned by App automatically. Users who join a room with the same ID can talk freely |
| role | string | The role is preset by App developer on the configuration page of Spear engine in Tencent Cloud |

#### 3.3 Voice Messaging API: It is called for the voice massaging feature.

**API Description:** Voice-to-text. To avoid poor recognition result caused by loud game sound, the background sound should be turned off or lowered at the game business layer during recording, to achieve a better voice recognition result.
**Function Prototype:** `int SpeechToText(string fileID);`

| Parameter | Type | Description |
|---------|---------|---------|
| fileID | string | The ID of voice file to be converted to text |

**API Description:** Configure the maximum voice recording length
**Function Prototype:** `int SetMaxMessageLength(int msTime);`

| Parameter | Type | Description |
|---------|---------|---------|
| msTime | int | Configure the duration of voice message (in sec) |

**API Description:** Start recording
**Function Prototype:** `int StartRecording(string filePath);`

| Parameter | Type | Description |
|---------|---------|---------|
| filePath | string | The path of voice file to be played, which can be NULL |

**API Description:** Stop recording
**Function Prototype:** `int StopRecording ();`
**API Description:** Upload voice file
**Function Prototype:** `int UploadRecordedFile (string filePath);`

| Parameter | Type | Description |
|---------|---------|---------|
| filePath | string | The path of voice file to be uploaded |

**API Description:** Download voice file 
**Function Prototype:** `int DownloadRecordedFile (string fileID, string downloadFilePath);`

| Parameter | Type | Description |
|---------|---------|---------|
| fileID | string | The file to be downloaded |
| downloadFilePath | string | The file storage path, which can be NULL |

**API Description:** Play voice file 
**Function Prototype:** `int PlayRecordedFile (string downloadFilePath);`

| Parameter | Type | Description |
|---------|---------|---------|
| downloadFilePath | string | The path of voice file to be played |

**API Description:** Stop playing voice file  
**Function Prototype:** `int StopPlayFile ();`

#### 3.4 Real-time Voice API: It is called for real-time voice feature.
**API Description:** Configure the business information
**Function Prototype:** `int SetAppInfo(string appID, string accountType, string openID);`

| Parameter | Type | Description |
|---------|---------|---------|
| appID | string | The game ID on the business activation page. You can apply for one through Tencent Cloud |
| accountType | string | It is applied for through Tencent Cloud |
| openID | string | The unique ID of player, such as the OpenID obtained from mobile QQ or WeChat |
| Returned Value | int | QAVError.AV_OK is returned for a successful operation |

**API Description:** Initialize QAVVoiceEngine. It must be called after SetAppInfo.
**Function Prototype:** `int Init(InitCompleteHandler initHandler);`

| Parameter | Type | Description |
|---------|---------|---------|
| initHandler | InitCompleteHandler | Callback |
| Returned Value | int | QAVError.AV_OK is returned for a successful operation |

**API Description:** Join the voice room 
**Function Prototype:** `int JoinRoom(int roomID, String role);`

| Parameter | Type | Description |
|---------|---------|---------|
| roomID | int | The ID for joining a room is assigned by App automatically. Users who join a room with the same ID can talk freely |
| role | string | The role is preset by App developer on the configuration page of Spear engine in Tencent Cloud |

**API Description:** Register audio callback. It is used to overlay the audio callback for accompaniment scenes.
**Function Prototype:** `int RegistAudioDataCallback(int srcType, 
QAVAudioCtrl.QAVAudioDataCallback audioDataCallback);`

| Parameter | Type | Description |
|---------|---------|---------|
| srcType | int | Callback |
| Returned Value | int | QAVAudioDataSource_MixToSend = 1, <br>///< Send the mix input to be overlaid for playback for remote users (for example, you cannot hear the accompaniment sound in a room)<br>QAVAudioDataSource_MixToPlay = 3, ///< The speaker mix input to be overlaid for you to hear the accompaniment sound)  |
| audioDataCallback |  | Audio callback, the business layer needs to register this callback function to SDK which obtains the audio data through this callback, and the business layer needs to insert the accompaniment data to SDK in this callback |

#### 4. Error Codes

| Error | Decimal Value | Description |
|---------|---------|---------|
| AV_OK | 0 | Success |
| AV_ERR_FAIL | 1 | Common error |
| AV_ERR_REPETITIVE_OPERATION | 1001 | Repetitive operation |
| AV_ERR_EXCLUSIVE_OPERATION | 1002 | Exclusive operation |
| AV_ERR_HAS_IN_THE_STATE | 1003 | Already in the desired status, without the need for further operation |
| AV_ERR_INVALID_ARGUMENT | 1004 | Error parameter |
| AV_ERR_TIMEOUT | 1005 | Operation timeout |
| AV_ERR_NOT_IMPLEMENTED | 1006 | Feature not implemented |
| AV_ERR_NOT_IN_MAIN_THREAD | 1007 | Operation not performed in the main thread |
| AV_ERR_RESOURCE_IS_OCCUPIED | 1008 | Resource is occupied |
| AV_ERR_CONTEXT_NOT_START | 1101 | AVContext is not enabled |
| AV_ERR_CONTEXT_NOT_STOP | 1102 | AVContext not yet completed |
| AV_ERR_ROOM_NOT_EXIST | 1201 | Room does not exist |
| AV_ERR_ROOM_NOT_EXITED | 1202 | Not exit the room |
| AV_ERR_DEVICE_NOT_EXIST | 1301 | Device does not exist |
| AV_ERR_ENDPOINT_NOT_EXIST | 1401 | Room member does not exist |
| AV_ERR_ENDPOINT_HAS_NOT_VIDEO | 1402 | This member does not join the video broadcasting |
| AV_ERR_TINYID_TO_OPENID_FAILED | 1501 | Failed to convert tinyid to identifier |
| AV_ERR_OPENID_TO_TINYID_FAILED | 1502 | Failed to convert identifier to tinyid |
| AV_ERR_NOT_TRY_NEW_ROOM | 2001 | Not try to join a new room, so stay in the original room |
| AV_ERR_TRY_NEW_ROOM_FAILED | 2002 | Try to join a new room but failed, and the original room is about to be closed |
| AV_ERR_SERVER_FAILED | 10001 | Internal Server Error |
| AV_ERR_SERVER_NO_PERMISSION | 10003 | No permission |
| AV_ERR_SERVER_REQUEST_ROOM_ADDRESS_FAIL | 10004 | Failed to request for the room address |
| AV_ERR_SERVER_CONNECT_ROOM_FAIL | 10005 | Failed to connect to the room |
| AV_ERR_SERVER_FREE_FLOW_AUTH_FAIL | 10006 | Failed to request for the room address because the verification of signature for getting traffic for free is failed in the scenario of free traffic |
| AV_ERR_IMSDK_UNKNOWN | 6999 | IMSDK internal error |
| AV_ERR_IMSDK_TIMEOUT | 7000 | IMSDK internal error |
| AV_ERR_UNKNOWN | 65536 | IMSDK internal error |
| AV_ERR_SOUTIL_INTERNAL_MEMORY_NOT_ENOUGH | 10101 | The mobile ROM space is not enough. It is recommended to delete some programs and restart the App |
| AV_ERR_SOUTIL_INTERNAL_ERROR | 10102 | Internal mobile error. It is recommended to reinstall |
