This document is divided into two parts: steps for activation of Tencent Mobile Gaming and description of audio/video key. To perform cross-room joint broadcasting after the connection, you need to encrypt the permission bit using audio/video key.
## Activating Tencent Mobile Gaming
### Overview of Steps
1. Register a Tencent Cloud account.
2. You need to activate ILVB after connecting to TMG.
3. Create an App to obtain the corresponding AppID (as the unique ID of App) and AccountType which are used by the API SetAppInfo.
4. Provide a unique AppID for the administrator to enable the signaling channel to connect to TMG, so that App can communicate with server using HTTP signaling channel.

### Detailed Steps
#### 1. Register a Tencent Cloud Account
Register a Tencent Cloud account via mailbox, WeChat, QQ and submit relevant information. Please refer to [How to sign up as a Tencent Cloud user](//cloud.tencent.com/document/product/378/8415).

***Note:*** Please use a public QQ number instead of your personal number, to avoid connection problems.
#### 2. Activate ILVB
Go to [Cloud Product - ILVB](//cloud.tencent.com/product/ilvb) page through Tencent Cloud official website, and click **Activate Service**. As shown below:
![Activate ILVB](https://mc.qcloudimg.com/static/img/b095673b7245e928ac4418dde3a8336e/image.png)
You are directed to the following page after clicking **Activate Service**, and then click **Apply for Activation of ILVB**. As shown below:
![Apply for Activation of ILVB](https://mc.qcloudimg.com/static/img/427cbff42f9ca344272ae504cf054dae/image.jpg)
In the activation page, as shown below, enter the user information (customer name, QQ number, contact number, etc.) and the business information (required services, product stage, etc.), and then submit the application.
![Enter Information](https://mc.qcloudimg.com/static/img/0e78cf07232df6e8bf2dcebccae733b2/image.jpg)
After you submit the application, a pop-up window indicating successful submission appears. The review process will be completed within five business days.
#### 3. Create App
Visit Tencent Cloud [Business Backend](//cloud.tencent.com/login?s_url=https%3A%2F%2Fconsole.cloud.tencent.com%2Filvb), and you need to complete identify verification if you have not passed the developer identity verification .For more information, please see [Guide](//cloud.tencent.com/document/product/378/3629) (Individual verification is recommended).
After entering the basic information, you can create a new App, and obtain the corresponding AppId and AccountType (***Note***: Remember these two parameters, as the API SetAppInfo may use them). 
![Obtain id and type](https://mc.qcloudimg.com/static/img/e52f0fb14bbda2d6915874aaa1036e4d/image.png)
#### 4. Enable Signaling Channel
You can use built-in HTTP signaling channel of SDK for connection by following the steps below:
1. Provide AppID to Tencent Cloud API user (or administrator) to configure it as supporting HTTP channel;
2. When you integrate the feature, use [Audio/Video Key to Encrypt Permission Bit](//cloud.tencent.com/document/product/268/3220) to perform "enterroom" operation. For more information, please see the description of audio/video key below.

## Audio/Video Key
ILVB provides audio/video key for the encryption and authentication of relevant features. Currently, the key is mainly used for the encryption of uplink and downlink permissions and the cross-room joint broadcasting.
* Key: AppId corresponds to the md5 value of audio/video key, with a length of 16 bytes.
* Encryption algorithm: Tea
* Encryption library and example: Appendix [tea.zip](https://mc.qcloudimg.com/static/archive/343de5a224bef9be41bb81192affdebb/tea.zip)

Obtain the key in the following location at Tencent Cloud backend.
![Obtain Key](https://mc.qcloudimg.com/static/img/8a42ee6789477a4074c2fc2b49724f80/image.png)
The key will take effect within 15 minutes to 1 hour once modified. Avoid frequent modification.
### Encrypting Permission for Joining Room
#### 1. Ciphertext Content
| Field Description | Type/Length | Value Definition/Note |
|---------|---------|---------|
| cVer | unsigned char/1 | Version Number. Enter 0 |
| wAccountLen | unsigned short /2 | Length of third-party account |
| buffAccount | wAccountLen | Characters of third-party account |
| dwSdkAppid | unsigned int/4 | sdkappid |
| dwAuthId | unsigned int/4 | Group ID, i.e. roomid |
| dwExpTime | unsigned int/4 | Expiration time <br>(current time + validity period) (in sec). 300 seconds is recommended.
| dwPrivilegeMap | unsigned int/4 | Permission bit. Recommendations: <br>**Audio-only scenario:**<br>If you need to join broadcasting, configure: AUTH_BITS_CREATE_ROOM&#124;AUTH_BITS_JOIN_ROOM&#124;<br>AUTH_BITS_SEND_AUDIO&#124;AUTH_BITS_RECV_AUDIO<br>If you don't need to join broadcasting, configure: AUTH_BITS_CREATE_ROOM&#124;AUTH_BITS_JOIN_ROOM&#124;<br>AUTH_BITS_RECV_AUDIO<br>**Video scenario:**<br>If you need to join broadcasting, configure: AUTH_BITS_CREATE_ROOM&#124;AUTH_BITS_JOIN_ROOM&#124;<br>AUTH_BITS_SEND_AUDIO&#124;AUTH_BITS_RECV_AUDIO&#124;<br>AUTH_BITS_SEND_CAMERA_VIDEO&#124;AUTH_BITS_RECV_CAMERA_VIDEO&#124;<br>AUTH_BITS_SEND_SCREEN_VIDEO&#124;AUTH_BITS_RECV_SCREEN_VIDEO<br>If you don't need to join broadcasting, configure: AUTH_BITS_CREATE_ROOM&#124;AUTH_BITS_JOIN_ROOM&#124;<br>AUTH_BITS_RECV_AUDIO&#124;AUTH_BITS_RECV_CAMERA_VIDEO&#124;<br>AUTH_BITS_RECV_SCREEN_VIDEO<br>[For more information, please click here](//cloud.tencent.com/document/product/268/3227) |
| dwAccountType | unsigned int/4 | Third-party account type. [Find it here](//cloud.tencent.com/login?s_url=https%3A%2F%2Fconsole.cloud.tencent.com%2Filvb) |

#### 2. Encryption Method
1. Click to download [google protobuf](//github.com/google/protobuf) for use. The output is a binary string after serialization.
2. Convert numbers in ciphertext to network byte order (big endian), and convert the encrypted string into a hexadecimal string in a case-insensitive manner.
3. Encrypt the binary string using Tea. The string output by symmetry_encrypt function is the encrypted string (authBuf).

#### 3. Tips on Usage
1. The encrypted string (authBuf) generated at the backend is sent to the client.
2. authBuf is passed when client calls JoinRoom function while joining a room.
