## 简介

客户端在发起上传前，需要向 APP 服务器请求上传签名（背景请参考[客户端上传综述](/document/product/266/9219)）。如果 APP 服务器允许客户端上传，则应按照本文介绍的签名规则为客户端生成一个上传签名。客户端执行上传操作时，必须携带该签名，让腾讯云点播验证客户端的上传是否被授权。

## 符号说明

### 签名参数

生成签名需要APP服务器确定4个必选参数（以及任意个可选参数），用户构造签名的明文串，参数如下：

#### 必选参数

| 参数名称 | 必选 | 类型 | 说明 |
| --- | --- | --- | --- | --- |
| secretId | 是 | String | 构造签名明文串的参数，[云 API 密钥](https://console.cloud.tencent.com/capi)中的 Secret ID。 |
| currentTimeStamp | 是 | Integer | 构造签名明文串的参数，当前 Unix 时间。 |
| expireTime | 是 | Integer| 构造签名明文串的参数，签名到期 Unix 时间。<br/>```expireTime = currentTimeStamp + 签名有效时长```<br/>签名有效时长最大取值为7776000，即90天。 |
| random | 是 | Integer | 构造签名明文串的参数，无符号32位随机数。 |

#### 可选参数

| 参数名称 | 必选 | 类型 | 说明 |
| --- | --- | --- | --- | --- |
| classId | 否 | Integer | 视频文件分类，默认为0。 | 
| procedure | 否 | String | 视频后续任务操作，详见[任务流综述](/document/product/266/10263)。| 


## 签名生成步骤

APP 服务器生成一个上传签名包括以下步骤。

### 第一步：获取 API 密钥

在 [云 API 密钥](https://console.cloud.tencent.com/capi) 管理里获取或者创建一个 SecretID，并拿到其对应的 SecretKey。

![](//mc.qcloudimg.com/static/img/23f95aaa97adf3eeae3bf90470fe5122/image.png)

### 第二步：拼接明文串

按照 URL QueryString 的格式要求生成签名明文串 Original<sup>[注 1](#.E6.B3.A8-1)</sup>，格式如下：

```
secretId=[secretId]&currentTimeStamp=[currentTimeStamp]&expireTime=[expireTime]&random=[random]
```

### 第三步：将明文串转为最终签名

生成签名明文串 Original 后，用已获取的 secretKey 对明文串进行 [HMAC-SHA1](https://www.ietf.org/rfc/rfc2104.txt) 加密，得到 SignatureTmp<sup>[注 2](#.E6.B3.A8-2)</sup>：

```
SignatureTmp = HMAC-SHA1(secretKey, Original) 
```

将密文串 SignatureTmp 放在明文串 Original 前面，拼接后进行 [Base64](https://tools.ietf.org/html/rfc4648) 编码，得到最终的签名 Signature：

```
Signature = Base64(append(SignatureTmp, Original)) 
```

## 注意事项
### 注 1

签名明文串 Original 需要满足：

* 至少包含 secretId， currentTimeStamp，expireTime 和 random 四个必选参数，可包含任意多个选填参数
* 参数值***必须***经过 URL 编码，否则可能导致 Query String 解析失败

***建议*** ：直接操作字符串的方式生成 Original 很容易出错，大多数编程语言均提供了相关类库帮助开发者完成 QueryString 的拼接和编码。因此，建议开发者尽量使用标准的类库来构造 Original。

### 注 2

签名密文串 SignatureTmp 的输出结果是20字节的二进制串。

## 多语言签名示例

此处提供多种语言平台的客户端签名生成示例，APP 可以根据开发语言的偏好参考对应的示例：

[PHP 示例](/document/product/266/9493)

[Node.js 示例](/document/product/266/9243)

[Java 示例](/document/product/266/9609)

[c# 示例](/document/product/266/9762)

## 签名生成和校验工具

此处提供了一组签名工具，帮助用户验证自己生成的签名是否正确：

[点播客户端上传-签名生成工具](https://video.qcloud.com/signature/ugcgenerate.html)：在页面上填写签名所需要的参数和密钥，即可生成一个合法的签名。

[点播客户端上传-签名校验工具](https://video.qcloud.com/signature/ugcdecode.html)：对一个合法的签名进行解析，获得生成签名时所使用的参数。
