## 转码参数模板介绍
对音视频文件进行转码，涉及很多复杂参数，开发者可以将这些参数组合成参数模板，在调用点播相关接口来处理视频时，可以仅指定参数模板，而无需传递一系列复杂参数。 
转码参数模板会在以下几种场景中用到：
1. 对视频文件进行处理接口（[ProcessFile](/document/product/266/9642)）中的[转码控制参数](/document/product/266/9642#transcode.EF.BC.88.E8.BD.AC.E7.A0.81.E6.8E.A7.E5.88.B6.E5.8F.82.E6.95.B0.EF.BC.89)。

### 转码模板通用参数说明
| 参数名称 | 说明 | 取值范围 |
|---------|---------|---------|
| 模板ID（definition） | 一个模板的唯一标志，由点播系统分配 | 大于0 |
| 封装格式（container） | 视频的封装格式 | HLS/MP4/FLV |
| 是否去除视频流（isFiltrateVideo） | 若去除，则为纯音频文件 | 1为去除视频流，0为保留，默认为0 |
| 是否去除音频流（isFiltrateAudio） | 若去除，则为纯视频文件 | 1为去除视频流，0为保留，默认为0 |

### 转码模板视频参数说明
| 参数名称 | 说明 | 取值范围 |
|---------|---------|---------|
| 编码器（codec） | 能够对视频进行压缩或者解压缩的程序或者设备 | libx264（H264编码），libx265（H265编码） |
| 帧率（fps） | 用于测量显示帧数的量度 | 24、25、30。单位hz |
| 分辨率开启自适应（resolutionSelfAdapting） | 若开启，则宽的值用于较长边，高的值用于较短边 | 1为开启，0为关闭。 默认为1 |
| 宽（width） | 视频播放时的宽 | [128，1920]。 单位：px |
| 高（height） | 视频播放时的高 | [128，最大1920]。 单位：px |
| 色度空间（colorSpace） | 在某些标准下用通常可接受的方式对彩色加以说明 | 只支持 YUV420P |
| 位深（bitDepth） | 每一个像素在计算机中所使用的位数就是位深 | 只支持 8 |
| 码率模式（rateControlMode）| 视频码率的格式 | 只支持 ABR |
| 码率（bitrate） | 视频流中，单位时间内传输或处理的比特的数量 | [128，10000]。单位kbps |

### 转码模板音频参数说明
| 参数名称 | 说明 | 取值范围 |
|---------|---------|---------|
| 编码器（codec） | 能够对音频进行压缩或者解压缩的程序或者设备 | AAC/MP3 |
| 码率（bitrate） | 音频流中，单位时间内传输或处理的比特的数量 | [26，256]。单位kps|
| 通道（soundSystem） | 音频通道个数 | 1或者2 |
| 采样频率（sampleRate） | 录音设备在一秒钟内对声音信号的采样次数，采样频率越高声音的还原就越真实越自然 | 44100,48000。单位hz |

## 点播系统标准转码输出模板
为简化调用，点播预定义了一系列标准转码模板，每一个模板都对应一组转码参数。
标准转码模板中，有一些参数都是统一的： 
1. 不会过滤视频流，音频流，
2. 开启分辨率自适应，
3. 色度空间为YUV420P，
4. 位深为8
5. 码率模式为ABR
6. 音频都是双通道的


<table style="display:table">
    <tr>
        <td rowspan=2>
            模板ID                
        </td>
        <td rowspan=2>
            封装格式                
        </td>
        <td colspan=4>    
            视频参数        
        </td>
        <td colspan=4>    
            音频参数        
        </td>
    </tr>
    <tr>
        <td>
            编码器
        </td>
        <td>
            帧率
        </td>
        <td>
            宽
        </td>
        <td>
            高
        </td>
        <td>
            码率
        </td>
        <td>
            编码器
        </td>
        <td>
            码率
        </td>
        <td>
            采样频率
        </td>
    </tr>
    <tr>
        <td>
            10
        </td>
        <td>
            MP4
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            320
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            256kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            20
        </td>
        <td>
            MP4
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            640
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            512kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            30
        </td>
        <td>
            MP4
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            1280
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            1024kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            40
        </td>
        <td>
            MP4
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            1920
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            2500kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            210
        </td>
        <td>
            HLS
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            320
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            256kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            220
        </td>
        <td>
            HLS
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            640
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            512kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            230
        </td>
        <td>
            HLS
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            1280
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            1024kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            240
        </td>
        <td>
            HLS
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            1920
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            2500kbps
        </td>
        <td>
            ACC
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            10046
        </td>
        <td>
            FLV
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            320
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            256kbps
        </td>
        <td>
            MP3
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            10047
        </td>
        <td>
            FLV
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            640
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            512kbps
        </td>
        <td>
            MP3
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            10048
        </td>
        <td>
            FLV
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            1280
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            1024kbps
        </td>
        <td>
            MP3
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            10049
        </td>
        <td>
            FLV
        </td>
        <td>
            H.264
        </td>
        <td>
            24
        </td>
        <td>
            1920
        </td>
        <td>
            按原视频的DAR或PAR缩放（DAR优先）
        </td>
        <td>
            2500kbps
        </td>
        <td>
            MP3
        </td>
        <td>
            48kbps
        </td>
        <td>
            44100Hz
        </td>
    </tr>
</table>
