## 接口名称
VodBackupGet

## 功能说明
1. 分页获取冷备视频文件
2. 指定fileId查询冷备视频文件
3. 指定文件名前缀搜索冷备视频文件
4. 按创建时间排序
5. 不指定任何查询/过滤条件即为全量拉取

## 请求方式

### 请求域名
vod.api.qcloud.com

### 最高调用频率
100次/分钟

### 参数说明
| 参数名称          | 必填   | 类型      | 说明                                       |
| ------------- | ---- | ------- | ---------------------------------------- |
| fileId.n      | 否    | String  | 视频ID列表（排斥其它过滤条件，最大100个）                  |
| prefix        | 否    | String  | 文件名前缀                                    |
| orderby       | 否    | Integer | 排序方式。0：创建时间升序；1：创建时间降序。默认0               |
| pageSize      | 否    | Integer | 分页大小，范围1-100，默认10                        |
| context       | 否    | String  | 续传上下文。首次不填，续拉时携带前一次返回的结果                 |
| COMMON_PARAMS | 是    |         | 参见[公共参数](/document/product/266/7782#.E5.85.AC.E5.85.B1.E5.8F.82.E6.95.B0) |

### 请求示例

1. 全量分页拉取冷备视频信息，使用默认页大小和默认排序

```
https://vod.api.qcloud.com/v2/index.php?Action=VodBackupGet
&COMMON_PARAMS
```

2. 全量分页拉取冷备视频信息，续传(context是上一请求返回的字段)

```
https://vod.api.qcloud.com/v2/index.php?Action=VodBackupGet
&context=OYdtlAD5DqRXFyB7fqPYFqD7FaPXGaD8GiNQeAd9DqTxfaPXfaNyfyHzeAdSDqTQL8drLkhrjCrvlIDVDS7QGqBXoH==
&COMMON_PARAMS
```

3. 指定文件名前缀搜索视频

```
https://vod.api.qcloud.com/v2/index.php?Action=VodBackupGet
&prefix=6000ab
&COMMON_PARAMS
```

4. 指定fileId获取文件信息
```
https://vod.api.qcloud.com/v2/index.php?Action=VodBackupGet
&fileId.0=9031868222808082655
&fileId.1=9031868222808082709
&COMMON_PARAMS
```

## 接口应答

### 参数说明
| 参数名称      | 类型      | 说明                     |
| --------- | ------- | ---------------------- |
| code      | Integer | 错误码, 0: 成功, 其他值: 失败    |
| message   | String  | 错误信息                   |
| fileCount | Integer | 返回的文件个数                |
| context   | String  | 续传上下文，续传时请求填写此字段，空表示完成 |
| fileSet   | Array   | 该视频的播放信息结果集            |

files该视频的播放信息结果集

| **参数名称**   | **类型**  | **描述**     |
| ---------- | ------- | ---------- |
| fileId     | String  | 文件唯一标识     |
| name       | Integer | 文件名        |
| size       | Integer | 文件大小，单位：字节 |
| type       | String  | 文件类型       |
| duration   | Integer | 时长，单位：秒    |
| createTime | String  | 创建时间       |
| expireTime | String  | 过期时间       |
| url        | String  | 冷备文件链接     |

### 错误码说明
| 错误码       | 含义说明                                  |
| --------- | ------------------------------------- |
| 4000-7000 | 参见[公共错误码](/document/product/266/7783) |
| 1         | 内部错误                                  |
| 1000      | 无效参数                                  |
| 1001      | 内部错误                                  |
| 1003      | 内部错误                                  |
| 2000      | 内部错误                                  |
| 10008     | 文件不存在                                 |
| 70005     | context无效                             |
| 70006     | context使用方式有误                         |
| 70008     | 拉取已经完成                                |

### 应答示例
```javascript
{
    "code": 0,
    "message": "",
    "codeDesc": "Success",
    "context": "OYdtlAD5DqRXFyB7fqPYFqD7FaPXGaD8FaRQeAd9DqTxfaPXfaNyfaNzeAdSDqTQL8drLkhrjCrvlIDVDS7QGqf2",
    "fileSet": [
        {
            "fileId": "9031868222808082655",
            "name": "6000_3dS-wEDrQl8_2016-11-30-10-32-51_2016-11-30-10-34-31",
            "duration": 35,
            "status": 2,
            "createTime": "2016-11-30 10:34:33",
            "expireTime": "2016-12-30 10:34:33,
            "url": "http://1000.vod2.myqcloud.com/vodgzp/9031868222808082655/0.mp4"
        },
        {
            "fileId": "9031868222808082684",
            "name": "6000_dJcYGl1xh20_2016-11-30-10-36-10_2016-11-30-10-36-52",
            "duration": null,
            "status": 2,
            "createTime": "2016-11-30 10:36:54",
            "expireTime": "2016-12-30 10:36:54",
            "url": "http://1000.vod2.myqcloud.com/vodgzp/9031868222808082684/xy.mp4"
        },
        {
            "fileId": "9031868222808082709",
            "name": "6000_d2Gy53yS9yU_2016-11-30-10-34-53_2016-11-30-10-37-52",
            "duration": 47,
            "status": 2,
            "createTime": "2016-11-30 10:37:55",
            "expireTime": "2016-12-30 10:37:55",
            "url": "http://1000.vod2.myqcloud.com/vodgzp/9031868222808082709/1.mp4"
        }
    ]
}
```
