## 接口名称
GetTaskList

## 功能说明
1. 查询任务列表；
2. 当列表数据比较多时，单次接口调用无法拉取整个列表，这时可以通过参数next分批拉取；
3. 只能查询到三天（72小时）内的任务。

## 请求方式

### 请求域名
vod.api.qcloud.com

### 最高调用频率
100次/分钟

### 参数说明
| 参数名称 | 必填 | 类型 | 说明 |
|---------|---------|---------|---------|
| fileId | 否 | String | 文件ID，该字段若填写，则只会查询该文件的任务列表。 |
| status      | 是    | String | 任务状态，有WAITING/PROCESSING/FINISH 三种。               |
| maxCount      | 否    | Integer | 本次查询返回多少个数据，范围在10-100之间，不填默认为10。                         |
| next        | 否    | String | 分批拉取时使用： 当列表数据比较多时，单次接口调用无法拉取整个列表，这时会返回拉取到的最后一个数据的ID，下次请求携带该ID，将会从该ID下一个开始拉取。                       |
| COMMON_PARAMS | 是 |  | 参见[公共参数](/document/api/213/6976)。 |

### 请求示例
```
https://vod.api.qcloud.com/v2/index.php?Action=GetTaskList
&next=59b61160f78939626efd644b
&startTime=1505294672
&endTime=1505295672
&status=Processing
&COMMON_PARAMS
```
## 接口应答

### 参数说明
| 参数名称 | 类型 | 说明 |
|---------|---------|---------|
| code | Integer | 错误码，0：成功, 其他值：失败。 |
| message | Integer | 错误信息。 |
| data | Object | 任务信息数据。 |
| data.next | String | 当列表比较多时，单次接口调用无法拉取全部列表，这时会返回拉取到的最后一个数据的ID，下次请求携带该ID，将会从该ID下一个开始拉取。 如果为空表示已经拉完最后一个数据。 |
| data.status | String | 任务状态，取值 WAITING/PROCESSING/FINISH。 |
| data.taskList | Array | 任务信息列表。 |
| data.taskList.vodTaskId | String | 任务ID。 |
| data.taskList.type | String | 任务类型。 |
| data.taskList.createTime | Integer | 任务创建时间（Unix时间戳）。 |
| data.taskList.beginProcessTime | Integer | 任务开始执行的时间（Unix时间戳），若任务还在排队中，该值为0。 |
| data.taskList.finishTime | Integer | 任务信息最近更新时间（Unix时间戳），若任务还未完成，该值为0。 |
| COMMON_PARAMS |  | 参见[公共参数](/document/product/266/7782#.E5.85.AC.E5.85.B1.E5.8F.82.E6.95.B0)。 |

### 错误码说明
| 错误码 | 含义说明|
|---------|---------|
| 4000-7000 | 参见[公共错误码](/document/product/266/7783)。  |
| 1000 | 参数非法。  |
| 10027 | 系统内部错误。  |

### 应答示例

```javascript
{
    "code": 0,
    "message": "",
    "data": {
        "status": "PROCESSING",
        "next": "68bfa4c7b3244d1c3acb5b70",
        "taskList": [
            {
                "vodTaskId": "1251132654-Procedure-d7c9631c15ecf653b1ff67e34cb046ff",
                "type": "procedure",
                "createTime": 1485156352,
                "beginProcessTime": 1485156354,
                "finishTime": 1485156352
            },
            {
                "type": "transcode",
                "vodTaskId": "1251132654-Procedure-d7c9631c15ecf653b1ff67e34cb046bb",
                "createTime": 1485156352,
                "beginProcessTime": 1485156354,
                "finishTime": 1485156352
            }
        ]
    }
}
```