## API Name
SimpleConcatHls

## Feature Description
1. This API is used to stitch together multiple HLS video m3u8 files into a new m3u8 file;
1. Main application scenario: If an APP uses Tencent Cloud LVB/ILVB service and enables recording, the recorded files will be placed into the VOD system; during LVB/ILVB, there may be a **temporary* interruption of recording (such as VJ network fluctuations), resulting in multiple recording files generated in a LVB process; assuming that the format of the recorded output video is HLS, then in some cases, the APP can directly stitch together the index files (m3u8 files) of the recorded video clips​into a new m3u8 file, thus achieving a simple and fast video stitching;
1. It is a synchronous API, and will immediately return to the newly generated m3u8 file;
1. Its advantage is that it can complete the stitching of m3u8 files in a fast manner; its disadvantage is that the output video may not be played back normally;
1. If you want to get a stitched video that can be played back normally, use the [Video Stitching](/document/product/266/7821) API.

**Note:**

1. **Not** all stitched m3u8 files of any two valid HLS video clips can be played back normally;
2. Even if a m3u8 file is generated by calling this API, the file may *not* be played back normally;
3. After completion of stitching, the caller needs to manually confirm whether the generated m3u8 file can be played back.

**When calling this API, the APP must ensure that: **

1. Each HLS to be stitched​has the same stream ID,  and each LVB/ILVB scenario should have the same stream ID or VJ;
1. All HLS files to be stitched​must be sorted in chronological order;
1. The interval between two adjacent HLS files to be stitched shall not exceed 1 minute.

Failure of any of the above conditions may lead to **failing** in playing back the generated HLS.

## Request Method

### Request Domain
vod.api.qcloud.com

### Peak Calling Frequency
100 counts/min

##### Parameter Description
| Parameter Name | Required | Type | Description |
|---------------|----------|---------|---------|
| srcFileList.n.fileId | Yes | String | List of file IDs|
| name          | Yes | String    | Name of the stitched file |
| COMMON_PARAMS | Yes |  | Refer to [Common Parameters](/document/product/266/7782#.E5.85.AC.E5.85.B1.E5.8F.82.E6.95.B0) |

### Request Example
```
https://vod.api.qcloud.com/v2/index.php?Action=SimpleConcatHls
&srcFileList.0.fileId=16092504232103571364
&srcFileList.1.fileId=16092504232103571365
&name=testfile
&COMMON_PARAMS
```
## API Response

##### Parameter Description
| Name | Type | Description |
|---------|---------|---------|
| code | Integer | Error code, 0:  Succeeded, other values:  Failed |
| message | String | Error message |
| fileId | String | ID of the stitched file |

### Error Code Description
| Error Code | Description |
|---------|---------|
| 4000-7000 | Refer to [Common Error Codes](/document/product/266/7783)  |
| 1000 | Invalid parameter  |
| 1001 | User information error  |
| 10009 | Unexpected file status  |

### Response Example
```javascript
{
    "code": 0,
    "message": "",
    "fileId": "16092504232103571365",
    "fileUrl": "http://vcloud1200.tc.qq.com/1200_5b9688d481d8b811095d30a78cf44c4285026a4c.playlist.m3u8"
}
```

