## 接口名称
CreateTranscodeTemplate

## 功能说明
1. 创建新的转码模板。

> 注意：
> - 用户创建的模板数最最多16个。

## 请求方式

### 请求域名
vod.api.qcloud.com

### 最高调用频率
100次/分钟

### 参数说明
| 参数名称 | 必填 | 类型 | 说明 |
|---------|---------|---------|---------|
| name | 否 | String | 转码模板的名字，长度必须小于64字节。 默认为空字符串。 |
| container | 是 | String | 封装格式，支持mp4，flv，hls。 |
| comment | 否 | String | 对该模板的描述，长度必须小于256字节。 默认为空字符串。 |
| isFiltrateVideo | 否 | Integer | 去除视频数据，1为去除，0为保留，默认为0。 |
| isFiltrateAudio | 否 | Integer | 去除音频数据，1为去除，0为保留，默认为0。 |
| video | 是 | Object | 视频流配置信息，当isFiltrateVideo为1，则该字段将被忽略。 |
| video.codec | 是 | String | 视频流的编码格式，可填 libx264（H264编码），libx265（H265编码），目前H265编码必须指定分辨率，并且需要在640*480以内。 |
| video.fps | 是 | Float | 帧率，取值 24、25、30等，单位：hz。 |
| video.resolutionSelfAdapting| 否 | String | 分辨率开启自适应：open为开启，close为关闭。 若为open，则width的值用于较长边，height的值用于较短边（长边的值不得短于短边）, 默认为open。 |
| video.width | 否 | Integer | 视频流宽度的最大值，若不填或者填0，而video.height填写了非0值，则按比例缩放，如果video.height也没填或者填0，则表示同源。 该值最小128，最大1920，单位：px。 |
| video.height | 否 | Integer | 视频流高度的最大值，若不填或者填0，而video.width填写了非0值，则按比例缩放，如果video.width也没填或者填0，则表示同源。 该值最小128，最大1920，单位：px。 |
| video.bitrate | 否 | Integer | 视频流的码率，大于等于128，小于等于10000，单位：kbps。 |
| video.minGop | 否 | Integer | 视频关键帧最小间隔，取值范围1~10。 |
| video.maxGop | 否 | Integer | 视频关键帧最大间隔，取值范围1~10。 |
| video.videoProfile | 否 | String | 视频编码档次，H.264编码档次可选择以上三种之一,默认为High，H.265则默认只能为Main。 |
| video.colorSpace | 否 | String | 视频色度空间，H.264只支持yuv420p，H.265支持yuv420p或者yuv420p10le。 |
| video.deinterlaced | 否 | Integer | 视频去隔行模式，1：去隔行，0：保持视频隔行模式。 |
| video.videoRateControl | 否 | Integer | 视频压缩模式，0表示one pass，1表示two pass。|
| audio | 是 | Object | 音频流配置信息，若isFiltrateAudio为1，则该字段将被忽略。 |
| audio.codec | 是 | String | 音频流的编码格式，目前有libfdk_aac（更适合mp4, hls），libmp3lame（更适合flv）。 |
| audio.bitrate | 是 | Integer | 音频流的码率，大于等于26，小于等于256，单位：kbps。 |
| audio.soundSystem | 否 | Integer | 音频通道方式，可填 1：双通道，2：双通道，默认为2。 |
| audio.sampleRate | 是 | Integer | 音频流的采样率，可填 44100，48000，单位：hz。|
| COMMON_PARAMS | 是 |  | 参见[公共参数](/document/api/213/6976)。 |

> 注意：
> - video,audio字段详细含义及取值，参见[转码能力综述](/document/product/266/11701#.E8.BD.AC.E7.A0.81.E8.83.BD.E5.8A.9B.E7.BB.BC.E8.BF.B0)
> - 分辨率开启自适应的情况下，长边的值（width）不得短于短边（height）
> - video.fps，video.bitrate，video.width，video.height，audio.bitrate，audio.sampleRate这5个字段可以通过支持填入负数，表示该字段禁止低转高。例如，video.bitrate赋值为-512的模板表示，若原视频码率低于512k，转码后视频码率将不会提升（即原视频码率为256k，则转码后视频码率仍为256k；如果原视频码率为1024k，则转码后视频码率为512k）。

### 请求示例
<pre>
https://vod.api.qcloud.com/v2/index.php?Action=CreateTranscodeTemplate
&name=highDefinition
&container=mp4
&comment=commDefinition
&video.codec=libx264
&video.fps=45
&video.width=564
&video.height=123
&video.bitrate=256
&audio.codec=libfdk_aac
&audio.bitrate=512
&audio.soundSystem=2
&audio.sampleRate=200
&COMMON_PARAMS
</pre>

## 接口应答

### 参数说明
| 参数名称 | 类型 | 说明 |
|---------|---------|---------|
| code | Integer | 错误码, 0: 成功, 其他值: 失败。 |
| message | String | 错误信息。 |
| data | Object | 返回的数据信息。 |
| data.definition | Integer | 转码模板ID。 |

### 错误码说明
| 错误码 | 含义说明|
|---------|---------|
| 4000-7000 | 参见[公共错误码](/document/product/266/7783)。  |
| 1000 | 参数非法  |
| 10700 | 内部错误  |
| 10730 | 请求中的container参数无效  |
| 10731 | 请求中的video.fps参数无效  |
| 10732 | 请求中的video.codec参数无效  |
| 10733 | 请求中的video.bitrate 参数无效  |
| 10734 | 分辨率非法  |
| 10754 | 请求中的audio.codec参数无效  |
| 10755 | 请求中的audio.sampleRate参数无效  |
| 10756 | 请求中的audio.bitrate参数无效  |
| 10757 | 请求中的audio.soundSystem参数无效  |
| 10736 | 请求中的isFiltrateVideo参数无效  |
| 10737 | 请求中的isFiltrateAudio参数无效  |
| 10738 | 请求中的video.minGop参数无效  |
| 10739 | 请求中的video.maxGop参数无效   |
| 10740 | 请求中的video.profile参数无效  |
| 10741 | 请求中的video.colorSpace参数无效  |
| 10742 | 请求中的video.deinterlaced参数无效  |
| 10743 | 请求中的video.videoRateControl参数无效  |
| 10745 | 请求中的denoise参数无效  |
| 10758 | 请求中的audio.audioResampler参数无效  |
| 10759 | 请求中的audio.audioDownmixMode  |

### 应答示例

```javascript
{
    "code": 0,
    "message": "",
    "data": {
        "definition": 1005
    }
}
```
