## 封装格式(Format)

所谓封装格式，就是将已经编码压缩好的视频流和音频流按照一定的格式规范，放到一个文件中。对于网络点播而言，更加合适的术语应该叫“流媒体网络传输协议”。在互联网中使用最为广泛的协议为：

- **MP4**：非常经典的文件格式，iOS/Android/PC Web三端支持度都很好。但是MP4的视频文件头太大，结构复杂；如果视频较长（比如长达数小时），则其文件头会过大，影响视频加载速度。所以其更适用于短视频场景。更多参见[维基百科：MP4](https://zh.wikipedia.org/wiki/MP4)。
- **HLS(HTTP Live Streaming)**：苹果公司力推的标准，iOS/Android端支持度较好，但IE的支持情况依赖Flash的二次开发工作（建议使用腾讯视频云的Flash播放器控件）。其精简的m3u8的索引结构可以规避MP4的索引慢问题，如果是用于点播，是非常不错的选择。更多参见[HTTP Live Streaming](https://developer.apple.com/streaming/)、[维基百科：HTTP Live Streaming](https://zh.wikipedia.org/wiki/HTTP_Live_Streaming)。
- **FLV**：Adobe公司所推的标准，在PC端有Flash的强力支持，但在移动终端只有App实现播放器才有可能支持（建议使用腾讯视频云的Flash播放器控件），大部分手机端浏览器均不支持。更多参见[维基百科：Flash Video](https://zh.wikipedia.org/wiki/Flash_Video)。

## 视频编码参数

### 编码方式(Codec)
能够对数字视频进行压缩或者解压缩（视频解码）的程序或者设备。常见的编码方式包括：

- H.26X系列，由ITU（国际电信联盟）主导。该系列标准中，目前应用最广泛的是H.264，其继任者为H.265。同等画质下，H.265的压缩率可以比H.264提高一倍，但受制于专利等因素，H.265的应用尚未普及；更多参见[维基百科：H.264](https://zh.wikipedia.org/wiki/H.264/MPEG-4_AVC)、[维基百科：H.265](https://zh.wikipedia.org/wiki/%E9%AB%98%E6%95%88%E7%8E%87%E8%A7%86%E9%A2%91%E7%BC%96%E7%A0%81)。
- MPEG系列，由ISO（国际标准组织机构）下属的MPEG（运动图象专家组）主导。
- 其他系列，例如Google主导的VP8、VP9，Real公司主导的RealVideo等。

### 码率(Bitrate)
单位时间播放连续媒体（如压缩后的音频或视频）所需的比特数量，测量单位为“比特每秒”（bit/s或bps）。更多参见[维基百科：比特率](https://zh.wikipedia.org/wiki/%E6%AF%94%E7%89%B9%E7%8E%87)。

### 帧率(Frame Rate)
单位时间内视频显示帧数的量度单位，测量单位为“每秒显示帧数”（Frame Per Second，FPS）或“赫兹”。更多参见[维基百科：帧率](https://zh.wikipedia.org/wiki/%E5%B8%A7%E7%8E%87)。

### 分辨率(Resolution)
用以描述视频对细节的分辨能力，通常表示为每一个方向上的像素数量，比如640x480等。更多参见[维基百科：分辨率](https://zh.wikipedia.org/wiki/%E5%88%86%E8%BE%A8%E7%8E%87)。

### GOP(Group of Pictures)
一组以MPEG编码的影片或视讯串流内部的连续图像，以I帧开头，到下一个I帧结束。一个GOP包含如下图像类型：

- I帧(Intra Coded Picture)：节点编码图像。一个固定影像，且独立于其它的图像类型，每个GOP由此类型的图像开始。
- P帧(Predictive Coded Picture)：预测编码图像。包含来自先前的I或P-画格的差异资讯。
- B帧(Bidirectionally Predictive Coded Pictures)：前后预测编码图像。包含来自先前和/或之后的I帧或P帧的差异信息。

一个GOP内的帧数，称为GOP长度。

### 编码档次(Profile)
编码档次是针对特定应用场景的特定编码功能的集合。H.264规定了三种主要档次：

- Baseline：支持I/P帧，只支持无交错（Progressive）和CAVLC，一般用于低阶或需要额外容错的应用，比如视频通话、手机视频等即时通信领域；
- Main：提供I/P/B帧，支持无交错（Progressive）和交错（Interlaced），同样提供对于CAVLC和CABAC的支持，用于主流消费类电子产品规格如低解码（相对而言）的MP4、便携的视频播放器、PSP和iPod等；
- High：在Main的基础上增加了8x8内部预测、自定义量化、无损视频编码和更多的YUV格式（如4:4:4），用于广播及视频碟片存储（蓝光影片），高清电视的应用。

### 颜色空间(Color Space)
使用一组值（通常使用三个、四个值或者颜色成分）表示颜色方法的抽象数学模型。更多参见[维基百科：颜色空间](https://zh.wikipedia.org/wiki/%E8%89%B2%E5%BD%A9%E7%A9%BA%E9%96%93)。

## 视频处理参数

### 视频降噪
所谓视频噪音，是由传感器、扫描仪电路或数码相机产生的图像的亮度或彩色随机变动。视频噪音也源自于胶片粒度和不变的量子检测器中的点噪声。 视频噪音通常被看作图像获取中不需要的成分。而视频降噪，则是除去这些不必要的噪声，保留视频中比较重要的细节等信息。更多参见[维基百科：视频降噪](https://zh.wikipedia.org/wiki/%E5%BD%B1%E5%83%8F%E9%99%8D%E5%99%AA)。

### 去隔行扫描
在模拟电视时代，播放设备的处理速度与网络带宽都存在限制。为了在确保不降低帧率的前提下降低传输码率，隔行扫描技术应运而生，该技术可以在图像质量下降不多的情况下，将视频传输带宽降低一半。但隔行扫描带来的负面影响也不可忽视，比如清晰度较低、容易产生闪烁、图像边缘锯齿化等。目前，视频播放设备与网络带宽都已经得到长足发展，故而隔行扫描已经在逐步淘汰。部分新型设备已经不再支持隔行扫描。因此，对于部分历史遗留的、使用隔行扫描技术的视频，需要进行“去隔行扫描”操作。更多参见[维基百科：隔行扫描](https://zh.wikipedia.org/wiki/%E9%9A%94%E8%A1%8C%E6%89%AB%E6%8F%8F)、[维基百科：去隔行扫描](https://zh.wikipedia.org/wiki/%E5%8E%BB%E4%BA%A4%E9%8C%AF)。

## 音频编码参数
### 编码方式(Codec)
将声音从模拟信号转换为数字信号（或反向转换）的方式。主要包括无损编码和有损编码两种方式。根据采样定理，音频编码只能“无限接近”自然信号，故而所有的音频编码方式实质上都是有损的。在计算机领域中，通常约定能够达到最高保真水平的[PCM编码](https://zh.wikipedia.org/wiki/%E8%84%88%E8%A1%9D%E7%B7%A8%E7%A2%BC%E8%AA%BF%E8%AE%8A)为无损编码。互联网中常见的音频编码均为有损编码，常见的编码格式有[MP3](https://zh.wikipedia.org/wiki/MP3)、[AAC](https://zh.wikipedia.org/wiki/%E9%80%B2%E9%9A%8E%E9%9F%B3%E8%A8%8A%E7%B7%A8%E7%A2%BC)等。

### 采样率(Sample Rate)
每秒从连续信号中提取并组成离散信号的采样个数，单位为赫兹(HZ)。更多参见[维基百科：采样率](https://zh.wikipedia.org/wiki/%E9%87%87%E6%A0%B7%E7%8E%87)。

### 码率(Bitrate)
参见视频[码率](#.E7.A0.81.E7.8E.87)。

### 声道(Sound Channel)
所谓声道，是指声音在录制（或播放）时，在不同空间位置采集（或播放）的相互独立的音频信号。所谓声道数，也就是声音录制时的音源数量或播放时的扬声器数量。