所谓视频转码（Video Transcoding），是指将一个视频码流转换成另一个视频码流，以适应不同的网络带宽、不同的终端处理能力和不同的用户需求。点播系统中的转码一般称为离线转码；对应的，直播系统中的转码称为即时转码。

离线转码的典型应用场景包括：

- **终端适配**：将特定格式的视频转换成终端适配能力较高的视频，以便在最广泛的终端上实现分发。例如，将AVI格式（对网络播放支持不友好）的视频转码成MP4（几乎所有网络播放器都支持），以便在互联网上进行分发；
- **带宽适配**：将视频转码为超清、高清、标清等多路不同码率的视频，以便不同网络带宽的用户选择不同码率的视频；
- **播放友好**：优化视频封装格式，以实现更好地播放效果；例如，某些MP4文件的MOOV头可能位于尾部，导致部分播放器需要下载整个MP4文件之后才能开始播放；可以通过转码将MOOV头调整到文件头部，以便播放器无需下载整个文件便可以开始播放；
- **增加水印**：在视频中增加版权相关图片（例如电视台的台标），宣示视频本身的版权归属；
- **降低分发带宽**：使用更先进的编码方式对视频进行编码，确保在不降低画质的前提下降低视频码率，从而达到节省带宽的目的；例如对原本使用H.264编码的视频进行H.265编码；
- **降低存储成本**：对于以归档、备案为目的的视频，直接存储原始视频可能会带来较高的存储成本，此时可以将视频转为低码率进行存储，从而大幅降低视频存储成本。

以下是一个经过离线转码的视频示例，包含多码率视频以及APNG动态水印：

<iframe src="https://playvideo.qcloud.com/vod/9031868223417574079/iplayer.html?appid=1253131631&fileid=9031868223417574079&autoplay=0&sw=1280&sh=720" frameborder="0" width="70%" height="360" scrolling="no"></iframe> <!-- 页面内多处使用iframe代码，后面的JS代码只需要使用一次(作用是调整iframe的高度) --> 
<script src="//imgcache.qq.com/open/qcloud/video/h5/fixifmheight.js" charset="utf-8"></script>

## 视频转码

### 转码能力综述

<table>
    <tr>
        <th style="width:18%">
            分类               
        </th>
        <th style="width:22%">
            参数/能力项
        </th>
        <th>
            说明
        </th>
    </tr>
    <tr>
        <td rowspan=5>
            <a href="/document/product/266/11732##.E5.B0.81.E8.A3.85.E6.A0.BC.E5.BC.8F(format)">封装格式(Format)</a>
        </td>
        <td>
            输入格式
        </td>
        <td>
            <li>AVI格式：文件后缀为AVI；</li>
            <li>QuickTime格式：文件后缀为MOV；</li>
            <li>MPEG格式：文件后缀为MPG, MPEG, MPE, DAT, VOB, ASF, 3GP, MP4等；</li>
            <li>WMV格式：文件后缀为WMV, ASF；</li>
            <li>Real格式：文件后缀为RM, RMVB；</li>
            <li>Flash格式：文件后缀为FLV, F4V；</li>
            <li>Matroska格式：文件后缀为MKV。</li>
        </td>
    </tr>
    <tr>
        <td>
            输出格式
        </td>
        <td>
            视频：
            <li>MP4</li>
            <li>HLS</li>
            <li>FLV</li>
            音频：
            <li>MP3</li>
            <li>AAC</li>
            <li>OGG</li>
            <li>FLAC</li>
            动态图片：
            <li>GIF</li>
        </td>
    </tr>
    <tr>
        <td>
            纯音频输出
        </td>
        <td>
            支持纯因音频输出，即删除视频流。
        </td>
    </tr>
    <tr>
        <td>
            纯视频输出
        </td>
        <td>
            支持纯视频输出，即删除音频流。
        </td>
    </tr>
    <tr>
        <td>
            转封装
        </td>
        <td>
            支持视频转封装，输出MP4、HLS、FLV三种格式。
        </td>
    </tr>
    <tr>
        <td rowspan=8>
            视频编码参数
        </td>
        <td>
            <a href="/document/product/266/11732#.E7.BC.96.E7.A0.81.E6.96.B9.E5.BC.8F(codec)">编码方式(Codec)</a>
        </td>
        <td>
            <li>H.264</li>
            <li>H.265</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E7.A0.81.E7.8E.87(bitrate)">码率(Bitrate)</a>
        </td>
        <td>
            支持输出码率范围10~50000kbps。
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E5.B8.A7.E7.8E.87(frame-rate)">帧率(Frame Rate)</a>
        </td>
        <td>
            支持如下三种帧率：
            <li>24fps</li>
            <li>25fps</li>
            <li>30fps</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E5.88.86.E8.BE.A8.E7.8E.87(resolution)">分辨率(Resolution)</a>
        </td>
        <td>
            <li>支持宽度范围：128~4096</li>
            <li>支持高度范围：128~4096</li>
        </td>
    </tr>
    <tr>
        <td>
            自动缩放
        </td>
        <td>
            <li>支持依照宽度等比例缩放</li>
            <li>支持依照高度等比例缩放</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#gop(group-of-pictures)">GOP</a>长度
        </td>
        <td>
            支持GOP长度范围：1~10秒。
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E7.BC.96.E7.A0.81.E6.A1.A3.E6.AC.A1(profile)">编码档次(Profile)</a>
        </td>
        <td>
            <li>H.264: 支持Baseline, Main, High三种编码档次；</li>
            <li>H.265: 仅支持Main。</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E9.A2.9C.E8.89.B2.E7.A9.BA.E9.97.B4(color-space)">颜色空间(Color Space)</a>
        </td>
        <td>
            支持YUV420P。
        </td>
    </tr>
    <tr>
        <td rowspan=4>
            视频处理参数
        </td>
        <td>
            <a href="/document/product/266/11732#.E8.A7.86.E9.A2.91.E9.99.8D.E5.99.AA">视频降噪</a>
        </td>
        <td>
            支持。
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E5.8E.BB.E9.9A.94.E8.A1.8C.E6.89.AB.E6.8F.8F">去隔行扫描</a>
        </td>
        <td>
            支持。
        </td>
    </tr>
    <tr>
        <td>
            码率控制方法
        </td>
        <td>
            支持如下几种码率控制方法：
            <li>动态比特率（Variable Bit Rate, VBR）；</li>
            <li>固定比特率（Constant Bit Rate, CBR）；</li>
            <li>固定码率系数（Constant Rate Factor，CRF）。</li>
        </td>
    </tr>
    <tr>
        <td>
            视频压缩模式
        </td>
        <td>
            支持OnePass和TwoPass两种压缩模式。
        </td>
    </tr>
    <tr>
        <td rowspan=4>
            音频编码参数
        </td>
        <td>
            <a href="/document/product/266/11732#.E7.BC.96.E7.A0.81.E6.A0.BC.E5.BC.8F(codec)">编码方式(Codec)</a>
        </td>
        <td>
            <li>MP3</li>
            <li>AAC</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E9.87.87.E6.A0.B7.E7.8E.87(sample-rate)">采样率(Sample Rate)</a>
        </td>
        <td>
            支持如下几种音频采样率：
            <li>44100HZ</li>
            <li>48000HZ</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E7.A0.81.E7.8E.87(bitrate)2">码率(Bitrate)</a>
        </td>
        <td>
            支持如下几种音频码率：
            <li>48kbps</li>
            <li>64kbps</li>
            <li>128kbps</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11732#.E5.A3.B0.E9.81.93(sound-channel)">声道(Channel)</a>
        </td>
        <td>
            <li>MP3：支持单声道、双声道</li>
            <li>AAC：支持单声道、双声道</li>
        </td>
    </tr>
    <tr>
        <td rowspan=3>
            转码控制
        </td>
        <td>
            HLS MasterPlayList
        </td>
        <td>
            支持输出HLS MasterPlayList。
        </td>
    </tr>
    <tr>
        <td>
            避免码率（或分辨率）低转高
        </td>
        <td>
            支持两种方式：
            <li>如果某一目标转码模板的码率（或分辨率）比源视频更高，则不进行该规格的视频转码。举例：假设源视频码率为600kbps，转码时指定输出三路，目标码率分别为256kbps, 512kbps, 1024bps；则开启该选项之后，只会输出256kbps和512kbps的两路转码结果。</li>
            <li>如果目标转码模板的码率（或分辨率）大于源视频的码率（或分辨率），则在进行该规格的转码时，输出码率（或分辨率）与源视频相同。例：假设源视频码率为600kbps，转码时指定输出三路，目标码率分别为256kbps, 512kbps, 1024bps；则开启该选项之后，第三路转出的视频码率依然为600kbps，但该路输出的其他参数依然符合转码模板中所规定的参数。</li>
        </td>
    </tr>
    <tr>
        <td>
            <a href="/document/product/266/11700#.E4.BB.BB.E5.8A.A1.E6.B5.81">转码流程可编程化</a>
        </td>
        <td>
            可以通过Lua程序灵活控制转码流程。
        </td>
    </tr>
    <tr>
        <td rowspan=1>
            视频内容安全
        </td>
        <td>
            <a href="/document/product/266/9638">视频加密</a>
        </td>
        <td>
            支持HLS标准视频加密。
        </td>
    </tr>
</table>

### 转码模板

视频处理的参数较多，故而点播系统使用转码模板来作为各种转码参数的容器，在进行视频处理时，只需指定转码模板即可。

为方便开发者的调用，点播系统预设了一批转码模板，参见[预置转码模板](#.E9.A2.84.E7.BD.AE.E8.BD.AC.E7.A0.81.E6.A8.A1.E6.9D.BF)。如果预设转码模板无法满足需求，开发者亦可根据自己的需求自定义转码模板。

### 通过控制台管理转码模板
当前暂不支持通过控制台管理转码模板，敬请期待。

### 通过服务端API管理转码模板
参见：
- 服务端API：[创建转码模板(CreateTranscodeTemplate)](/document/product/266/9910)
- 服务端API：[更新转码模板(UpdateTranscodeTemplate)](/document/product/266/9911)
- 服务端API：[查询转码模板详情(QueryTranscodeTemplate)](/document/product/266/9912)
- 服务端API：[查询转码模板列表(QueryTranscodeTemplateList)](/document/product/266/9913)
- 服务端API：[删除转码模板(DeleteTranscodeTemplate)](/document/product/266/9914)


### 发起转码

#### 在点播控制台发起转码
文档完善中。

#### 通过服务端API发起转码
参见：
- [使用任务流处理视频](/document/product/266/11700#.E4.BD.BF.E7.94.A8.E4.BB.BB.E5.8A.A1.E6.B5.81.E5.A4.84.E7.90.86.E8.A7.86.E9.A2.91)
- 服务端API：[视频转码(ConvertVodFile)](/document/product/266/7822)

> 注意：
> 在调用服务端API进行转码时，推荐使用任务流而非独立的视频转码接口。

## 视频转封装
所谓视频转封装，是指不改变视频的编码方式，而仅改变封装格式。例如将HLS视频转封装为MP4，以便于下载到本地进行编辑。

转封装可以认为是一种比较特殊的转码。发起视频转封装的方式视频转码相同，参见[发起转码](#.E5.8F.91.E8.B5.B7.E8.BD.AC.E7.A0.81)。

点播系统预设了一组转码模板来支持转封装，参见[预置转封装模板](#.E9.A2.84.E7.BD.AE.E8.BD.AC.E5.B0.81.E8.A3.85.E6.A8.A1.E6.9D.BF)。

## 视频水印

所谓视频水印，即在视频中增加版权相关图片（例如电视台的台标），宣示视频本身的版权归属。在视频转码过程中，可以指定[水印模板](#.E6.B0.B4.E5.8D.B0.E6.A8.A1.E6.9D.BF)来为输出的视频文件增加水印。

### 水印类型

点播系统支持两种水印：
- **静态水印**：使用一张图片作为水印，该图片固定位于视频的某个位置，从片头贯穿到片尾；支持JPG和PNG两种格式的水印图片，推荐使用PNG格式图片；
- **动态水印**：使用[APNG](https://zh.wikipedia.org/wiki/APNG)动图作为水印，该动画图片位于视频的固定位置循环播放。

### 水印位置

水印位置是通过`left`, `top`, `width`, `height`四个参数决定的，如下图所示：

![水印位置参数示意图](//mc.qcloudimg.com/static/img/c030e8efdcdda7c6abbd7875dbc68d7c/image.png)

各参数含义如下：
- `left`：决定水印左侧到视频左侧的距离；
- `top`：决定水印顶部到视频顶部的距离；
- `width`：决定水印图片的宽度；
- `height`：决定水印图片的高度。

四个参数均支持两种计算方式：

1. 以像素为单位进行计算；
1. 以相对视频宽度/高度的百分比进行计算，即：
    1. `left`和`width`支持以视频宽度的百分比来计算；
    1. `top`和`height`支持以视频高度的百分比来计算。

如果仅指定`width`而不指定`height`，则意味着保持原始水印图片的宽高比。

举例：
> 假设需要添加水印的视频文件分辨率为1280 × 720，水印图片的分辨率为100 × 100，则：
> - `left`为100px，意味着水印左侧距离视频左侧为100像素；
> - `top`为10%，意味着水印顶部到视频顶部的距离为视频高度的10%，即128像素(1280 × 10% = 128)；
> - 指定`width`为5%，不指定`height`，意味着水印的宽度为64像素(1280 × 5% = 64)，高度为64像素（水印图片宽高比为1:1，故而水印的高度与宽度相同，亦为64像素）。

在进行多码率转码的情况下，如果需要保持各个码率的视频水印大小、位置相同，建议使用百分比为单位来衡量。

### 水印模板

视频水印的参数较多，故而点播系统使用水印模板来作为各种水印参数的容器。如果在转码过程中需要为视频增加水印，只需指定水印模板即可。

开发者可以通过控制台和服务端API来管理水印模板。控制台当前只支持以宽高百分比的方式来设置水印位置，不支持像素偏移的方式；也不支持指定水印大小。控制台完整的水印管理功能敬请期待。

### 通过控制台管理水印模板
文档完善中。

### 通过服务端API管理水印模板

通过服务端API创建水印模板分为三步：
1. 调用[申请上传水印文件(ApplyUploadWatermark)](/document/product/266/11607)接口，申请水印文件的上传URL；
1. 使用HTTP PUT方法，将水印文件上传到上一步返回的上传URL，请求Body为水印图片的二进制数据；
1. 调用[创建水印模板(CreateWatermarkTemplate)](/document/product/266/11599)接口，创建水印模板。

> 第2步上传水印文件示例如下：
> 假定调用ApplyUploadWatermark接口返回的URL为`http://123.test.com/123.png&sign=abcd`，要上传的本地水印文件为`123.png`，则使用curl上传水印文件的操作为：
> 
> <pre>
> curl 'http://123.test.com/123.png&sign=abcd' --upload-file 123.png
> </pre>

参见：
- 服务端API：[申请上传水印文件(ApplyUploadWatermark)](/document/product/266/11607)
- 服务端API：[创建水印模板(CreateWatermarkTemplate)](/document/product/266/11599)
- 服务端API：[更新水印模板(UpdateWatermarkTemplate)](/document/product/266/11605)
- 服务端API：[查询水印模板详情(QueryWatermarkTemplate)](/document/product/266/11606)
- 服务端API：[查询水印模板列表(QueryWatermarkTemplateList)](/document/product/266/11608)
- 服务端API：[删除水印模板(DeleteWatermarkTemplate)](/document/product/266/11604)

## 预置转码模板

### 预置转码模板
<table>
    <tr>
        <th rowspan=2>
            规格等级                
        </th>
        <th rowspan=2>
            模板ID                
        </th>
        <th rowspan=2>
            封装格式(Format)
        </th>
        <th colspan=4>    
            视频参数
        </th>
        <th colspan=1>    
            音频参数
        </th>
    </tr>
    <tr>
        <th>
            分辨率(Resolution)
        </th>
        <th>
            码率(Bitrate)
        </th>
        <th>
            帧率(FPS)
        </th>
        <th>
            编码(Codec)
        </th>
        <th>
            编码(Codec)
        </th>
    </tr>
    <tr>
        <td rowspan=6>
            流畅(FLU)
        </td>
        <td>
            10
        </td>
        <td>
            MP4
        </td>
        <td>
            320 × 按比例缩放
        </td>
        <td>
            256kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            510
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 240
        </td>
        <td>
            250kbps
        </td>
        <td>
            15
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            210
        </td>
        <td>
            HLS
        </td>
        <td>
            320 × 按比例缩放
        </td>
        <td>
            256kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            610
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 240
        </td>
        <td>
            250kbps
        </td>
        <td>
            15
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            10046
        </td>
        <td>
            FLV
        </td>
        <td>
            320 × 按比例缩放
        </td>
        <td>
            256kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            MP3
        </td>
    </tr>
    <tr>
        <td>
            710
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 240
        </td>
        <td>
            250kbps
        </td>
        <td>
            15
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td rowspan=6>
            标清(SD)
        </td>
        <td>
            20
        </td>
        <td>
            MP4
        </td>
        <td>
            640 × 按比例缩放
        </td>
        <td>
            512kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            520
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 480
        </td>
        <td>
            600kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            220
        </td>
        <td>
            HLS
        </td>
        <td>
            640 × 按比例缩放
        </td>
        <td>
            512kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            620
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 480
        </td>
        <td>
            600kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            10047
        </td>
        <td>
            FLV
        </td>
        <td>
            640 × 按比例缩放
        </td>
        <td>
            512kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            MP3
        </td>
    </tr>
    <tr>
        <td>
            720
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 480
        </td>
        <td>
            600kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td rowspan=6>
            高清(HD)
        </td>
        <td>
            30
        </td>
        <td>
            MP4
        </td>
        <td>
            1280 × 按比例缩放
        </td>
        <td>
            1024kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            530
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 720
        </td>
        <td>
            800kbps
        </td>
        <td>
            25
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            230
        </td>
        <td>
            HLS
        </td>
        <td>
            1280 × 按比例缩放
        </td>
        <td>
            1024kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            630
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 720
        </td>
        <td>
            800kbps
        </td>
        <td>
            25
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            10048
        </td>
        <td>
            FLV
        </td>
        <td>
            1280 × 按比例缩放
        </td>
        <td>
            1024kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            MP3
        </td>
    </tr>
    <tr>
        <td>
            730
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 720
        </td>
        <td>
            800kbps
        </td>
        <td>
            25
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td  rowspan=6>
            全高清(FHD)
        </td>
        <td>
            40
        </td>
        <td>
            MP4
        </td>
        <td>
            1920 × 按比例缩放
        </td>
        <td>
            2500kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            540
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 1080
        </td>
        <td>
            1400kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            240
        </td>
        <td>
            HLS
        </td>
        <td>
            1920 × 按比例缩放
        </td>
        <td>
            2500kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            640
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 1080
        </td>
        <td>
            1400kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            10049
        </td>
        <td>
            FLV
        </td>
        <td>
            1920 × 按比例缩放
        </td>
        <td>
            2500kbps
        </td>
        <td>
            24
        </td>
        <td>
            H.264
        </td>
        <td>
            MP3
        </td>
    </tr>
    <tr>
        <td>
            740
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 1080
        </td>
        <td>
            1400kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td  rowspan=6>
            2K
        </td>
        <td>
            70
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 1440
        </td>
        <td>
            3072kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            570
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 1440
        </td>
        <td>
            2048kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            270
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 1440
        </td>
        <td>
            3072kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            670
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 1440
        </td>
        <td>
            2048kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            370
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 1440
        </td>
        <td>
            3072kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.264
        </td>
        <td>
            MP3
        </td>
    </tr>
    <tr>
        <td>
            770
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 1440
        </td>
        <td>
            2048kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td  rowspan=6>
            4K
        </td>
        <td>
            80
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 2160
        </td>
        <td>
            6144kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            580
        </td>
        <td>
            MP4
        </td>
        <td>
            按比例缩放 × 2160
        </td>
        <td>
            4096kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            280
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 2160
        </td>
        <td>
            6144kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.264
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            680
        </td>
        <td>
            HLS
        </td>
        <td>
            按比例缩放 × 2160
        </td>
        <td>
            4096kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
    <tr>
        <td>
            380
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 2160
        </td>
        <td>
            6144kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.264
        </td>
        <td>
            MP3
        </td>
    </tr>
    <tr>
        <td>
            780
        </td>
        <td>
            FLV
        </td>
        <td>
            按比例缩放 × 2160
        </td>
        <td>
            4096kbps
        </td>
        <td>
            30
        </td>
        <td>
            H.265
        </td>
        <td>
            AAC
        </td>
    </tr>
</table>

以上转码模板中未注明的参数全部相同，分别是：

<table>
    <tr>
        <th style="width:18%">
            分类               
        </th>
        <th style="width:22%">
            参数/能力项
        </th>
        <th>
            说明
        </th>
    </tr>
    <tr>
        <td rowspan=6>
            视频参数
        </td>
        <td>
            编码档次
        </td>
        <td>
            使用H.264编码的均为High<br />使用H.265编码的均为Main
        </td>
    </tr>
    <tr>
        <td>
            GOP长度
        </td>
        <td>
            240帧
        </td>
    </tr>
    <tr>
        <td>
            颜色空间
        </td>
        <td>
            YUV420P
        </td>
    </tr>
    <tr>
        <td>
            视频降噪
        </td>
        <td>
            未启用
        </td>
    </tr>
    <tr>
        <td>
            去隔行扫描
        </td>
        <td>
            未启用
        </td>
    </tr>
    <tr>
        <td>
            码率控制方法
        </td>
        <td>
            动态比特率编码（VBR）
        </td>
    </tr>
    <tr>
        <td rowspan=3>
            音频参数
        </td>
        <td>
            采样率
        </td>
        <td>
            44100Hz
        </td>
    </tr>
    <tr>
        <td>
            码率
        </td>
        <td>
            48kbps
        </td>
    </tr>
    <tr>
        <td>
            声道数
        </td>
        <td>
            双通道（Stereo）
        </td>
    </tr>
</table>

### 预置转封装模板
| 输出格式 | 模板ID |
|---------|---------|
| MP4 | 9 |
| HLS | 6 |