数字版权管理（Digital Rights Management，DRM），对于在线教育、行业培训等领域都是十分重要的。视频文件的泄露，有可能造成十分严重的经济损失。

传统的视频服务提供商大多是通过各种各样的防盗链机制来实现视频内容保护。该方案的基本原理是：APP服务端给客户派发专属的视频URL，CDN服务对请求URL、请求IP、HTTP头等参数进行校验，如果校验通过，则返回正常的视频数据；否则返回403错误码。

但是，对于需要付费观看的视频，一旦恶意用户通过一次付费行为拿到了合法的防盗链播放URL，其便可以将视频完整下载到本地，进而实现二次分发。因此，防盗链方案对于视频版权保护是远远不够的。要进一步提升视频内容的保护程度，就不能仅仅在视频的分发环节做文章，而是必须对视频数据本身的加密。对视频数据加密之后，即使恶意用户把视频下载到本地，视频本身也是被加密的，这样就提高了恶意用户将视频内容二次分发的门槛。

腾讯云视频加密服务目前正处于内测阶段。**如果需要试用，请提需求工单进行开通**。

## 腾讯云点播视频加密方案

### 加密算法
点播系统目前支持[HTTP Live Streaming](https://tools.ietf.org/html/draft-pantos-http-live-streaming-23)中规定的加密方案，该方案的安全级别可以达到：
1. 使用AES-128对视频内容本身进行加密；
1. 支持对单个视频文件使用多个秘钥进行加密，避免单个秘钥泄露导致整个文件泄密。

如果您需要定制私有化的视频加密方案，可以与腾讯云客服联系。

### 播放器适配性
腾讯云点播视频加密方案能够支持所有HLS播放器。

## 术语介绍

### 秘钥管理服务（Key Management Service，简称KMS）
一项安全管理服务，主要负责数据秘钥的生产、加密、解密等工作。例如腾讯云的[秘钥管理服务](https://cloud.tencent.com/product/kms)。

### 数据秘钥（Data Key，简称DK）
由KMS系统生成的，用于对称加解密的秘钥。

### 加密后的数据秘钥（Encrypted Data Key，简称EDK）
经过KMS系统加密之后的DK，可以用于公开分发。要通过EDK换取DK，必须调用KMS的解密接口。

## 整体架构
![](//mc.qcloudimg.com/static/img/b88e3ed66a8d1856501554465454ccb7/image.png)

视频加密过程是通过转码操作来实现的，不会产生新的FileID。与一般转码场景相比，视频加密转码的主要区别在于：
1. 加密转码，转出来的视频是经过加密的；
1. 加密转码完成之后，如果通过点播播放器来播放视频，源文件播放地址是不会被获取到的。

## 准备工作

### 建立秘钥管理服务（KMS）
秘钥管理服务主要用于管理视频秘钥。视频加密过程需要与KMS系统进行交互的步骤包括：

1. 生成用于视频加密的数据秘钥，即架构图中第II步。这一步将返回DK和EDK。在后续环节中，能够接触到DK的角色包括：点播转码服务、APP后台、经过合法身份校验的最终用户。EDK可以分发给任意用户，但通过EDK获取DK这一步，必须由APP后台进行身份校验。
1. 根据EDK获取DK来进行数据播放，即架构图中的第4步。APP后台在通过用户的身份验证之后，需要调用KMS相关接口，使用EDK去获取DK，即架构图中的第5步。

腾讯云点播系统支持以下三种秘钥管理服务：

1. 腾讯云点播内置KMS服务：为最大限度地降低开发者的接入成本，腾讯云点播服务内部集成了KMS服务，并且提供了最简单的调用接口。如果使用点播内置KMS服务，则在整个视频加密方案中，APP后台与KMS服务唯一需要交互的地方在于获取解密秘钥（架构图中的第5步）。
2. 腾讯云KMS服务（即将支持）：在开通腾讯云KMS服务之后，您可以将根据某个主秘钥来生成数据秘钥的权限授权给点播服务，点播系统便可融入您在云端的秘钥管理体系中。
3. 自建KMS服务（即将支持）：如果您已经自建了KMS服务，您可以在每次加密操作中自行指定DK和EDK，从而达到最灵活的秘钥控制级别。

### 搭建鉴权与秘钥派发服务

对于已经加密的视频，只有经过APP后台认证过的客户端才能得到DK。因此，最终客户获取秘钥的行为必须要有APP后台参与鉴权。该服务的主要业务逻辑是：
1. 对于客户端携带EDK换取DK的请求（即架构图中第4步），对请求方进行身份认证；
2. 如果身份认证通过，则去KMS系统获取对应的DK（即架构图中第5步），并返回给客户端。

建议：
1. 由于EDK所对应的的DK总是固定的，故而APP后台可以缓存（甚至永久保存）EDK和DK之间的对应关系，以降低调用KMS系统的次数（即减少架构图中第5步的调用次数）；
2. APP后台给客户端的应答，可以增加HTTP缓存控制参数（例如Cache-Control），以降低客户端到APP后台获取DK的次数（即减少架构图中第4步的调用次数）。

### 配置视频加密模板
为确保点播后台能够进行正确的加密操作，您需要配置视频加密模板。详情参见[视频加密参数模板](/document/product/266/9645)。

## 业务流程

## 视频上传
可以通过服务端上传、客户端上传、控制台上传、录制上传、URL转拉上传等方式来将已有视频文件上传到点播平台。

## 视频加密

视频加密主要分为以下四个步骤：

### I. APP后台发起视频加密

目前您可以通过[ProcessFile](/document/product/266/9642)接口发起视频加密，目前只支持对HLS文件进行加密。

如下示例的含义是：

1. 对视频文件进行转码，转码目标输出模板为210、220、230、240；禁止从较低码率转为较高码率；
2. 转码过程使用加密模板10进行加密；
3. 事件通知模式为：待整个事件执行完毕之后发起一次事件通知。

```
https://vod.api.qcloud.com/v2/index.php?Action=ProcessFile
&transcode.definition.0=210
&transcode.definition.1=220
&transcode.definition.3=230
&transcode.definition.4=240
&transcode.disableHigherBitrate=1
&transcode.drm.definition=10
&notifyMode=Finish
&COMMON_PARAMS
```

### II. 点播平台获取加密秘钥
点播平台根据调用方指定的加密参数模板，读取秘钥获取方式、最终用户获取解密秘钥的URL（假定为`https://getkey.example.com`），然后从指定KMS系统中获取视频加密秘钥DK、EDK。

### III. 点播平台发起视频加密转码

点播转码平台在进行视频加密时，不仅会依照指定的加密算法和秘钥对目标输出文件进行加密，而且会将获取解密秘钥的URL写入视频文件中。例如，对于HLS，该URL会被写入到m3u8文件的EXT-X-KEY标签中。但在写入之前，转码平台会在该URL的QueryString中增加三个参数：

1. fileID：被加密文件的ID；
1. keySource：KMS的类型，为以下三种之一：
    1. VodBuildInKMS：腾讯云点播内置KMS；
    1. QCloudKMS：腾讯云KMS系统（暂不支持）；
    1. PrivateKMS：用于自有KMS系统（暂不支持）。
1. edk：即DK对应的EDK。

在增加上述参数之后，写入转码目标视频文件的URL可能为`https://getkey.example.com?fileId=123456&keySource=BuildInKMS&edk=abcdef`，该URL也是客户端最终在视频播放过程中获取解密秘钥时访问的URL。

### IV. 点播平台发起加密完成回调
包含加密操作的任务流状态发生变化（或者执行完毕）之后，点播平台将发起[任务流状态变更通知](/document/product/266/9636)。

## 媒资管理
视频加密操作完成之后，可以通过[GetVideoInfo](/document/product/266/8586)接口获取视频的加密信息。
GetVideoInfo接口会返回该视频Id所有转码规格的视频播放地址，包括源文件的播放地址，由于源文件是没有加密处理的，APP服务端可以过滤掉源文件的播放地址，只提供加密视频的播放地址给客户端。GetVideoInfo获取到的源文件definition参数是0，可以根据这个值来过滤源文件的视频播放地址。

## 视频播放综述

只有经过合法身份认证的客户才应当得到视频解密秘钥。因此在播放过程中，如何对用户的身份信息校验就成为关键因素。

播放过程中，播放器会访问m3u8文件中EXT-X-KEY标签所标识的URL以获取秘钥，播放器需要在这一步中携带观看者的身份认证信息。此时有两种方式可以将这一信息传递给APP鉴权服务：

1. 将用户身份信息通过参数的方式追加到URL中，带给APP的鉴权服务；该方案适用于所有的HLS播放器。具体方案参见视频播放方案1：通过QueryString传递身份认证信息。
2. 将用户身份信息通过Cookie带给APP的鉴权服务；该方案安全性更高，但其仅适用于在访问EXT-X-KEY标签所标识的URL时会携带Cookie的播放器。具体方案参见视频播放方案2：通过Cookie传递身份认证信息。

## 视频播放方案1：通过QueryString传递身份认证信息

该方案适用于任意支持HLS的播放器。

### 1. 登录并派发用于身份校验的Token
只有经过合法身份认证的客户才应当得到视频解密秘钥。因此在视频播放之前，客户端必须进行登录操作，并由APP服务端给客户端派发包含身份认证信息的签名，我们称其为Token。

### 2. 获取包含Key防盗链签名的多码率播放地址
<!--腾讯云点播Web端视频播放器提供了多码率播放能力，即可以根据FileID获取一个视频对应的多码率播放地址。如果您使用了其他播放器，则必须自行获取多码率播放地址。-->
加密转码API ProcessFile的回调通知或者GetVideoInfo API都可以获取到加密视频的多码率播放地址。

在拿到多码率播放地址之后，客户端需要将用户身份信息添加到播放地址中。对于任意播放URL，增加用户身份信息的方法是：在URL中的**文件名**之前增加`voddrm.token.<Token>`。

例如，假定用户身份信息标识为ABC123；某一码率的播放地址为`http://example.vod2.myqcloud.com/path/to/a/video.m3u8`；则最终URL为`http://example.vod2.myqcloud.com/path/to/a/voddrm.token.ABC123.video.m3u8`。

### 3. 获取视频内容(已加密)

当播放器访问已经按照上一步所述流程携带用户身份信息的URL时，点播后台会自动将Token信息以QueryString的方式附加到原始m3u8文件EXT-X-KEY标签所标识的URL中。

例如，假定某一码率的已加密视频URL为`http://example.vod2.myqcloud.com/path/to/a/video.m3u8`；该文件中，EXT-X-KEY标签所标识的获取视频解密秘钥的URL为`https://getkey.example.com?fileId=123456&keySource=BuildInKMS&edk=abcdef`。则当播放器访问携带Token信息的播放地址，即`http://example.vod2.myqcloud.com/path/to/a/voddrm.token.ABC123.video.m3u8`时，其中EXT-X-KEY标签所标识的获取视频解密秘钥的URL会被替换为`https://getkey.example.com?fileId=123456&keySource=BuildInKMS&edk=abcdef&token=ABC123`。此时，播放器获取解密秘钥dk时便会带上第1步派发的Token。

### 4 & 5. 获取视频解密秘钥（携带身份验证Cookie）

当播放器获取到视频索引文件（m3u8文件）之后，会在播放视频文件之前自动发起第4步。

APP后台在收到客户端的请求之后，首先对QueryString中的Token进行校验。如果用户身份非法，则直接拒绝请求。如果用户身份合法，则根据URL中携带的fileId、keySource、edk等参数，到KMS系统中获取DK，并返回给客户端。

以上步骤均完成之后，客户端便拿到了视频解密秘钥，从而可以进行正常的视频解密与播放。

## 视频播放方案2：通过Cookie传递身份认证信息

该方案仅适用于iOS/PC平台的H5/Flash播放器；在该平台下，播放器在访问EXT-X-KEY标签所标识的URL时会带上Cookie。

注意：实际测试发现，Android平台的H5播放器在访问EXT-X-KEY标签所标识的URL时不会携带Cookie，所以安卓平台目前只能使用方案1。

### 1. 登录并派发用于身份校验的Cookie
只有经过合法身份认证的客户才应当得到视频解密秘钥。因此在视频播放之前，客户端必须进行登录操作，并由APP服务端给客户端派发签名。例如，客户端通过`login.example.com`进行账号密码登录，APP后台在通过身份认证之后，给客户端下发`example.com`域的cookie来标识用户身份。

### 2. 获取指定视频的多码率播放地址
腾讯云点播Web端视频播放器提供了多码率播放能力，即可以根据FileID获取一个视频对应的多码率播放地址。如果您使用了其他播放器，则必须自行获取多码率播放地址。

### 3. 获取视频内容(已加密)
当开始播放视频时，视频播放器会自动发起这一步。

视频播放器开始播放视频时，会向点播CDN边缘节点请求视频数据文件。对于HLS格式的视频，播放器会根据m3u8文件中的EXT-X-KEY标签来获取视频解密秘钥。例如，假设EXT-X-KEY标签中获取视频解密秘钥的URL为`https://getkey.example.com?fileId=123456&keySource=BuildInKMS&edk=abcdef`。则当播放器获取解密秘钥dk时，会带上第1步由APP后台派发的`example.com`域的cookie。

### 4 & 5. 获取视频解密秘钥（携带身份验证Cookie）

当播放器获取到视频索引文件（m3u8文件）之后，会在播放视频文件之前自动发起第4步。

APP后台在收到客户端的请求之后，首先对cookie中的身份认证标识进行校验。如果用户身份非法，则直接拒绝请求。如果用户身份合法，则根据URL中携带的fileId、keySource、edk等参数，到KMS系统中获取DK，并返回给客户端。

以上步骤均完成之后，客户端便拿到了视频解密秘钥，从而可以进行正常的视频解密与播放。

## FAQ

###  1. 加密的HLS文件有什么不一样的地方？
根据HLS文档规范，HLS加密是对媒体文件(TS文件)进行加密，m3u8文件描述了播放器如何解密TS文件的方法。加密HLS的m3u8文件里包含了
#EXT-X-KEY参数，该参数包含METHOD和URI属性。METHOD属性描述了加密的算法，如AES-128。URI属性描述了获取解密密钥的地址， 播放器访问这个URI就可以获取到解密的密钥数据。如URI为`http://www.test.com/getdk?fileId=123&edk=14cf`,播放器解析该m3u8文件时就会向这个URI发起http请求，从返回包里获取到密钥数据。

###  2. 开通点播加密功能需要提供哪些信息？
开通点播加密功能需要提供getkeyurl，即上面所说的#EXT-X-KEY URI。APP服务端需要部署客户端播放加密视频时获取密钥数据的http服务。点播服务在加密视频时，会把加密视频的m3u8文件的#EXT-X-KEY URI设置为getkeyurl。为了获取密钥和管理方便，我们会在getkeyurl后面附加三个参数fileId、edk、keySource。fileId即视频Id，edk是加密后的密钥， keySource是密钥来源，使用点播内置KMS系统的加密文件，keySource为VodBuildInKMS。播放器发起获取解密密钥请求时，APP服务端收到的http请求的QueryString就会包含fileId， edk等参数，APP服务端可以根据fileId和edk等参数来返回对应的dk给播放器。

###  3. 播放器播放加密视频时从哪里获取解密密钥？
播放器播放加密视频时根据m3u8文件里的#EXT-X-KEY URI发起获取密钥的请求，即APP提供给点播的getkeyurl地址。注意，播放器不是向点播服务器发起获取密钥的请求。APP服务器在调用点播ProcessFile API进行加密时，加密完成后再调用[获取视频解密秘钥](https://cloud.tencent.com/document/product/266/9643) API获取到密钥后，需要将密钥保存起来，当播放器请求密钥时，根据播放器的请求参数来返回对应的密钥。

###  4. APP服务端如何返回密钥给播放器？
播放器向APP服务端发起获取密钥请求时，APP服务端需要将对应的密钥数据返回给播放器，返回的密钥数据为16字节的二进制数据。通过[获取视频解密秘钥](https://cloud.tencent.com/document/product/266/9643) API获取到密钥为Base64编码的字符串，返回给播放器时需要将这个字符串转换为二进制数据。
例如，dkData为Base64编码的密钥数据

java
```
  import java.util.Base64;
  byte[] dkBin = Base64.getDecoder().decode(dkData）;
```  

php
```
$dkBin = base64_decode($dkData);
```



