## 如何快速对接
在[快速体验](http://cloud.tencent.com/doc/product/267/4697)章节中我们介绍了如何使用直播管理控制台和终端Demo来体验腾讯云视频直播的功能。

如果您只是想做一些直播活动，那么这种手工创建频道的方式就足够了，毕竟一场活动所需要的直播频道数量只需要1-2个。

但如果您是想要做一个体验闭环的音视频直播APP，手工为每一个主播创建频道显然是不现实的，我们需要一种让您的APP自动创建和分发频道的解决方案，本页文档主要介绍这一部分。

## 云服务器SDK
替代手工创建频道的做法都是基于腾讯云的服务器API实现的，如何简单快速地访问腾讯云服务器是第一个我们需要搞清楚的问题。

此处您可以简单把腾讯云后台理解为一个简单的双层系统：**接入层** + **业务层**，您的请求需要经过一系列安全握手和鉴权验证才会真正走到业务逻辑层，内部细节还是挺多挺复杂的。

所以我们比较建议您通过[腾讯云服务端SDK](https://cloud.tencent.com/doc/sdk)进行对接，它可以让您只关心API调用，而无需关心其它细节，从而可以最大限度地减少您的对接成本。
![](//mccdn.qcloud.com/static/img/69c999e5599eaac3de6af2875a4c6702/image.jpg)

## 对接攻略（频道托管）
### 方案概述
**频道托管方案**即把频道的管理放在腾讯云上实现，腾讯云负责管理和维护频道的增、删、改、查 以及状态的监控，其本质原理跟[快速体验](http://cloud.tencent.com/doc/product/267/4697)中提到的网页手动管理频道没有什么区别，只是将原来的手工操作改由后台API方式实现。

接下来的几个步骤简单地介绍了一套基于频道托管的直播服务解决方案，该方案的优势就是频道都是动态创建的，直播开始前创建，直播结束后删除，频道的活跃度高，而且由于频道地址每次都是随机生成，所以安全性也非常高。
![](//mccdn.qcloud.com/static/img/5f9f08330b500d2c81b7c28be5307fee/image.png)


### Step1:创建频道
主播在开启直播之前，首先要**创建频道**，您可以使用 [CreateLVBChannel](http://cloud.tencent.com/doc/api/258/4703) 进行创建，但腾讯云后台系统不会直接返回推流URL，而是返回一个全局唯一的频道ID，接下来您还需要通过 [DescribeLVBChannel](https://cloud.tencent.com/doc/api/258/4717) 查询频道的推流地址。

>  **缓存列表**：
> 我们强烈建议您在您的服务上增加一个 - 缓存列表：
> 
> 在Step4中，观看端会请求直播中列表，如果您的APP这项功能比较受欢迎，那么直播中列表的请求频率和压力也会非常大。如果有缓存列表您的服务器程序可以直接从缓存中把直播中列表返回给客户端，从而减少了一次服务器之间的通讯，这会极大的减少失败率，因为腾讯云对于查询请求目前设置有频率限制（1分钟最多100次），这种限制显然不能满足一个稍热门APP的访问需求。
> 
> 与此同时，腾讯云API在频道管理这里只能提供频道相关信息（频道ID）等等，但真正的产品中，用户希望看到的是一个带有主播封面和主播介绍的图文并茂的列表，所以直播中列表需要填充更多信息，缓存列表的存在也会让这种信息填充的次数近似于频道创建次数，远小于列表查询次数。
> 


> **僵尸频道（20101）**：
> 所谓僵尸频道是指那些创建了之后没有使用且没有被回收的频道，它会挤占您可以创建的频道的数量，导致您可以创建的频道数量会越来越少，最终直至超限（报20101错误码）。
> 
> 为什么会有这种事情发生呢？这是由于如果频道的创建和删除都由APP来主控，那么就会有一个隐患：APP可能在开始直播后没有正常退出（崩溃或者被后台强杀）导致这个频道一直处于“未直播”状态，进而变成一个僵尸频道。
> 
> 要避免这个问题，最好的办法是在您的服务器加一个5分钟一次的回收机制，也就是每隔5分钟调用一次[DescribeLVBChannelList](http://cloud.tencent.com/doc/api/258/4703)获取频道列表，将channelStatus 不等于1（正在直播）的频道进行关闭和删除。

### Step2:SDK推流
Step2如果一切顺利，您的服务器会拿到推流URL，接下来可以直接返回给您的APP，剩下的工作交给APP来完成：把推流URL交给RTMP SDK进行推流，具体使用方法详见[推流SDK介绍](http://cloud.tencent.com/doc/api/258/4734)。

### Step3:删除频道
APP端如果推流结束，记得一定要将通知后台进行**频道删除**，注意`没有关闭的频道是不能随便删除的`，所以删除一个频道之前，要先通过[停止直播频道](https://cloud.tencent.com/doc/api/258/4720)接口先将频道状态置为停止，之后在调用[删除直播频道](https://cloud.tencent.com/doc/api/258/4722)接口对频道进行删除。

![step1_step3](//mccdn.qcloud.com/static/img/5b38a86c6679d2eca5d56a9ce2313c57/image.png)

前面三步实现的是主播端的逻辑，现在我们把视角切到观众这一侧的逻辑：

### Step4:查询频道列表
用户在打开您的APP之后，首先要做的是查看直播列表，这一步的实现建议如下：

您可以通过[DescribeLVBChannelList](http://cloud.tencent.com/doc/api/258/4703)实现频道列表的拉取，该API支持您设置过滤参数，通过对该参数的控制，您能实现诸如只查询直播中频道、分多页拉取、或者升序降序等高级功能。如果您在Step1中实现了缓存列表（强烈建议），那么您可以直接用缓存列表中的数据返回给客户端即可，这样可以实现更快地响应速度而且不受腾讯云后台访问频率限制。

真正的产品中，用户希望看到的是一个带有主播封面和主播介绍的图文并茂的列表，但[DescribeLVBChannelList](http://cloud.tencent.com/doc/api/258/4703)只能返回频道相关的信息，所以推荐您使用您的用户信息数据库中的用户信息对列表返回内容进行完善。如果您在Step1中有按建议实现一个列表缓存模块（强烈建议），那么只需要在频道列表增加的同时完善其中的主播信息就可以了。

### Step5:获取播放地址
观众在APP列表中选择一个喜欢的主播，并点击进入视频直播界面，这一步要按如下方式实现：

您的APP根据用户所选的频道ID，向您的服务器索要播放URL，您的服务器程序可以通过 [DescribeLVBChannel](https://cloud.tencent.com/doc/api/258/4717) 来查询频道的播放地址。获取到的播放地址可以是RTMP、FLV以及HLS协议的（在 [CreateLVBChannel](http://cloud.tencent.com/doc/api/258/4703) 时通过outputSourceType参数进行指定），推荐您使用FLV的地址进行播放，这是目前腾讯云最稳定也是最可靠的播放协议。

有的客户可能会问？为什么不在Step4时直接把播放地址拿到呢？

因为有很大的概率，[DescribeLVBChannel](https://cloud.tencent.com/doc/api/258/4717)返回的频道状态（channel_status）不是1（直播中）。因为在用户打开APP获取直播列表，到点开某一个主播之间的这段时间，我们是无法评估的，这段时间里，主播可能已经结束直播，也可能由于网络不畅等原因暂时中断了数据上传。如果您过早了取回了直播地址，可能无法在上诉情况下有好的提示用户。

>**防盗链**
>腾讯视频云的直播服务支持防盗链协议，如果启用了防盗链机制，那么在观看端获取的直播URL必须在短时间内使用，超过有效期即作废，这种情况下就更能有必要吧Step5和Step4分开了。

### Step6:SDK播放
成功获取到播放地址后，使用腾讯云提供的播放SDK即可进行播放。具体使用方法详见具体使用方法详见[播放SDK介绍](http://cloud.tencent.com/doc/api/258/4736)

![step4_step6](//mccdn.qcloud.com/static/img/196f467c6c8bf898df7154428f7ae34a/image.png)

### FAQ

#### 1. 频道数总超限制？
部分客户对接后发现在 [CreateLVBChannel](http://cloud.tencent.com/doc/api/258/4703) 时总是会被报告 20101（ 频道数超过上限）错误，这是因为腾讯云直播服务对单个客户最多可创建的频道数量进行了限制。

如果您刚开通直播服务，您最多只可以创建5个频道。这对于仅做直播活动的客户而言是足够用了，但是如果您预期是做一个直播类APP，这显然是不够的，您可以联系我们申请开通更多。

如果频道数限制已经被拉高（比如500）之后，依然频繁遭遇20101（ 频道数超过上限）错误，原因可能是僵尸频道问题，这种情况推荐您按Step1中建议进行处理：通过轮训机制检索和删除僵尸频道。

#### 2. 用户数 = 频道数？
不少客户认为APP有多少潜在的主播就应该有多少个频道，这种模式在技术上是可以实现的，但是并不经济。一方面，按照正常的发展规律会出现90%以上的频道都是闲置不用的。另一方面，用户跟频道号直接绑定后，TOP主播的频道号很容易被探测到，带来的安全风险也需要有更复杂的保护机制进行完善。

本文中频道托管模式所推荐的方案是一种动态创建和回收频道的方案，它能保证绝大多数时间频道都是在使用的，而且由于每个频道都是动态创建的，跟用户ID没有绑定关系，所以很难进行安全攻击。

#### 3. 推流地址的保护？
不少客户担心推流地址如果外泄了怎么办？其实这个担心在频道托管方案里是多虑的：

一方面，如果一个推流地址正在推流中，另一个客户端是无法去挤占的，这是一个最基本的保护。

另一方面，如果您按照本文档中建议的方式对接频道托管方案，那么每个主播每次直播所创建的频道都是动态生成的， 动态生成的频道最大的一个优势就是其推流地址是随机计算出来的，非常难于碰撞，而且有效期只保存于推流结束之后，所以猜测碰撞以及攻击成本都很高，没有必要做特殊的保护。

#### 4. 频道收费情况？
腾讯云的频道收费是根据**直播中频道**的最高并发数进行收费的，也就是每天有多少个主播在同时在线直播。活跃的频道有大量的后台服务器计算成本开销，出于成本考虑，腾讯云会对正在直播的频道的并发数收取后台服务器计算费用。如果并发数小于等于5个，这部分是免费的，如果并发频道数大于5，超出的数量按 **60元/个/月** 进行收费。

## 对接攻略（直播码）

### 方案概述
**直播码方案**，方案目的是让客户确保其最大的掌控能力，即频道的管理完全由客户来实现，这包括频道的ID由客户指定（称之为“直播码"），频道的状态监控由客户的后台系统看护，客户的后台系统要跟腾讯云协商鉴权KEY用来进行安全保护，避免恶意第三方冒充客户的账号身份进行机器人爆刷攻击。

因此，此种方式对客户的研发实力有一定的要求，故目前仅开放给大体量VIP客户，如需要请联系腾讯云架构师团队。
![](//mccdn.qcloud.com/static/img/43ef0a92314f787d2bc4b9f86498e5eb/image.png)

由于相关资料的对外优化还在处理中，直播码方案的具体对接攻略会在未来几天内完善，敬请期待...



