## 1.接口描述

### 1.1 通过http协议请求接口cgi

<br  />

    http://fcgi.video.qcloud.com/common_access

### 1.2 通过URI传递鉴权参数

<br  />

    http://fcgi.video.qcloud.com/common_access?appid=1252500000&interface=Mix_StreamV2&t=t&sign=sign

**参数说明:**

| 参数 | 参数含义 | 类型 | 备注|是否必填
|---------|---------|---------|---------|---------|
| appid | 客户ID | int |填写直播APPID，用于区分不同客户的身份 | Y |
| interface |接口名称 | string | 混流接口名称固定填写：Mix_StreamV2 |Y |
| t |有效时间 |int |UNIX时间戳，即从1970年1月1日（UTC/GMT的午夜）开始所经过的秒数；这个字段表示的是请求过期时间，请您在获取当前时间（秒）的基础上加60秒偏移 |Y|
| sign |安全签名|string|ign = MD5(key + t) ，即把加密key 和 t 进行字符串拼接后，计算一下md5值。这里的key是您在腾讯云直播管理控制台中设置的API鉴权key |y |

<br  />

举例说明安全签名sign的计算方法

<br  />

    key = "40328529ca4381a80c6ecf2e6aa57438"                    //API鉴权key 
    t = 1490858347                                              //t 过期时间
    key + t = "40328529ca4381a80c6ecf2e6aa574381490858347"      //key 和 t 进行字符串拼接
    sign = MD5（key + t） = "7f29ed83c61b77de1b0d66936fd4fd44"   //对拼接后的字符串计算MD5

<br  />

HTTP请求说明

    POST /common_access?interface=mix_streamv2.start_mix_stream_advanced&sign=xxxxxxxxx&appid=125250000 HTTP/1.0
    Content-Length: 741
    ...

### 1.3 通过POST方法传递混流body

<br  />

示例

<br  />

    {
        "timestamp":int(time.time()),           # UNIX时间戳，即从1970年1月1日（UTC/GMT的午夜）开始所经过的秒数
        "eventId":int(time.time()),             # 取随机数即可，标识一次网络请求
        "interface":
        {
            "interfaceName":"Mix_StreamV2",        # 固定取值"Mix_StreamV2"
            "para":
            {
                "app_id": appid,                # 填写直播APPID
                "interface": "mix_streamv2.start_mix_stream_advanced",  # 固定取值"mix_streamv2.start_mix_stream_advanced"
                "mix_stream_session_id" : "5000_enson",                # 填大主播的流ID
                "output_stream_id": "5000_enson11",                      # 填大主播的流ID
                "output_stream_type": 0,                                          # 填输出流类型
                "input_stream_list":
                [
                    # 大主播：背景画面
                    {
                        "input_stream_id":"5000_enson11",    # 流ID
                        "layout_params":
                        {   
                            "image_layer": 1                # 图层标识号：大主播填 1 ;  小主播按照顺序填写2、3、4、5、6
                        }   
                    },
                    # 小主播1
                    {
                        "input_stream_id":"5000_enson22",    # 流ID
                        "layout_params":
                        {   
                            "image_layer": 2,               # 图层标识号
                            "image_width": 160,             # 小主播画面宽度
                            "image_height": 240,            # 小主播画面高度
                            "location_x": 380,              # x偏移：相对于大主播背景画面左上角的横向偏移
                            "location_y": 630               # y偏移：相对于大主播背景画面左上角的纵向偏移
                        }   
                     },
                    # 小主播2
                     {
                         "input_stream_id":"5000_enson33",
                         "layout_params":
                         {
                             "image_layer": 3,
                             "image_width": 160,
                             "image_height": 240,
                             "location_x": 380,
                             "location_y": 390
                         }
                     },
                    # 小主播3
                     {
                         "input_stream_id":"5000_enson44",
                         "layout_params":
                         {
                             "image_layer": 4,
                             "image_width": 160,
                             "image_height": 240,
                             "location_x": 380,
                             "location_y": 150
                         }
                     }
                ]
            }
        }
    }

**具体参数说明**

>必填参数说明

| 参数名称| 数含义|输入类型|	备注	|是否必填|
|---------|---------|---------|---------|---------|
|timestamp|	当前时间	|int|	取当前时间（秒）即可|	Y|
|eventId	|标识一次网络请求|	int	|取随机值即可|	Y|
|interfaceName	|接口标识|string|	Mix_StreamV2，固定值|	Y|
|app_id|	直播APPID|	int	|直播APPID|	Y|
|interface|	混流接口名称	|string	|填写mix_streamv2.start_mix_stream_advanced，固定值|	Y|
|mix_stream_session_id	|一次混流操作标识	|string|	填写80字节以内，仅含字母、数字以及下划线的字符串|	Y|
|output_stream_id|	输出流ID|	string	|指定输出流ID	|Y|
|input_stream_id	|输入源ID	|string	|指定输入源ID|	Y|
|image_layer	|图层标识号	|int|	视频输入源目前支持1-6，音频输入源支持1-8|	Y|

>选填参数说明

|参数名称	|参数含义	|输入类型	|备注	|是否必填|
|---------|---------|---------|---------|---------|
|output_stream_type	|输出流类型	|int	|当输出流为输入流list中的一条时，填写0；  <br/>当输出流并非输入流list中的流时，该值为1。  <br/>不填默认为0。  <br/>注意：对于使用1的情况，请联系客服人员咨询使用方法。|	N|
|mix_stream_template_id| 输入模版ID|	int|	目前两输入源支持10、20、30、40； <br/>三输入源支持310、390、391； <br/>四输入源支持410； <br/>五输入源支持510、590； <br/>六输入源支持610。<br/>不填默认为0。|	N|
|input_type|	输入源类型|	int	|目前支持： <br/>0表示输入源为音视频； <br/>3表示输入源为画布 ； <br/>4表示输入源为音频； <br/>5表示输入源为纯视频。|	N|
|image_width	|输入画面的宽度	|double|	像素建议在0-3000以内。 百分比建议0.01-0.99。|	N|
|image_height	|输入画面的高度	|double|	像素建议在0-3000以内。 百分比建议0.01-0.99。|	N|
|location_x	|x偏移	|double	|相对于大主播背景画面左上角的横向偏移。  像素建议在0-3000以内。百分比建议0.01-0.99	|N|
|location_y|	y偏移|	double|	相对于大主播背景画面左上角的纵向偏移。 像素建议在0-3000以内。百分比建议0.01-0.99	|N|
|color|	颜色	|string	|使用画布时，常用的颜色有： <br/>黑色：0x000000; <br/>白色：0xFFFFFF; <br/>蓝色：0x99CCFF。|	N|
|crop_width|	裁剪源画面的宽度	|int|	建议在0-3000以内。|	N|
|crop_height	|裁剪源画面的高度	|int	|建议在0-3000以内。|	N|
|crop_x	|相对裁剪源画面左上角横向偏移。|	int	建议在0-3000以内。	|N|
|crop_y	|相对裁剪源画面左上角纵向偏移。|	int|	建议在0-3000以内。|N|


**常用的颜色说明：**

红色：0xcc0033

黄色：0xcc9900

绿色：0xcccc33

蓝色：0x99CCFF

黑色：0x000000

白色：0xFFFFFF

灰色：0x999999

<br  />

### 1.4 接口返回

<br  />

    {"code":0, "message":"Success!", "timestamp":1490079362}

<br  />

**参数说明**

| 参数名 | 参数含义| 类型 |备注|
|---------|---------|---------|---------|
| code  |返回错误码|int|0表示成功，其他表示失败|
|message |错误信息|string|  返回错误信息|
|timestamp|时间戳| Long int | 返回时间|

**常见错误码说明：**

|错误码 	|含义|
|---------|---------|
|-505 | 表示当前输入流查询失败 |
|-21 |表示当前输入的小画面位置参数非法，小画面越出主画面边界 |
|-30xxx| 对当前sessionid下的输出流未取消混流操作，同时用该sessionid去操作其他的输出流。 |
|其他 | 其他错误，请联系客户提供技术支持。|

### 1.5 取消混流的方法

<br  />

    {
        "timestamp":int(time.time()),           # UNIX时间戳，即从1970年1月1日（UTC/GMT的午夜）开始所经过的秒数
        "eventId":int(time.time()),             # 混流事件ID，取时间戳即可，后台使用
        "interface":
        {
            "interfaceName":"Mix_StreamV2",        # 固定取值"Mix_StreamV2"
            "para":
            {
                "app_id": appid,                # 填写直播APPID
                "interface": "mix_streamv2.start_mix_stream_advanced",  # 固定取值"mix_streamv2.start_mix_stream_advanced"
                "mix_stream_session_id" : "5000_enson",                # 填大主播的流ID
                "output_stream_id": "5000_enson11",                      # 填大主播的流ID
                "input_stream_list":
                [
                    # 大主播：背景画面
                    {
                        "input_stream_id":"5000_enson11",    # 流ID
                        "layout_params":
                        {   
                            "image_layer": 1                # 图层标识号：大主播填 1 ;  小主播按照顺序填写2、3、4
                        }   
                    }
                ]
             }
        }
    }  

<br  />

说明 ：使用当前sessionid操作当前输入流即可取消混流，半分钟后即可使用该sessionid操作其他输出流

<br  />

## 2.使用场景及部分特殊处理说明

### 2.1 支持功能列表

**功能列表**

|功能描述	|使用条件	|demo文档名称|
|---------|---------|---------|
|2-6条音视频流混流能力	|输入源为音视频|	test_video_and_audio.py|
|2-6条音视频流+画布混流能力	|输入源为音视频以及画布	|test_stream_and_canvas.py|
|2-6条音视频流+纯视频流混流能力|	输入源为音视频流以及纯视频流|	test_stream_and_video.py|
|2-6条音视频流+纯音频流混流能力	|输入源为音视频流以及纯音频流|	test_stream_and_audio.py|
|云端裁剪能力|	输入源为音视频流或纯视频流|	test_stream_crop.py|
|2-8条纯音频混流能力|输入源为纯音频流|	test_audio_only.py|


### 2.2 常用模版说明

常用的模版有10、20、30、40、310、410、510、610。使用这八种模版时，输入流不需要填写位置和长宽参数,，为原始画面的等比例缩放。只需要传入模版id即可。


模版10效果图：
![](https://mc.qcloudimg.com/static/img/1165deb7f41c182acce7175983fabdb7/t10.png)
<br  />

模版20效果图：
![](https://mc.qcloudimg.com/static/img/643d7cdb2e5359d226b6ae74bb2c46f7/t20.png)
<br  />

模版30效果图：
![](https://mc.qcloudimg.com/static/img/0e3e6e5063db197331d8bc33110cbd9e/t30.png)
<br  />

模版40效果图：
![](https://mc.qcloudimg.com/static/img/b706bf7f2424f953893ae7884309a693/t40.png)
<br  />

模版310效果图：
![](https://mc.qcloudimg.com/static/img/6c09ec743e7151947ff0cc0e14d53845/t310.png)
<br  />

模版410效果图：
![](https://mc.qcloudimg.com/static/img/c7e1ea8da4076b40f1572ac39df0e355/tt410.png)
<br  />

模版510效果图：
![](https://mc.qcloudimg.com/static/img/60882af92ec703a08f463a276cbbef53/t510.png)
<br  />

模版610效果图：
![](https://mc.qcloudimg.com/static/img/20dcad307192885fca4fd604b1fafad0/t610.png)
<br  />

### 2.3 特殊模版的说明

<br  />

为了便于部分用户的同屏对比需求，目前定制了三个特殊的模版390、391以及590

<br  />

模版390效果图：
![](https://mc.qcloudimg.com/static/img/e33d616ef0eeea4695b32ae70b0e3e6b/390.png)


<br  />

模版391效果图：
![](https://mc.qcloudimg.com/static/img/ccb23cfad471444edf75ba0b38c1a88f/391.png)


<br  />

模版590效果图：
![](https://mc.qcloudimg.com/static/img/bacb9a8107ef3f28cd2d8818c3970261/590.png)


<br  />

Note:当使用这三个模版时，图层id为1的那个输入源必须传入画布，颜色可以自定义指定

<br  />

### 2.4 自定义位置参数的填写规则说明

<br  />

示意图：
![](https://mc.qcloudimg.com/static/img/63d5f94f2ab6d271ab23aa5114f7ec54/weizhi.jpg)


<br  />

从上面的示意图可以看出，需要注意：

<br  />

位置参数location_x、location_y为小画面左上角相对背景画面左上角的绝对像素距离。

### 2.5 云端裁剪位置参数的填写规则说明

**示意图**

![](https://mc.qcloudimg.com/static/img/e1d42a1345a7c6adc199c1246e92081a/5555.png)

从上面的示意图可以看出，需要注意的有以下两点： 
 
a、输入的宽高、位置参数全部是像素绝对值。对于不同分辨率的流，需要不同处理。 
b、位置参数crop_x、crop_y表示相对原始流左上角绝对像素的位置坐标。

### 2.6 demo下载

**混流demo下载**

请点击[此处](https://mc.qcloudimg.com/static/archive/979c7ef4396772089532cc9d5a25619e/demo.zip)下载demo。
