
## 1. API Description

- **API**
  - **Live_Queue_Get**: This API is used to query the screenshot files generated in a channel during LVB.

- **URL**
  - URL for calling API: http://fcgi.video.qcloud.com/common_access

- **Use**
  - Tencent Cloud provides scheduled screenshot service for LVB. If you enable this service, you will receive a screenshot file of the LVB stream every several seconds.
  - Our customers often use this service for porn detection and LVB game customers use this service to periodically update the LVB cover image on the webpage.

- **Note**
  - Screenshot files are generated frequently and the file quantity is large, especially when there are many LVB channels. Therefore, Tencent Cloud provides query service for customers in the form of message queue.
  - A **message queue** is a screenshot file queue. When a new screenshot picture is generated in the LVB channel, the image ID and LVB code are placed in the dedicated message queue in the form of messages. You can periodically call the API to retrieve the latest screenshot messages.
  - The screenshot service is not a completely open service. It provides API support only for VIP customers. The API is invalid for customers who haven't activated screenshot-related services.

- **History**
  - Live_Queue_Get was planned to be used to retrieve various types of messages. As the [Notification Mechanism](https://cloud.tencent.com/doc/api/258/5957) becomes gradually accepted by more customers, this service is not widely applied. Currently, this service is mainly used to provide service for high frequency events such as screenshot.


## 2. Input Parameters

| Parameter Name | Description | Type | Remarks | Required |
|---------|---------|---------|---------|---------|
| appid                       | Customer ID     | int       | LVB APPID used for identifying customers |  Y          | 
| interface                 | API name   | string |  such as: Get_LivePushStat  |  Y          | 
| t | [Validity period](https://cloud.tencent.com/doc/api/258/5956#.E5.AE.89.E5.85.A8.E6.A3.80.E6.9F.A5 ) | int  | UNIX time stamp (decimal) |  Y | 
| sign | [Security signature](https://cloud.tencent.com/doc/api/258/5956#.E5.AE.89.E5.85.A8.E6.A3.80.E6.9F.A5 ) | string | MD5 (key + t) | Y | 
| Param.n.bid   | Message queue ID  | int  | 100: ID of the dedicated screenshot queue | Y |
| Param.n.count | Number of messages obtained at a time | int   |1-100. Default value is 1 | N |

## 3. Output Parameters
| Parameter Name | Description | Type | Remarks |
|---------|---------|---------|------------------|
| ret      | Error code |   int  |  0: Successful; other values: Failed |
| message | Error message |   string  |  Error message |
| output | Message content |   array  |  See below |

"output" is composed as follows:

| Field Name | Description | Type | Remarks                 |
|---------|---------|---------|------------------|
| count | Quantity    |   int      |    |
| data    | Screenshot URL list |   array  | See below  |

"data" is composed as follows:

| Field Name | Description | Type | Remarks                 |
|---------|---------|---------|------------------|
| stream_id | LVB code    |   string      |            |
| pic_url   | Screenshot URL|   string  |   Complete URL:  `http://(cos_bucketname)-(cos_appid).file.myqcloud.com/<file name>` |
| create_time | Screenshot time |   int  |  The time cannot be accurate to seconds due to interference of the I frame position  |

## 4. Example

Purpose: To query the screenshot files generated by all LVB channels under your current account.

| Component |   Example      |
|-------------|------------------|
| API URL | http://fcgi.video.qcloud.com/common_access? |
|appid     | 1234 |
| interface       | Live_Queue_Get |
|Param.n.bid | 100 |
| Param.n.count | 10 |
|t |1471850187 |
| sign | b17971b51ba0fe5916ddcd96692e9fb3 |

```
// When copying them, remove the invisible line breaks used for improving layout. Otherwise URL construction errors may occur, such as "appid is invalid"
URL = http://fcgi.video.qcloud.com/common_access?
			appid=1234&interface=Live_Queue_Get
			&Param.n.bid=100
			&Param.n.count=10
			&t=1471850187&sign=b17971b51ba0fe5916ddcd96692e9fb3
```
			
			







