## 1.How to Get URL Quickly
If you want to generate a group of URLs for testing, you only need to open ["LVB Console" -> "LVB Code Access" -> "Push Generator"](https://console.cloud.tencent.com/live/livecodemanage), and click **"Generate Push URL"** button to generate a push URL and three playback URLs with different playback protocols.

![](//mc.qcloudimg.com/static/img/98b9b659be67a9ac32384b606ace943f/image.png)


You can use [RTMP SDK DEMO](https://cloud.tencent.com/document/product/454/6555) to quickly test the validity of the push URL and playback URL.


## 2.How to realize auto construction at the backend

### 2.1Push URL 
In practical application of products, you cannot create push and playback URLs for each VJ manually. These URLs should be constructed by your server automatically. You can use any URL that conforms to the Tencent Cloud standards to push. The following URL is a standard push URL comprised of three elements:
 ![url](//mc.qcloudimg.com/static/img/6b4fd09ab2c7d6f1503070f8c994f4e0/image.png)

- **LVB Code**
It is also called room ID, and a random number or a user ID is recommended. Note, you need to add BIZID as the prefix in a valid LVB code.

- **txTime**
It refers to the time when the URL expires. The format is UNIX time stamp in hexadecimal notation, for example, 5867D600 means that the URL will expire at 00:00:00 AM on Jan. 1, 2017. Generally, our customers set txTime as follows: the URL will expire after 24 hours from the current time. It is not recommended to minimize the expiration time, because VJ will resume push in case of network interruption during LVB. If the expiration time is too short, VJ cannot resume push due to expiration of push URL.

- **txSecret**
The hotlink protection signature is used to prevent attackers from forging your backend to generate push URL. For calculation method, see [Hotlink Protection Calculation](#.E9.98.B2.E7.9B.97.E9.93.BE.E7.9A.84.E8.AE.A1.E7.AE.97.EF.BC.9F).

- **Sample Codes**
Sample codes (PHP and Java) in the lower half of ["LVB Console" -> "LVB Code Access" -> "Push Generator"](https://console.cloud.tencent.com/live/livecodemanage) page show how to generate hotlink protection URL.

### 2.2Playback URL
Constructing a playback URL is as simple as that for constructing a push URL. You only need to change the sub-domain name from **livepush** to **liveplay**:
![](//mc.qcloudimg.com/static/img/b7d8744654af4a174edf47f8998348a4/image.png)

## 3.How to Calculate Hotlink Protection
The security hotlink protection refers to **txSecret** field in push and playback URLs. It is used to prevent attackers from forging your backend to generate push URL, or stealing your playback URL for their benefits.

### 3.1Security Principle
To prevent attackers from forging your server to generate push URL, you need to configure **hotlink protection encryption key** in LVB console. Since the attackers are unable to obtain the encryption key easily, they cannot forge a valid push URL, as shown below:
![](//mccdn.qcloud.com/static/img/4ea1512fd335f68f30cca0a01e902966/image.png)


### 3.2Calculation Procedure
- **Step1: Exchange the key**
You need to negotiate one **encryption key** on the console at the official website. This encryption key is used to generate a hotlink protection signature on your server. Since Tencent Cloud has the same key as yours, it can decrypt and acknowledge the hotlink protection signature generated by your server.

 Encryption keys are classified into **push hotlink protection keys** and **playback hotlink protection keys**. The former are used to generate the push hotlink protection URLs and the latter are used to generate the playback hotlink protection URLs. In [LVB Console](https://console.cloud.tencent.com/live), you can configure the push hotlink protection key, as shown below:
![](//mc.qcloudimg.com/static/img/6be1d875f1120a16d3692c60bb4485a9/image.png)
 >  **Playback hotlink protection is disabled by default**
 >   
 > Since the configuration of playback hotlink protection key needs to be synced to thousands of CDN clusters, it cannot be frequentlymodified in the debugging phase due to long synchronization period. Contact us if you need to configure the playback hotlink protection by calling our customer service. It generally takes 1 to 3 days to complete the synchronization in all of the clusters.

- **Step 2: Generate txTime**
In the signature, the plaintext is txTime, which indicates the URL validity period. For example, if the current time is 2016-07-29 11:13:45 and the generated URL is expected to expire after 24 hours, txTime can be set to 2016-07-30 11:13:45.

 The long time string occupies large space in the URL. In actual application, 2016-07-30 11:13:45 is converted into the UNIX time stamp, i.e. 1469848425 (the various backend programming languages are directly handled by available time functions during the conversion). Then, the time stamp is converted into a hexadecimal string to further reduce the character size, that is, txTime = 1469848425 (hexadecimal) = 579C1B69 (hexadecimal).
 
 Generally, our customers set txTime as follows: the URL will expire after 24 hours from the current time. It is not recommended to minimize the expiration time, because VJ will resume push in case of network interruption during LVB. If the expiration time is too short, VJ cannot resume push due to expiration of push URL.

- **Step 3: Generate txSecret**
txSecret is generated as follows: txSecret = **MD5 (KEY+ stream_id + txTime)**. The **KEY** here is the encryption key you configured in Step 1. In this example, stream_id is 8888_test001, txTime is 579C1B69 as calculated above, and **MD5** is the standard unidirectional irreversible hash algorithm.

- **Step 4: Combine to obtain the hotlink protection URL**
  After obtaining the push (or playback) URL, the txTime used to inform Tencent Cloud of the URL expiration time, and the txSecret that can be decrypted and verified only by Tencent Cloud, you can combine them to obtain a hotlink protection security URL.
	
### 3.3Sample Codes
Sample codes (PHP and Java) in the lower half of ["LVB Console" -> "LVB Code Access" -> "Push Generator"](https://console.cloud.tencent.com/live/livecodemanage) page show how to generate hotlink protection URL.
