## 1. 为什么会卡顿
![](//mc.qcloudimg.com/static/img/b41b15c344f8c34011e4ee0e55db21e5/image.png)

卡顿的原因无外乎三种情况：
- **原因A - 帧率太低**
如果主播端手机性能较差，或者有很占 CPU 的后台程序在运行，可能导致视频的帧率太低。正常情况下，每秒 15FPS 以上的视频流才能保证观看的流畅度，如果FPS低于 10 帧，可以判定为**帧率太低**，这会导致 <font color='red'>全部观众</font> 的观看体验都很卡顿。

- **原因B - 上传阻塞**
主播的手机在推流时会源源不断地产生音视频数据，但如果手机的上传网速太小，那么产生的音视频数据都会被堆积在主播的手机里传不出去了，上传阻塞会导致 <font color='red'>全部观众</font> 的观看体验都很卡顿。

 **国内运营商** 提供的宽带上网套餐中，下载网速虽然已经达到了 10Mbps， 20Mbps 甚至是 100Mbps，但上传网速却还一直限制的比较小，很多小城市的上行网速最快是 512Kbps（也就是每秒最多上传 64KB 的数据）。
 
 **WiFi 上网** 遵循 IEEE 802.11 规定的载波多路侦听和冲突避免标准，简言之就是一个 WiFi 热点同时只能跟一个手机通讯，其它手机在跟热点通讯前都要先探测或询问自己是否能够通讯，所以一个 WiFi 热点使用的人越多就越慢。同时，WiFi 信号受建筑墙体的屏蔽干扰很厉害，而一般的中国普通家庭很少在装修时考虑好 WiFi 路由器和各个房间的信号衰减问题，可能主播本人也不清楚自己做直播的房间离家里的路由器究竟穿了几堵墙？

- **原因C - 下行不佳**
就是观众的下载带宽跟不上，或者网络很波动。比如直播流的码率是1Mbps 的，也就是每秒钟有 1M 比特的数据流要下载下来。但如果观众端的带宽不够，就会导致观众端体验非常卡顿。 下行不佳只会影响当前网络环境下的观众。

## 2. 发现问题的“眼睛”
推流 SDK 提供了一种状态反馈机制，每隔 1-2 秒就会将内部各种状态参数反馈出来，我们可以通过注册 **TXLivePushListener** 监听器来获取这些状态。

![](//mc.qcloudimg.com/static/img/48fd46af4e17b0299fd00a0e661a16f0/image.png)

|  推流状态                   |  含义说明                    |   
| :------------------------  |  :------------------------ | 
| NET_STATUS_CPU_USAGE     |当前进程的CPU使用率和本机总体的CPU使用率|
|	NET_STATUS_VIDEO_FPS     | 当前视频帧率，也就是视频编码器每条生产了多少帧画面|
|	NET_STATUS_NET_SPEED     | 当前的发送速度（单位：kbps）|
|	NET_STATUS_VIDEO_BITRATE | 当前视频编码器输出的比特率，也就是编码器每秒生产了多少视频数据，单位： kbps|
|	NET_STATUS_AUDIO_BITRATE | 当前音频编码器输出的比特率，也就是编码器每秒生产了多少音频数据，单位： kbps|
|	NET_STATUS_CACHE_SIZE    | 音视频数据堆积情况，这个数字超过个位数，即说明当前上行带宽不足以消费掉已经生产的音视频数据|
|	NET_STATUS_CODEC_DROP_CNT  |全局丢包次数，为了避免延迟持续恶性堆积，SDK在数据积压超过警戒线以后会主动丢包，丢包次数越多，说明网络问题越严重。|
| NET_STATUS_SERVER_IP     | 连接的推流服务器的IP，一般应该是离客户端跳数比较少的就近服务器 |


## 3. 帧率太低
### 3.1 帧率太低的评判
通过 TXLivePushListener 的 **VIDEO_FPS** 的状态数据，我们可以获得当前推流的视频帧率。正常来说，每秒 15FPS 以上的视频流才能保证观看的流畅度，如果FPS在 10 帧以下，观众就会明显的感到画面卡顿。

### 3.2 针对性优化方案
- **3.2.1 观察 CPU_USAGE 的大小**
通过 TXLivePushListener 的 **CPU_USAGE** 的状态数据，我们可以获得**当前推流SDK的CPU占用情况** 和 **当前系统的CPU占用情况**。

 如果当前系统的整体 CPU 使用率超过 80%，那么视频的采集和编码都会受到影响，无法正常发挥作用；如果 CPU 使用率达到 100%，那么主播端本身就已经卡的一塌糊涂了，观众端要有流畅的观看体验显然是不可能的。

- **3.2.2 确认谁在消耗CPU**
一款直播 APP 中使用CPU的不可能只有RTMP SDK，弹幕、飘星、文本消息互动等等，都有可能会消耗一定的CPU，这些都是不可避免的。如果单纯要测试推流 SDK 的 CPU 占用情况，可以使用我们的 [简单版 DEMO](https://cloud.tencent.com/document/product/454/6555) 来观察和评估。

- **3.2.3 不盲目追高分辨率**
过高的视频分辨率并不一定能带来清晰的画质：首先，较高的分辨率要配合较高的码率才能发挥效果，低码率高分辨的清晰度很多时候比不上高码率低分辨率。其次，像1280 * 720 这样的分辨率，在平均 5寸 左右的手机屏幕上并不能看出优势，要像跟 960 * 540 的分辨率拉开差距，只有在 PC 上全屏观看才能有明显的感官差异。

 但较高的分辨率会显著提升 SDK 的 CPU 使用率，因此常规情况下，推荐使用 TXLivePush 的 setVideoQuality 设置 **高清** 档即可，盲目追高分辨率有可能达不到预期的目标。

- **3.3.4 适当使用硬件加速**
现在的智能手机都支持硬件编码来降低视频编码对 CPU 的依赖，如果您发现您的 
App 的 CPU 使用率过高，可以开启硬件编码来降低 CPU 使用率。

 TXLivePush 的 setVideoQuality 的**高清档**默认使用的是软件编码（硬件编码在部分 Android 手机上的编码效果不佳，马赛克感很强是个硬伤），如果要使用硬件编码，可以使用 TXLivePushConfig 的 enableHWAcceleration 选项开启。

## 4. 上传阻塞
据统计，视频云客户群 80% 以上的直播间卡顿问题，均是由于主播端上传阻塞所致。

### 4.1 上传阻塞的评判
- **4.1.1 : BITRATE 与 NET_SPEED 的关系**
 BITRATE( = VIDEO_BITRATE + AUDIO_BITRATE ) 指的是编码器每秒产生了多少音视频数据要推出去，NET_SPEED 指的是每秒钟实际推出了多少数据，所以如果 BITRATE == NET_SPEED 的情况是常态，则推流质量会非常良好；而如果 BITRATE >= NET_SPEED 这种情况的持续时间比较长，推流质量就很难有什么保障。

- **4.1.2 : CACHE_SIZE 和 DROP_CNT 的数值**
BITRATE >= NET_SPEED 的情况一旦出现，编码器产生的音视频数据就会在主播的手机上积压起来，积压的严重程度以 CACHE_SIZE 这个状态值展示出来，如果 CACHE_SIZE 超过警戒线，SDK 会主动丢弃一些音视频数据，从而触发 DROP_CNT 的增长。

 下图所示就是一个典型的上行阻塞，途中 CACHE_SIZE 始终在 红色警戒线 以上，说明上行网络不足以满足数据的传输需求，也就是上行阻塞严重：

![](//mc.qcloudimg.com/static/img/319d6197da603ca15ffc6e2afd778e48/image.png)

![](//mc.qcloudimg.com/static/img/e241222c0591e6b5ffa41738a8a35d62/image.png)
 > PS: 您可以在[直播控制台>>质量监控](https://console.cloud.tencent.com/live/livesdk) 里看到类似上图的图表。


### 4.2 针对性优化方案
- **4.2.1 主动提示主播**
对于注重清晰度的场景下，通过合适的 UI 交互提示主播 **“当前网络质量很糟糕，建议您拉近离路由器的距离，避免WiFi穿墙！”** 是最好的选择。

 RTMP SDK 的推流功能文档中有涉及 **事件处理** 的介绍，您可以利用它来做到这一点。推荐的做法是：如果 App 在短时间内连续收到  RTMP SDK  的多个 **PUSH_WARNING_NET_BUSY** 事件，则提示主播网络关注一下当前网络质量，因为对于上行阻塞这种情况而言，主播本人是没办法通过视频的表现感知到的，只能通过观众的提醒或者 APP 的提醒来了解。

- **4.2.2 合理的编码设置**
如下是我们推荐的编码设置（适合美女秀场，更多信息请参考 [如何实现更好的画质？](https://cloud.tencent.com/document/product/454/7955)），可以通过 TXLivePush 里的 setVideoQuality 接口进行相应档位的设置：

| 档位   | 分辨率| FPS| 码率 | 使用场景 | 
|:-------:|---------|---------|:-------:|---------|
| **标清** | 360\*640 | 15 | 400kbps - 800kbps | 如果您比较关注带宽成本，推荐选择该档位，画质会偏模糊，但带宽费用较高清档要低 60%。 |
| **高清**<br><font color='red'>（推荐）</font> | 540\*960 | 15 | 1200kbps | 如果您比较关注画质，推荐选择该档位，能确保绝大多数主流手机都能推出很清晰的画面。 |
| **超清** | 720\*1280 | 15 | 1800kbps | 慎用：如果您的场景多是小屏观看不推荐使用。如果是大屏幕观看，且主播网络质量很好可以考虑。|

- **4.2.3 启用流控辅助**
有些客户会说：“我们的 APP 任何用户都有可能使用，让我去决定他们的网速不现实。”

 如果主播的上传网速的不确定性确实很大，推荐开启网络自适应，参考文档见 [iOS平台](https://cloud.tencent.com/document/product/454/7884#4.-.E6.99.BA.E8.83.BD.E6.8E.A7.E9.80.9F) &  [Android平台](https://cloud.tencent.com/document/product/454/7890#4.-.E6.99.BA.E8.83.BD.E6.8E.A7.E9.80.9F) 。

 不过我们依然建议优先参考 **4.2.1 主动提示主播** 中的方案，毕竟既要高清流畅，又不能保证上传网速，本身就是 **即要马儿跑得快，又要马儿不吃草** 的事情。

| 设置项 | 中文含义 | 建议值 |
|---------|------------|--------------|
| MinVideoBitrate | 最小码率 | 400 |
| MinVideoBitrate | 最大码率 | 1000（推荐根据具体分辨率而定） |
| AutoAdjustBitrate | 码率自适应 | 开启 |
| setAutoAdjustStrategy | 码率调整策略 | AUTO_ADJUST_BITRATE_STRATEGY_2 |


## 5. 播放端的优化
![](//mc.qcloudimg.com/static/img/9ccfcf56c0993232cc5637f306c21ba5/image.png)

### 5.1 卡顿 & 延迟
如上图，下行网络的波动或者下行带宽不沟通，都会导致在播放过程中出现一段段的**饥饿期**—— APP这段时间内拿不到可以播放的音视频数据。如果想要让观看端的视频卡顿尽量少，就要尽可能地让APP缓存足够多的视频数据，以保证它能平安度过这些“饥饿期”。

但是，APP缓存太多的音视频数据，会引入一个新的问题 —— **高延迟**，这对互动性要求高的场景是很坏的消息。同时，如果不做延迟修正和控制，卡顿引起的延迟会有**累积效应**，就是播放时间越久，延迟越高。延迟修正做得好不好是衡量一款播放器是否足够优秀的关键指标。

所以，**延迟和流畅是一架天平的两端**，如果过分强调低延迟，就会导致轻微的网络波动即产生明显的播放端卡顿。反之，如果过分强调流畅，就意味着引入大量的延迟（典型的案例就是HLS(m3u8)通过引入10-30秒的延迟来实现流畅的播放体验)。

### 5.2 针对性优化方案
为了能够让您无需了解过多流控处理知识就能优化出较好的播放体验，腾讯云 RTMP SDK 经过多个版本的改进，优化出一套自动调节技术，并在其基础上推出了三种比较优秀的延迟控制方案：

- **自动模式**：如果您不太确定您的主要场景是什么，可以直接选择这个模式。
>把 TXLivePlayConfig 中的 setAutoAdjustCache 开关打开，即为自动模式.在该模式下，播放器会根据当前网络情况，对延迟进行自动调节（默认情况下播放器会在1s - 5s 这个区间内自动调节延迟大小，您可以通过setMinCacheTime 和 setMaxCacheTime对默认值进行修改），以保证在足够流畅的情况下尽量降低观众跟主播端的延迟，确保良好的互动体验。

- **极速模式**：主要适用于**秀场直播**等互动性高，因而对延迟要求比较苛刻的场景。
> 极速模式设置方法是  **setMinCacheTime = setMaxCacheTime = 1s**  ， 而您也发现了，自动模式跟极速模式的差异只是MaxCacheTime 有所不同 （极速模式的 MaxCacheTime 一般比较低，而自动模式的MaxCacheTime 则相对较高 ），这种灵活性主要得益于SDK内部的自动调控技术，可以在不引入卡顿的情况下自动修正延时大小，而MaxCacheTime 反应的就是调节速度：MaxCacheTime的值越大，调控速度会越发保守，当然卡顿概率就会越低。
 
- **流畅模式**：主要适用于**游戏直播** 等大码率高清直播场景。
> 当把播放器中的 setAutoAdjustCache 开关关闭，即为流畅模式，在该模式下，播放器采取的处理策略跟Adobe FLASH内核的缓存出策略如出一辙：当视频出现卡顿后，会进入 loading 状态直到缓冲区蓄满，之后进入playing状态，直到下一次遭遇无法抵御的网络波动。默认情况下，缓冲大小为5s，您可以通过setCacheTime进行更改。
> 
> 在延迟要求不高的场景下，这种看似简单的模式会更加可靠，因为该模式本质上就是通过牺牲一点延迟来降低卡顿率。





