## 客户服务器作用

如下图所示，客户服务器在流程中的作用为：当 App 申请上传视频文件时，校验 App 是否有上传权限，如校验通过，则计算并派发上传签名，当 App 拿到上传签名后即可利用 UGC SDK 完成视频文件的上传。

![](//mc.qcloudimg.com/static/img/9c1893434805c80c44684207d47e4ab1/image.jpg)

这种流程设计可以确保您的服务器对视频文件的上传有绝对的掌控权：一方面，您可以在服务器端控制上传权限开放给哪些用户；另一方面，由于上传签名的计算密钥位于您的服务器上，也可以有效避免攻击者盗用您的云存储空间和CDN流量。


## 签名的生成计算

签名的计算我们有专门的 [文档](https://cloud.tencent.com/document/product/266/9221) 进行介绍，文档内容比较详细，但简单概括一下就是如下三个步骤：

- **【步骤一】获取 SecretID+SecretKey**
你可以在 [云 API 密钥](https://console.cloud.tencent.com/capi) 管理里获取或者创建一个 SecretID，并拿到其对应的 SecretKey：
![](//mc.qcloudimg.com/static/img/23f95aaa97adf3eeae3bf90470fe5122/image.png)

- **【步骤二】拼接待加密的明文字符串**
拼接签名明文字符串，形式为HTTP QueryString。格式如下：
```
Original = secretId=[SecretId]&currentTimeStamp=[currentTime]&expireTime=[expireTime]&random=[rand]
```

- **【步骤三】将明文字符串转化为密文签名**
拼接好签名的明文字符串Original后，用已经获取的SecretKey对明文串进行 [HMAC-SHA1](https://www.ietf.org/rfc/rfc2104.txt) 加密，得到SignTmp：
```
SignTmp = HMAC-SHA1(SecretKey, Original) 
```

 将密文串SignTmp放在明文串 Original 前面，拼接后进行 [Base64](https://tools.ietf.org/html/rfc4648) 编码，得到最终的签名Sign：
```
Sign = Base64(append(SignTmp, Original)) 
```

-  **<font color='red'>【示例代码 & 检查工具】</font>**
由于字符串拼接过程中会有各种不可见字符和编码问题，所以我们非常不推荐您手工编写程序进行签名计算，而是推荐采用我们的示例代码：
  + [PHP示例](/document/product/266/7906)
  + [Node.js示例](/document/product/266/7905)

 如下的两个工具可以辅助您检查您所生成的签名是否正确：
 + [UGC 上传签名生成工具](https://video.qcloud.com/signature/ugcgenerate.html)：在页面上填写签名所需要的参数和密钥，即可生成一个合法的签名。
 + [UGC 上传签名解析工具](https://video.qcloud.com/signature/ugcdecode.html)：对一个合法的签名进行解析，获得生成签名时所使用的参数。
