## 背景介绍
绝大多数客户拿到小直播代码之后，第一件事情就是替换账号系统，毕竟自己 APP 的账号系统是不能随随便便更换的。

在小直播的设计之初我们就考虑到了这一点，所以小直播相关功能设计均 **没有强依赖账号系统**，目的就是能让您快速完成账号体系的替换。

虽然说没有强依赖，但多多少少还是有点依赖，我们需要对下面的模块做一下修改和调整：
- **聊天室模块** ： 替换账号系统后，要修改此模块让聊天室中参与者的名字都变成您的账号体系里的用户。
- **UserInfo模块**：主播的头像、昵称、封面等等信息，都是跟账号想绑定的，所以该模块必须要调整。

## 聊天室模块
如果您不想对聊天室中的参与者做太多限制，比如任何 APP 用户都可以参与进来，那么可以走 **简单替换** 模式；
如果您需要将聊天室中的个体和您的账号系统中的ID一一强绑定，以确保聊天室中的参与者身份都已经过您的服务器认可，那么您可以选择 **安全对接** 模式。

### 1. 简单替换
简单对接模式的目标：只需修改几行代码，就能把小直播的聊天室成员替换成您现有的账号体系，对聊天参与者没有太多安全性限制。

[访客模式](https://cloud.tencent.com/document/product/454/7980#3.2-.E8.AE.BF.E5.AE.A2.EF.BC.88.E6.89.98.E7.AE.A1.EF.BC.89.E6.A8.A1.E5.BC.8F)  ：是腾讯云通讯服务的运行模式之一，该模式下，腾讯云会为每个消息收发者在后台对应一个“访客账号”，这样就避免了让 IM 通讯服务跟您现有的账号系统强耦合，同时又能满足 IM 服务必须要有账号才能收发消息的限制。

聊天室里的每个消息发送者，会将其用户信息（昵称、头像等等）打包放在消息体中发出去，聊天室中其它的接收者也是从消息体中把用户信息解析出来。

- **step1: 选择托管模式**
> 确保腾讯[云通讯控制台](https://console.cloud.tencent.com/avc)中的集成模式为**托管模式**，这样能让腾讯云为访客模式的访客账号提供后台支持。
> ![](//mc.qcloudimg.com/static/img/d52ac3662d5310673a5d6c6a78f50da4/image.png)

- **step2: 屏蔽TLS常规登录逻辑**
> iOS平台：TCLoginViewController##viewDidLoad 实现了小直播自带的用户名密码“自动登录”逻辑。
> Android平台：TCLoginActivity##onCreate 里对 userNameLoginViewInit 函数的调用相当于是一种“自动登录”。

- **step3: 只对接访客模式**
> iOS平台：访客模式启动IM SDK 的代码位于TCIMPlatform.h 中的 guestLogin。
> Android平台：访客模式启动IM SDK 的代码位于TCLoginMgr.java 中的 guestLogin 函数。

### 2. 安全对接
如果您需要将聊天室中的个体和您的账号系统中的ID一一强绑定，以确保聊天室中的参与者身份都已经过您的服务器认可，那么您可以选择此模式，改模式的对接方式可以参考 [如何绑定 IM 身份](https://cloud.tencent.com/document/product/454/6562#.E7.BB.91.E5.AE.9Aim.E8.BA.AB.E4.BB.BD)。

## UserInfo模块
这里说的用户资料都是主播的资料（比如昵称、头像），也就是APP当前用户的资料，观众这一方看到的各个主播的信息是在拉取直播间列表的时候就已经取到了。

小直播默认使用了腾讯云的托管账号服务，故其默认的用户资料是存储于腾讯云托管账号资料系统中的，所以替换账号后，用户资料部分自然也要相应的调整。

### 1. iOS平台
- **屏蔽旧逻辑**：
屏蔽自动从腾讯服务器拉取用户资料的逻辑，小直播在登录成功后，会自动从服务器拉取用户资料，如果资料存在您自己的服务器，这个逻辑需要屏蔽，做法是删除TCIMPlatform.m中的setIdentifier的调用：
![](//mc.qcloudimg.com/static/img/6942eb366e524855e8a2a898e6689cf5/image.jpg)
	 
- **对接新资料**：
推荐的做法是调用TCUserInfoMgr中的setUserProfile接口设置新的用户资料（如昵称、头像、封面等），小直播在用到用户资料时，将会从用户资料管理类TCUserInfoMgr中获取，从而最小化您的适配工作：
![](//mc.qcloudimg.com/static/img/e78f80670d85478432e4fe5d932d2430/image.jpg)

### 2. Android平台
小直播默认的逻辑是在登录完成后，调用TCUserInfoMgr中的queryUserInfo()，改函数的作用是从腾讯云账号系统中拉取用户资料并将其设置到mUserInfo成员变量中，故修改该函数即为最简单和快速的适配方案：
![](//mc.qcloudimg.com/static/img/3cc88fb62c6b7fac4215c034806f8d06/image.jpg)





