本文主要介绍如何在小直播现有代码的基础上进一步加固安全性，安全性需求不同客户可能有不同的标准，所以如果您对安全性要求不是特别苛刻，仅做了解即可，不需要照搬执行。

## 后台协议鉴权
### 1. 什么是鉴权？
鉴权（鉴定权限），就是 APP 在跟后台服务器交互时，服务器会检查当前用户是否已经登录过？是否有权限完成当前的操作？

考虑到您会使用自有的账号系统，我们在小直播中并没有默认实现鉴权相关的安全保护措施，因为鉴权必然跟账号系统绑定，换言之，小直播默认是 **<font color='red'>不鉴权</font> ** 登录态的。

目前小直播的前后台交互协议有如下几条：

| 协议   | 作  用 | 是否有必要做登录检查 | 检查的目的|
|---------|---------|:---------------------------:| ------------|
| RequestLVBAddr| APP 请求推流地址| <font color='red'>是</font>| 防止任何APP用户都能进行直播|
| ChangeStatus| 修改直播间推流状态| <font color='red'>是</font> | 防止恶意用户关闭正常的直播流|
| ChangeCount | 修改点赞、观看人数等计数项| 否 | 公开型信息 |
| FetchList       | 拉取直播or回看列表 | 否 | 公开型信息 |
| GetCOSSign  | 获取COS文件上传的签名| 是 | 非登录用户上传的文件无法跟账号关联 |
| GetUserInfo  | 获取指定主播的详细信息| 否| 公开型信息 |

- **观众端**
一般而言，对普通观众的登录态检查并不是特别必要，否则容易影响直播活跃度。

- **推流端**
对主播的登录检查一般都是必须的，尤其是随着相关部门对主播的身份认证抓的越来越严格了，越来越多的直播平台要求不仅仅是注册用户才能直播，还必须是认证的用户才能直播。

所以，我们需要保护的交互协议主要是 RequestLVBAddr、ChangeStatus 和 GetCOSSign 三条协议，前两个是创建直播间时必须的，适用于主播。 GetCOSSign 是用来上传直播封面等信息用的，隶属个人资料，也必然以登录为基础。


### 2. 常规实现方案

相信您目前后台的登录和权限校验系统已经很完善了，如何给后台协议添加登录Session检查并没有什么困难，但这里我们还是简单以 RequestLVBAddr 为例做一个说明：

![](//mc.qcloudimg.com/static/img/1a9e97f735c89d3557c3e76db15bc7e5/image.png)

1. App 将用户名和密码进行MD5单向不可逆加密，然后连同用户名和时间戳一起发给服务器。更安全的登录协议需要更复杂的流程，比如密码空间置换避免彩虹表破解等等。

2. 服务器确认用户是合法的注册用户之后，给客户分配一个短期有效的 sessionkey，App会将这个 sessionkey 存在手机上。

3. 主播按下“开始直播”按钮时，App会向后台发起 RequestLVBAddr 请求，请求头部需要携带 sessionkey（http请求一般放在cookie字段里）

4. 后台检查 sessionkey 是否有效以及是否过期，检查通过后才会向 App 下发 房间号 和 推流URL。


## 绑定IM身份

### 1. 绑定什么？
小直播默认的消息发送方案是将消息发送者的用户名、昵称、头像等身份信息以 JSON 的格式拼装在消息体中，这种方式的优势就是简单，对于安全性要求不高的聊天室是非常合适的。

如果你需要更强的安全性，比如需要将消息发送者的身份跟您的账号系统强绑定，也就是消息发送者的身份一定是您账号系统里的一个确定的 ID， 那么就需要通过对接 IM 云通讯服务的 [**独立模式**](https://cloud.tencent.com/document/product/454/7980#3.3-.E7.8B.AC.E7.AB.8B.EF.BC.88.E9.89.B4.E6.9D.83.EF.BC.89.E6.A8.A1.E5.BC.8F) 来实现了。

### 2. 独立模式 
独立模式下，APP 用户在成功登录后，您的登录服务器需要派发imLogin ( IM SDK 运行的第一个步骤 ) 所需求的 UserSig 签名（签名的计算采用跟腾讯云后台协商的非对称密钥实现），腾讯云通过检查 UserSig 签名的有效性后，才允许其收发消息。

如此一来，就能保证：**只有通过您的服务器认证的用户，才能正常的通过 IM 云通讯服务器的验证。** 

当然，更重要的意义是，既然没有经过您认可的用户不能使用 IM 功能，那么您就不需要将用户名和昵称放在 IM 消息体中，而是直接通过 IM 消息头里的 ID 身份确认消息发送者，因为消息头不破解 IM SDK 无法伪造，因此这种方式**可以更安全的确认消息发送者的身份**，也就是刚才提到的，将消息发送者的身份跟您现有的账号系统强绑定。


### 3. UserSig签名
UserSig签名，是腾讯云 IM 服务后台跟您的服务器之间认证的一种手段，用于解决两家不同公司的服务器之间怎么相互信任的问题，我们打个更形象的比方来解释其原理：

> 1. 某个美女用户在您的App上登录了，她使用了之前在您这里注册的ID和登录口令，ID叫做 “花仙子”。
>
> 2. 您这边在拿到ID和口令后立刻进行了验证，并且确认她可以登录 APP 。于此同时，您还开给她一张**放行条(UserSig)**，上面写着“<font color='blue'> '花仙子' 是良民的干活，到你腾讯的地盘，你可得伺候好了，不要亏待她...</font>”，为了确保这个放行条不被伪造，您还在上面用正楷签了名。
>
> 3. 腾讯云在看了您的放行条以后，确认签字为您本人亲笔所签，自然会提供相应的服务。

上述就是消息鉴权背后的对接方案，它的核心目标就是限制哪些没有得到您的后台服务器认可的用户收发消息，但让您的服务器检查每一条消息又是不合适的，所以才演化出了这样一套方案。

UserSig 签名使用了最普通的非对称密钥加密技术，您在开通独立模式的时候，会在腾讯云拿到一组公私密钥对，用私钥[加密](https://cloud.tencent.com/doc/product/269/1510)指定的信息即可。


### 4. 对接流程
- **step1: 选择独立模式**
> 确保腾讯[云通讯控制台](https://console.cloud.tencent.com/avc)中的集成模式为**独立模式**，并且下载计算签名用的公私钥。
> ![](//mc.qcloudimg.com/static/img/4e79ff175d8053f8998e02732468e398/image.png)

- **step2: 完成后台对接**
> 这部分由贵团队的后台工程师完成，它要使用step1中获取的签名秘钥，为您的 APP 提供一个拉取 UserSig 签名的接口，APP 登录成功后就可以通过该接口获取计算好的 UserSig。

- **step3: imLogin(ID, UserSig) **
> APP 获取到来自您的服务器签发的 UserSig 后，就可以调用 IM SDK 的 imLogin(ID, UserSig) 接口激活 IM 服务了，腾讯云后台会使用 step1 中对应的公钥对 UserSig 进行解密，从而验证当前用户是否得到了您的登录服务器的认可。

- **step4: 修改消息发送逻辑**
>修改消息发送端代码，不需要将发送者身份放入消息体中。同时修改消息接收端代码，通过 TIMMessage 的 sender 属性，来更加确定地获取消息发送者的身份。

以上步骤的示意图如下：
![](//mc.qcloudimg.com/static/img/1e541b2931d0cb8fb1815f26aa8fb493/image.png)


