## 功能体验

在微信小程序中搜索 **腾讯视频云** 可以加载到我们的演示用小程序，其中 **多人音视频** 功能可用于体验和测试最多 6 人的实时音视频功能（再多也是可以的，但是考虑到低端 Android 机的存在，我们没有放开限制） 。

## 技术指标
- 通讯延迟：300ms - 800ms
- 底层协议：UDP 改造后的 RTMP 协议，支持丢包恢复和网络自适应，并针对实时音视频场景进行了优化。
- 安全加密：每次连接都独立启用一对全新的非对称加密密钥，整个通讯过程无法监听和篡改。
- 支持录制：如果需要可以在云端进行录制，适用于在线客服、金融开户等商用音视频解决方案，支持私有化部署。

## 原理解读
![](//mc.qcloudimg.com/static/img/b1a7b46753e43e0530bfeca587234bd3/image.jpg)

通讯的双方 A 和 B 各自创建一个 RTC 模式的 &lt;live-pusher&gt; 和 &lt;live-player&gt; 剩下的事情就是置换 URL 了。

## 对接攻略
![](//mc.qcloudimg.com/static/img/c1c5ec3e686ad87d23a54a325eb03a42/image.jpg)
- step1：A 跟业务服务器沟通，获取 **push-url-A** 和低延时的 **play-url-A**，服务器分配 URL 的方法参考 [DOC](https://cloud.tencent.com/document/product/454/7915)。

- step2：A 创建一个  RTC 模式的 [&lt;live-pusher&gt;](https://cloud.tencent.com/document/product/454/12518) 标签，指定 url 为 step1 中获得的 push-url-A，并通过 bindstatechange 属性绑定一个 javascript 函数（比如叫 onPushEvent）。

- step3：A 这边需要一些时间启动推流，推流开始以后，&lt;live-pusher&gt; 会通过 onPushEvent 的 PUSH_EVT_PUSH_BEGIN（1002）事件通知给 A， 此时 A 可以向 B 发起通话请求，请求中可以携带 play-url-A。

- step4：B 需要等待 UI 界面上的确认，如果 B 确认接通，接下来要做的就是创建一个  RTC 模式的 &lt;live-player&gt;，并指定 src 为 play-url-A。

- step5：B 此时还要跟业务服务器沟通，获取 **push-url-B** 和低延时的 **play-url-B**，并创建一个  RTC 模式的 [&lt;live-pusher&gt;](https://cloud.tencent.com/document/product/454/12518) 标签，指定 url 为 push-url-B，并通过 bindstatechange 属性绑定一个 javascript 函数（比如叫 onPushEvent）。

- step6：B 此时需要一些时间启动推流，推流开始以后，&lt;live-pusher&gt; 会通过 onPushEvent 的 PUSH_EVT_PUSH_BEGIN（1002）事件通知给 B，之后 B 可以向 A 响应通话请求，请求中可以携带 play-url-B。

- step7: A 此时要做的就是创建一个  RTC 模式的 &lt;live-player&gt;，并指定 src 为 play-url-B。

## 真实场景
以上 7 个步骤看似复杂，本质上就是 A 和 B 各自创建一个 RTC 模式的 &lt;live-pusher&gt; 和 &lt;live-player&gt;，然后进行 URL 的置换。

但在真实的应用场景中，问题要比远比置换 URL 要复杂：

- **房间管理**
以金融开户和保险定损为例，如果 A 端使用的是小程序，那么真正的 B 端一般情况下会是企业的客服人员，而且她们都不是一个人，所以这里就有房间的概念。每位客服都已经事先开启了一个房间。当有用户接入进来的时候，客服系统会根据每个房间的空闲状态分配一个客服，或者让当前用户进入排队等候状态。

- **多于两人**
两人之间的通讯只需要置换 URL，一旦把人数增加到 3 个或者 3 个以上，就不仅仅是兑换 URL 的问题，还有状态同步和事件通知。当有新的参与者进入房间，或者有人离开时，就需要对房间里的人进行信息广播，这就需要一个不错的 IM 系统负责收发消息。
![](//mc.qcloudimg.com/static/img/17f2edb8bcbcfa46e7ef5e47ebbe8fe0/image.jpg)

出于降低真实场景实现复杂度的考虑，腾讯云提供了 RTCRoom 的解决方案。

## RTCROOM

RTCRoom（RealTime ChatRoom）存在的意义在于封装掉双人或者多人音视频实现过程中需要考虑的各种细节逻辑问题，比如房间管理、状态同步，消息收发等等，让您只需要面对几个非常简单的接口，从而快速构建自己的音视频能力。

![](//mc.qcloudimg.com/static/img/5c24e7220b809dfb68e7a1e2dc4d0f64/image.jpg)

#### 源码下载 
RTCRoom 是一套开源实现，在 iOS，Android，Windows、小程序以及服务器端均有一套示例源码。其中客户端的源码主要是提供 CreateRoom、EnterRoom、ExitRoom 等进出房间的接口，而服务端源码则用于房间管理，并通过腾讯云通讯（IM）服务向房间内成员发送事件通知。

| 操作系统 | 下载链接 | 源码位置 |
|---------|---------|---------|
| iOS | [DOWNLOAD](https://cloud.tencent.com/document/product/454/7873#iOS) | SDK 开发包 RtcRoom.m |
| Android | [DOWNLOAD](https://cloud.tencent.com/document/product/454/7873#Android) |  SDK 开发包 RtcRoom.java |
| Windows | [DOWNLOAD](https://cloud.tencent.com/document/product/454/7873#Windows) | Demo 源码中的 RTCRoom.h+RTCRoom.cpp |
| 小程序 | [DOWNLOAD](https://cloud.tencent.com/document/product/454/7873#XiaoChengXu) | 小程序源码 zip 包中的 wxlite 文件夹 |
| 服务端 | [DOWNLOAD](https://cloud.tencent.com/document/product/454/7873#XiaoChengXu) | 小程序源码 zip 包中的 server 文件夹  |
