## 房间列表
每一个主播都有一个自己的直播间，所有主播的直播间组成一个列表，就是下图中的房间列表了：
![001](//mc.qcloudimg.com/static/img/1e6d141a053482e568110d1c1cfc7344/image.png)

## 如何实现
### 1. 设计原理
一个直播后台的核心职能就是管理和维护 **房间列表**，并对外提供针对房间列表进行增、删、改、查的业务接口：
![](//mc.qcloudimg.com/static/img/e8a2be9cf6c85a65d0cbdbaac0951228/image.png)

- **创建房间（增）**
当一个主播开始直播前需要先创建一个房间，这就等于是在房间列表中增加一条新的数据。

- **关闭房间（删）**
当一个直播结束后，App要通知后台把当前房间状态修改为 **直播已结束**，或者干脆将其从列表中删除。

- **修改状态（改）**
当有新的观众加入时，意味着某个房间的观众数要+1；
当有观众给主播点赞，意味着某个房间的点赞数要+1；
当有一条视频流意外断流时，会收到来自腾讯云的通知，意味着某个房间的状态要进行修正；
当监管人员发现某一房间内容涉及违规行为时，需要对其禁播，意味着某个房间的状态要改为已禁播。

- **列表查询（查）**
每一个打开App的观众，都会到直播后台查询一下当前的房间列表，所以直播后台要提供列表拉取的相关接口供 App 使用。并且，如果您的App装机量不俗，那么这个接口要能承受一定的并发访问压力才行。

### 2. 开通直播码
开通方式请参考 [直播码接入怎么配？](https://cloud.tencent.com/document/product/454/7953#1.2-.E7.9B.B4.E6.92.AD.E7.A0.81.E6.8E.A5.E5.85.A5.E6.80.8E.E4.B9.88.E9.85.8D.EF.BC.9F)

### 3. 创建新房间

终端 App 在发起直播前首先会通过一条协议向服务器请求创建一个房间：

- **请求(App->Server)**
最关键的信息就是自己的账号ID了，同时，最好再附上直播的标题、地理位置、直播封面URL等等信息，直播后台会用这些信息创建一个房间。

- **响应(Server->App)**
服务器的回包信息包含两种情况：一情况是允许直播，则可以把推流URL（见下图）等信息返回给App；另一种情况是给予拒绝并返回错误原因。

- **如何生成推流URL**
推流URL您可以在后台自行拼装，参考 [如何获取推流URL](https://cloud.tencent.com/document/product/454/7915) ？

- **修改状态(新房间->直播中)**
新创建的房间<font color='red'>不要直接设置状态为“直播中”</font>，因为主播并不一定能够成功推流，此时将房间状态改成“直播中”会导致黑屏房间。至于推流失败，这里有很多奇葩的原因，比如：推流用的端口 1935 被所处网络的安全防火墙禁用了，或者是主播的App刚刚安装，在看到摄像头权限申请时误点了拒绝。

 正确的姿势应该是：让App在成功收到 RTMP SDK 的 **PUSH_BEGIN** 事件后确定推流成功之后，再通过一条协议通知后台把房间状态改为“直播中”。
 
 > 小直播中在此处选择了App通知的方案，示例实现可以参考 [协议详解-修改在线状态](https://cloud.tencent.com/doc/product/454/6808#2..E4.BF.AE.E6.94.B9.E5.9C.A8.E7.BA.BF.E7.8A.B6.E6.80.81)。


### 4. 关闭房间

App在直播结束时，需要通过一条协议通知服务器，这样服务器就可以第一时间把相应的记录删掉，否则直播列表里就满满都是已经离线的主播了。

但如果只做到这里，总会有一些 “漏网之鱼”，比如主播的手机意外断网，或者APP意外崩溃了，甚至是流量突然用完了，这些情况都会让APP根本没有机会通知服务器该主播已经下线，从而会在直播列表中残留一些 “僵尸频道”。

僵尸频道对于用户体验影响是非常大的，所以我们需要**<font color='red'>“双重保险”</font>**来规避这个问题，您有两种方案可选：

- **接收通知**
您可以使用腾讯云的**[消息通知服务](https://cloud.tencent.com/doc/api/258/5957)**：您的服务器可以注册一个自己的回调URL给腾讯云，腾讯云会在您关心的频道在线状态有变化时通知给您。

- **主动查询**
您可以通过腾讯云的状态查询接口（**[Live_Channel_GetStatus](https://cloud.tencent.com/doc/api/258/5958)**）定时地检查所有<font color='red'>“正在直播中”</font>的频道是不是真的都是“正在推流”状态。推荐的调用方式是一分钟轮询一次，如果某个频道在连续三次的轮询结果中均为离线，您就可以考虑将它的状态设置为离线了。

> 小直播App 此处复用了创建房间中使用的修改房间状态的协议，在创建房间时，App使用此协议将房间状态从”新房间“改成“直播中”，此处我们则是从“直播中”改为“已关闭”，具体实现可以参考 [协议详解-修改在线状态](https://cloud.tencent.com/doc/product/454/6808#2..E4.BF.AE.E6.94.B9.E5.9C.A8.E7.BA.BF.E7.8A.B6.E6.80.81)。


### 5. 修改房间信息

很多场景下，我们都需要修改某一个房间的信息，比如：

- **加观众数**
当有新的观众加入时，意味着某个房间的观众数要+1，可以让App在进入房间时发一条通知协议实现之。
> 小直播此处的实现可以参考 [协议详解-修改计数器](https://cloud.tencent.com/doc/product/454/6808#3..E4.BF.AE.E6.94.B9.E8.AE.A1.E6.95.B0.E5.99.A8) 。

- **加点赞数**
当有观众给主播点赞，意味着某个房间的点赞数要+1，App在点赞按钮的响应函数中发一条通知协议即可。当然，完整的点赞实现方案还要用IM通道来实现点赞消息群发，不过这不是本节的讨论重点。
> 小直播此处的实现可以参考 [协议详解-修改计数器](https://cloud.tencent.com/doc/product/454/6808#3..E4.BF.AE.E6.94.B9.E8.AE.A1.E6.95.B0.E5.99.A8) 。

- **意外断流**
您可以使用腾讯云的**[消息通知服务](https://cloud.tencent.com/doc/api/258/5957)**，当有一条视频流意外断流时，会收到来自腾讯云的通知，意味着某个房间的状态要进行修正。
> 小直播此处的实现可以参考小直播的后台PHP源码。

- **违规禁播**
当监管人员发现某一房间内容涉及违规行为时，需要对其禁播，意味着某个房间的状态要改为已禁播。禁播需要用到后台相关API [直播码-开启关闭推流](https://cloud.tencent.com/doc/api/258/5959)。

- **补充说明**
观众数和点赞数，是相对高频的修改操作。我们在第一版小直播的PHP源码中采用了数据库存储这些状态数据，但您需要知道这种设计容易理解但并不合理，如果您的 App 的装机量不俗，建议您使用腾讯云 [**Redis**](https://cloud.tencent.com/product/crs.html) 服务对这里进行优化，我们后续的源码版本也会提供相应的实现。


### 6. 房间列表查询接口

服务器辛辛苦苦维护和管理房间列表，最终目的还是给观众端 APP 使用，所以查询接口是必然要提供的。查询接口在实现上需要注意如下三个细节：

- **注意分页逻辑**
如果列表中房间数量比较多，比如20个以上，就推荐要加上分页逻辑了，分页逻辑对于减少服务器压力，提高列表展示速度方面非常有帮助。
> 小直播此处的实现可以参考 [协议详解-拉取列表](https://cloud.tencent.com/doc/product/454/6808#4..E6.8B.89.E5.8F.96.E5.88.97.E8.A1.A8) 。

- **拼装播放地址**
有了直播码（或者房间ID），播放地址就可以简单拼装出来，下图是用直播码 **8888_test_12345_test** 拼装出来的rtmp flv 和 hls 三种播放地址，App拿到播放URL后就可以直接丢给腾讯云的RTMP SDK进行播放：
> ![play](//mccdn.qcloud.com/static/img/8438aadc91d16a1f02921bb178881893/image.png)

- **<font color='red'>千万不要在App端拼装播放地址</font>**
这样会导致逻辑被锁死在APP的代码上，建议由服务器拼装完成后返送给APP，比如随着业务的发展，您可能会考虑在播放端增加播放防盗链，避免您的直播视频被盗用，而播放防盗链签名只有可能在服务器签发，故客户端拼装逻辑根本无法满足这个需求。
