## 对接攻略

这部分有两项工作要做：
（1）后台工程师：开发直播间列表的增删改查相关逻辑 - 这部分可以参考小直播App的后台源码。
（2）终端工程师：开发直播间列表的拉取和展示逻辑 - 这部分可以参考小直播App的终端源码。

## 后台搭建
### 1. 功能设计
一个直播后台的核心职能是管理和维护一个叫做**直播间列表**的数据，并对外提供针对直播间列表进行增、删、改、查的业务接口，因为一个视频直播解决方案的大部分功能都是围绕直播间在做文章：
![](//mc.qcloudimg.com/static/img/e8a2be9cf6c85a65d0cbdbaac0951228/image.png)

- **创建房间（增）**
当一个主播开始直播前需要先创建一个直播间，这就等于是在直播间列表中增加一条新的数据。

- **关闭房间（删）**
当一个直播结束后，App要通知后台把当前直播间状态修改为“直播结束”，或者干脆将其从列表中删除。

- **修改状态（改）**
当有新的观众加入时，意味着某个直播间的观众数要+1；
当有观众给主播点赞，意味着某个直播间的点赞数要+1；
当有一条视频流意外断流时，会收到来自腾讯云的通知，意味着某个直播间的状态要进行修正；
当监管人员发现某一直播间内容涉及违规行为时，需要对其禁播，意味着某个直播间的状态要改为已禁播。

- **列表查询（查）**
每一个打开App的观众，都会到直播后台查询一下当前的直播间列表，所以直播后台要提供列表拉取的相关接口供 App 使用。并且，如果您的App装机量不俗，那么这个接口要能承受一定的并发访问压力才行。

### 2. 开通直播码
腾讯云后台有两种 API 对接模式，直播码和频道托管，我们推荐直播码模式。

开通直播服务，进入[直播码接入](https://console.cloud.tencent.com/live/livecodemanage)配置页面：
![](//mc.qcloudimg.com/static/img/32158e398ab9543b5ac3acf5f04aa86e/image.png)

| 配置项 | 取值范围            | 具体含义  |
|----------|----------------------|--------------|
| 直播录制 | 开启 OR 关闭 | 开启直播录制后，只要是直播的视频，都会被后台默认的录制下来。[参考文档](https://cloud.tencent.com/doc/api/258/5691) |
| 推流防盗链key | 32位小写的字符串  | 出于安全考虑，推流地址需要绑定防盗链以避免被其他人抢占，该KEY用于计算防盗链签名。[参考文档](https://cloud.tencent.com/doc/api/258/5693) |
| API鉴权key | 32位小写的字符串  | 您的服务器在调用腾讯云后台API时，需要提供身份鉴权信息，该KEY用于帮助腾讯云确定您的服务器的合法身份。[参考文档](https://cloud.tencent.com/doc/api/258/5956) |
| 回调URL | HTTP协议URL地址 | 腾讯云会把视频的推流断流等事件通知通过这个URL投递给您，尚不支持HTTPS协议。[参考文档](https://cloud.tencent.com/doc/api/258/5957)  |

点击**确定接入**按钮，即可将您的腾讯云直播服务切换到直播码模式了。

### 3. 创建房间

终端 App 在发起直播前首先会通过一条协议向服务器请求创建一个直播间：

- **请求(App->Server)**
最关键的信息就是自己的账号ID了，同时，最好再附上直播的标题、地理位置、直播封面URL等等信息，直播后台会用这些信息创建一个直播间。

- **响应(Server->App)**
服务器的回包信息包含两种情况：一情况是允许直播，则可以把推流URL（见下图）等信息返回给App；另一种情况是给予拒绝并返回错误原因。

- **如何生成推流URL**
推流URL您可以在后台自行拼装，只要符合腾讯云的标准规范就可以用来推流，如下是一条标准的推流URL，它由三部分组成：
   + **直播码** ：也叫房间号，推荐用随机数字或者用户ID，注意一个合法的直播码需要拼接 bizid 前缀。
   + **txTime**：何时该URL会过期，格式是十六进制的UNIX时间戳，比如 5867D600 代表 2017年1月1日0时0点0分过期。
   + **txSecret**：防盗链签名 - **txSecret = MD5( KEY + stream_id + txTime )**

 ![url](//mc.qcloudimg.com/static/img/6b4fd09ab2c7d6f1503070f8c994f4e0/image.png)
 > 更多详情可以参考 [直播码-如何分配推流地址](https://cloud.tencent.com/doc/api/258/5649#2.-.E5.88.86.E9.85.8D.E6.8E.A8.E6.B5.81.E5.9C.B0.E5.9D.80)。

- **修改状态(新房间->直播中)**
新创建的直播间<font color='red'>不要直接设置状态为“直播中”</font>，因为主播并不一定能够成功推流，此时将房间状态改成“直播中”会导致黑屏房间。至于推流失败，这里有很多奇葩的原因，比如：推流用的端口 1935 被所处网络的安全防火墙禁用了，或者是主播的App刚刚安装，在看到摄像头权限申请时误点了拒绝。

 正确的姿势应该是：让App在成功收到 RTMP SDK 的 **PUSH_BEGIN** 事件后确定推流成功之后，再通过一条协议通知后台把直播间状态改为“直播中”。
 
 > 小直播中在此处选择了App通知的方案，示例实现可以参考 [协议详解-修改在线状态](https://cloud.tencent.com/doc/product/454/6808#2..E4.BF.AE.E6.94.B9.E5.9C.A8.E7.BA.BF.E7.8A.B6.E6.80.81)。


### 4. 关闭房间

App在直播结束时，需要通过一条协议通知服务器，这样服务器就可以第一时间把相应的记录删掉，否则直播列表里就满满都是已经离线的主播了。

但如果只做到这里，总会有一些 “漏网之鱼”，比如主播的手机意外断网，或者APP意外崩溃了，甚至是流量突然用完了，这些情况都会让APP根本没有机会通知服务器该主播已经下线，从而会在直播列表中残留一些 “僵尸频道”。

僵尸频道对于用户体验影响是非常大的，所以我们需要**<font color='red'>“双重保险”</font>**来规避这个问题，您有两种方案可选：

- **接收通知**
您可以使用腾讯云的**[消息通知服务](https://cloud.tencent.com/doc/api/258/5957)**：您的服务器可以注册一个自己的回调URL给腾讯云，腾讯云会在您关心的频道在线状态有变化时通知给您。

- **主动查询**
您可以通过腾讯云的状态查询接口（**[Live_Channel_GetStatus](https://cloud.tencent.com/doc/api/258/5958)**）定时地检查所有<font color='red'>“正在直播中”</font>的频道是不是真的都是“正在推流”状态。推荐的调用方式是一分钟轮询一次，如果某个频道在连续三次的轮询结果中均为离线，您就可以考虑将它的状态设置为离线了。

> 小直播App 此处复用了创建房间中使用的修改房间状态的协议，在创建房间时，App使用此协议将房间状态从”新房间“改成“直播中”，此处我们则是从“直播中”改为“已关闭”，具体实现可以参考 [协议详解-修改在线状态](https://cloud.tencent.com/doc/product/454/6808#2..E4.BF.AE.E6.94.B9.E5.9C.A8.E7.BA.BF.E7.8A.B6.E6.80.81)。


### 5. 修改状态

- **加观众数**
当有新的观众加入时，意味着某个直播间的观众数要+1，可以让App在进入直播间时发一条通知协议实现之。
> 小直播此处的实现可以参考 [协议详解-修改计数器](https://cloud.tencent.com/doc/product/454/6808#3..E4.BF.AE.E6.94.B9.E8.AE.A1.E6.95.B0.E5.99.A8) 。

- **加点赞数**
当有观众给主播点赞，意味着某个直播间的点赞数要+1，App在点赞按钮的响应函数中发一条通知协议即可。当然，完整的点赞实现方案还要用IM通道来实现点赞消息群发，不过这不是本节的讨论重点。
> 小直播此处的实现可以参考 [协议详解-修改计数器](https://cloud.tencent.com/doc/product/454/6808#3..E4.BF.AE.E6.94.B9.E8.AE.A1.E6.95.B0.E5.99.A8) 。

- **意外断流**
您可以使用腾讯云的**[消息通知服务](https://cloud.tencent.com/doc/api/258/5957)**，当有一条视频流意外断流时，会收到来自腾讯云的通知，意味着某个直播间的状态要进行修正。
> 小直播此处的实现可以参考小直播的后台PHP源码。

- **违规禁播**
当监管人员发现某一直播间内容涉及违规行为时，需要对其禁播，意味着某个直播间的状态要改为已禁播。禁播需要用到后台相关API [直播码-开启关闭推流](https://cloud.tencent.com/doc/api/258/5959)。

- **补充说明**
观众数和点赞数，是相对高频的修改操作。我们在第一版小直播的PHP源码中采用了数据库存储这些状态数据，但您需要知道这种设计容易理解但并不合理，如果您的 App 的装机量不俗，建议您使用腾讯云 [**Redis**](https://cloud.tencent.com/product/crs.html) 服务对这里进行优化，我们后续的源码版本也会提供相应的实现。


### 6. 列表查询
服务器将状态处于“正在直播中”的房间以列表的形式返回给终端 App 即可，实现上需要注意如下两个细节：
- **注意分页逻辑**
如果列表中直播间数量比较多，比如20个以上，就推荐要加上分页逻辑了，分页逻辑对于减少服务器压力，提高列表展示速度方面非常有帮助。
> 小直播此处的实现可以参考 [协议详解-拉取列表](https://cloud.tencent.com/doc/product/454/6808#4..E6.8B.89.E5.8F.96.E5.88.97.E8.A1.A8) 。

- **拼装播放地址**
有了直播码（或者直播间ID），播放地址就可以简单拼装出来，下图是用直播码 **8888_test_12345_test** 拼装出来的rtmp flv 和 hls 三种播放地址，App拿到播放URL后就可以直接丢给腾讯云的RTMP SDK进行播放：
> ![play](//mccdn.qcloud.com/static/img/8438aadc91d16a1f02921bb178881893/image.png)

- **特别提醒**
<font color='red'>千万不要在App端拼装播放地址</font>，这样会导致逻辑被锁死在APP的代码上，建议由服务器拼装完成后返送给APP，比如随着业务的发展，您可能会考虑在播放端增加播放防盗链，避免您的直播视频被盗用，而播放防盗链签名只有可能在服务器签发，故客户端拼装逻辑根本无法满足这个需求。


## 终端对接
终端 App 在房间列表这里的业务逻辑相对比比较轻，主要代码集中在UI展示部分。如果对房间列表的实时性要求不高，只需要实现手动刷新逻辑即可。而如果要求房间信息更新的非常及时，可以考虑添加一些定时刷新，局部刷新的优化逻辑辅之。

> - 小直播（iOS）此处的实现逻辑可以参考 [iOS-主界面&列表管理](https://cloud.tencent.com/doc/product/454/6809#.E4.B8.BB.E7.95.8C.E9.9D.A2.26amp.3B.E5.88.97.E8.A1.A8.E7.AE.A1.E7.90.86) 。
>
> - 小直播（Android）此处的实现逻辑可以参考 [Android-主界面&列表管理](https://cloud.tencent.com/doc/product/454/6810#.E4.B8.BB.E7.95.8C.E9.9D.A2.26amp.3B.E5.88.97.E8.A1.A8.E7.AE.A1.E7.90.86) 。


