﻿实例元数据是有关您运行的实例的数据，可以用来配置或管理正在运行的实例。

>注：虽然只能从实例自身内部访问实例元数据，但数据并未进行加密保护。可访问实例的人员均可查看其元数据。因此，您应当采取适当的预防措施来保护敏感数据（例如使用永久加密密钥）。


## 实例元数据分类
腾讯云现在提供如下元数据信息：

| 数据 | 描述 | 引入版本 |
|---------|---------|---------|
| instance-id | 实例 ID | 1.0 |
| uuid | 实例 ID | 1.0 |
| local-ipv4 | 实例内网 IP | 1.0 |
| public-ipv4 | 实例公网 IP | 1.0 |
| mac | 实例 eth0 设备 mac 地址 | 1.0 |
| placement/region | 实例所在地域信息 | 2017-09-19 更新|
| placement/zone | 实例所在可用区信息 | 2017-09-19 更新|
| network/network/macs/<font style="color:red">mac</font>/mac | 实例网络接口设备地址 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/primary-local-ipv4 | 实例网络接口主内网 IP 地址 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/public-ipv4s | 实例网络接口公网 IP 地址 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/local-ipv4s/<font style="color:red">local-ipv4</font>/gateway | 实例网络接口网关地址 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/local-ipv4s/<font style="color:red">local-ipv4</font>/local-ipv4 | 实例网络接口内网 IP 地址 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/local-ipv4s/<font style="color:red">local-ipv4</font>/public-ipv4 | 实例网络接口公网 IP 地址 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/local-ipv4s/<font style="color:red">local-ipv4</font>/public-ipv4-mode | 实例网络接口公网网络模式 | 1.0 |
| network/network/macs/<font style="color:red">mac</font>/local-ipv4s/<font style="color:red">local-ipv4</font>/subnet-mask | 实例网络接口子网掩码 | 1.0 |

> 以上表格中红色字体 <font style="color:red">mac</font> 和 <font style="color:red">local-ipv4</font> 字段分别表示实例指定网络接口的设备地址和内网 IP 地址。
> 
> 请求的目标URL地址，大小写敏感。请严格按照请求的返回结果来构造新请求的目标URL地址。
>
> 当前版本对placement返回数据发生了变更，若您需要使用以前版本的数据，则您可以指定以前版本路径或是不指定版本路径从而访问版本1.0的数据，对于placement返回数据请参考[地域和可用区](/document/product/213/6091)。

## 查询实例元数据
在实例内部可以通过实例元数据访问实例本地IP、公网IP等数据以管理与外部应用程序的连接。
要从运行实例内部查看所有类别的实例元数据，请使用以下 URI：
```
http://metadata.tencentyun.com/latest/meta-data/
```
你可以通过cURL工具或是HTTP的GET请求来访问metadata，例如：
```
curl http://metadata.tencentyun.com/latest/meta-data/
```
* 对于不存在的资源，会返回HTTP错误代码404 - Not Found。
* 对实例元数据的操作均只能从**实例内部**进行。请先完成实例登录操作。有关登录实例的更多内容，请参考 [登录 Windows 实例](/doc/product/213/5435) 和 [登录 Linux 实例](/doc/product/213/5436)。

### 查询元数据示例

以下示例说明如何获取metadata版本信息。注意，当腾讯云修改metadata访问路径或返回数据时，会发布新的metadata版本，如果你的应用程序或脚本依赖于以前版本的结构或返回数据，则您可以使用指定早期版本访问metadata。不指定版本则默认访问1.0版本。
```
[qcloud-user]# curl http://metadata.tencentyun.com/
1.0
2017-09-19
latest
meta-data
```

以下示例说明如何查看metadata根目录。其中以`/`结尾的单词表示目录，不以`/`结尾的单词表示访问数据。具体访问数据含义请参考前文**实例 metadata 分类**。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/
instance-id
local-ipv4
mac
network/
placement/
public-ipv4
uuid
```

以下示例说明如何获取实例物理所在地信息。返回数据与物理所在地关系请参考[地域和可用区](/document/product/213/6091)。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/placement/region
ap-guangzhou

[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/placement/zone
ap-guangzhou-3
```

以下示例说明如何获取实例内网IP。实例存在多张网卡时，返回eth0设备的网络地址。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/local-ipv4
10.104.13.59
```

以下示例说明如何获取实例公网IP。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/public-ipv4
139.199.11.29
```

以下示例说明如何获取实例ID。实例ID是实例的唯一标识。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/instance-id
ins-3g445roi
```

以下示例说明如何获取实例uuid。实例uuid可作为实例的唯一标识，推荐使用实例ID用于区分实例。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/uuid
cfac763a-7094-446b-a8a9-b995e638471a
```

以下示例说明如何获取实例eth0设备mac地址。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/mac
52:54:00:BF:B3:51
```

以下示例说明如何获取实例网卡信息。多张网卡会返回多行数据，每行数据为一张网卡的数据目录。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/
52:54:00:BF:B3:51/
```

以下示例说明如何获取指定网卡信息。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/
local-ipv4s/
mac
primary-local-ipv4
public-ipv4s
```

以下示例说明如何获取指定网卡绑定内网IP地址列表。网卡若绑定多个内网IP，则返回多行数据。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/local-ipv4s/
10.104.13.59/
```

以下示例说明如何获取内网IP信息。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/local-ipv4s/10.104.13.59
gateway
local-ipv4
public-ipv4
public-ipv4-mode
subnet-mask
```

以下示例说明如何获取内网IP网关。仅VPC机型可查询该数据。VPC机型请参考[私有网络](/document/product/215)。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/local-ipv4s/10.104.13.59/gateway
10.15.1.1
```

以下示例说明如何获取内网IP访问公网模式。仅VPC机型可查询该数据。基础网络机型通过公网网关访问公网。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/local-ipv4s/10.104.13.59/public-ipv4-mode
NAT
```

以下示例说明如何获取内网IP绑定公网IP。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/local-ipv4s/10.104.13.59/public-ipv4
139.199.11.29
```

以下示例说明如何获取内网IP子网掩码。
```
[qcloud-user]# curl http://metadata.tencentyun.com/latest/meta-data/network/interfaces/macs/52:54:00:BF:B3:51/local-ipv4s/10.104.13.59/subnet-mask
255.255.192.0
```
