Tencent Cloud Container Service (CCS) is a container management service with high scalability and high performance. You can easily run applications on a hosted CVM pod cluster. In this tutorial, you will learn how to use CCS to quickly create and manage container cluster, and deploy your service in the cluster in a fast and flexible way.

## Step 1: Create a cluster
First, you need to create a cluster. A cluster is a collection of cloud resources required by containers to run, including several CVMs, load balancers and other Tencent Cloud resources.
1. Log in to the [Tencent CCS Console](https://console.cloud.tencent.com/ccs).
2. Click "Cluster" in the left navigation bar, and click "+ New" in the cluster list page.
![](https://mc.qcloudimg.com/static/img/41f819632bb146b6d89fea7f2980cc08/Deploy_TCC_11.jpg)
3. Configure the basic cluster information.
 - **Cluster name**: The name of the cluster to be created. It cannot exceed 60 characters.
 - **Billing method**: Two billing methods are supported: Prepaid and Postpaid. For more information, please see [Billing Method](/doc/product/213/2180).
 - **Region**: Select a closest region based on your location. This helps minimize access latency and improve download speed.
 - **Availability zone**: Clusters in the same region are interconnected with each other through private network, but the ones in different regions cannot communicate with each other through private network. Users who communicate with each other through private network need to choose the same region.
 - **Node network**: The system assigns the IP addresses within the node network address range to the CVMs in the cluster. For more information, please see [Network Configuration of Container and Node](/doc/product/457/9083).
 - **Container network**: The system assigns the IP addresses within the container network address range to the containers in the cluster. For more information, please see [Network Configuration of Container and Node](/doc/product/457/9083).
 - **Cluster Description**: Information about cluster creation. This information is displayed in **Cluster Information** page.
![Alt text](https://mc.qcloudimg.com/static/img/fe4f9f9bd9a129c2992d20366fd45e3b/Deploy_TCC_12.jpg)
4. Select a model (all models with cloud disks as system disks are supported).
 - **Series**: **Series 1** and **Series 2** are provided. For more information, please see [Pod Types](/doc/product/213/7153#.E5.8F.AF.E7.94.A8.E5.AE.9E.E4.BE.8B.E7.B1.BB.E5.9E.8B2).
 - **Model**: For more information about the model options, please see [Select CVM Configuration Option](/doc/product/213/2764#.E7.A1.AE.E5.AE.9A.E4.BA.91.E6.9C.8D.E5.8A.A1.E5.99.A8.E9.85.8D.E7.BD.AE.E6.96.B9.E6.A1.88).
![Alt text](https://mc.qcloudimg.com/static/img/7fc38e8d897735e0ab694ed9ff680f45/Deploy_TCC_13.jpg) 
5. Enter CVM configurations and click "Done".
 - **System disk**: Always 50 GB.
 - **Data disk**: Increment is 10 GB. Maximum value is 4,000 GB.
 - **Public bandwidth**: Two billing methods are available. For more information, please see [Purchase Network Bandwidth](/doc/product/213/509).
 - **Bandwidth**: If you check **Assign public IP for free**, the system assigns a public IP at no cost. If there is no need, set bandwidth value to 0.
 - **Login method**: Three login methods are provided.
  i. **Set password**: Set a password according to instructions.
	ii. **Associate with key immediately**: Key pair is a pair of parameters generated by an algorithm. It is a more secure method to log to CVM than a password. For more information, please see [SSH Key](/doc/product/213/503).
	iii. **Automatically generated password**: The automatically generated password is sent to you through the internal message.
 - **Security group**: Security group functions as a firewall and is used to control network access settings of CVMs. For more information, please see [Configuration of CCS Security Group](/doc/product/457/9084).
 - **Number of CVMs**: Select the number of CVMs.
![Alt text](https://mc.qcloudimg.com/static/img/a65dda393d4dfe2e89624ab82b7ea693/Deploy_TCC_14.jpg)
6. The created cluster is displayed in the cluster list.
![Alt text](https://mc.qcloudimg.com/static/img/0cec22abebd970383c0f23c1dcd19b39/Deploy_TCC_15.jpg)

## Step 2: Create a service
After a cluster is created, you need to create a service. A service is a microservice comprised of multiple containers with the same configuration and rules used to access these containers.
1. Click "Service" in the left navigation bar, and click "+ New" in the service list page.
![](https://mc.qcloudimg.com/static/img/cce6e5a1d89d6d4172cf5f5506455153/Deploy_TCC_21.jpg)
2. Configure basic service information.
 - **Service name**: The name of the cluster to be created. Name is composed of lowercase letters, numbers and "-". It starts with a lowercase letter and ends with a lowercase letter or a number.
 - **Region**: Select a closest region based on your location.
 - **Running cluster**: Select a cluster that runs a service. To run a cluster, you need to select a running cluster with available CVMs in it.
 - **Service description**: Information about service creation. This information is displayed in **Service Information** page.
![](https://mc.qcloudimg.com/static/img/ab57c7cd6ca4763fe6066568d1641045/Deploy_TCC_22.jpg)
3. Configure data volume.
Click "Add Data Volume" when you specify a specific path to which a container is mounted.
>**Note:**
>If no source path is specified, a temporary path is assigned by default.

 - **Type**: Four types of data volumes are supported: local disk, cloud disk, NFS disk, and configuration file. For more information, please see [How to Use CCS Data Volume](https://cloud.tencent.com/document/product/457/9112#.E5.AE.B9.E5.99.A8.E6.9C.8D.E5.8A.A1.E6.95.B0.E6.8D.AE.E5.8D.B7.E4.BD.BF.E7.94.A8.E8.AF.B4.E6.98.8E).
 - **Name**: The name of data volume.
 - **Path**: Specify the path to which a container is mounted.
 ![](https://mc.qcloudimg.com/static/img/a42df4c0c935cdf2a6a22137935c5098/Deploy_TCC_23.jpg)
4. Configure a running container.
 - **Name**: The name of the cluster to be created.
 - **Image**: Click "Select an Image" to create a service under My Images, My Favorites, TencentHub Image, DockerHub Image and other images.
 - **Version**: A default version for CCS. If you need to use a different image version, click version display window to select one.
 ![](https://mc.qcloudimg.com/static/img/7a81c773ee47bbb5498365819cad5244/Deploy_TCC_24.jpg)
5. Other configurations.
 -  **Number of pods**: A pod is composed of one or more relevant containers. You can specify the number of pods by clicking + or -.
 -  **Service access method**: The method for accessing a service determines the network attribute of this service. Different access methods offer different network capabilities. For more information about the four access methods, please see [Configuration of Service Access Methods](https://cloud.tencent.com/document/product/457/9098).
 ![](https://mc.qcloudimg.com/static/img/cac060dd65006ccc5f018aa6d95edf9e/Deploy_TCC_25.jpg)
6. Click "Create Service" to complete the creation of service. A created service is displayed in service list.

## Step 3: View resources
In previous steps, you have created a cluster and a service. In this step, you can view all the resources you created.
### Viewing Cluster
1. Click "Cluster" in the left navigation bar, and click "ID/Name" of a cluster in the cluster list page, such as cls-dt8p2oe3.
![](https://mc.qcloudimg.com/static/img/b99d0691840dccf5f0b6526954bd2a5d/Deploy_TCC_31.jpg)
2. **Node list**: A node is a CVM registered in the cluster. You can create a cluster, add an existing cluster, or remove a cluster.
**Namespace list**: Namespace is an abstract collection of a group of resources and objects. Click "Namespace List" to create and delete a Namespace.
**Cluster information**: It displays the basic cluster information.
![](https://mc.qcloudimg.com/static/img/7924a50aadef57d761bf9f13f03bcc1c/Deploy_TCC_32.jpg)

#### Viewing Service
1. Click "Service" in the left navigation bar, and click "Name" of a service in the service list page, such as cfs1.
![](https://mc.qcloudimg.com/static/img/0eebf8996eaee16de43753e94a99e7c5/Deploy_TCC_33.jpg)
2. **Pod list**: A pod is composed of one or more relevant containers. You can specify the number of pods or terminate a pod.
**Service information**: It displays the basic service information, configuration information, and port mapping information.
**Pod information**: It displays the basic pod information.
**Event**: You are redirected to this page when creating a service. It displays the details during the creation of service.
![](https://mc.qcloudimg.com/static/img/8fa9c1268b584cdb44e20218758ce448/Deploy_TCC_34.jpg)

## Step 4: Delete a resource
In this tutorial, you have enabled two types of resources: cluster and service. In this step, you can delete all the resources to avoid unnecessary costs.
### Deleting a Cluster
1. Click "Cluster" in the left navigation bar, and click "Delete" on the right side of the cluster list page.
![](https://mc.qcloudimg.com/static/img/760a9da38aa88011a7c55b673ec8182d/Deploy_TCC_41.jpg)
2. Click "OK".
![](https://mc.qcloudimg.com/static/img/f40a7ab650424a0d6394d44f10778828/Deploy_TCC_42.jpg)
>**Note:**
>The cluster cannot provide services during deletion. Please prepare in advance to avoid the impact.

### Deleting a Service
1. Click "Service" in the left navigation bar, and click "Delete" in "More" on the right side of the service list page.
![](https://mc.qcloudimg.com/static/img/63077520951eed847cad0c86b31f107a/Deploy_TCC_43.jpg)
2. Click "OK".
![](https://mc.qcloudimg.com/static/img/d38e030d34a3b146540c4f67b048f6d0/Deploy_TCC_44.jpg)

## More
In this tutorial, you have leant how to configure, deploy and delete services in Tencent CCS. With Tencent CCS, you don't need to install, operate, maintain or expand your cluster management infrastructure. You can enable and disable Docker applications, query full status of the cluster, and use various cloud services by simply calling APIs.

Go to the next tutorial, learn about the basic concepts and operations of [Load Balance](https://cloud.tencent.com/document/product/457/9110) and [Image Registry](https://cloud.tencent.com/document/product/457/9118). You can also create a service quickly using a pod in [Quick Start](https://cloud.tencent.com/document/product/457/7851).
