## 数据卷 ( Volume )
Docker 镜像是由多个文件系统叠加而成，当启动一个容器的时候，Docker 会加载只读镜像层并在上面添加一个读写层。当删除 Docker 容器并通过该镜像重新启动时，之前的更改将会丢失。为了能够保存数据以及共享容器间的数据，Docker 提出了 数据卷 ( Volume ) 的概念。简单来说，数据卷就是目录或者文件，它可以绕过默认的联合文件系统，以正常的文件或者目录的形式存在于宿主机上。

在 Docker 中，数据卷只是磁盘或另一容器中的目录。其生命周期不受管理，且 Docker 现在提供的卷驱动程序功能非常有限。腾讯云容器服务采用的是 Kubernetes 的数据卷的概念，Kubernetes 数据卷具有明确的生命周期管理，支持多种类型的数据卷，同时实例 ( pod ) 可以使用任意数量的数据卷。

更多 Kubernetes 数据卷信息可见 [Volumes](https://kubernetes.io/docs/concepts/storage/volumes/)。

## 容器服务数据卷使用说明
腾讯云容器服务是基于 Kubernetes 编排系统搭建的，支持以下类型的数据卷：
- **emptyDir**：用于临时存储，生命周期同实例 ( pod )。在腾讯云容器服务中创建服务的时候，数据卷的源路径不填写即默认为 emptydir 模式。
- **hostPath**：在腾讯云容器服务中创建服务时，指定主机文件系统的中文件或目录挂载到容器的某一路径中，填写源路径即为 hostPath 模式。
- **云硬盘**：类似 Kubernetes 的第三方块存储插件（腾讯云正在积极加入开源建设，相关插件后续会提交到社区）。这里指定一块腾讯云的 CBS 云硬盘挂载到容器的某一路径下，创建数据卷时选择对应的云硬盘即可。
- **NFS 盘**：指定一个 NFS 目录进行挂载。
- **配置文件**：将配置文件中某个 key 映射到容器中，可以用于挂载配置文件到指定容器目录，详情请参阅 [配置项概述](https://cloud.tencent.com/document/product/457/10173)。

**使用步骤**：
1. 在创建服务页面 **数据卷** 选项下单击【添加数据卷】。
![](//mc.qcloudimg.com/static/img/0286498ec3ada210c6c01f9ef8ca7b52/image.png)
2. 配置数据卷。
 - **类型**：单击【∨】，在下拉框中选择数据卷的类型。
 - **名称**：数据卷的名称。
由小写字母和数字和连接符 “-” 组成，必须是小写字母开头，且在 20 个字符以内。
 - **路径**：指定容器要挂载的路径。
![](//mc.qcloudimg.com/static/img/4495a452a8b1bbf9bb3b4e2fcb1bcf99/image.png)
3. 设置挂载路径。
在 **运行容器**下单击【显示高级设置】。
![](//mc.qcloudimg.com/static/img/789e7fc5148ef53f44035194c5c6bd2c/image.png)
在高级设置展开页面中，单击 **挂载点** 下【∨】选择数据卷配置挂载路径。
![](//mc.qcloudimg.com/static/img/e762feea4f8b551fa5d8dd45721e597a/image.png)
>**注意：**
>- 创建服务时，数据卷挂载可以为空。
>- 数据卷挂载的卷名称和目标路径不能重复。
>- 若需要数据卷挂载，则卷名称和目标路径不能为空；
>- 若数据卷挂载的源路径为空，系统将分配一个临时目录在 `/var/lib/kubelet/pods/pod_name/volumes/kubernetes.io~empty-dir`。不建议您使用临时的数据卷，该数据卷的生命周期与实例的生命周期保持一致。
>- 若数据卷挂载的权限未选择，系统将自动设置该权限为读写权限。

## 持久卷( PersistentVolume and PersistentVolumeClaim )
敬请期待

