﻿在应用部署时，可以通过使用不同的配置项描述不同环境的差异化信息，从而实现应用在不同环境的部署。在应用中配置项信息包含两个主要左右：

1. 使用配置项，替换模板内容中的变量

2. 将配置项作为文件挂载到容器指定目录

## 配置项变量替换

在应用模板中支持使用变量，应用模板变量使用的详细信息可以参考[变量设置][1]。

例如，对于一个apache服务的支持两个变量`NAMESPACE`和`CPULIMITS`，模板内容如下所示：

**模板内容：**
```
apiVersion: extensions/v1beta1
kind: Deployment
metadata:
  creationTimestamp: null
  name: apache
  namespace: '{{.NAMESPACE}}'
spec:
  replicas: 1
  revisionHistoryLimit: 5
  selector: {}
  strategy: {}
  template:
    metadata:
      creationTimestamp: null
    spec:
      containers:
      - image: httpd:latest
        imagePullPolicy: Always
        name: httpd
        resources:
          limits:
            cpu: {{.CPULIMITS}}
            memory: 1Gi
          requests:
            cpu: 200m
            memory: 1Gi
        securityContext:
          privileged: false
      serviceAccountName: ""
      volumes: null
status: {}
---
apiVersion: v1
kind: Service
metadata:
  creationTimestamp: null
  name: apache
  namespace: '{{.NAMESPACE}}'
spec:
  ports:
  - name: tcp-80-80-oa2nr
    nodePort: 0
    port: 80
    protocol: TCP
    targetPort: 80
  selector: {}
  type: LoadBalancer
status:
  loadBalancer: {}
```
**配置项内容：**
```
NAMESPACE: default
CPULIMITS: 500m
```
在应用部署时，会使用配置项中变量`NAMESPACE`和`CPULIMITS`分别替换模板中变量位置的内容。

## 配置项内容挂载到容器目录

Kubernetes中支持将将配置文件(configmap资源)的内容转换成文件，挂载到容器指定的目录。更多关于Kubernetes挂载到容器目录的说明可以参考[Kubernetes配置文件使用][2]

在应用部署时，会自动将应用的配置文件转换成Kubernetes中`configmap`资源。在应用中使用自定义变量`ReleaseConfig`，则可将应用中的配置项挂载到容器指定目录。更多关于`ReleaseConfig`变量的说明可以参考[自定义变量-ReleaseConfig][3]。

下面将用一个示例说明如何挂载应用中配置项的内容到指定目录：

**模板内容：**
```
apiVersion: extensions/v1beta1
kind: Deployment
metadata:
  creationTimestamp: null
  labels:
    qcloud-app: python
  name: python
  namespace: '{{.NAMESPACE}}'
spec:
  replicas: 1
  revisionHistoryLimit: 5
  selector:
    matchLabels:
      qcloud-app: python
  strategy: {}
  template:
    metadata:
      creationTimestamp: null
      labels:
        qcloud-app: python
    spec:
      containers:
      - args:
        - "36000"
        command:
        - sleep
        image: python:latest
        imagePullPolicy: Always
        name: python
        resources:
          requests:
            cpu: 200m
        securityContext:
          privileged: false
        volumeMounts:
        - mountPath: /mnt
          name: data
      serviceAccountName: ""
      volumes:
      - configMap:
          name: '{{.ReleaseConfig}}'
          items:
          - key: DASHBOARD.CONF.INI
            mode: 511
            path: DASHBOARD.CONF.INI
        name: data
status: {}

---
apiVersion: v1
kind: Service
metadata:
  creationTimestamp: null
  labels:
    qcloud-app: python
  name: python
  namespace: '{{.NAMESPACE}}'
spec:
  ports:
  - name: tcp-80-80-yog7a
    nodePort: 0
    port: 80
    protocol: TCP
    targetPort: 80
  selector:
    qcloud-app: python
  type: ClusterIP
status:
  loadBalancer: {}
```

**配置项内容：**
```
NAMESPACE: default
DASHBOARD.CONF.INI: |
  [mysqld]
  log-bin = mysql-bin
  [port]
  serviceport="80"
```

上面的示例中，应用部署时，会将配置文件中`DASHBOARD.CONF.INI`的内容，以DASHBOARD.CONF.INI文件的方式，挂载到容器目录。

  [1]: https://cloud.tencent.com/document/product/457/11956
  [2]: https://kubernetes.io/docs/tasks/configure-pod-container/configure-pod-configmap/
  [3]: https://cloud.tencent.com/document/product/457/11956#.E8.87.AA.E5.AE.9A.E4.B9.89.E5.8F.98.E9.87.8F--releaseconfig