
## 一个最简单的例子
本例介绍如何使用命令行来提交一个简单的作业，例子是用 Python 实现的对斐波那契数列求和，代码直接由 Batch 提供的任务命令配置部分输入，结果直接输出到任务配置的 stdout 输出地址上。

## 开始前的准备
开始前请根据文档 [开始前的准备](
/doc/product/599/10807) 里的检查清单做好准备，同时本例将使用到命令行工具（CLI）和对象存储（COS），用户需要先安装和配置命令行工具以及创建一个 COS Bucket。

### 安装和配置命令行工具
配置命令行工具请查看 [配置命令行工具](/doc/product/440/6184)，安装完后检查下安装成功。
```
qcloudcli batch help

DescribeAvailableCvmInstanceTypes       	|DescribeTask
DescribeJob                             	|SubmitJob
DescribeJobs                            	|TerminateTaskInstance
```

### 创建保存结果的COS Bucket

这个简单例子里，结果直接输出到系统标准输出里，Batch 可以采集系统标准输出 stdout 和 stderr，并在任务结束后将信息上传到你指定的 COS Bucket 里，你需要提前准备好保存信息的 Bucket 和 子文件夹。

请参照 [命令行工具 - 前置准备](/doc/product/599/10548) 里第三章节 **『准备 COS 目录』**，创建对应 COS Bucket 和 子文件夹。

## 作业配置简介

你可以从官方提供的例子来修改出一个在你的账号下可执行的 Batch 作业配置，在这之前先看一下作业的配置项各代表什么含义。

```
qcloudcli batch SubmitJob --Version 2017-03-12 --Job '{
    "JobName": "TestJob",       // 作业名称
    "JobDescription": "for test ",    // 作业描述
    "Priority": "1",            // 作业优先级
    "Tasks": [                  // 任务列表（本例仅一个任务）
        {
            "TaskName": "Task1",   // 任务1名称
            "Application": {        // 任务执行命令
                "DeliveryForm": "LOCAL",    // 执行本地命令
                "Command": "python -c \"fib=lambda n:1 if n<=2 else fib(n-1)+fib(n-2); print(fib(20))\" "   // 命令具体内容（斐波拉契求和）
            },
            "ComputeEnv": {         // 计算环境配置
                "EnvType": "MANAGED",   // 计算环境类型，托管型和非托管型
                "EnvData": {        // 具体配置（当前托管型，可参照CVM 创建实例说明）
                    "InstanceType": "S1.SMALL1",    // CVM 实例类型
                    "ImageId": "img-i91njcmx",      // CVM 镜像 ID（需替换）
                }
            },
            "RedirectInfo": {       // 标准输出重定向配置           
                "StdoutRedirectPath": "cos://dondonbatchv5-1251783334.cosgz.myqcloud.com/logs/",    // 标准输出（需替换）
                "StderrRedirectPath": "cos://dondonbatchv5-1251783334.cosgz.myqcloud.com/logs/"     // 标准错误（需替换）
            }
        }
    ]
}'
--Placement'{
    "Zone": "ap-guangzhou-2"    // 可用区（可能需替换）
}'
```

Batch 的 SubmitJob 命令包含 3 个参数
* **Version**：版本号，目前固定填写 2017-03-12
* **Job**：作业配置，JSON 格式，详细字段意义见示例
* **Placement**：执行作业的可用区

``* 1. Job 里标识需替换的字段，需要替换成用户自己的信息后才可以执行，比如自定义镜像 Id，VPC相关信息，COS Bucket 地址和对应 SecretId、SecretKey。``

``* 2. 上面的例子加入了注释文字，因此无法直接在命令行工具运行，请复制下方的示例然后填写完『待填写』字段后再执行。命令较长，请使用后方复制按钮防止复制不完整。``

``* 3. 详细 Job 配置说明请参考 `` [作业配置说明](https://cloud.tencent.com/document/product/599/11040) ``。``

```
qcloudcli batch SubmitJob --Version 2017-03-12  --Job '{"JobName": "TestJob",  "JobDescription": "for test", "Priority": "1", "Tasks": [{"TaskName": "Task1",  "TaskInstanceNum": 1,  "Application": {"DeliveryForm": "LOCAL", "Command":  "python -c \"fib=lambda n:1 if n<=2 else fib(n-1)+fib(n-2); print(fib(20))\" "},  "ComputeEnv": {"EnvType":  "MANAGED", "EnvData": {"InstanceType": "S1.SMALL1",  "ImageId": "img-i91njcmx" }  }, "RedirectInfo": {"StdoutRedirectPath": "待替换", "StderrRedirectPath":   "待替换"}, "MaxRetryCount":  1 } ] }' --Placement '{"Zone": "ap-guangzhou-2"}'
```

### 修改配置

#### 1. 填写 ImageId
```"ImageId": "待替换"```

内测需要使用基于 Cloud-init 服务和配置过的镜像，官方提供 CentOS 6.5 的可直接使用镜像，镜像 ID 是 img-i91njcmx。

#### 2. 配置 StdoutRedirectPath 和 StderrRedirectPath
```"StdoutRedirectPath": "待替换", "StderrRedirectPath":   "待替换"```

将你在前置准备里创建 COS Bucket 的访问地址填写到 StdoutRedirectPath 和 StderrRedirectPath 中。

#### 3. 修改可用区（可选）
```
--Placement '{"Zone": "ap-guangzhou-2"}'
```

例子中指定在广州二区申请资源，你可以根据你在命令行工具配置的默认地域，选择相应的可用区申请资源，地域和可用区的详细信息请查看[地域和可用区>>](/doc/product/213/6091)。

#### 4. Windows下命令行输入JSON格式修改（可选）
Windows 下的命令行工具输入 JSON 格式数据会区别于 Linux，比如 " 号需要替换成 \"，详细请见 [快速使用腾讯云命令行工具](/doc/product/440/6185) 的 『JSON 格式作为入参』章节。

## 查看结果

```
{
    "Response": {
        "RequestId": "5d928636-bba2-4ab3-bef3-cf17d7c73c51",
        "JobId": "job-1rqdgnqn"
    }
}
```
返回 JobId 则表示执行成功。

```
$ qcloudcli batch DescribeJob  --Version 2017-03-12 --JobId job-1z4yl2bp
{
    "Response": {
        "JobState": "STARTING",
        "Zone": "ap-guangzhou-2",
        "JobName": "test job",
        "Priority": 1,
        "RequestId": "b116f9b5-410c-4a69-bbe8-b695a2d6a869",
        "TaskSet": [
            {
                "TaskName": "hello2",
                "TaskState": "STARTING"
            }
        ],
        "JobId": "job-1z4yl2bp",
        "DependenceSet": []
    }
}
```
可以通过 DescribeJob 来查看刚才提交的任务信息。

```
$ qcloudcli batch DescribeJobs  --Version 2017-03-12
```
还可以通过 DescribeJobs 查看当前地域作业列表。

## 下一步可以干什么？

这个是一个最简单的例子，它是一个单任务的作业，也没有使用到远程存储映射能力，仅仅是向用户展示最基本的能力，你可以根据 API 说明文档继续测试 Batch 更高阶的能力。

* **更简单的操作方法**：Batch 的能力强大，配置项较多，通过脚本来调用会更加简便快捷，从 [前置准备](/doc/product/599/10548) 和 [1_简单开始](/doc/product/599/10551) 开始尝试这种方式。

* **执行远程代码包**：Batch 提供**自定义镜像 + 远程代码包 + 命令行**的方式，在技术上全方位的覆盖您的业务需要，详细查看 [2_执行远程代码包](/doc/product/599/10552)。

* **远程存储映射**：Batch 在存储访问上进行优化，将对远程存储服务的访问简化为对本地文件系统操作，详细查看 [3_远程存储映射](/doc/product/599/10983)。
