```
由于 SCF 的底层容器环境使用了 CentOS 7.2 版本的镜像。因此本示例中的 Linux 示例部分是在 CentOS 7.2 环境下的操作，如果您本地环境为其他 Linux 发行版，请适当调整操作
```
## 创建图片处理代码
1) 新建目录
如果您本地环境为Windows，请在任意位置新建一个名为 CreateThumbnail 的文件夹，如下图所示：
![](//mc.qcloudimg.com/static/img/73c192c719687a5a64d98d3240015ca7/image.png)
如果您本地环境为 Linux，请在任意位置新建一个名为 CreateThumbnail 的文件夹，如下图所示：
![](//mc.qcloudimg.com/static/img/a6999a456a083698490381246da19ac2/image.png)

2) 打开文本编辑器，输入以下代码
请特别注意，将参数 `appid, secret_id, secret_key, region` 改为您的实际数据，其中：
- appid可在控制台【账户信息】中获得
![](//mc.qcloudimg.com/static/img/8149e0d15b64340c2a2dca5569854af8/image.png)
- secret_id 和 secret_key可在控制台【云API密钥】中获得
![](//mc.qcloudimg.com/static/img/e1eecfe7459069d0f453083ff459e30e/image.png)
- region 为 函数 和 COS Bucket 所在地域，支持 `sh、gz、bj` 三个值。请注意，必须保持和上一步骤中创建的 COS Bucket 在同一个地域。此处由于步骤一：准备COS Bucket 中创建的存储桶位于华南（广州），因此代码中的 region 值必须为 `gz`

```
import uuid
import json
import os
import logging
from PIL import Image
import PIL.Image
import commands
import datetime
from qcloud_cos import CosClient
from qcloud_cos import DownloadFileRequest
from qcloud_cos import UploadFileRequest


print('Loading function')
appid = 1251762222  #please change to your appid. Find it in Account Info
secret_id = u'AKIDYDh085xQp48161uOn2CKKVbeebvDu6j2'   #please change to your API secret id. Find it in API secret key pair
secret_key = u'lLkxx40kIfuyqW0IOI0WqyueCYjlgZQ2'  #please change to your API secret key. Find it in API secret key pair
region = u'gz' 

cos_client = CosClient(appid, secret_id, secret_key, region)
logger = logging.getLogger()

def resize_image(image_path, resized_path):
    with Image.open(image_path) as image:
        image.thumbnail(tuple(x / 2 for x in image.size))
        image.save(resized_path)

def delete_local_file(src):
    logger.info("delete files and folders")
    if os.path.isfile(src):
        try:  
            os.remove(src)  
        except:  
            pass 
    elif os.path.isdir(src):  
        for item in os.listdir(src):  
            itemsrc=os.path.join(src,item)  
            delete_file_folder(itemsrc)  
        try:  
            os.rmdir(src)  
        except:  
            pass     
     
def main_handler(event, context):
    logger.info("start main handler")
    for record in event['Records']:
        try:
            bucket = record['cos']['cosBucket']['name']
            cosobj = record['cos']['cosObject']['key']
            cosobj = cosobj.replace("/"+str(appid)+"/"+bucket,"")
            key = urllib.unquote_plus(cosobj.encode('utf8'))
            download_path = '/tmp/{}{}'.format(uuid.uuid4(), key)
            upload_path = '/tmp/resized-{}'.format(key)
            print("Get from [%s] to download file [%s]" %(bucket,key))
           
            # download image from cos
            request = DownloadFileRequest(bucket, key, download_path)
            download_file_ret = cos_client.download_file(request)
            if download_file_ret['code'] == 0:
                logger.info("Download file [%s] Success" % key)
                logger.info("Image compress function start")
                starttime = datetime.datetime.now()
                    
                #compress image here
                resize_image(download_path, upload_path)
                endtime = datetime.datetime.now()
                logger.info("compress image take " + str((endtime-starttime).microseconds/1000) + "ms")
                    
                #upload the compressed image to resized bucket
                request = UploadFileRequest(u'%sresized' % bucket, key.decode('utf-8'), upload_path.decode('utf-8'))
                upload_file_ret = cos_client.upload_file(request)
                logger.info("upload image, return message: " + str(upload_file_ret))

                #delete local file
                delete_local_file(str(download_path))
                delete_local_file(str(upload_path))
            else:
                logger.error("Download file [%s] Failed, err: %s" % (key, download_file_ret['message']))
                return -1
        except Exception as e:
            print(e)
            print('Error getting object {} from bucket {}. Make sure the object exists and your bucket is in the same region as this function.'.format(key, bucket))
            raise e

```
3) 将文件另存为 `CreateThumbnail.py`，保存在刚刚创建的目录下：
![](//mc.qcloudimg.com/static/img/9629a86384751950f6e8ecdefaf5a25f/image.png)
![](//mc.qcloudimg.com/static/img/609faa717c1eefb5dd1c6747dfb99ab1/image.png)
![](//mc.qcloudimg.com/static/img/66d8a074d8577257880c4713bb8a4c86/image.png)
## 创建部署程序包
### 如果您本地环境是 Windows
由于本示例程序依赖与 Python 的 Pillow 依赖库，为了避免您本地 Windows 环境下安装的依赖库与平台冲突，我们建议您:

直接点击链接下载 [Pillow 库](https://mc.qcloudimg.com/static/archive/66534c4192eefc53af8ce3b319c521c9/PIL.zip)，并将该zip包解压至刚刚创建的CreateThumbnail 文件夹内：
![](//mc.qcloudimg.com/static/img/29c635b9dd94551cd34e2bde9331c255/image.png)
压缩该文件夹下的所有内容至一个名为 CreateThumbnailDemo.zip 的压缩包中（注意不是压缩文件夹本身！）：选中所有文件，点击右键，选择您的压缩工具如winrar，点击【添加到压缩文件…】，将压缩文件设置为zip格式，点击【确定】按钮，将生成一个zip包（此处命名为`CreateThumbnailDemo.zip`）。
![](//mc.qcloudimg.com/static/img/c8c91ff1b0e8473b21ede7cafe9be250/image.png)
![](//mc.qcloudimg.com/static/img/3f2fe60ba03ac61395ca9d3cc829ab06/image.png)
![](//mc.qcloudimg.com/static/img/4b542a9ddd8c464f3cee28a2368b63b3/image.png)


### 如果您本地环境是 Linux
```
请注意：以下步骤是假设在 CentOS 7.2 环境下，如果您的环境是其他 Linux 发行版，请根据该版本的相关方法修改命令，并确保 Python 版本为2.7
```

1) 安装 python 环境
```
sudo yum install python
```
2) 请确保您当前的 Linux 环境安装了必要的依赖
```
sudo yum install python-devel python-pip gcc libjpeg-devel zlib-devel python-virtualenv
```

3) 创建和激活虚拟环境
```
virtualenv ~/shrink_venv
source ~/shrink_venv/bin/activate
```

4) 在虚拟环境下安装 Pillow 库
```
pip install Pillow
```

5) 将 lib 和 lib64 的相关内容添加至一个 .zip 文件中（假定路径为 `/CreateThumbnailDemo.zip`）
```
cd $VIRTUAL_ENV/lib/python2.7/site-packages
zip -r /CreateThumbnailDemo.zip *
cd $VIRTUAL_ENV/lib64/python2.7/site-packages
zip -r /CreateThumbnailDemo.zip *
```

6) 将第一步中创建的 PY 文件也添加至 .zip文件中
```
cd /CreateThumbnail
zip -g /CreateThumbnailDemo.zip CreateThumbnail.py
```
