## 通用问题
### 什么是 SCF？
腾讯云云函数（SCF）是腾讯云提供的无服务器（serverless）执行环境。您只需编写简单的、目的单一的云函数，并将它与您的腾讯云基础设施及其他云服务产生的事件关联起来。
使用云函数时，用户只需关注自己的代码。腾讯云完全管理底层计算资源，包括服务器CPU、内存、网络和其他配置/资源维护、代码部署、弹性伸缩、负载均衡、安全升级、资源运行情况监控等，用户只需使用平台支持的语言（目前支持Python）提供代码。同时，这意味着您无法登录或管理服务器、无法自定义系统和环境。

代码在执行时将根据请求负载扩缩容，无需人工配置和介入即可满足不同情景下服务的可用性和稳定性，从每天几个请求到每秒数千个请求，都由云函数底层自行伸缩。云函数自动地在地域内的多个可用区部署，提供极高的容错性。用户只需为运行中的云函数付费，代码未运行时不产生任何费用。

您可以自定义何时运行您的代码，比如在COS Bucket上传或删除了文件时、应用程序通过SDK调用了代码时，或自行指定代码定期执行。因此，您可以使用云函数作为COS服务的数据处理触发程序，轻松实现IFTTT逻辑。也可构建灵活的定时自动化任务来覆盖手工完成的操作，轻松构建灵活可控的软件架构。

### 什么是无服务器计算？

借助无服务器计算，用户无需考虑服务器，即可构建和运行应用程序与服务。Serverless并不代表没有了服务器，只是用户不再需要关心这些底层资源了。当然，这也意味着用户无法登录服务器，并且也不需要想办法优化它。开发者只需关心最核心的代码片段，从而跳过复杂的、无聊的其他工作。这些代码完全由事件触发（event-trigger），平台根据请求自动平行调整服务资源，拥有近乎无限的扩容能力，空闲时则没有任何资源在运行。代码运行无状态，可以轻易实现快速迭代、极速部署。SCF 是腾讯云无服务器计算的核心，支持您运行代码，且无需预置或管理服务器。

### 哪些事件可以触发 SCF 函数？

当前支持：手动触发（API）、定时触发、COS 触发、CMQ 触发、API网关触发等触发方式，后续更多触发方式正在持续添加中。

### SCF 支持哪些语言？

目前支持 Python 2.7，Python 3.6，Node.js 6.10，Java 8。后续更多开发语言支持正在持续添加中。

### 能否访问 SCF 运行所在的基础设施？

不能。SCF 会代您运行和管理计算基础设施。

### SCF 如何隔离代码？

每个函数都运行在自己独有的环境中，拥有自己的资源和文件系统。SCF 使用与 CVM 相同的技术在基础设施和执行级别上提供安全性和隔离。

## SCF 函数

### SCF 函数是什么？

无服务器云函数上运行的代码以“SCF 函数”的形式上传。每个函数都有相关的配置信息，如其名称、描述、资源要求等。代码必须以“无状态”样式编写，即应假设与底层计算基础设施无密切关系。本地文件系统访问、子进程等严格控制在云函数的生命周期内，且任何持续状态都应存储在外部可用的存储如COS或CDB。SCF 函数可包含外部库，甚至是本机库。

### SCF 是否会重复使用函数实例？

为了提高性能，SCF 会在一定时间内保留您的函数实例，将其再用于服务后续请求。但您的代码不应假设此操作总是发生。

### SCF 函数的本地存储形态是什么？

每个函数都会在其自己的目录 `/tmp` 中拥有 `500MB` 的非持久性磁盘空间。函数生命周期结束后，此空间的文件并不会保存。

### 为何要保持 SCF 函数无状态？

保持函数的无状态性可使函数按需要尽可能多地启动多个实例，从而满足请求的速率

### 能否在我的函数代码中使用线程和进程？

能。用户可使用正常的语言和操作系统功能，如创建额外的线程和进程。分配至函数的资源，包括内存、执行时间、磁盘和网络，都通过其使用的所有线程/进程进行共享。

### 有哪些限制适用于函数代码？

我们尽量不对正常的语言和操作系统活动施加限制，但有些活动仍被禁用。比如：入站网络连接将被阻止

### 如何使用 CLI 创建 SCF 函数？

您可以将代码 (以及任何依赖库) 打包为 zip 并使用 CLI 从您的本地环境上传 zip 文件，或将 zip 文件上传 COS Bucket 后，在创建函数时指定拉取代码 zip 包的 Bucket 名和文件名。

### 如何进行故障排除？

SCF 集成了日志功能，每次调用都会将该次调用的日志输出到控制台日志窗口中，日志记录了该函数每次使用时所消耗的资源、代码中的log及平台调用信息等，您可以轻松将故障排除相关的log语句插入到代码中。

### 通过上传zip包创建函数后，函数代码没有展示在详情页里？
通常是执行方法写得不对，或压缩时包括了外层文件夹。执行方法格式为`a.b`，其中：a是py文件的名称，b是代码中的方法名。
如果用户上传的zip包在解压后的根目录下找不到名为`a.py`的文件，则会提示"函数代码无法显示，代码 zip 包中找不到执行方法指定的文件名"。

例如：文件结构如下

--RootFolder
----SecondFolder
------a.py
------thirdfolder
--------sth.json

压缩代码zip包时，如果压缩的是SecondFolder，则会出现上述错误；需要选择`a.py`和`thirdfoler`进行压缩。

### 选择内存不管多少，同一段代码的执行时间都差不多？

在公测期，我们为用户的每个函数实例都统一分配了相同的计算资源（即容器核数是固定的） ，公测后会根据选择内存大小进行按比例分配。

### 出现timeout时如何处理？

请先将超时时间设置为一个较大值（不超过300均可）再测试一遍，如果仍然超时，请检查您的代码 log 中是否存在过大的输入数据和计算量、无法跳出的循环、长时间的sleep等。

### 如何扩容？

用户不必关心函数扩缩容问题，SCF 平台会代您自动扩展。每当接收函数请求时，SCF 会快速定位空闲容量并运行您的代码。由于您的代码是无状态的，可以在需要时尽可能多地启动实例，而不会发生冗长的部署和配置延迟。

### 如何分配函数计算资源？

用户可以选择函数分配的内存量，CPU 和其他资源按比例进行分配。例如，选择 256MB 的内存时，分配至函数的 CPU 约是分配 128MB 内存的两倍。

### 能否使用本地库？

可以。用户可以在函数代码中包含自己的代码库，并以zip包的形式上传至平台。

## 事件处理

### 什么是事件源？

事件源是一类腾讯云服务或开发人员创建的应用程序，用于生成可触发SCF函数的事件。

### 有哪些事件源？

当前支持：手动触发（API）、定时触发、COS 触发、CMQ 触发、API网关触发等触发方式


### 应用程序如何直接触发函数？

可以通过调用 SCF 的 Invoke API 直接触发函数。该函数的所有者或有调用该函数 Invoke API权限的帐号能直接调用。

### 函数响应事件的延迟如何？

SCF 在常规请求中可在毫秒级别内处理请求响应时间。但在函数创建、更新时，或如果它最近未被使用，延迟都将升高。


## 扩展性和可用性

### 云函数的可用性如何？

SCF 云函数通过跨地域部署、复制和冗余来提供高可用性。

### 改动代码或配置时，云函数还可以使用吗？

可以。更新函数时会有短暂的窗口期，通常不到 1 分钟，在这期间请求将由旧函数代码或新函数代码实现。

### 单次运行的函数数量有没有限制？

SCF 可以支持大量函数实例并行。但是，我们有一项默认的安全阈值：每个函数最多 20 个并发执行量。此阈值可以通过提交工单进行提升。

### 函数在处理事件时发生故障会怎样？

如遇故障，进行同步调用的函数会返回异常信息。异步调用的函数将在后台自动重试 3 次。