函数代码是无服务器云函数最重要的部分。用户以 *SCF 函数* 的形式将应用程序代码上传至腾讯云无服务器函数平台，由 *SCF 函数* 代表用户运行代码，并执行所有相关的服务器管理工作。

基于云函数的应用程序的生命周期通常包括：编写代码、创建云函数、部署云函数至 SCF 平台、测试、监控和故障排除等。本部分介绍与函数代码相关的一切，监控和故障排除的具体内容请参考监控云函数和云函数日志部分。

## 为云函数编写代码
用户需要使用 SCF 平台支持的语言编写云函数代码，目前仅支持 Python。可以任意选用代码编写工具如 SCF 控制台，本地编辑器和本地 IDE 等。需要注意的是，如果您的代码中引入了平台暂未引入的其他依赖库，则 *必须*上传这些依赖库，平台提供的依赖库请参考 [执行环境](https://cloud.tencent.com/document/product/583/9694#.E6.89.A7.E8.A1.8C.E7.8E.AF.E5.A2.83.E5.92.8C.E5.8F.AF.E7.94.A8.E5.BA.93) 章节，上传代码请参考 [创建部署程序包](https://cloud.tencent.com/document/product/583/9702) 章节。

下面列出了平台支持的语言、可用工具和相关注意事项：

|平台支持的语言|可用工具|注意事项|
|--|--|--|
|Python 2.7 & 3.6|SCF 控制台<br>您自己的编写环境如：<br>&nbsp;&nbsp;编辑器：可以选用vim + Pydiction, sublime text, NotePad等多种编辑器编写Python代码。<br>&nbsp;&nbsp;IDE：需要 IDE 本身集成 python 环境，如 WIngIDE, eclipse + pydev, pycharm等。|如果代码不需要编译且没有引入任何外部库时，可直接使用 SCF 控制台编写代码。平台将自动把代码保存在单个 .py 文件中并自动部署。|
|Node.js 6.10|SCF 控制台<br>您自己的编写环境如：<br>&nbsp;&nbsp;编辑器：可以选用vim , sublime text, VS code, NotePad等多种编辑器编写 Nodejs 代码。<br>&nbsp;&nbsp;IDE：如 WebStorm, Eclipse等。|如果代码不需要编译且没有引入任何外部库时，可直接使用 SCF 控制台编写代码。平台将自动把代码保存在单个 .js 文件中并自动部署。|

同时，SCF 平台提供了一套函数编写的基本范式。例如，如何确定函数最先调用的方法、如何从参数中获取信息、如何输出日志、如何与当前运行环境交互等。具体的函数范式请参考 [编写处理方法](https://cloud.tencent.com/document/product/583/9210) 章节。


## 创建部署程序包

用户需要提供代码或部署程序包（deployment package)：

- 当您的代码中使用的都是 python 标准库和腾讯云提供的库（如各类云产品的 Python SDK）时，只需在控制台提供代码，SCF 平台会自动打包此代码文件并上传至 SCF 平台。

- 如果您需要引入外部库，请按照 [创建部署程序包](https://cloud.tencent.com/document/product/583/9702) 中的特定方式组织您的代码和依赖项，打包并上传至 SCF 平台。

## 创建及及部署 SCF 云函数

用户可以通过 SCF 控制台、 API、 SDK或 qcloud cli工具等创建云函数。首先您需要提供云函数的配置信息，包括计算资源、运行环境等，详细信息请参考 [创建 SCF 云函数](https://cloud.tencent.com/document/product/583/9207)。


## 测试 SCF 云函数
您可以通过以下方法测试云函数：

- 在控制台点击【测试】按钮测试云函数。
- 使用API、SDK 或 qcloud cli工具的 InvokeFunction 方法测试云函数。

测试时需要提供调用数据，您可以功过传入特定云产品的调用数据（如COS等）来测试函数是否按您期望地响应这些云产品产生的事件。有关不同云产品产生的事件数据的详细信息可以参考 [管理云函数触发器](https://cloud.tencent.com/document/product/583/9707) 章节。

## 监控和故障排除
在云函数进入生产环境时，腾讯云 SCF 将自动为您监控函数的运行状况。后续将把云函数指标上报至云监控平台，以便用户自行查阅函数的运行状态。

为了帮助您调试和排除故障，腾讯云 SCF 平台将记录此函数的所有调用及处理结果，并将用户代码中生成的输出以日志的形式存储下来。有关更多信息，请参阅 [函数日志]() 章节。

## 基于无服务器云函数的应用程序示例
请确保您在使用云函数前，阅读并练习以下章节中的示例：

- [新手入门](https://cloud.tencent.com/document/product/583/9179)：如果您第一使用腾讯云无服务器云函数，请首先阅读并尝试新手入门章节的所有操作。
- [代码实操](https://cloud.tencent.com/document/product/583/9734)：如果您需要引入外部库，则必须在本地环境中创建您的代码程序包，并上传至 SCF 平台。请根据您选用的编程语言和需要处理的事件阅读并练习使用示例中的操作步骤。




