Tencent Cloud SCF is a typical event-triggered serverless execution environment. The core components are SCF and event source. The event source is a Tencent Cloud service that publishes Event or a user-defined code. SCF is an event processor. Function trigger is a set to manage the corresponding relation between function and event source. For example, in the following scenario:

- Image/Video processing: When a user uploads an image, he or she needs to crop the image to a proper size. When the user uploads pictures using the application, the application stores these pictures into COS and create a thumbnail for each picture, and displays these thumbnails on user page. In this scenario, you need to select COS as the event source to publish the Event to SCF during the creation of a file. The event data provides all the information about the bucket and file.
- Data processing: Analyze the data (such as clickstream) collected on the previous day at 0:00 am and generate a report. In this scenario, you need to select Timer as the event source to publish the Event to SCF at a specified time.
- Custom application: Call the first image to process SCF in one of your applications as a module of the application. In this scenario, you need to allow [InvokeFunction]() to be called automatically in the application to publish the Event.

These event sources can be one of the following options:

- Internal event source: It is a pre-configured Tencent Cloud service that can be used in combination with SCF. Currently, SCF supports two internal event sources: COS and Timer. When you configure these event sources to trigger function, the function is called automatically when an event is generated. Relation between event source and function (i.e. event source mapping) is maintained at event source end. For example, COS provides [Bucket Notification Configuration API](https://cloud.tencent.com/document/product/436/8588). You can bind the Bucket event with the function by using this API.
- Custom application: You can allow the custom application to publish event and call Lambda function.

## Example 1: COS Publishes Event and Calls Function

You can configure the event source mapping of COS to determine what operation (for example, PUT, DELETE object, etc.) performed by COS can trigger SCF. The event source mapping of COS is stored in COS. You can use bucket notification feature to allow COS to call the function when a specific event is generated:

- Create a COS trigger
- Users create/delete an object in a bucket.
- COS detects object creation/deletion event.
- COS calls the function automatically, and determines which function is to be called based on the event source mapping stored in COS configuration. Pass Bucket and Object information as event data to the function.

## Example 2: Timer Publishes Time and Calls Function
The event source mapping of timer is stored in SCF function configuration to determine when to trigger the function:

- Create a timer trigger
- This timer calls the function automatically during configuration of time.

## Example 3: Custom Application Calls Function
If you need to call a certain SCF in a custom application, you don't need to configure a function trigger nor event source mapping. At this point, use Invoke API as the event source.

- The custom application uses InvokeFunction API to call function, and passes the event data automatically.
- The function receives the trigger request and perform triggering.
- If synchronous call is used, the function returns the result to the application.

Note: In this example, since the custom application and the function are generated by the same user, the user credential (appid, secretid and secretkey) can be specified.

## Note
1. Currently, a cloud function only supports 2 COS triggers and 2 timer triggers.
2. Due to limitations of different cloud services, event source mapping relation is subject to specific restrictions. For example, for COS trigger, the same event (such as file upload) of the same COS Bucket cannot trigger multiple different functions.






