## 简介
路由表由一系列路由规则组成，用于控制私有网络（VPC）内子网的流量走向。如下图所示，腾讯云上的路由表有两种类型：默认路由表和自定义路由表。每个子网都必须关联一个路由表，每个路由表可以关联多个子网。

路由表由一系列路由策略组成，路由策略包括路由目的端、下一跳类型和下一跳组成，下一跳的类型可以是下图中的所有组件。

![](//mccdn.qcloud.com/static/img/2788ddc8974023b2c4b9d83b007c8bda/image.png)

## 默认路由表
用户创建私有网络时，系统会自动为其生成一个默认路由表。在之后创建子网的过程中，如果用户没有选择自定义路由表则子网会自动关联该默认路由表。可以在默认路由表中添加、删除和修改路由规则，但无法删除该默认路由表。

## 自定义路由表
除了默认路由表之外，还可以在 VPC 中创建其他自定义路由表，自定义路由表可以被删除。用户可以为具有相同路由策略的子网建立一个自定义路由表，并将路由表和需要遵循其中路由策略的所有子网关联。具体的操作方法可以参考[绑定子网和路由表]()。

## 关联路由表
每个路由表可以关联同一个私有网络中的多个子网，但每个子网有且只能关联一个路由表。

## 路由规则
路由规则用来控制数据包的路由途径。有默认路由规则和自定义路由规则两种类型，其中每条路由规则包含了三个参数：
- 目的端：目的网段描述（仅支持网段格式，如果希望目的端为单个 IP，可设置掩码为`32`（如：`172.16.1.1/32`），目的端 ***不可以*** 是路由表所在私有网络内的IP段。
- 下一跳类型：私有网络的数据包出口。私有网络下一跳类型支持“公网网关”、“VPN网关”、“专线网关”等类型。 
- 下一跳：指定具体跳转至哪个下一跳实例（使用下一跳 ID 标识）。

>备注：
所有路由表均包含一条默认 local 路由规则，含义为私有网络内网互通。其路由规则为 [ Local，Local，Local ]，该路由规则不能被删除和修改。


## 路由规则优先级
当路由表中存在多条路由规则时，路由优先级由高至低分别为：
- 私有网络内流量：私有网络内流量最优先匹配
- 最精确路由：非私有网络内流量根据最精确路由规则匹配
- 公网IP：路由规则均匹配失效时，通过公网 IP 对 Internet 进行外访

例如：私有网络内一云主机绑定了弹性 IP，同时又在关联了 NAT 网关的子网内（路由表中设置了该子网访问 Internet 流量的下一跳是 NAT 网关），那么该云主机访问 Internet 的流量会全部通过 NAT 网关实现，因为最精确路由的优先级高于公网 IP。

## 使用约束
- 每个子网必须关联一个路由表，每个路由表可以关联多个子网
- 默认路由表及已经关联了子网的自定义路由表不能删除
- 默认 local 路由规则不能删除
- 不支持 BGP 和 OSPF 等动态路由协议
- 如下表所示，每个 VPC 上创建的路由表和在每个路由表中添加的路由规则均存在数量限制：

| 资源| 限制（个） | 
|---------|---------|
| 每个私有网络内的路由表个数 | 10	 | 
| 每个子网关联路由表个数 | 1	 | 
| 每个路由表的路由策略数 | 50	|

## 计费方式
路由表的创建和使用完全免费。有关私有网络的其他价格信息，可以参考[私有网络价格总览](https://cloud.tencent.com/doc/product/215/3079)。

## 操作指南

### 修改默认路由表
在创建私有网络时系统会自动创建一个默认路由表，新建子网默认与默认路由表相关联。

1)	登录[腾讯云控制台](https://console.cloud.tencent.com/)点击导航条【私有网络】，进入[私有网络控制台](https://console.cloud.tencent.com/vpc/vpc?rid=8)。
2)	点击左导航栏中【路由表】，在路由表列表中点击路由表 ID 进入路由表详情页。
3)	点击路由策略的【编辑】按钮，即可开始修改路由规则。
4)	（可选）点击【新增一行】即可新增路由规则。输入目的端网段，选择下一跳类型（公网网关、VPN网关、专线网关等），再选择下一跳 ID。
5) （可选）点击路由规则右侧的按钮，可删除该路由策略。
6) 点击【确定】按钮，此编辑立即生效。

### 创建自定义路由表 
除了系统自动生成的默认路由表，用户还可以自定义新的路由表。

1)	登录[腾讯云控制台](https://console.cloud.tencent.com/)点击导航条【私有网络】，进入[私有网络控制台](https://console.cloud.tencent.com/vpc/vpc?rid=8)。
2) 点击左导航栏中【路由表】，点击列表上方【新建】按钮，在创建路由表弹出框中输入路由表名称、所属私有网络及新建路由策略。
3) 点击【创建】按钮，即可在路由表列表中看到您新建的路由表。

### 删除自定义路由表
系统自动生成的默认路由表无法删除，但自定义路由表可以任意创建、修改和删除。

1)	登录[腾讯云控制台](https://console.cloud.tencent.com/)点击导航条【私有网络】，进入[私有网络控制台](https://console.cloud.tencent.com/vpc/vpc?rid=8)。
2) 点击左导航栏中【路由表】，点击要删除的路由表所在行的【删除】按钮。
3) 点击确认弹窗中的【删除】按钮即可删除所选的自定义路由表。

### 更改子网关联路由表
1)	登录[腾讯云控制台](https://console.cloud.tencent.com/)点击导航条【私有网络】，进入[私有网络控制台](https://console.cloud.tencent.com/vpc/vpc?rid=8)。
2)	点击左导航栏中【子网】选项卡，鼠标移动到需要修改的子网路由表编辑按钮即会出现在【关联路由表】列中。
3)	点击【编辑】按钮，在下拉框中选择关联路由表。
4)	点击【保存】即完成子网与路由表的关联。

## API概览

您可以使用API操作来设置和管理您的路由表，点击查看[私有网络所有API概览](https://cloud.tencent.com/doc/product/215/4954)。

| 接口功能 | Action ID | 功能描述 |
|---------|---------|---------|
| 创建路由表 | [CreateRouteTable](http://cloud.tencent.com/doc/api/245/%E5%88%9B%E5%BB%BA%E8%B7%AF%E7%94%B1%E8%A1%A8) | 创建一个路由表。 |
| 删除路由表 | [DeleteRouteTable](http://cloud.tencent.com/doc/api/245/%E5%88%A0%E9%99%A4%E8%B7%AF%E7%94%B1%E8%A1%A8) | 删除指定路由表，删除后该路由表内路由策略都失效。 |
| 修改路由表 | [ModifyRouteTableAttribute](http://cloud.tencent.com/doc/api/245/%E4%BF%AE%E6%94%B9%E8%B7%AF%E7%94%B1%E8%A1%A8) | 修改指定路由表名称。 |
| 查询路由表 | [DescribeRouteTable](http://cloud.tencent.com/doc/api/245/%E6%9F%A5%E8%AF%A2%E8%B7%AF%E7%94%B1%E8%A1%A8) | 根据用户输入信息，如routeTableId、路由表名称等，查询对应路由表的详细信息。|
| 修改子网关联的路由表 | [AssociateRouteTable](http://cloud.tencent.com/document/product/215/1416) | 修改子网关联的路由表。 |