
### 策略语法
CAM 策略：

```
{	 
        "version":"2.0", 
        "statement": 
        [ 
           { 
              "effect":"effect", 
              "action":["action"], 
              "resource":["resource"], 
               "condition": {"key":{"value"}} 
           } 
       ] 
} 

```
- **版本 version**是必填项，目前仅允许值为"2.0"。
- **语句 statement**是用来描述一条或多条权限的详细信息。该元素包括 effect、action、resource，condition 等多个其他元素的权限或权限集合。一条策略有且仅有一个 statement 元素。
 1. **操作 action** 用来描述允许或拒绝的操作。操作可以是 API （以 name 前缀描述）或者功能集（一组特定的 API ，以 permid 前缀描述）。该元素是必填项。
 2. **资源 resourcce** 描述授权的具体数据。资源是用六段式描述。每款产品的资源定义详情会有所区别。有关如何指定资源的信息，请参阅您编写的资源声明所对应的产品文档。该元素是必填项。
 3. **生效条件 condition** 描述策略生效的约束条件。条件包括操作符、操作键和操作值组成。条件值可包括时间、IP 地址等信息。有些服务允许您在条件中指定其他值。该元素是非必填项。
 4. **影响 effect** 描述声明产生的结果是“允许”还是“显式拒绝”。包括 allow (允许)和 deny (显式拒绝)两种情况。该元素是必填项。


### BM 的操作

在 CAM 策略语句中，您可以从支持 CAM 的任何服务中指定任意的 API 操作。对于 bm，请使用以 name/bm: 为前缀的 API 。例如： name/bm:StartDevice 或者 name/bm:ReloadDeviceOs 。
如果您要在单个语句中指定多个操作的时候，请使用逗号将它们隔开，如下所示:
```
"action":["name/bm:action1","name/bm:action2"]
```
您也可以使用通配符指定多项操作。例如，您可以指定名字以单词" Describe "开头的所有操作，如下所示：
```
"action":["name/bm:Describe*"]
```
如果您要指定 CVM 中所有操作，请使用 * 通配符，如下所示：
```
"action"：["name/bm:*"]
```

 
### BM 的资源路径
每个 CAM 策略语句都有适用于自己的资源。
资源路径的一般形式如下：
```
qcs:project_id:service_type:region:account:resource
```
**project_id**：描述项目信息，仅为了兼容CAM早期逻辑，无需填写。
**service_type**：产品简称，如 bm。
**region**：地域信息，如 ap-beijing。
**account**：资源拥有者的根帐号信息，如 uin/164256472。
**resource**：各产品的具体资源详情，如 instance/instance_id1 或者 instance/*。

例如，您可以使用特定实例 (cpm-34xw9x3t) 在语句中指定它，如下所示：
```
"resource":[ "qcs::bm:ap-beijing:uin/164256472:instance/cpm-34xw9x3t"]
```
您还可以使用 * 通配符指定属于特定账户的所有实例，如下所示：
```
"resource":[ "qcs::bm:ap-beijing:uin/164256472:instance/*"]
```

您要指定所有资源，或者如果特定 API 操作不支持 资源级权限，请在 Resource 元素中使用 * 通配符，如下所示：
```
"resource": ["*"]
```
如果您想要在在一条指令中同时指定多个资源，请使用逗号将它们隔开，如下所示为指定两个资源的例子：
```
"resource":["resource1","resource2"]
```
下表描述了 BM 能够使用的资源和对应的资源描述方法。
<style>
table th:nth-of-type(1){
width:250px;
}
table th:nth-of-type(2){
width:500px;
}
</style>
在下表中，$为前缀的单词均为代称。
- 其中，project指代的是项目ID。
- 其中，region指代的是地域。
- 其中，account指代的是账户ID。

| 资源 | 授权策略中的资源描述方法 |
|-------|-------|
|实例|  qcs::bm:$region:$account:instance/$instanceId|

 


### BM 的条件密钥
在策略语句中，您可以选择性指定控制策略生效的条件。每个条件都包含一个或多个密钥值对。条件密钥不区分大小写。

- 如果您指定了多个条件或在单一条件中指定了多个密钥，我们将通过逻辑 AND 操作对其进行评估。
- 如果您在单一条件中指定了一个具有多个值的密钥，我们将通过逻辑 OR 操作对其进行评估。必须匹配所有条件才能授予权限。
下表描述了 BM 用于特定于服务的条件键。

|条件键|参考类型|键值对|
|---|---|---|
|bm:vpcId|String|bm:vpcId=vpc-xxxxx <br/>vpc-xxxx为黑石私有网络的唯一ID|
|bm:subnetId|String|bm:subnetId=subnet-xxxxx <br/>subnet-xxxx为黑石私有网络子网的唯一ID|
