
## 简介
欢迎使用腾讯云开发者工具套件（SDK）。为方便 .NET 开发者调试和接入腾讯云产品 API，这里向您介绍适用于 .NET 的腾讯云开发工具包，并提供首次使用开发工具包的简单示例。让您快速获取腾讯云 .NET SDK 并开始调用。

## 依赖环境
1. 从 [腾讯云控制台](https://console.cloud.tencent.com) 开通相应产品，
2. [获取 SecretID、SecretKey](https://console.cloud.tencent.com/capi) 以及调用地址（endpoint），endpoint 一般形式为`*.api.qcloud.com`，如CVM 的调用地址为 `cvm.api.qcloud.com`，具体参考各产品说明。
3. 下载相关资料并做好相关文件配置。

## 获取安装
安装 .NET SDK 前，先获取安全凭证。在第一次使用云 API 之前，用户首先需要在腾讯云控制台上申请安全凭证，安全凭证包括 SecretID 和 SecretKey, SecretID 是用于标识 API 调用者的身份，SecretKey是用于加密签名字符串和服务器端验证签名字符串的密钥。SecretKey 必须严格保管，避免泄露。


### 通过 GitHub 获取源码安装
打开腾讯云为您提供的 .NET SDK GitHub 地址，[获取 GitHub 资源 >>](https://github.com/QcloudApi/qcloudapi-sdk-dotnet)。
1. 在 `qcloudapi-sdk-dotnet`的 github 地址上下载源码
2. 解压源码到您项目合适的位置
3. 配置方法可参考 Demo.dotnet 示例配置和引用源码

## 入门 DEMO
以 CVM 查看实例列表（DescribeInstances）为例：
```
 static void Main(string[] args)
    {
        SortedDictionary<string, object> config = new SortedDictionary<string, object>(StringComparer.Ordinal);
        config["SecretId"] = "你的secretId";
        config["SecretKey"] = "你的secretKey";
        config["RequestMethod"] = "GET";
        config["DefaultRegion"] = "gz";

        QCloudAPIModuleCenter module = new QCloudAPIModuleCenter(new Cvm(), config);
        SortedDictionary<string, object> requestParams = new SortedDictionary<string, object>(StringComparer.Ordinal);
        requestParams["offset"] = 0;
        requestParams["limit"] = 3;
        Console.WriteLine(module.GenerateUrl("DescribeInstances", requestParams));
        Console.WriteLine(module.Call("DescribeInstances", requestParams));


        //SortedDictionary<string, object> config = new SortedDictionary<string, object>(StringComparer.Ordinal);
        //config["SecretId"] = "你的secretId";
        //config["SecretKey"] = "你的secretKey";
        //config["RequestMethod"] = "POST";
        //config["DefaultRegion"] = "gz";

        //UploadCdnEntity
        //string fileName = "c:\\del.bat";
        //SortedDictionary<string, object> requestParams = new SortedDictionary<string, object>(StringComparer.Ordinal);
        //requestParams["entityFileName"] = "/upload/del.bat";
        //requestParams["entityFile"] = fileName;
        //QCloudAPIModuleCenter module = new QCloudAPIModuleCenter(new Cdn(), config);
        //Console.WriteLine(module.Call("UploadCdnEntity", requestParams));

        Console.ReadKey();
    }
```
