## 1. 接口描述
本接口提供中文到英日韩、英日韩到中文的文本翻译功能。

  * 域名：tmt.api.qcloud.com
  * 接口名: TextTranslate
  
## 2. 输入参数

| 参数名称 |必选 | 类型 |描述|
|---------|---------|---------|---------|
| sourceText | 是 | 	String |待翻译的文本|
| source | 是 | 	String |源语言，参照支持语言列表|
| target | 是 | 	String |目标语言，参照支持语言列表|

## 3. 支持语言列表
| 参数名称 | 描述 | 备注|
|---------|---------|-------|
| zh | 中文 ||
| en | 英文 ||
| jp | 日语 ||
| kr | 韩语 ||
|auto| 自动识别源语言| 只能用于source字段|

## 4. 输出参数

| 参数名称 |类型 | 描述 |
|---------|---------|---------|
| code | Int32 | 错误码, 0 - 成功, 其他值 - 失败， 参考错误码说明 |
| message | String | 错误信息 |
| targetText | String | 翻译后的文本 |
| source | String | 源语言|
| target | String | 目标语言|

**注意:** 当code不为0时，除message以外的字段可能不存在。

## 5. 错误码说明

| 错误码 |描述 | 解决方法
|--------|--------|-------|
| 0  |  成功    |
| > 0 | 腾讯云公共错误码| 具体错误码的含义和解决方法可以参考[错误码页面](/document/product/551/7391)|
| -1 | 内部错误 | 稍后重试或联系腾讯云客服 | 
| -3 | 参数错误 | 检查参数格式 | 
| -4 | 参数格式错误 | 检查参数格式 |
| -6 | 访问频率受限 | 降低调用频率
| -7 | 超过配额 | 确认当天/当月配额是否用完
| -9 | 单次请求text超过长度限制 | 请保证单次请求长度低于2000
| -1001 | 未识别到语言类型 | 请确认文本在支持语言列表中
| -2001| 不支持的源语言 | 检查源语言字段
| -2002| 不支持的目标语言 | 检查目标语言字段
| -2003| 不支持的语言 | 检查语言字段


## 6. 详细示例

  示例业务详细信息如下表：
	
<table class="t">
<tr>
<th width="100"> <br />
</th><th width="80"> <b>参数名称</b>
</th><th width="100"> <b>参数描述</b>
</th><th width="50"> <b>必选</b>
</th><th width="150"> <b>参数值示例</b>
</th></tr>
<tr>
<td rowspan="4">腾讯云公共参数 </td><td> Action </td><td> 方法名 </td><td> 是 </td><td> TextTranslate
</td></tr>
<tr>
<td> SecretId </td><td> SecretId </td><td> 是 </td><td> AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA
</td></tr>
<tr>
<td> Timestamp </td><td> 当前时间戳 </td><td> 是 </td><td> 1480060650
</td></tr>
<tr>
<td> Nonce </td><td> 随机正整数 </td><td> 是 </td><td> 3253
</td></tr>
<tr>
<td rowspan="4">业务参数 </td><td> sourceText </td><td> 待翻译的文本 </td><td> 是 </td><td> 你好
</td></tr>
<tr>
<td> source </td><td> 源语言 </td><td> 是 </td><td> zh
</td></tr>
<tr>
<td> target </td><td> 目标语言 </td><td> 是 </td><td> en
</td></tr>
<tr>
</tr></table>

  下面以上述业务为例，详细说明翻译接口的使用方法。

### 6.1 接口鉴权

  上述业务的参数列表如下：
	
```
{
    'Action' : 'TextTranslate',
    'Nonce' : 3253,
    'Region' : 'gz',
    'SecretId' : 'AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA',
    'Timestamp' : 1480060650,
    'sourceText': "你好",
    'source': "zh",
    'target': 'en'
}
```

  根据上述参数列表进行签名，得出的数字签名为：HgIYOPcx5lN6gz8JsCFBNAWp2oQ（示例），详细的数字签名的生成方法请参照[签名方法](/document/product/551/7393)。
  <b>注意：</b>鉴权时，需要将参数列表按key进行排序：字典序，同时大写在前。
### 6.2 API调用
  根据上一步（6.1）中得到的数字签名，构造 GET 请求 URL，将数字签名加入到参数 Signature 中。**注意：对所有GET请求参数值均需要做URL编码**，比如“你好”应转换成"%E4%BD%A0%E5%A5%BD"
  
```
    https://tmt.api.qcloud.com/v2/index.php?
  	Action=TextTranslate
  	&Nonce=3253
	&Region=gz
	&SecretId=AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA
  	&Timestamp=1480060650
  	&Signature=HgIYOPcx5lN6gz8JsCFBNAWp2oQ
  	&source=zh
  	&sourceText=%E4%BD%A0%E5%A5%BD
  	&target=en
```

  上述指令返回的数据结构如下：
	
```
{
    "code": 0,
    "message": "",
    "source": "zh",
    "target": "en",
    "targetText": "Hello"
}
```


