## 1. 接口描述
本接口提供音频内文字识别 + 翻译功能，目前支持中英和英中的翻译。
待识别和翻译的音频文件可以是 pcm、mp3、amr和speex 格式，音频内语音清晰，采用流式传输和翻译的方式。

  * 域名：tmt.api.qcloud.com
  * 接口名: SpeechTranslate
  
## 2. 输入参数

| 参数名称 |必选 | 类型 |描述|
|---------|---------|---------|---------|
| data   | 是 | String |语音分片的base64编码字符串|
| audioFormat   | 是 | String |音频文件的格式 支持的类型有：pcm/mp3/amr/pseex |
| source   | 是 | String |源语言，参照支持语言列表|
| target   | 是 | String |目标语言，参照支持语言列表|
| sessionUuid   | 是 | String |一段完整语音的标识|
| seq   | 是 | String |语音分片的序列 0-n  需要转换成字符串格式|
| isEnd   | 是 | String |是否最后一片语音，0：否，1：是  需要转换成字符串格式|

-----------------------------------------------------------------------------
**输入参数说明**：
语音翻译接口的使用场景 - 用户说一段完整的语音，客户端需要在用户输入音频的同时，将语音实时分片，每一片调用语音翻译接口进行翻译，并将每片语音翻译的结果展示出来。
一段完整的语音会分成很多语音分片，他们有共同的sessionUuid 来标识是同一段语音，POST请求中的data（语音分片）建议每个大小不超过40K，对分片内容进行base64编码转换成字符串。
语音翻译服务针对同一个sessionUuid的语音分片，会不断的翻译和纠正，最后一个语音分片的isEnd参数为1，语音翻译服务在接收到此分片后，会返回最终的翻译结果。

## 3. 支持语言列表
| 参数名称 | 描述 |
|---------|---------|
| zh | 中文 |
| en | 英文 |

## 4. 输出参数

| 参数名称 |类型 | 描述 |
|---------|---------|---------|
| code | Int32 | 错误码, 0 - 成功, 其他值 - 失败， 参考错误码说明 |
| message | String | 错误信息 |
| sourceText | String | 语音识别的源文本 |
| targetText | String | 语音翻译的目标文本|

**注意:** 当code不为0时，除message以外的字段可能不存在。

## 5. 错误码说明

| 错误码 |描述 | 解决方法
|--------|--------|-------|
| 0  |  成功    |
| > 0 | 腾讯云公共错误码| 具体错误码的含义和解决方法可以参考[错误码页面](/document/product/551/7391)|
| -1 | 内部错误 | 稍后重试或联系腾讯云客服 | 
| -3 | 参数错误 | 检查参数格式 | 
| -4 | 参数格式错误 | 检查参数格式 |
| -6 | 访问频率受限 | 降低调用频率
| -7 | 超过配额 | 确认当天/当月配额是否用完
| -9 | 单次请求text超过长度限制 | 请保证单次请求长度低于2000
| -1001 | 未识别到语言类型 | 请确认文本在支持语言列表中
| -2001| 不支持的源语言 | 检查源语言字段
| -2002| 不支持的目标语言 | 检查目标语言字段
| -2003| 不支持的语言 | 检查语言字段


## 6. 详细示例

  示例业务详细信息如下表：
	
<table class="t">
<tr>
<th width="100"> <br />
</th><th width="80"> <b>参数名称</b>
</th><th width="100"> <b>参数描述</b>
</th><th width="50"> <b>必选</b>
</th><th width="150"> <b>参数值示例</b>
</th></tr>
<tr>
<td rowspan="4">腾讯云公共参数 </td><td> Action </td><td> 方法名 </td><td> 是 </td><td> ImageTranslate
</td></tr>
<tr>
<td> SecretId </td><td> SecretId </td><td> 是 </td><td> AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA
</td></tr>
<tr>
<td> Timestamp </td><td> 当前时间戳 </td><td> 是 </td><td> 1480060650
</td></tr>
<tr>
<td> Nonce </td><td> 随机正整数 </td><td> 是 </td><td> 3537
</td></tr>
<tr>
<td rowspan="8">业务参数 </td><td> data</td><td> 语音分片的base64编码字符串</td>
<td> 是 </td><td> </td>
</tr>
<tr>
<td> audioFormat</td><td> 音频文件类型 </td><td> 是 </td><td> pcm
</td></tr>
<tr>
<tr>
<td> source </td><td> 源语言 </td><td> 是 </td><td> zh
</td></tr>
<tr>
<td> target </td><td> 目标语言 </td><td> 是 </td><td> en
</td></tr>
<tr>
<td> sessionUuid </td><td> 语音唯一标识 </td><td> 是 </td><td> 
</td></tr>
<tr>
<td> seq </td><td> 语音分片序列 </td><td> 是 </td><td> 0-n
</td></tr>
<tr>
<td> isEnd </td><td> 是否最后一个语音分片 </td><td> 是 </td><td> 0/1
</td></tr>
<tr>
</tr></table>

  下面以上述业务为例，详细说明翻译接口的使用方法。

### 6.1 接口鉴权

  上述业务的参数列表如下：
	
```
{
    'Action' : 'SpeechTranslate',
    'Nonce' : 3537,
    'Region' : 'gz',
    'SecretId' : 'AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA',
    'Timestamp' : 1480060650,
    'data': '/9j/4QCcRXhpZgAASUkqAAgAAAAHADIBAgAUAAAAYgAAAAi',
    'audioFormat': 'pcm',
    'source': "zh",
    'target': 'en',
    'sessionUuid': 'sid-000001',
    'seq': "0",
    'isEnd': '1',    
}
```

  根据上述参数列表进行签名，得出的数字签名为：JIC7PbJ3wtVI3sFX30chC/GSJYzJdu9jyHPrjXvp/Hc=（示例），详细的数字签名的生成方法请参照[签名方法](/document/product/551/7393)。
  <b>注意：</b>鉴权时，需要将参数列表按key进行排序：字典序，同时大写在前。
  
### 6.2 API调用
  根据上一步（6.1）中得到的数字签名，构造 POST 请求，将数字签名加入到参数 Signature 中。
  
```
    调用URL:
    https://tmt.api.qcloud.com/v2/index.php
    
    Post参数:
{
    'Action' : 'SpeechTranslate',
    'Nonce' : 3537,
    'Region' : 'gz',
    'SecretId' : 'AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA',
    'Timestamp' : 1480060650,
    'data': '/9j/4QCcRXhpZgAASUkqAAgAAAAHADIBAgAUAAAAYgAAAAi',
    'audioFormat': 'pcm',
    'source': "zh",
    'target': 'en',
    'sessionUuid': 'sid-000001',
    'seq': "0",
    'isEnd': '1',    
}
```

  上述指令返回的数据结构如下：
	
```
{
    "code": 0,
    "message": "",
    "sourceText": "你好",
    "targetText": "hello"
}
```

