## 1. 接口描述
本接口提供图片内文字识别 + 翻译功能，目前支持中英和英中的翻译。
待识别和翻译的图片必须是 Jpg 格式，图片内文字清晰，图片大小建议不超过1M。

  * 域名：tmt.api.qcloud.com
  * 接口名: ImageTranslate
  
## 2. 输入参数

| 参数名称 |必选 | 类型 |描述|
|---------|---------|---------|---------|
| data[0-n]   | 是 | String |将待识别和翻译的图片进行数据分片，每片大小不超过30K，然后将每片数据转换为base64编码的字符串。根据实际切分的数量来设置参数，如图片被切成3份，则参数为data0、data1 和 data2。详见下方示例|
| ocrType   | 否 | Int32 | 0：对图片进行识别并按句子翻译 <br>1：对图片进行识别并按单词翻译<br>默认值为0。 |
| source   | 是 | String |源语言，参照支持语言列表|
| target   | 是 | String |目标语言，参照支持语言列表|

-----------------------------------------------------------------------------
**输入参数说明**：腾讯云API的POST请求建议每个参数值的大小不超过30K，如果要识别和翻译的图片大于30K，需要进行数据分割，切割后的每片数据的字节数组进行base64编码转换成字符串。
具体POST请求中用于传输图片数据的参数个数，根据图片的大小来定，比如1M大小的图片，按每片大小30K切割成35片，那么图片请求参数是 data0、data1 ... data34，共35个参数来传输图片数据。

## 3. 支持语言列表
| 参数名称 | 描述 | 备注|
|---------|---------|-------|
| zh | 中文 ||
| en | 英文 ||

## 4. 输出参数

| 参数名称 |类型 | 描述 |
|---------|---------|---------|
| code | Int32 | 错误码, 0 - 成功, 其他值 - 失败， 参考错误码说明 |
| message | String | 错误信息 |
| result | String | 图片识别并翻译后的文本，Json 格式。Json中x,y,w,h 四个属性的单位是像素，x,y 表示识别的文字距离图片左上角的距离；w,h 表示识别的文字的宽和高。<br> 例如：[{ sourceText: 'hello',targetText: '你好',x: 70, y: 29, w: 619, h: 79}] |

**注意:** 当code不为0时，除message以外的字段可能不存在。

## 5. 错误码说明

| 错误码 |描述 | 解决方法
|--------|--------|-------|
| 0  |  成功    |
| > 0 | 腾讯云公共错误码| 具体错误码的含义和解决方法可以参考[错误码页面](/document/product/551/7391)|
| -1 | 内部错误 | 稍后重试或联系腾讯云客服 | 
| -3 | 参数错误 | 检查参数格式 | 
| -4 | 参数格式错误 | 检查参数格式 |
| -6 | 访问频率受限 | 降低调用频率
| -7 | 超过配额 | 确认当天/当月配额是否用完
| -9 | 单次请求text超过长度限制 | 请保证单次请求长度低于2000
| -1001 | 未识别到语言类型 | 请确认文本在支持语言列表中
| -2001| 不支持的源语言 | 检查源语言字段
| -2002| 不支持的目标语言 | 检查目标语言字段
| -2003| 不支持的语言 | 检查语言字段


## 6. 详细示例

  示例业务详细信息如下表：
	
<table class="t">
<tr>
<th width="100"> <br />
</th><th width="80"> <b>参数名称</b>
</th><th width="100"> <b>参数描述</b>
</th><th width="50"> <b>必选</b>
</th><th width="150"> <b>参数值示例</b>
</th></tr>
<tr>
<td rowspan="4">腾讯云公共参数 </td><td> Action </td><td> 方法名 </td><td> 是 </td><td> ImageTranslate
</td></tr>
<tr>
<td> SecretId </td><td> SecretId </td><td> 是 </td><td> AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA
</td></tr>
<tr>
<td> Timestamp </td><td> 当前时间戳 </td><td> 是 </td><td> 1480060650
</td></tr>
<tr>
<td> Nonce </td><td> 随机正整数 </td><td> 是 </td><td> 3537
</td></tr>
<tr>
<td rowspan="5">业务参数 </td><td> data[0-n]</td><td> 待识别和翻译的图片切分后的base64编码字符串</td>
<td> 是 </td><td> </td>
</tr>
<tr>
<td> ocrType</td><td> OCR识别类型 </td><td> 否 </td><td> 0
</td></tr>
<tr>
<tr>
<td> source </td><td> 源语言 </td><td> 是 </td><td> zh
</td></tr>
<tr>
<td> target </td><td> 目标语言 </td><td> 是 </td><td> en
</td></tr>
<tr>
</tr></table>

  下面以上述业务为例，详细说明翻译接口的使用方法。

### 6.1 接口鉴权

  上述业务的参数列表如下：
	
```
{
    'Action' : 'ImageTranslate',
    'Nonce' : 3537,
    'Region' : 'gz',
    'SecretId' : 'AKIDz8krbsJ5yKBZQpn74WFkmLPx3gnPhESA',
    'Timestamp' : 1480060650,
    'data0': '/9j/4QCcRXhpZgAASUkqAAgAAAAHADIBAgAUAAAAYgAAAAi',
    'data1': 'UkqAAgAAAAHADIBAgAAAAAHADIBAgAAAAAHADIBAgAAYgAQ',
    'data2': 'HADIBAgAUAADIBAgAUAADIBAgAUAADIBAgAUAAY',
    'ocrType': 0,
    'source': "zh",
    'target': 'en'
}
```

  根据上述参数列表进行签名，得出的数字签名为：JIC7PbJ3wtVI3sFX30chC/GSJYzJdu9jyHPrjXvp/Hc=（示例），详细的数字签名的生成方法请参照[签名方法](/document/product/551/7393)。
  <b>注意：</b>鉴权时，需要将参数列表按key进行排序：字典序，同时大写在前。
  
### 6.2 API调用
  根据上一步（6.1）中得到的数字签名，构造 POST 请求，将数字签名加入到参数 Signature 中。
  
```
    调用URL:
    https://tmt.api.qcloud.com/v2/index.php
    
    Post参数:
  	{
        Action: 'ImageTranslate',
        Nonce: 3537,
        Region: 'gz',
  	    SecretId: 'AKIDBHBtOlNztbAXihSgmkZCzgCXwGToF80F',
        Timestamp: 1480060650,
        data0: '/9j/4QCcRXhpZgAASUkqAAgAAAAHADIBAgAUAAAAYgAAAAi ... ',
        data1: 'UkqAAgAAAAHADIBAgAAAAAHADIBAgAAAAAHADIBAgAAYgAQ ... ',
        data2: 'HADIBAgAUAADIBAgAUAADIBAgAUAADIBAgAUAAY ... ',
        ocrType: 0,
        source: en,
        target: zh,
        Signature: 'HgIYOPcx5lN6gz8JsCFBNAWp2oQ'
    }
```

  上述指令返回的数据结构如下：
	
```
{
    "code": 0,
    "message": "",
    "result": "[{ sourceText: '你好',targetText: 'hello', x: 70, y: 29, w: 619, h: 79} ... ]"
}
```


